@@ -13,8 +13,8 @@
 
 =========================================================================*/
 
-#ifndef vtkParticlePipeline_H
-#define vtkParticlePipeline_H
+#ifndef vtkParticlePipeline_h
+#define vtkParticlePipeline_h
 
 #include "vtkCPPipeline.h"
 #include "vtkPVAdaptorsParticleModule.h" // For export macros
@@ -39,11 +39,11 @@ class VTKPVADAPTORSPARTICLE_EXPORT vtkParticlePipeline : public vtkCPPipeline
 public:
   static vtkParticlePipeline* New();
   vtkTypeMacro(vtkParticlePipeline, vtkCPPipeline);
-  void PrintSelf(ostream& os, vtkIndent indent);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  virtual int RequestDataDescription(vtkCPDataDescription* desc);
+  int RequestDataDescription(vtkCPDataDescription* desc) override;
 
-  virtual int CoProcess(vtkCPDataDescription* desc);
+  int CoProcess(vtkCPDataDescription* desc) override;
 
   // Description:
   // name of the image file to output
@@ -86,7 +86,7 @@ public:
 
 protected:
   vtkParticlePipeline();
-  virtual ~vtkParticlePipeline();
+  ~vtkParticlePipeline() override;
 
   void SetupPipeline();
 
@@ -124,4 +124,4 @@ private:
   void operator=(const vtkParticlePipeline&) = delete;
 };
 
-#endif /* vtkParticlePipeline_H */
+#endif /* vtkParticlePipeline_h */
