@@ -19,7 +19,7 @@
  * Class for creating vtkUnstructuredGrids for a test driver.  The
  * UnstructuredGrid is built directly from a vtkUniformGrid to demonstrate
  * how to input a grid into the coprocessor.
-*/
+ */
 
 #ifndef vtkCustomUnstructuredGridBuilder_h
 #define vtkCustomUnstructuredGridBuilder_h
@@ -44,7 +44,7 @@ public:
    * that were returned were already built before.
    * vtkCustomUnstructuredGridBuilder will also delete the grid.
    */
-  virtual vtkDataObject* GetGrid(unsigned long timeStep, double time, int& builtNewGrid) override;
+  vtkDataObject* GetGrid(unsigned long timeStep, double time, int& builtNewGrid) override;
 
   /**
    * Customized function to build UnstructuredGrid.
@@ -53,7 +53,7 @@ public:
 
 protected:
   vtkCustomUnstructuredGridBuilder();
-  ~vtkCustomUnstructuredGridBuilder();
+  ~vtkCustomUnstructuredGridBuilder() override;
 
   /**
    * Method to compute the centroid of Cell and return the values in xyz.
