@@ -18,7 +18,7 @@
 
 namespace
 {
-vtkCPProcessor* Processor = NULL;
+vtkCPProcessor* Processor = nullptr;
 vtkUnstructuredGrid* VTKGrid;
 
 void BuildVTKGrid(Grid& grid)
@@ -92,7 +92,7 @@ void UpdateVTKAttributes(Grid& grid, Attributes& attributes, vtkCPInputDataDescr
 
 void BuildVTKDataStructures(Grid& grid, Attributes& attributes, vtkCPInputDataDescription* idd)
 {
-  if (VTKGrid == NULL)
+  if (VTKGrid == nullptr)
   {
     // The grid structure isn't changing so we only build it
     // the first time it's needed. If we needed the memory
@@ -109,7 +109,7 @@ namespace FEAdaptor
 
 void Initialize(int numScripts, char* scripts[])
 {
-  if (Processor == NULL)
+  if (Processor == nullptr)
   {
     Processor = vtkCPProcessor::New();
     Processor->Initialize();
@@ -136,12 +136,12 @@ void Finalize()
   if (Processor)
   {
     Processor->Delete();
-    Processor = NULL;
+    Processor = nullptr;
   }
   if (VTKGrid)
   {
     VTKGrid->Delete();
-    VTKGrid = NULL;
+    VTKGrid = nullptr;
   }
 }
 
