@@ -1,6 +1,6 @@
 #include "FEDataStructures.h"
 
-#include <assert.h>
+#include <cassert>
 #include <iostream>
 #include <mpi.h>
 
@@ -26,13 +26,13 @@ void Grid::Initialize(const unsigned int numPoints[3], const double spacing[3])
   MPI_Comm_size(MPI_COMM_WORLD, &mpiSize);
   this->Extent[0] = mpiRank * numPoints[0] / mpiSize;
   this->Extent[1] = (mpiRank + 1) * numPoints[0] / mpiSize;
-  if (mpiSize != mpiRank + 1)
+  if (mpiSize == mpiRank + 1)
   {
-    this->Extent[1]++;
+    this->Extent[1]--;
   }
   this->Extent[2] = this->Extent[4] = 0;
-  this->Extent[3] = numPoints[1];
-  this->Extent[5] = numPoints[2];
+  this->Extent[3] = numPoints[1] - 1;
+  this->Extent[5] = numPoints[2] - 1;
 }
 
 unsigned int Grid::GetNumberOfLocalPoints()
@@ -49,7 +49,7 @@ unsigned int Grid::GetNumberOfLocalCells()
 
 void Grid::GetLocalPoint(unsigned int pointId, double* point)
 {
-  unsigned int logicalX = pointId % (this->Extent[1] - this->Extent[0] + 1);
+  unsigned int logicalX = this->Extent[0] + pointId % (this->Extent[1] - this->Extent[0] + 1);
   assert(logicalX <= this->Extent[1]);
   point[0] = this->Spacing[0] * logicalX;
   unsigned int logicalY =
@@ -80,7 +80,7 @@ double* Grid::GetSpacing()
 
 Attributes::Attributes()
 {
-  this->GridPtr = NULL;
+  this->GridPtr = nullptr;
 }
 
 void Attributes::Initialize(Grid* grid)
@@ -108,7 +108,7 @@ double* Attributes::GetVelocityArray()
 {
   if (this->Velocity.empty())
   {
-    return NULL;
+    return nullptr;
   }
   return &this->Velocity[0];
 }
@@ -117,7 +117,7 @@ float* Attributes::GetPressureArray()
 {
   if (this->Pressure.empty())
   {
-    return NULL;
+    return nullptr;
   }
   return &this->Pressure[0];
 }
