@@ -32,11 +32,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "myMainWindow.h"
 #include "ui_myMainWindow.h"
 
-#include "pqActiveObjects.h"
-#include "pqApplicationCore.h"
-#include "pqObjectBuilder.h"
-#include "pqRenderView.h"
-#include "pqServerResource.h"
+#include <pqActiveObjects.h>
+#include <pqApplicationCore.h>
+#include <pqObjectBuilder.h>
+#include <pqRenderView.h>
+#include <pqServerResource.h>
 
 //-----------------------------------------------------------------------------
 myMainWindow::myMainWindow(QWidget* parentObject, Qt::WindowFlags wflags)
@@ -60,6 +60,4 @@ myMainWindow::myMainWindow(QWidget* parentObject, Qt::WindowFlags wflags)
 }
 
 //-----------------------------------------------------------------------------
-myMainWindow::~myMainWindow()
-{
-}
+myMainWindow::~myMainWindow() = default;
