@@ -32,33 +32,41 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "SpreadSheetMainWindow.h"
 #include "ui_SpreadSheetMainWindow.h"
 
-#include "pqActiveObjects.h"
-#include "pqActiveObjects.h"
-#include "pqAlwaysConnectedBehavior.h"
-#include "pqApplicationCore.h"
-#include "pqLoadDataReaction.h"
-#include "pqObjectBuilder.h"
-#include "pqOutputPort.h"
-#include "pqPersistentMainWindowStateBehavior.h"
-#include "pqPipelineSource.h"
-#include "pqRecentFilesMenu.h"
-#include "pqSpreadSheetView.h"
-#include "pqSpreadSheetViewDecorator.h"
+#include <pqActiveObjects.h>
+#include <pqApplicationCore.h>
+#include <pqObjectBuilder.h>
+#include <pqParaViewBehaviors.h>
+#include <pqRecentFilesMenu.h>
+#include <pqSpreadSheetView.h>
+#include <pqSpreadSheetViewDecorator.h>
+#include <vtkPVGeneralSettings.h>
+
+#include "pqSpreadsheetLoadDataReaction.h"
 
 //-----------------------------------------------------------------------------
-SpreadSheetMainWindow::SpreadSheetMainWindow(QWidget* parentObject, Qt::WindowFlags wflags)
-  : Superclass(parentObject, wflags)
+class SpreadSheetMainWindow::pqInternals : public Ui::pqClientMainWindow
 {
-  Ui::SpreadSheetMainWindow ui;
-  ui.setupUi(this);
+};
 
-  // Define default behaviors - create only small subset, since this application
-  // is not really a ParaView-like application at all.
-  new pqAlwaysConnectedBehavior(this);
-  new pqPersistentMainWindowStateBehavior(this);
+//-----------------------------------------------------------------------------
+SpreadSheetMainWindow::SpreadSheetMainWindow()
+  : Internals(new pqInternals())
+{
+  // Setup default GUI layout.
+  this->Internals->setupUi(this);
 
-  /// We do need the recent files menu, so set it up.
-  new pqRecentFilesMenu(*ui.menuRecent_Datasets, ui.menuRecent_Datasets);
+  // Create a custom file menu with only Open and close
+  QList<QAction*> qa = this->Internals->menu_File->actions();
+  QAction* mqa = qa.at(0);
+  new pqSpreadsheetLoadDataReaction(mqa);
+  new pqRecentFilesMenu(*this->Internals->menuRecent_Files, this->Internals->menuRecent_Files);
+  QObject::connect(
+    qa.at(2), SIGNAL(triggered()), QApplication::instance(), SLOT(closeAllWindows()));
+
+  new pqParaViewBehaviors(this, this);
+
+  // Use auto apply to show data automatically
+  vtkPVGeneralSettings::GetInstance()->SetAutoApply(true);
 
   // Create spread-sheet view and set it as the central Widget.
   pqSpreadSheetView* view =
@@ -66,35 +74,7 @@ SpreadSheetMainWindow::SpreadSheetMainWindow(QWidget* parentObject, Qt::WindowFl
       pqSpreadSheetView::spreadsheetViewType(), pqActiveObjects::instance().activeServer()));
   this->setCentralWidget(view->widget());
   new pqSpreadSheetViewDecorator(view);
-
-  pqActiveObjects::instance().setActiveView(view);
-
-  // Reactions
-  new pqLoadDataReaction(ui.action_Open_Dataset);
-  QObject::connect(
-    ui.action_Exit, SIGNAL(triggered()), pqApplicationCore::instance(), SLOT(quit()));
-
-  // We need to destroy the previously opened source and show the new one
-  // every time a new source is created.
-  QObject::connect(pqApplicationCore::instance()->getObjectBuilder(),
-    SIGNAL(sourceCreated(pqPipelineSource*)), this, SLOT(showData(pqPipelineSource*)));
 }
 
 //-----------------------------------------------------------------------------
-SpreadSheetMainWindow::~SpreadSheetMainWindow()
-{
-}
-
-//-----------------------------------------------------------------------------
-void SpreadSheetMainWindow::showData(pqPipelineSource* source)
-{
-  pqActiveObjects& activeObjects = pqActiveObjects::instance();
-
-  if (activeObjects.activeSource())
-  {
-    pqApplicationCore::instance()->getObjectBuilder()->destroy(activeObjects.activeSource());
-  }
-  activeObjects.setActiveSource(source);
-  pqApplicationCore::instance()->getDisplayPolicy()->setRepresentationVisibility(
-    source->getOutputPort(0), activeObjects.activeView(), true);
-}
+SpreadSheetMainWindow::~SpreadSheetMainWindow() = default;
