@@ -1,58 +1,83 @@
-// -*- c++ -*-
 /*=========================================================================
- *
- *  Program:   Visualization Toolkit
- *  Module:    vtkCDIReader.h
- *
- *  Copyright (c) 2018 Niklas Roeber, DKRZ Hamburg
- *  All rights reserved.
- *  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
- *
- *     This software is distributed WITHOUT ANY WARRANTY; without even
- *     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- *     PURPOSE.  See the above copyright notice for more information.
- *
- *  =========================================================================*/
-// .NAME vtkCDIReader - reads ICON/CDI netCDF data sets
-// .SECTION Description
-// vtkCDIReader is based on the vtk MPAS netCDF reader developed by
-// Christine Ahrens (cahrens@lanl.gov). The plugin reads all ICON/CDI
-// netCDF data sets with point and cell variables, both 2D and 3D. It allows
-// spherical (standard), as well as equidistant cylindrical and Cassini projection.
-// 3D data can be visualized using slices, as well as 3D unstructured mesh. If
-// bathymetry information (wet_c) is present in the data, this can be used for
-// masking out continents. For more information, also check out our ParaView tutorial:
-// https://www.dkrz.de/Nutzerportal-en/doku/vis/sw/paraview
-//
-// .SECTION Caveats
-// The integrated visualization of performance data is not yet fully developed
-// and documented. If interested in using it, see the following presentation
-// https://www.dkrz.de/about/media/galerie/Vis/performance/perf-vis
-// and/or contact Niklas Roeber at roeber@dkrz.de
-//
-// .SECTION Thanks
-// Thanks to Uwe Schulzweida for the CDI code (uwe.schulzweida@mpimet.mpg.de)
-// Thanks to Moritz Hanke for the sorting code (hanke@dkrz.de)
+
+   Program: ParaView
+   Module:  vtkCDIReader.h
+
+   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
+   All rights reserved.
+
+   ParaView is a free software; you can redistribute it and/or modify it
+   under the terms of the ParaView license version 1.2.
+
+   See License_v1.2.txt for the full ParaView license.
+   A copy of this license can be obtained by contacting
+   Kitware Inc.
+   28 Corporate Drive
+   Clifton Park, NY 12065
+   USA
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
+CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+========================================================================*/
+
+/*-------------------------------------------------------------------------
+   Copyright (c) 2018 Niklas Roeber, DKRZ Hamburg
+  -------------------------------------------------------------------------*/
 
 #ifndef vtkCDIReader_h
 #define vtkCDIReader_h
 
-#define DEBUG 0
-#define MAX_VARS 100
-
-#include "vtkCDIReaderModule.h"
-#include "vtkDataArraySelection.h"
-#include "vtkIntArray.h"
-#include "vtkSmartPointer.h"
+#include "vtkCDIReaderModule.h" // for export macro
 #include "vtkUnstructuredGridAlgorithm.h"
 
-#ifdef PARAVIEW_USE_MPI
-class vtkMultiProcessController;
-#endif
+#include "vtkDataArraySelection.h" // for ivars
+#include "vtkSmartPointer.h"       // for ivars
+#include "vtkStringArray.h"        // for ivars
+
+#include "projections.h" // for projection enum
+
+#include <memory> // for unique_ptr
+#include <vector> // for std::vector
 
 class vtkCallbackCommand;
 class vtkDoubleArray;
-class vtkStringArray;
+class vtkFieldData;
+class vtkMultiProcessController;
+
+/**
+ *
+ * @class vtkCDIReader
+ * @brief reads ICON/CDI netCDF data sets
+ *
+ * vtkCDIReader is based on the vtk MPAS netCDF reader developed by
+ * Christine Ahrens (cahrens@lanl.gov). The plugin reads all ICON/CDI
+ * netCDF data sets with point and cell variables, both 2D and 3D. It allows
+ * spherical (standard), as well as equidistant cylindrical and Cassini projection.
+ * 3D data can be visualized using slices, as well as 3D unstructured mesh. If
+ * bathymetry information (wet_c) is present in the data, this can be used for
+ * masking out continents. For more information, also check out our ParaView tutorial:
+ * https://www.dkrz.de/Nutzerportal-en/doku/vis/sw/paraview
+ *
+ * @section caveats Caveats
+ * The integrated visualization of performance data is not yet fully developed
+ * and documented. If interested in using it, see the following presentation
+ * https://www.dkrz.de/about/media/galerie/Vis/performance/perf-vis
+ * and/or contact Niklas Roeber at roeber@dkrz.de
+ *
+ * @section thanks Thanks
+ * Thanks to Uwe Schulzweida for the CDI code (uwe.schulzweida@mpimet.mpg.de)
+ * Thanks to Moritz Hanke for the sorting code (hanke@dkrz.de)
+ */
 
 class VTKCDIREADER_EXPORT vtkCDIReader : public vtkUnstructuredGridAlgorithm
 {
@@ -68,9 +93,8 @@ public:
   vtkGetMacro(NumberOfCellVars, int);
   vtkGetMacro(NumberOfPointVars, int);
 
-  vtkStringArray* VariableDimensions;
-  vtkStringArray* AllDimensions;
-  vtkSmartPointer<vtkIntArray> LoadingDimensions;
+  vtkSmartPointer<vtkStringArray> VariableDimensions;
+  vtkSmartPointer<vtkStringArray> AllDimensions;
   void SetDimensions(const char* dimensions);
   vtkStringArray* GetAllVariableArrayNames();
   vtkSmartPointer<vtkStringArray> AllVariableArrayNames;
@@ -85,6 +109,8 @@ public:
     this->SetCellArrayStatus(name, status);
   }
 
+  void SetMaskingVariable(const char* name);
+
   int GetNumberOfPointArrays() { return this->PointDataArraySelection->GetNumberOfArrays(); }
   const char* GetPointArrayName(int index);
   int GetPointArrayStatus(const char* name)
@@ -127,55 +153,78 @@ public:
   vtkGetVector2Macro(LayerThicknessRange, int);
   vtkGetMacro(LayerThickness, int);
 
+  void SetLayer0Offset(double val);
+  vtkGetVector2Macro(Layer0OffsetRange, double);
+  vtkGetMacro(Layer0Offset, double);
+
   void SetProjection(int val);
   vtkGetMacro(ProjectionMode, int);
 
   void SetDoublePrecision(bool val);
   vtkGetMacro(DoublePrecision, bool);
 
+  void SetWrapping(bool val);
+  vtkGetMacro(WrapOn, bool);
+
+  void SetShowClonClat(bool val);
+  vtkGetMacro(ShowClonClat, bool);
+
   void SetInvertZAxis(bool val);
   vtkGetMacro(InvertZAxis, bool);
 
-  void SetTopography(bool val);
-  vtkGetMacro(IncludeTopography, bool);
+  void SetUseMask(bool val);
+  vtkGetMacro(UseMask, bool);
 
-  void InvertTopography(bool val);
-  vtkGetMacro(InvertedTopography, bool);
+  void SetInvertMask(bool val);
+  vtkGetMacro(InvertMask, bool);
+
+  void SetSkipGrid(bool val);
+  vtkGetMacro(SkipGrid, bool);
+
+  void SetUseCustomMaskValue(bool val);
+  vtkGetMacro(UseCustomMaskValue, bool);
+
+  void SetCustomMaskValue(double val);
+  vtkGetMacro(CustomMaskValue, double);
 
   void SetShowMultilayerView(bool val);
   vtkGetMacro(ShowMultilayerView, bool);
 
-#ifdef PARAVIEW_USE_MPI
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
   virtual void SetController(vtkMultiProcessController*);
-#endif
 
 protected:
   vtkCDIReader();
   ~vtkCDIReader() override;
+
   int OpenFile();
   void DestroyData();
   void SetDefaults();
   int CheckForMaskData();
+  int AddMaskHalo();
   int GetVars();
   int ReadAndOutputGrid(bool init);
   int ReadAndOutputVariableData();
   int ReadTimeUnits(const char* Name);
+  vtkSmartPointer<vtkDoubleArray> ReadTimeAxis();
   int BuildVarArrays();
   int AllocSphereGeometry();
   int AllocLatLonGeometry();
-  int EliminateXWrap();
-  int EliminateYWrap();
+  int Wrap(int axis);
   void OutputPoints(bool init);
   void OutputCells(bool init);
+  void InsertPolyhedron(std::vector<vtkIdType> polygon);
   unsigned char GetCellType();
   void LoadGeometryData(int var, double dTime);
   int LoadPointVarData(int variable, double dTime);
   int LoadCellVarData(int variable, double dTime);
   int LoadDomainVarData(int variable);
+  int ReplaceFillWithNan(const int varID, vtkDataArray* dataArray);
   int RegenerateGeometry();
   int ConstructGridGeometry();
+  void GuessGridFile();
   int LoadClonClatVars();
+  int AddClonClatHalo();
   int MirrorMesh();
   bool BuildDomainCellVars();
   void RemoveDuplicates(
@@ -186,6 +235,12 @@ protected:
 
   int RequestUpdateExtent(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
   int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
+  void ResetVarDataArrays();
+
+  void OutputTimeAxis(vtkInformation* outInfo, const vtkSmartPointer<vtkDoubleArray>& timeValues);
+
+  void GetFileSeriesInformation(vtkInformation* outInfo);
+
   int RequestInformation(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
   static void SelectionCallback(vtkObject* vtkNotUsed(caller), unsigned long vtkNotUsed(eid),
@@ -194,20 +249,21 @@ protected:
     static_cast<vtkCDIReader*>(clientdata)->Modified();
   }
 
+  int GetTimeIndex(double DataTimeStep);
   int GetDims();
   int ReadHorizontalGridData();
   int ReadVerticalGridData();
-  int FillVariableDimensions();
+  int FillGridDimensions();
   int RegenerateVariables();
+  int AddMirrorPointX(int index, double dividerX, double offset);
+  int AddMirrorPointY(int index, double dividerY, double offset);
 
-#ifdef PARAVIEW_USE_MPI
   vtkMultiProcessController* Controller;
-#endif
+
+  bool Initialized;
 
   int NumberOfProcesses;
-  bool InvertedTopography;
-  bool FilenameSet;
-  float MaskingValue;
+  double CustomMaskValue;
   int BeginPoint, EndPoint, BeginCell, EndCell;
   int Piece, NumPieces;
   int NumberLocalCells;
@@ -215,29 +271,49 @@ protected:
   int NumberLocalPoints;
   int NumberAllPoints;
   bool Decomposition;
+  long FirstDay;
+  int ModNumPoints;
+  int ModNumCells;
+  unsigned int CurrentExtraPoint;     // current extra point
+  unsigned int CurrentExtraCell;      // current extra cell
+  std::vector<unsigned int> CellMap;  // maps from added cell to original cell #
+  std::vector<unsigned int> PointMap; // maps from added point to original point #
 
   std::string FileName;
   std::string FileNameGrid;
+  std::string FileNameGridSelect;
   std::string FileSeriesFirstName;
-  int* VariableType;
+  std::string MaskingVarname;
   int NumberOfTimeSteps;
+  int NumberOfAllTimeSteps;
+  std::vector<int> TimeSeriesTimeSteps;
+  bool TimeSeriesTimeStepsAllSet;
+  bool TimeSet;
   double DTime;
+  std::vector<double> TimeSteps;
   int FileSeriesNumber;
   int NumberOfFiles;
-  double TStepDistance;
+  double Bloat;
 
-  vtkCallbackCommand* SelectionObserver;
+  bool UseMask;
+  bool InvertMask;
+  bool GotMask;
+  bool UseCustomMaskValue;
+
+  bool SkipGrid;
+
+  vtkNew<vtkCallbackCommand> SelectionObserver;
   bool InfoRequested;
   bool DataRequested;
   bool Grib;
 
-  vtkDataArraySelection* CellDataArraySelection;
-  vtkDataArraySelection* PointDataArraySelection;
-  vtkDataArraySelection* DomainDataArraySelection;
+  vtkNew<vtkDataArraySelection> CellDataArraySelection;
+  vtkNew<vtkDataArraySelection> PointDataArraySelection;
+  vtkNew<vtkDataArraySelection> DomainDataArraySelection;
 
-  vtkDataArray** CellVarDataArray;
-  vtkDataArray** PointVarDataArray;
-  vtkDoubleArray** DomainVarDataArray;
+  vtkNew<vtkFieldData> CellVarDataArray;
+  vtkNew<vtkFieldData> PointVarDataArray;
+  vtkNew<vtkFieldData> DomainVarDataArray;
 
   int VerticalLevelSelected;
   int VerticalLevelRange[2];
@@ -246,14 +322,16 @@ protected:
   int DomainDataSelected;
   int LayerThickness;
   int LayerThicknessRange[2];
+  double Layer0Offset;
+  double Layer0OffsetRange[2];
 
   int DimensionSelection;
   bool InvertZAxis;
-  bool GotMask, AddCoordinateVars;
-  int ProjectionMode;
+  bool AddCoordinateVars;
+  projection::Projection ProjectionMode;
   bool DoublePrecision;
+  bool ShowClonClat;
   bool ShowMultilayerView;
-  bool IncludeTopography;
   bool HaveDomainData;
   bool HaveDomainVariable;
   bool BuildDomainArrays;
@@ -271,30 +349,25 @@ protected:
   bool ReconstructNew;
   bool NeedHorizontalGridFile;
   bool NeedVerticalGridFile;
+  bool WrapOn;
 
-  double* CLonVertices;
-  double* CLatVertices;
-  double* CLon;
-  double* CLat;
+  std::vector<double> CLon;
+  std::vector<double> CLat;
   double* DepthVar;
-  double* PointX;
-  double* PointY;
-  double* PointZ;
-  int ModNumPoints;
-  int ModNumCells;
-  int* OrigConnections;
-  int* ModConnections;
-  int* CellMask;
-  int* DomainMask;
+  std::vector<double> PointX;
+  std::vector<double> PointY;
+  std::vector<double> PointZ;
+  std::vector<int> OrigConnections;
+  std::vector<int> ModConnections;
+  std::vector<bool> CellMask;
   double* DomainCellVar;
   int MaximumCells;
   int MaximumPoints;
-  int* VertexIds;
+  std::vector<int> VertexIds;
 
   int NumberOfCellVars;
   int NumberOfPointVars;
   int NumberOfDomainVars;
-  double* PointVarData;
   bool GridReconstructed;
 
   int StreamID;
@@ -303,16 +376,18 @@ protected:
   int ZAxisID;
   int SurfID;
 
-  char* TimeUnits;
-  char* Calendar;
-  vtkSmartPointer<vtkUnstructuredGrid> Output;
+  std::string TimeUnits;
+  std::string Calendar;
+  vtkSmartPointer<vtkDoubleArray> ClonArray;
+  vtkSmartPointer<vtkDoubleArray> ClatArray;
+  vtkNew<vtkUnstructuredGrid> Output;
 
 private:
   vtkCDIReader(const vtkCDIReader&) = delete;
   void operator=(const vtkCDIReader&) = delete;
 
   class Internal;
-  Internal* Internals;
+  std::unique_ptr<Internal> Internals;
 
   template <typename ValueType>
   int LoadCellVarDataTemplate(int variable, double dTime, vtkDataArray* dataArray);
