@@ -18,7 +18,6 @@
 #include "vtkByteSwap.h"
 #include "vtkCallbackCommand.h"
 #include "vtkCellArray.h"
-#include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkDataArraySelection.h"
 #include "vtkErrorCode.h"
@@ -32,6 +31,7 @@
 #include "vtkPolyData.h"
 #include "vtkPolyhedron.h"
 #include "vtkRectilinearGrid.h"
+#include "vtkSmartPointer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStringArray.h"
 #include "vtkStructuredGrid.h"
@@ -61,7 +61,8 @@ namespace GMVRead
 {
 // include GMV's I/O utility provided by GMV's author, Frank Ortega (LANL).
 // import it from VisItBridge's include directories
-extern "C" {
+extern "C"
+{
 #include "gmvread.c"
 }
 
@@ -85,10 +86,10 @@ void minmax(C* pointer, size_t len, C& min_out, C& max_out)
 template <class C>
 void cleanup(C** pointer)
 {
-  if ((*pointer) != (C*)NULL)
+  if ((*pointer) != (C*)nullptr)
   {
     free(*pointer);
-    *pointer = (C*)(NULL);
+    *pointer = (C*)(nullptr);
   }
 }
 
@@ -133,7 +134,7 @@ void cleanupAllData(void)
 //----------------------------------------------------------------------------
 vtkGMVReader::vtkGMVReader()
 {
-  this->FileName = NULL;
+  this->FileName = nullptr;
   this->FileNames = vtkStringArray::New();
   this->NumberOfTracersMap.clear();
   this->NumberOfPolygonsMap.clear();
@@ -149,21 +150,21 @@ vtkGMVReader::vtkGMVReader()
   this->NumberOfFieldComponents = 0;
   this->DecrementNodeIds = true; // node numbering starts at 1, in VTK at 0
 
-  this->Mesh = NULL;
-  this->FieldDataTmp = NULL;
+  this->Mesh = nullptr;
+  this->FieldDataTmp = nullptr;
   this->NumberOfNodes = 0;
   this->NumberOfCells = 0;
 
-  this->Tracers = NULL;
+  this->Tracers = nullptr;
   this->NumberOfTracers = 0;
   this->ImportTracers = 1;
 
-  this->Polygons = NULL;
+  this->Polygons = nullptr;
   this->NumberOfPolygons = 0;
   this->ImportPolygons = 0;
 
-  this->NodeDataInfo = NULL;
-  this->CellDataInfo = NULL;
+  this->NodeDataInfo = nullptr;
+  this->CellDataInfo = nullptr;
 
   this->PointDataArraySelection = vtkDataArraySelection::New();
   this->CellDataArraySelection = vtkDataArraySelection::New();
@@ -194,16 +195,14 @@ vtkGMVReader::~vtkGMVReader()
   if (this->FileNames)
   {
     this->FileNames->Delete();
-    this->FileNames = NULL;
+    this->FileNames = nullptr;
   }
-  this->SetFileName(0);
+  this->SetFileName(nullptr);
   this->NumberOfTracersMap.clear();
   this->NumberOfPolygonsMap.clear();
 
-  if (this->NodeDataInfo)
-    delete[] this->NodeDataInfo;
-  if (this->CellDataInfo)
-    delete[] this->CellDataInfo;
+  delete[] this->NodeDataInfo;
+  delete[] this->CellDataInfo;
 
   this->PointDataArraySelection->RemoveObserver(this->SelectionObserver);
   this->PointDataArraySelection->Delete();
@@ -223,7 +222,7 @@ vtkGMVReader::~vtkGMVReader()
     this->Polygons->Delete();
 
 #if VTK_MODULE_ENABLE_VTK_ParallelCore
-  this->SetController(NULL);
+  this->SetController(nullptr);
 #endif
 }
 
@@ -244,6 +243,8 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
   size_t numNodesSoFar = 0;
   unsigned int blockNo;
   vtkCellArray* polygonCells;
+  vtkSmartPointer<vtkCellArray> lineCells;
+  vtkSmartPointer<vtkCellArray> vertexCells;
   vtkCellArray* tracerCells;
   vtkFloatArray* coords;
   vtkIdType list[27];
@@ -284,7 +285,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
   int ierr = GMVRead::gmvread_open(this->FileName);
   if (ierr > 0)
   {
-    if (GMVRead::gmv_data.errormsg != NULL)
+    if (GMVRead::gmv_data.errormsg != nullptr)
     {
       vtkErrorMacro("" << GMVRead::gmv_data.errormsg);
     }
@@ -299,33 +300,33 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
   if (ierr != -1)
     this->BinaryFile = 1;
 
-  pd = NULL;
+  pd = nullptr;
   keepParsing = true;
   firstPolygonParsed = false;
-  polygonPoints = NULL;
-  polygonCells = NULL;
-  polygonMaterials = NULL;
+  polygonPoints = nullptr;
+  polygonCells = nullptr;
+  polygonMaterials = nullptr;
   polygonMaterialPosInDataArray = -1;
 
   if (this->Mesh)
   {
     this->Mesh->Delete();
-    this->Mesh = NULL;
+    this->Mesh = nullptr;
   }
   if (this->FieldDataTmp)
   {
     this->FieldDataTmp->Delete();
-    this->FieldDataTmp = NULL;
+    this->FieldDataTmp = nullptr;
   }
   if (this->Tracers)
   {
     this->Tracers->Delete();
-    this->Tracers = NULL;
+    this->Tracers = nullptr;
   }
   if (this->Polygons)
   {
     this->Polygons->Delete();
-    this->Polygons = NULL;
+    this->Polygons = nullptr;
   }
 
   while (keepParsing)
@@ -334,7 +335,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
     switch (GMVRead::gmv_data.keyword)
     {
       case (GMVERROR):
-        if (GMVRead::gmv_data.errormsg != NULL)
+        if (GMVRead::gmv_data.errormsg != nullptr)
         {
           vtkErrorMacro("" << GMVRead::gmv_data.errormsg);
         }
@@ -451,7 +452,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
             // An i/o error may have occurred
             if (GMVRead::gmv_meshdata.intype == GMVERROR)
             {
-              if (GMVRead::gmv_data.errormsg != NULL)
+              if (GMVRead::gmv_data.errormsg != nullptr)
               {
                 vtkErrorMacro("" << GMVRead::gmv_data.errormsg);
               }
@@ -515,9 +516,9 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
               // Catch case that only generic cells are present. Then cellnnode is not set.
               numNodes = 0;
               numFaces = 0;
-              if (GMVRead::gmv_meshdata.cellnnode != NULL)
+              if (GMVRead::gmv_meshdata.cellnnode != nullptr)
                 numNodes = GMVRead::gmv_meshdata.cellnnode[i];
-              if (GMVRead::gmv_meshdata.celltoface != NULL)
+              if (GMVRead::gmv_meshdata.celltoface != nullptr)
                 numFaces =
                   GMVRead::gmv_meshdata.celltoface[i + 1] - GMVRead::gmv_meshdata.celltoface[i];
 
@@ -686,7 +687,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
 
                   ugrid->InsertNextCell(VTK_POLYGON, numPts, pointIds);
                   delete[] pointIds;
-                  pointIds = NULL;
+                  pointIds = nullptr;
                 }
 
                 else // 3D cell
@@ -699,8 +700,8 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
                   std::set<int> auxIds;
                   std::set<int>::iterator auxIt;
 
-                  vtkIdType* face = NULL;
-                  vtkCellArray* faces = NULL;
+                  vtkIdType* face = nullptr;
+                  vtkCellArray* faces = nullptr;
                   faces = vtkCellArray::New();
                   for (unsigned long j = 0; j < numFaces; j++)
                   {
@@ -721,7 +722,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
                     }
                     faces->InsertNextCell(numVerts, face);
                     delete[] face;
-                    face = NULL;
+                    face = nullptr;
                   }
 
                   // number of unique vertices of generic element i
@@ -736,9 +737,9 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
                   ugrid->InsertNextCell(VTK_POLYHEDRON, numPts, pointIds, faces->GetNumberOfCells(),
                     faceData->GetPointer(0));
                   delete[] pointIds;
-                  pointIds = NULL;
+                  pointIds = nullptr;
                   faces->Delete();
-                  faces = NULL;
+                  faces = nullptr;
                 }
               }
               // Unknown/no handler yet
@@ -1307,9 +1308,9 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
 
               for (unsigned long int i = 0; i < this->NumberOfNodes; ++i)
                 // -1 because GMV file format starts to count from 1 while here we start from 0
-                flags->SetValue(
-                  i, &GMVRead::gmv_data
-                        .chardata1[(GMVRead::gmv_data.longdata1[i] - 1) * MAXCUSTOMNAMELENGTH]);
+                flags->SetValue(i,
+                  &GMVRead::gmv_data
+                     .chardata1[(GMVRead::gmv_data.longdata1[i] - 1) * MAXCUSTOMNAMELENGTH]);
               this->Mesh->GetPointData()->AddArray(flags);
               flags->Delete();
             }
@@ -1338,9 +1339,9 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
 
               for (unsigned long int i = 0; i < this->NumberOfCells; ++i)
                 // -1 because GMV file format starts to count from 1 while here we start from 0
-                flags->SetValue(
-                  i, &GMVRead::gmv_data
-                        .chardata1[(GMVRead::gmv_data.longdata1[i] - 1) * MAXCUSTOMNAMELENGTH]);
+                flags->SetValue(i,
+                  &GMVRead::gmv_data
+                     .chardata1[(GMVRead::gmv_data.longdata1[i] - 1) * MAXCUSTOMNAMELENGTH]);
               this->Mesh->GetCellData()->AddArray(flags);
               flags->Delete();
             }
@@ -1378,6 +1379,8 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
 
             polygonPoints = vtkPoints::New();
             polygonCells = vtkCellArray::New();
+            lineCells = vtkSmartPointer<vtkCellArray>::New();
+            vertexCells = vtkSmartPointer<vtkCellArray>::New();
 
             // Find out whether material property has been selected for reading.
             // Done once before reading the first polygon and re-used for
@@ -1405,6 +1408,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
             firstPolygonParsed = true;
           }
 
+          vtkCellArray* currentCells = nullptr;
           switch (GMVRead::gmv_data.datatype)
           {
             unsigned int npts;
@@ -1414,8 +1418,18 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
               vtkDebugMacro(
                 "GMVReader::RequestData: Found " << npts << " points for polygon definition ");
 
+              currentCells = polygonCells;
+              if (npts == 2)
+              {
+                currentCells = lineCells;
+              }
+              else if (npts == 1)
+              {
+                currentCells = vertexCells;
+              }
+
               // Number of points polygon cell consists of
-              polygonCells->InsertNextCell(npts);
+              currentCells->InsertNextCell(npts);
 
               for (unsigned int i = 0; i < npts; i++)
               {
@@ -1423,17 +1437,19 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
                 vtkIdType id = polygonPoints->InsertNextPoint(GMVRead::gmv_data.doubledata1[i],
                   GMVRead::gmv_data.doubledata2[i], GMVRead::gmv_data.doubledata3[i]);
                 // Add point to cell definition
-                polygonCells->InsertCellPoint(id);
+                currentCells->InsertCellPoint(id);
               }
 
               if (polygonMaterialPosInDataArray >= 0 &&
                 this->CellDataArraySelection->GetArraySetting(polygonMaterialPosInDataArray))
               {
+                vtkIdType numberOfCells = polygonCells->GetNumberOfCells() +
+                  lineCells->GetNumberOfCells() + vertexCells->GetNumberOfCells();
                 vtkDebugMacro("GMVReader::RequestData: Polygon #"
-                  << polygonCells->GetNumberOfCells() << "  material #" << GMVRead::gmv_data.num
-                  << "  total polygon #" << this->NumberOfPolygons);
+                  << numberOfCells << "  material #" << GMVRead::gmv_data.num << "  total polygon #"
+                  << this->NumberOfPolygons);
                 polygonMaterials->SetComponent(
-                  polygonCells->GetNumberOfCells() - 1, 0, vtkTypeInt64(GMVRead::gmv_data.num));
+                  numberOfCells - 1, 0, vtkTypeInt64(GMVRead::gmv_data.num));
               }
 
               break;
@@ -1441,6 +1457,8 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
               // Set polygon points and cells
               this->Polygons->SetPoints(polygonPoints);
               this->Polygons->SetPolys(polygonCells); // essential for calling BuildCells()
+              this->Polygons->SetLines(lineCells);
+              this->Polygons->SetVerts(vertexCells);
               this->Polygons
                 ->BuildCells(); // mandatory to be able to call vtkPolyData::GetCellPoints,
                                 // e.g. when using CleantoGrid filter.
@@ -1986,7 +2004,7 @@ int vtkGMVReader::RequestData(vtkInformation* vtkNotUsed(request),
       newData->Delete();
     }
     this->FieldDataTmp->Delete();
-    this->FieldDataTmp = NULL;
+    this->FieldDataTmp = nullptr;
   }
 
   this->UpdateProgress(1.0);
@@ -2014,7 +2032,7 @@ int vtkGMVReader::RequestInformation(vtkInformation* vtkNotUsed(request),
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
   if (ierr > 0)
   {
-    if (GMVRead::gmv_data.errormsg != NULL)
+    if (GMVRead::gmv_data.errormsg != nullptr)
     {
       vtkErrorMacro("" << GMVRead::gmv_data.errormsg);
     }
@@ -2046,7 +2064,7 @@ int vtkGMVReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     switch (GMVRead::gmv_data.keyword)
     {
       case (GMVERROR):
-        if (GMVRead::gmv_data.errormsg != NULL)
+        if (GMVRead::gmv_data.errormsg != nullptr)
         {
           vtkErrorMacro("" << GMVRead::gmv_data.errormsg);
         }
@@ -2082,7 +2100,7 @@ int vtkGMVReader::RequestInformation(vtkInformation* vtkNotUsed(request),
         // An i/o error may have occurred
         if (GMVRead::gmv_meshdata.intype == GMVERROR)
         {
-          if (GMVRead::gmv_data.errormsg != NULL)
+          if (GMVRead::gmv_data.errormsg != nullptr)
           {
             vtkErrorMacro("" << GMVRead::gmv_data.errormsg);
           }
@@ -2476,7 +2494,7 @@ int vtkGMVReader::CanReadFile(const char* name)
   }
 
   gmvin = fopen(name, "r");
-  if (gmvin == NULL)
+  if (gmvin == nullptr)
   {
     // Cannot open file
     fclose(gmvin);
@@ -2582,7 +2600,7 @@ int vtkGMVReader::GetNumberOfPointArrays()
 const char* vtkGMVReader::GetPointArrayName(int index)
 {
   if (index >= (int)this->NumberOfNodeComponents || index < 0)
-    return NULL;
+    return nullptr;
   else
     return this->PointDataArraySelection->GetArrayName(index);
 }
@@ -2624,7 +2642,7 @@ int vtkGMVReader::GetNumberOfCellArrays()
 const char* vtkGMVReader::GetCellArrayName(int index)
 {
   if (index >= (int)this->NumberOfCellComponents || index < 0)
-    return NULL;
+    return nullptr;
   else
     return this->CellDataArraySelection->GetArrayName(index);
 }
@@ -2666,7 +2684,7 @@ int vtkGMVReader::GetNumberOfFieldArrays()
 const char* vtkGMVReader::GetFieldArrayName(int index)
 {
   if (index >= (int)this->NumberOfFieldComponents || index < 0)
-    return NULL;
+    return nullptr;
   else
     return this->FieldDataArraySelection->GetArrayName(index);
 }
