@@ -45,20 +45,20 @@ ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifndef vtkGenIOReader_h
 #define vtkGenIOReader_h
 
-#include "vtkCellArray.h"
-#include "vtkDataArraySelection.h"
-#include "vtkGenericIOReaderModule.h"
-#include "vtkPoints.h"
-#include "vtkSmartPointer.h"
+#include "vtkCellArray.h"             // for vtkCellArray
+#include "vtkDataArraySelection.h"    // for vtkDataArraySelection
+#include "vtkGenericIOReaderModule.h" // for export macro
+#include "vtkPoints.h"                // for vtkPoints
+#include "vtkSmartPointer.h"          // for vtkSmartPointer
 #include "vtkUnstructuredGridAlgorithm.h"
 
-#include "utils/gioData.h"
-#include "utils/log.h"
+#include "utils/gioData.h" // genio header
+#include "utils/log.h"     // genio header
 
-#include <mutex>
-#include <sstream>
-#include <string>
-#include <vector>
+#include <mutex>   // for std::mutex
+#include <sstream> // for std::stringstream
+#include <string>  // for std::string
+#include <vector>  // for std::vector
 
 class vtkDataArray;
 class vtkMultiProcessController;
@@ -144,9 +144,12 @@ public:
   int GetCellArrayStatus(const char* name) { return CellDataArraySelection->ArrayIsEnabled(name); }
   void SetCellArrayStatus(const char* name, int status);
 
+  vtkGenIOReader(const vtkGenIOReader&) = delete;
+  void operator=(const vtkGenIOReader&) = delete;
+
 protected:
   vtkGenIOReader();
-  ~vtkGenIOReader();
+  ~vtkGenIOReader() override;
 
   bool doMPIDataSplitting(int numDataRanks, int numMPIranks, int myRank, int ranksRangeToLoad[2],
     std::vector<size_t>& readRowsInfo);
