@@ -43,6 +43,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "pqLineEdit.h"
 #include "pqPropertiesPanel.h"
+#include "pqQtDeprecated.h"
 
 #include <QComboBox>
 #include <QGridLayout>
@@ -186,8 +187,8 @@ void pqIntegrationModelSeedHelperWidget::resetSeedWidget(bool force)
           vtkPVDataSetAttributesInformation* cellDataInfo =
             flowProxy->GetDataInformation()->GetAttributeInformation(
               vtkDataObject::FIELD_ASSOCIATION_CELLS);
-          QPixmap cellPixmap(":/pqWidgets/Icons/pqCellData16.png");
-          QPixmap pointPixmap(":/pqWidgets/Icons/pqPointData16.png");
+          QPixmap cellPixmap(":/pqWidgets/Icons/pqCellData.svg");
+          QPixmap pointPixmap(":/pqWidgets/Icons/pqPointData.svg");
 
           for (int ipd = 0; ipd < pointDataInfo->GetNumberOfArrays(); ipd++)
           {
@@ -214,7 +215,7 @@ void pqIntegrationModelSeedHelperWidget::resetSeedWidget(bool force)
         gridLayout->addWidget(gb, i, 0);
       }
     }
-    emit(this->arrayToGenerateChanged());
+    Q_EMIT(this->arrayToGenerateChanged());
   }
 }
 
@@ -225,7 +226,7 @@ void pqIntegrationModelSeedHelperWidget::updateEnabledState()
   QGroupBox* gb = qobject_cast<QGroupBox*>(cb->parent());
   bool constant = cb->itemData(cb->currentIndex()).toInt() == vtkLagrangianSeedHelper::CONSTANT;
   gb->findChild<QComboBox*>("Arrays")->setEnabled(!constant);
-  foreach (pqLineEdit* line, gb->findChildren<pqLineEdit*>())
+  Q_FOREACH (pqLineEdit* line, gb->findChildren<pqLineEdit*>())
   {
     line->setEnabled(constant);
   }
@@ -235,7 +236,7 @@ void pqIntegrationModelSeedHelperWidget::updateEnabledState()
 QList<QVariant> pqIntegrationModelSeedHelperWidget::arrayToGenerate() const
 {
   QList<QVariant> values;
-  foreach (QGroupBox* gb, this->findChildren<QGroupBox*>())
+  Q_FOREACH (QGroupBox* gb, this->findChildren<QGroupBox*>())
   {
     // Recover the state of each groupbox
     if (gb->isChecked())
@@ -257,14 +258,14 @@ QList<QVariant> pqIntegrationModelSeedHelperWidget::arrayToGenerate() const
       {
         for (unsigned int i = 0; i < nComponents; i++)
         {
-          str << lines[i]->text().toLatin1().data() << ";";
+          str << lines[i]->text().toUtf8().data() << ";";
         }
         values.push_back(str.str().c_str());
       }
       else
       {
         str << cbArray->itemData(cbArray->currentIndex()).toInt() << ';'
-            << cbArray->currentText().toLatin1().data();
+            << cbArray->currentText().toUtf8().data();
         values.push_back(str.str().c_str());
       }
     }
@@ -277,7 +278,7 @@ void pqIntegrationModelSeedHelperWidget::setArrayToGenerate(const QList<QVariant
 {
   QGroupBox* gb;
   QList<QGroupBox*> gbs = this->findChildren<QGroupBox*>();
-  foreach (gb, gbs)
+  Q_FOREACH (gb, gbs)
   {
     gb->setChecked(false);
   }
@@ -296,7 +297,7 @@ void pqIntegrationModelSeedHelperWidget::setArrayToGenerate(const QList<QVariant
     QString arrayName = i->toString();
     int type = (i + 1)->toInt();
     gb = nullptr;
-    foreach (gb, gbs)
+    Q_FOREACH (gb, gbs)
     {
       // Identify correct combo box
       if (arrayName == gb->property("name"))
@@ -341,7 +342,7 @@ void pqIntegrationModelSeedHelperWidget::setArrayToGenerate(const QList<QVariant
     }
     // Recover values
     int nComponents = (i + 3)->toInt();
-    QStringList dataStrings = (i + 4)->toString().split(';', QString::SkipEmptyParts);
+    QStringList dataStrings = (i + 4)->toString().split(';', PV_QT_SKIP_EMPTY_PARTS);
     if (constOrFlow == vtkLagrangianSeedHelper::CONSTANT)
     {
       QList<pqLineEdit*> lines = gb->findChildren<pqLineEdit*>();
