@@ -57,6 +57,9 @@ public:
 
   ~pqLookingGlassDockPanel();
 
+  // Reset the focal distance slider range
+  void resetFocalDistanceSliderRange();
+
 protected Q_SLOTS:
   void setView(pqView* view);
   void onRender();
@@ -65,6 +68,16 @@ protected Q_SLOTS:
   void resetToCenterOfRotation();
   void pushFocalPlaneBack();
   void pullFocalPlaneForward();
+  void updateEnableStates();
+  void saveQuilt();
+  void onRecordQuiltClicked();
+  void onTargetDeviceChanged(int index);
+  void setAttachedDevice(const std::string& deviceType);
+
+  void startRecordingQuilt();
+  void stopRecordingQuilt();
+
+  void onFocalDistanceEdited(double position);
 
   void reset();
 
@@ -79,12 +92,15 @@ protected:
 
   vtkCommand* EndObserver = nullptr;
   vtkCommand* ViewRenderObserver = nullptr;
+  vtkCommand* FocalDistanceObserver = nullptr;
   vtkTextureObject* CopyTexture = nullptr;
   QVTKOpenGLWindow* Widget = nullptr;
   vtkLookingGlassInterface* Interface = nullptr;
   vtkOpenGLRenderWindow* DisplayWindow = nullptr;
 
   bool RenderNextFrame = false;
+  bool IsRecording = false;
+  QString MovieFilepath;
 
   QMap<pqRenderView*, vtkSMProxy*> ViewToSettingsMap;
 
@@ -92,6 +108,14 @@ protected:
 
   vtkRenderWindow* getRenderWindow();
 
+  // Get the recommended suffix (without the extension) for a quilt
+  // file name, based upon the number of tiles. Example: "_qs5x9".
+  // This communicates the tile information to the LG software.
+  QString getQuiltFileSuffix();
+
+  // Compute the focal distance and direction
+  double computeFocalDistanceAndDirection(double directionOfProjection[3]);
+
   // Get the Looking Glass settings for the displayed view
   vtkSMProxy* getSettingsForView(pqRenderView* view);
 
@@ -101,7 +125,6 @@ protected:
 
   class pqInternal;
   pqInternal* Internal = nullptr;
-  ;
 
 private:
   void constructor();
