@@ -18,11 +18,12 @@
   Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
   the U.S. Government retains certain rights in this software.
 -------------------------------------------------------------------------*/
-
 #include "pqSLACManager.h"
+#include "ui_pqSLACActionHolder.h"
 
 #include "pqActiveObjects.h"
 #include "pqApplicationCore.h"
+#include "pqCoreUtilities.h"
 #include "pqObjectBuilder.h"
 #include "pqOutputPort.h"
 #include "pqPipelineFilter.h"
@@ -48,6 +49,7 @@
 #include "vtkSMPropertyHelper.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMSourceProxy.h"
+#include "vtkSMViewProxy.h"
 #include "vtkTable.h"
 #include "vtkTemporalRanges.h"
 
@@ -55,8 +57,6 @@
 #include <QPointer>
 #include <QtDebug>
 
-#include "ui_pqSLACActionHolder.h"
-
 //=============================================================================
 class pqSLACManager::pqInternal
 {
@@ -66,17 +66,17 @@ public:
 };
 
 //=============================================================================
-QPointer<pqSLACManager> pqSLACManagerInstance = NULL;
+QPointer<pqSLACManager> pqSLACManagerInstance = nullptr;
 
 pqSLACManager* pqSLACManager::instance()
 {
-  if (pqSLACManagerInstance == NULL)
+  if (pqSLACManagerInstance == nullptr)
   {
     pqApplicationCore* core = pqApplicationCore::instance();
     if (!core)
     {
       qFatal("Cannot use the SLAC Tools without an application core instance.");
-      return NULL;
+      return nullptr;
     }
 
     pqSLACManagerInstance = new pqSLACManager(core);
@@ -95,7 +95,7 @@ pqSLACManager::pqSLACManager(QObject* p)
 
   // This widget serves no real purpose other than initializing the Actions
   // structure created with designer that holds the actions.
-  this->Internal->ActionPlaceholder = new QWidget(NULL);
+  this->Internal->ActionPlaceholder = new QWidget(nullptr);
   this->Internal->Actions.setupUi(this->Internal->ActionPlaceholder);
 
   this->actionShowParticles()->setChecked(true);
@@ -122,6 +122,14 @@ pqSLACManager::pqSLACManager(QObject* p)
     SLOT(resetRangeCurrentTime()));
 
   this->checkActionEnabled();
+
+  // If toolbar not enabled at startup, listed for source-created signals
+  if (!this->actionSolidMesh()->isEnabled())
+  {
+    const auto* builder = pqApplicationCore::instance()->getObjectBuilder();
+    QObject::connect(
+      builder, &pqObjectBuilder::sourceCreated, this, &pqSLACManager::onSourceCreated);
+  }
 }
 
 pqSLACManager::~pqSLACManager()
@@ -194,21 +202,8 @@ QAction* pqSLACManager::actionCurrentTimeResetRange()
 //-----------------------------------------------------------------------------
 pqServer* pqSLACManager::getActiveServer()
 {
-  pqApplicationCore* app = pqApplicationCore::instance();
-  pqServerManagerModel* smModel = app->getServerManagerModel();
-  pqServer* server = smModel->getItemAtIndex<pqServer*>(0);
-  return server;
-}
-
-//-----------------------------------------------------------------------------
-QWidget* pqSLACManager::getMainWindow()
-{
-  foreach (QWidget* topWidget, QApplication::topLevelWidgets())
-  {
-    if (qobject_cast<QMainWindow*>(topWidget))
-      return topWidget;
-  }
-  return NULL;
+  auto& objects = pqActiveObjects::instance();
+  return objects.activeServer();
 }
 
 //-----------------------------------------------------------------------------
@@ -217,7 +212,7 @@ pqView* pqSLACManager::findView(pqPipelineSource* source, int port, const QStrin
   // Step 1, try to find a view in which the source is already shown.
   if (source)
   {
-    foreach (pqView* view, source->getViews())
+    Q_FOREACH (pqView* view, source->getViews())
     {
       pqDataRepresentation* repr = source->getRepresentation(port, view);
       if (repr && repr->isVisible())
@@ -234,7 +229,7 @@ pqView* pqSLACManager::findView(pqPipelineSource* source, int port, const QStrin
   // showing anything.
   pqApplicationCore* core = pqApplicationCore::instance();
   pqServerManagerModel* smModel = core->getServerManagerModel();
-  foreach (view, smModel->findItems<pqView*>())
+  Q_FOREACH (view, smModel->findItems<pqView*>())
   {
     if (view && (view->getViewType() == viewType) &&
       (view->getNumberOfVisibleRepresentations() < 1))
@@ -244,7 +239,7 @@ pqView* pqSLACManager::findView(pqPipelineSource* source, int port, const QStrin
   }
 
   // Give up.  A new view needs to be created.
-  return NULL;
+  return nullptr;
 }
 
 pqView* pqSLACManager::getMeshView()
@@ -269,13 +264,13 @@ pqPipelineSource* pqSLACManager::findPipelineSource(const char* SMName)
   pqServerManagerModel* smModel = core->getServerManagerModel();
 
   QList<pqPipelineSource*> sources = smModel->findItems<pqPipelineSource*>(this->getActiveServer());
-  foreach (pqPipelineSource* s, sources)
+  Q_FOREACH (pqPipelineSource* s, sources)
   {
     if (strcmp(s->getProxy()->GetXMLName(), SMName) == 0)
       return s;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 pqPipelineSource* pqSLACManager::getMeshReader()
@@ -298,10 +293,18 @@ pqPipelineSource* pqSLACManager::getTemporalRanges()
   return this->findPipelineSource("TemporalRanges");
 }
 
+void pqSLACManager::loaderCreatingPipeline()
+{
+  // If the loader is building the pipeline, stop listening for source-created signals
+  const auto* builder = pqApplicationCore::instance()->getObjectBuilder();
+  QObject::disconnect(
+    builder, &pqObjectBuilder::sourceCreated, this, &pqSLACManager::onSourceCreated);
+}
+
 //-----------------------------------------------------------------------------
 static void destroyPortConsumers(pqOutputPort* port)
 {
-  foreach (pqPipelineSource* consumer, port->getConsumers())
+  Q_FOREACH (pqPipelineSource* consumer, port->getConsumers())
   {
     pqSLACManager::destroyPipelineSourceAndConsumers(consumer);
   }
@@ -312,7 +315,7 @@ void pqSLACManager::destroyPipelineSourceAndConsumers(pqPipelineSource* source)
   if (!source)
     return;
 
-  foreach (pqOutputPort* port, source->getOutputPorts())
+  Q_FOREACH (pqOutputPort* port, source->getOutputPorts())
   {
     destroyPortConsumers(port);
   }
@@ -325,7 +328,7 @@ void pqSLACManager::destroyPipelineSourceAndConsumers(pqPipelineSource* source)
 //-----------------------------------------------------------------------------
 void pqSLACManager::showDataLoadManager()
 {
-  pqSLACDataLoadManager* dialog = new pqSLACDataLoadManager(this->getMainWindow());
+  pqSLACDataLoadManager* dialog = new pqSLACDataLoadManager(pqCoreUtilities::mainWidget());
   dialog->setAttribute(Qt::WA_DeleteOnClose, true);
   QObject::connect(dialog, SIGNAL(createdPipeline()), this, SLOT(checkActionEnabled()));
   QObject::connect(dialog, SIGNAL(createdPipeline()), this, SLOT(showEField()));
@@ -359,26 +362,38 @@ void pqSLACManager::checkActionEnabled()
     vtkPVDataInformation* dataInfo = outputPort->getDataInformation();
     vtkPVDataSetAttributesInformation* pointFields = dataInfo->GetPointDataInformation();
 
-    this->actionShowEField()->setEnabled(pointFields->GetArrayInformation("efield") != NULL);
-    this->actionShowBField()->setEnabled(pointFields->GetArrayInformation("bfield") != NULL);
+    this->actionShowEField()->setEnabled(pointFields->GetArrayInformation("efield") != nullptr);
+    this->actionShowBField()->setEnabled(pointFields->GetArrayInformation("bfield") != nullptr);
 
     this->actionSolidMesh()->setEnabled(true);
     this->actionWireframeSolidMesh()->setEnabled(true);
     this->actionWireframeAndBackMesh()->setEnabled(true);
 
-    this->actionPlotOverZ()->setEnabled(pointFields->GetArrayInformation("efield") != NULL);
+    this->actionPlotOverZ()->setEnabled(pointFields->GetArrayInformation("efield") != nullptr);
 
     this->actionTemporalResetRange()->setEnabled(true);
     this->actionCurrentTimeResetRange()->setEnabled(true);
   }
 
-  this->actionShowParticles()->setEnabled(particlesReader != NULL);
+  this->actionShowParticles()->setEnabled(particlesReader != nullptr);
+}
+
+//-----------------------------------------------------------------------------
+void pqSLACManager::onSourceCreated(pqPipelineSource* source)
+{
+  const char* SName = "SLACReader";
+  if (strcmp(source->getProxy()->GetXMLName(), SName) == 0)
+  {
+    // After data is loaded, call checkActionEnabled() to enable toolbar
+    QObject::connect(source, QOverload<pqPipelineSource*>::of(&pqPipelineSource::dataUpdated), this,
+      &pqSLACManager::checkActionEnabled);
+  }
 }
 
 //-----------------------------------------------------------------------------
 void pqSLACManager::showField(QString name)
 {
-  this->showField(name.toLocal8Bit().data());
+  this->showField(name.toUtf8().data());
 }
 
 void pqSLACManager::showField(const char* name)
@@ -452,7 +467,7 @@ void pqSLACManager::showField(const char* name)
       pm->NewProxy("strategies", "ClientDeliveryStrategy"));
     vtkSMSourceProxy* temporalRangesProxy =
       vtkSMSourceProxy::SafeDownCast(temporalRanges->getProxy());
-    delivery->AddInput(temporalRangesProxy, NULL);
+    delivery->AddInput(temporalRangesProxy, nullptr);
     delivery->Update();
     vtkAlgorithm* alg = vtkAlgorithm::SafeDownCast(delivery->GetOutput()->GetClientSideObject());
     vtkTable* ranges = vtkTable::SafeDownCast(alg->GetOutputDataObject(0));
@@ -460,7 +475,7 @@ void pqSLACManager::showField(const char* name)
     if (!rangeData)
     {
       QString magName = QString("%1_M").arg(name);
-      rangeData = ranges->GetColumnByName(magName.toLocal8Bit().data());
+      rangeData = ranges->GetColumnByName(magName.toUtf8().data());
     }
 
     this->CurrentFieldRangeKnown = true;
@@ -538,7 +553,7 @@ void pqSLACManager::updatePlotField()
   // with the viewed mesh.
   auto domain =
     reprProxy->GetProperty("SeriesVisibility")->FindDomain<vtkSMChartSeriesSelectionDomain>();
-  if (domain == NULL)
+  if (domain == nullptr)
   {
     return;
   }
@@ -553,14 +568,12 @@ void pqSLACManager::updatePlotField()
       visibility << seriesName << 1;
 
       double color[3] = { 0.0, 0.0, 0.0 };
-      vtkSMPropertyHelper(reprProxy, "SeriesColor")
-        .SetStatus(seriesName.toLocal8Bit().data(), color, 3);
+      vtkSMPropertyHelper(reprProxy, "SeriesColor").SetStatus(seriesName.toUtf8().data(), color, 3);
 
       vtkSMPropertyHelper(reprProxy, "SeriesLineThickness")
-        .SetStatus(seriesName.toLocal8Bit().data(), 1);
+        .SetStatus(seriesName.toUtf8().data(), 1);
 
-      vtkSMPropertyHelper(reprProxy, "SeriesLineStyle")
-        .SetStatus(seriesName.toLocal8Bit().data(), 1);
+      vtkSMPropertyHelper(reprProxy, "SeriesLineStyle").SetStatus(seriesName.toUtf8().data(), 1);
     }
     else
     {
@@ -749,7 +762,7 @@ void pqSLACManager::createPlotOverZ()
   dataInfo->GetBounds(bounds);
 
   // Create the plot filter.
-  QMap<QString, QList<pqOutputPort*> > namedInputs;
+  QMap<QString, QList<pqOutputPort*>> namedInputs;
   QList<pqOutputPort*> inputs;
   inputs.push_back(meshReader->getOutputPort(1));
   namedInputs["Input"] = inputs;
@@ -759,27 +772,37 @@ void pqSLACManager::createPlotOverZ()
   // Set up the line for the plot.  The line is one of the inputs to the filter
   // which is implicitly set up through a proxy list domain.
   vtkSMProxy* plotProxy = plotFilter->getProxy();
-  pqSMProxy lineProxy = pqSMAdaptor::getProxyProperty(plotProxy->GetProperty("Source"));
-  if (!lineProxy)
-  {
-    qWarning() << "Could not retrieve plot line source.  "
-               << "Plot not set up correctly.";
-  }
-  else
-  {
-    QList<QVariant> minPoint;
-    minPoint << 0.0 << 0.0 << bounds[4];
-    pqSMAdaptor::setMultipleElementProperty(lineProxy->GetProperty("Point1"), minPoint);
-    QList<QVariant> maxPoint;
-    maxPoint << 0.0 << 0.0 << bounds[5];
-    pqSMAdaptor::setMultipleElementProperty(lineProxy->GetProperty("Point2"), maxPoint);
-    pqSMAdaptor::setElementProperty(lineProxy->GetProperty("Resolution"), 1000);
-    lineProxy->UpdateVTKObjects();
-  }
+  QList<QVariant> minPoint;
+  minPoint << 0.0 << 0.0 << bounds[4];
+  pqSMAdaptor::setMultipleElementProperty(plotProxy->GetProperty("Point1"), minPoint);
+  QList<QVariant> maxPoint;
+  maxPoint << 0.0 << 0.0 << bounds[5];
+  pqSMAdaptor::setMultipleElementProperty(plotProxy->GetProperty("Point2"), maxPoint);
+  pqSMAdaptor::setElementProperty(plotProxy->GetProperty("SamplingPattern"), 2);
+  pqSMAdaptor::setElementProperty(plotProxy->GetProperty("Resolution"), 1000);
+  plotProxy->UpdateVTKObjects();
   plotFilter->updatePipeline();
 
   // Make representation
-  controller->Show(plotFilter->getSourceProxy(), 0, plotView ? plotView->getViewProxy() : nullptr);
+  if (plotView)
+  {
+    controller->Show(plotFilter->getSourceProxy(), 0, plotView->getViewProxy());
+  }
+  else
+  {
+    auto newview = vtkSMViewProxy::SafeDownCast(
+      controller->ShowInPreferredView(plotFilter->getSourceProxy(), 0, nullptr));
+    if (newview)
+    {
+      const auto& activeObjects = pqActiveObjects::instance();
+      controller->AssignViewToLayout(
+        newview, activeObjects.activeLayout(), activeObjects.activeLayoutLocation());
+    }
+    else
+    {
+      qWarning() << "Failed to create 'Plot View'.";
+    }
+  }
 
   this->updatePlotField();
 
@@ -813,15 +836,18 @@ void pqSLACManager::toggleBackgroundBW()
   {
     color[0] = color[1] = color[2] = 1.0;
     helper.Set(color, 3);
+    vtkSMPropertyHelper(viewProxy, "UseColorPaletteForBackground").Set(0);
   }
   else if ((color[0] == 1.0) && (color[1] == 1.0) && (color[2] == 1.0))
   {
     smProperty->ResetToXMLDefaults();
+    vtkSMPropertyHelper(viewProxy, "UseColorPaletteForBackground").Set(1);
   }
   else
   {
     color[0] = color[1] = color[2] = 0.0;
     helper.Set(color, 3);
+    vtkSMPropertyHelper(viewProxy, "UseColorPaletteForBackground").Set(0);
   }
   viewProxy->UpdateVTKObjects();
   view->render();
