@@ -1,5 +1,5 @@
 /***************************************************************************************************
- * Copyright 2019 NVIDIA Corporation. All rights reserved.
+ * Copyright 2021 NVIDIA Corporation. All rights reserved.
  **************************************************************************************************/
 /// \file
 /// \brief Type traits
@@ -15,6 +15,8 @@
 #include <mi/math/spectrum.h>
 #include <mi/math/vector.h>
 
+#include <string>
+
 namespace mi {
 
 /** \addtogroup mi_neuray_types
@@ -718,6 +720,18 @@ template<> struct Type_traits<const char*>
     typedef mi::IString Interface_type;
 };
 
+template<> struct Type_traits<std::string>
+{
+    static const char* get_type_name() { return "String"; };
+    typedef mi::IString Interface_type;
+};
+
+template<std::size_t N> struct Type_traits<char[N]>
+{
+    static const char* get_type_name() { return "String"; };
+    typedef mi::IString Interface_type;
+};
+
 template<> struct Type_traits<mi::base::Uuid>
 {
     static const char* get_type_name() { return "Uuid"; };
@@ -1129,6 +1143,15 @@ template<> struct Vector_type_traits<mi::Sint32, 3>
 template<> struct Vector_type_traits<mi::Sint32, 4>
 { typedef mi::ISint32_4 Interface_type; };
 
+template<> struct Vector_type_traits<mi::Uint32, 2>
+{ typedef mi::IUint32_2 Interface_type; };
+
+template<> struct Vector_type_traits<mi::Uint32, 3>
+{ typedef mi::IUint32_3 Interface_type; };
+
+template<> struct Vector_type_traits<mi::Uint32, 4>
+{ typedef mi::IUint32_4 Interface_type; };
+
 template<> struct Vector_type_traits<mi::Float32, 2>
 { typedef mi::IFloat32_2 Interface_type; };
 
