@@ -1,4 +1,4 @@
-/* Copyright 2020 NVIDIA Corporation. All rights reserved.
+/* Copyright 2021 NVIDIA Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -54,6 +54,10 @@ size_t vtknvindex_irregular_volume_data::get_memory_size(const std::string& scal
   {
     scalar_size = sizeof(mi::Uint16);
   }
+  else if (scalar_type == "int" || scalar_type == "unsigned int")
+  {
+    scalar_size = sizeof(mi::Uint32);
+  }
   else if (scalar_type == "float")
   {
     scalar_size = sizeof(mi::Float32);
@@ -188,12 +192,12 @@ vtknvindex_host_properties* vtknvindex_cluster_properties::get_host_properties(
 {
   std::map<mi::Sint32, mi::Uint32>::const_iterator rankit = m_rankid_to_hostid.find(rankid);
   if (rankit == m_rankid_to_hostid.end())
-    return NULL;
+    return nullptr;
 
   std::map<mi::Uint32, vtknvindex_host_properties*>::const_iterator shmit =
     m_hostinfo.find(rankit->second);
   if (shmit == m_hostinfo.end())
-    return NULL;
+    return nullptr;
 
   return shmit->second;
 }
@@ -220,6 +224,7 @@ bool vtknvindex_cluster_properties::retrieve_process_configuration(
 {
   // Volume general properties.
   m_regular_vol_properties->set_scalar_type(dataset_parameters.scalar_type);
+  m_regular_vol_properties->set_scalar_components(dataset_parameters.scalar_components);
   m_regular_vol_properties->set_voxel_range(mi::math::Vector<mi::Float32, 2>(
     dataset_parameters.voxel_range[0], dataset_parameters.voxel_range[1]));
   m_regular_vol_properties->set_scalar_range(mi::math::Vector<mi::Float32, 2>(
@@ -330,7 +335,8 @@ bool vtknvindex_cluster_properties::retrieve_process_configuration(
       }
       else
       {
-        ERROR_LOG << "The scalar type: " << scalar_type << " is not supported by NVIDIA IndeX.";
+        ERROR_LOG << "The scalar type " << scalar_type
+                  << " is not supported by NVIDIA IndeX for structured grids.";
         return false;
       }
 
@@ -346,13 +352,18 @@ bool vtknvindex_cluster_properties::retrieve_process_configuration(
         ;
       else if (scalar_type == "unsigned short")
         ;
+      else if (scalar_type == "unsigned int")
+        ;
+      else if (scalar_type == "int")
+        ;
       else if (scalar_type == "float")
         ;
       else if (scalar_type == "double")
         ;
       else
       {
-        ERROR_LOG << "The scalar type: " << scalar_type << " is not supported by NVIDIA IndeX.";
+        ERROR_LOG << "The scalar type " << scalar_type
+                  << " is not supported by NVIDIA IndeX for unstructured grids.";
         return false;
       }
 
@@ -656,7 +667,7 @@ bool vtknvindex_cluster_properties::retrieve_cluster_configuration(
       }
 
       host_properties->set_shminfo(time_step, current_rankid, ss.str(), current_bbox, shm_size,
-        reinterpret_cast<void*>(all_data_ptrs[i]));
+        reinterpret_cast<void*>(all_data_ptrs[i])); // NOLINT(performance-no-int-to-ptr)
     }
   }
 
