@@ -1,4 +1,4 @@
-/* Copyright 2019 NVIDIA Corporation. All rights reserved.
+/* Copyright 2021 NVIDIA Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -27,24 +27,21 @@
 
 #include <cassert>
 
+#include "vtksys/FStream.hxx"
 #include "vtksys/SystemInformation.hxx"
 #include "vtksys/SystemTools.hxx"
 
 #include "vtknvindex_scene.h"
 
-#include <nv/index/idistributed_compute_algorithm.h>
 #include <nv/index/idistributed_data_import_callback.h>
 #include <nv/index/iirregular_volume_rendering_properties.h>
 #include <nv/index/ilight.h>
 #include <nv/index/imaterial.h>
 #include <nv/index/iplane.h>
-#include <nv/index/iregular_volume_rendering_properties.h>
-#include <nv/index/iregular_volume_texture.h>
 #include <nv/index/irendering_kernel_programs.h>
 #include <nv/index/iscene.h>
 
 #include <nv/index/isparse_volume_rendering_properties.h>
-#include <nv/index/ivolume_filter_mode.h>
 
 #include "vtkCamera.h"
 #include "vtkRenderWindow.h"
@@ -56,39 +53,13 @@
 #include "vtknvindex_clock_pulse_generator.h"
 #include "vtknvindex_cluster_properties.h"
 #include "vtknvindex_forwarding_logger.h"
+#include "vtknvindex_global_settings.h"
 #include "vtknvindex_instance.h"
 #include "vtknvindex_irregular_volume_importer.h"
 #include "vtknvindex_rtc_kernel_params.h"
 #include "vtknvindex_sparse_volume_importer.h"
 #include "vtknvindex_volume_compute.h"
 
-//-------------------------------------------------------------------------------------------------
-bool file_to_string(const std::string& file_path, std::string& out_file_string)
-{
-  std::ifstream src_file;
-
-  src_file.open(file_path.c_str(), std::ios::in | std::ios::binary | std::ios::ate);
-
-  if (!src_file.is_open())
-    return false;
-
-  const std::ifstream::pos_type src_file_size = src_file.tellg();
-  src_file.seekg(std::ios::beg);
-
-  out_file_string.resize(src_file_size, '\0');
-  src_file.read(&out_file_string[0], src_file_size);
-
-  if (!src_file)
-  {
-    out_file_string.clear();
-    return false;
-  }
-
-  src_file.close();
-
-  return true;
-}
-
 //-------------------------------------------------------------------------------------------------
 void update_slice_planes(nv::index::IPlane* plane, const vtknvindex_slice_params& slice_params,
   const mi::math::Vector_struct<mi::Uint32, 3>& volume_size)
@@ -134,29 +105,21 @@ void update_slice_planes(nv::index::IPlane* plane, const vtknvindex_slice_params
   plane->set_extent(extent);
 }
 
+//-------------------------------------------------------------------------------------------------
 vtknvindex_scene::vtknvindex_scene()
   : m_scene_created(false)
   , m_only_init(true)
   , m_is_parallel(false)
-  , m_vol_properties_tag(mi::neuraylib::NULL_TAG)
-  , m_timeseries_tag(mi::neuraylib::NULL_TAG)
-  , m_root_group_tag(mi::neuraylib::NULL_TAG)
-  , m_static_group_tag(mi::neuraylib::NULL_TAG)
-  , m_volume_tag(mi::neuraylib::NULL_TAG)
-  , m_prog_se_mapping_tag(mi::neuraylib::NULL_TAG)
-  , m_rtc_program_params_tag(mi::neuraylib::NULL_TAG)
-  , m_rtc_program_tag(mi::neuraylib::NULL_TAG)
-  , m_volume_compute_attrib_tag(mi::neuraylib::NULL_TAG)
-  , m_sparse_volume_render_properties_tag(mi::neuraylib::NULL_TAG)
+  , m_cluster_properties(nullptr)
 {
-  m_cluster_properties = NULL;
   m_index_instance = vtknvindex_instance::get();
 }
 
+//-------------------------------------------------------------------------------------------------
 vtknvindex_scene::~vtknvindex_scene()
 {
   // Remove this volume instance and complementary elements from scene graph
-  if (m_index_instance->is_index_viewer() && m_root_group_tag != mi::neuraylib::NULL_TAG)
+  if (m_index_instance->is_index_viewer() && m_root_group_tag)
   {
     mi::base::Handle<mi::neuraylib::IDice_transaction> dice_transaction(
       m_index_instance->m_global_scope->create_transaction<mi::neuraylib::IDice_transaction>());
@@ -170,106 +133,85 @@ vtknvindex_scene::~vtknvindex_scene()
       assert(scene_geom_group_edit.is_valid_interface());
 
       scene_geom_group_edit->remove(m_root_group_tag, dice_transaction.get());
-
-      // ERROR_LOG << "Removing tag: " << m_root_group_tag.id
-      //          << " from Geom group: " << m_index_instance->get_scene_geom_group();
     }
 
     dice_transaction->commit();
   }
-
-  m_vol_properties_tag = mi::neuraylib::NULL_TAG;
-  m_timeseries_tag = mi::neuraylib::NULL_TAG;
-  m_root_group_tag = mi::neuraylib::NULL_TAG;
-  m_volume_tag = mi::neuraylib::NULL_TAG;
-  m_prog_se_mapping_tag = mi::neuraylib::NULL_TAG;
-  m_rtc_program_params_tag = mi::neuraylib::NULL_TAG;
-  m_rtc_program_tag = mi::neuraylib::NULL_TAG;
-  m_volume_compute_attrib_tag = mi::neuraylib::NULL_TAG;
-  m_sparse_volume_render_properties_tag = mi::neuraylib::NULL_TAG;
-  m_static_group_tag = mi::neuraylib::NULL_TAG;
-
-  for (mi::Uint32 i = 0; i < m_plane_tags.size(); i++)
-    m_plane_tags[i] = mi::neuraylib::NULL_TAG;
 }
 
 //-------------------------------------------------------------------------------------------------
-void vtknvindex_scene::set_visibility(bool visibility)
+void vtknvindex_scene::activate(mi::neuraylib::IDice_transaction* dice_transaction)
 {
-  if (m_root_group_tag != mi::neuraylib::NULL_TAG)
+  if (!m_root_group_tag)
   {
-    mi::base::Handle<mi::neuraylib::IDice_transaction> dice_transaction(
-      m_index_instance->m_global_scope->create_transaction<mi::neuraylib::IDice_transaction>());
-    assert(dice_transaction.is_valid_interface());
+    return;
+  }
 
+  //
+  // Ensure that only the scene group for the current dataset is enabled.
+  //
+  mi::base::Handle<const nv::index::IStatic_scene_group> scene_geom_group(
+    dice_transaction->access<nv::index::IStatic_scene_group>(
+      m_index_instance->get_scene_geom_group()));
+
+  for (mi::Uint32 i = 0; i < scene_geom_group->nb_elements(); ++i)
+  {
+    const mi::neuraylib::Tag group_tag = scene_geom_group->get_scene_element(i);
+    mi::base::Handle<const nv::index::IStatic_scene_group> group(
+      dice_transaction->access<nv::index::IStatic_scene_group>(group_tag));
+    if (!group)
     {
-      mi::base::Handle<nv::index::IStatic_scene_group> root_group_edit(
-        dice_transaction->edit<nv::index::IStatic_scene_group>(m_root_group_tag));
-      assert(root_group_edit.is_valid_interface());
-
-      root_group_edit->set_enabled(visibility);
-
-      // Update scene transformation
-      if (visibility)
-      {
-        // Reset the affinity information to IndeX in case it changed. Otherwise it will be ignored.
-        mi::base::Handle<vtknvindex_affinity> affinity = m_cluster_properties->get_affinity();
-
-        // NVIDIA IndeX session will take ownership of the affinity.
-        affinity->retain();
-        m_index_instance->m_iindex_session->set_affinity_information(affinity.get());
-
-        // Access the session instance from the database.
-        mi::base::Handle<const nv::index::ISession> session(
-          dice_transaction->access<const nv::index::ISession>(m_index_instance->m_session_tag));
-        assert(session.is_valid_interface());
-
-        // Access (edit mode) the scene instance from the database.
-        mi::base::Handle<nv::index::IScene> scene(
-          dice_transaction->edit<nv::index::IScene>(session->get_scene()));
-        assert(scene.is_valid_interface());
-
-        mi::base::Handle<const mi::neuraylib::IElement> vol_elem(
-          dice_transaction->access<mi::neuraylib::IElement>(m_volume_tag));
-
-        mi::base::Handle<const nv::index::ISparse_volume_scene_element> sparse_vol_elem(
-          vol_elem->get_interface<nv::index::ISparse_volume_scene_element>());
-
-        // Set global scene transform (only required for regular volumes).
-        mi::math::Matrix<mi::Float32, 4, 4> scene_rotation_matrix(1.0f);
-        mi::math::Vector_struct<mi::Float32, 3> scene_translate_vec;
-        mi::math::Vector_struct<mi::Float32, 3> scene_scaling_vec;
-
-        // Is regular volume?
-        if (sparse_vol_elem.is_valid_interface())
-        {
-          vtknvindex_regular_volume_properties* regular_volume_properties =
-            m_cluster_properties->get_regular_volume_properties();
-
-          mi::math::Vector<mi::Float32, 3> translation, scaling;
-          regular_volume_properties->get_volume_translation(translation);
-          regular_volume_properties->get_volume_scaling(scaling);
-
-          // Need to translate if the volume doesn't start at [0,0,0].
-          scene_translate_vec.x = translation.x;
-          scene_translate_vec.y = translation.y;
-          scene_translate_vec.z = translation.z;
-
-          scene_scaling_vec.x = scaling.x;
-          scene_scaling_vec.y = scaling.y;
-          scene_scaling_vec.z = scaling.z;
-        }
-        else
-        {
-          scene_translate_vec.x = scene_translate_vec.y = scene_translate_vec.z = 0.0f;
-          scene_scaling_vec.x = scene_scaling_vec.y = scene_scaling_vec.z = 1.0f;
-        }
-        scene->set_transform_matrix(scene_translate_vec, scene_rotation_matrix, scene_scaling_vec);
-      }
+      continue;
     }
 
-    dice_transaction->commit();
+    // Only enable the group belonging to this instance.
+    const bool enable = (group_tag == m_root_group_tag);
+    if (group->get_enabled() != enable)
+    {
+      mi::base::Handle<nv::index::IStatic_scene_group> group_edit(
+        dice_transaction->edit<nv::index::IStatic_scene_group>(group_tag));
+      group_edit->set_enabled(enable);
+    }
   }
+
+//
+// Update the affinity.
+//
+#ifdef VTKNVINDEX_USE_KDTREE
+  // Set kd-tree affinity only when running in multiple ranks.
+  if (vtkMultiProcessController::GetGlobalController()->GetNumberOfProcesses() == 1 &&
+    m_cluster_properties->get_affinity_kdtree() != nullptr)
+  {
+    m_index_instance->m_iindex_session->set_affinity_information(nullptr);
+  }
+  else
+#endif
+  {
+    // Reset the affinity information to IndeX in case it changed. Otherwise it will be ignored.
+    m_index_instance->m_iindex_session->set_affinity_information(
+      m_cluster_properties->copy_affinity());
+  }
+
+  //
+  // Update global scene transform.
+  //
+  mi::math::Matrix<mi::Float32, 4, 4> scene_rotation_matrix(1.f);
+  mi::math::Vector<mi::Float32, 3> scene_translate_vec(0.f);
+  mi::math::Vector<mi::Float32, 3> scene_scaling_vec(1.f);
+
+  mi::base::Handle<const nv::index::ISession> session(
+    dice_transaction->access<nv::index::ISession>(m_index_instance->m_session_tag));
+  mi::base::Handle<nv::index::IScene> scene(
+    dice_transaction->edit<nv::index::IScene>(session->get_scene()));
+
+  vtknvindex_regular_volume_properties* regular_volume_properties =
+    m_cluster_properties->get_regular_volume_properties();
+
+  // Need to translate if the volume doesn't start at [0,0,0].
+  regular_volume_properties->get_volume_translation(scene_translate_vec);
+  regular_volume_properties->get_volume_scaling(scene_scaling_vec);
+
+  scene->set_transform_matrix(scene_translate_vec, scene_rotation_matrix, scene_scaling_vec);
 }
 
 //-------------------------------------------------------------------------------------------------
@@ -281,23 +223,6 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
   if (m_scene_created)
     return;
 
-  // Set the affinity information.
-  mi::base::Handle<vtknvindex_affinity> affinity = m_cluster_properties->get_affinity();
-
-  std::ostringstream s;
-  affinity->scene_dump_affinity_info(s);
-  INFO_LOG << s.str();
-
-  // NVIDIA IndeX session will take ownership of the affinity.
-  affinity->retain();
-
-  m_index_instance->m_iindex_session->set_affinity_information(affinity.get());
-
-  // // DiCE database access.
-  // mi::base::Handle<mi::neuraylib::IDice_transaction> dice_transaction(
-  //  m_index_instance.m_global_scope->create_transaction<mi::neuraylib::IDice_transaction>());
-  // assert(dice_transaction.is_valid_interface());
-
   // GUI settings.
   vtknvindex_config_settings* pv_config_settings = m_cluster_properties->get_config_settings();
 
@@ -314,7 +239,7 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
     assert(scene.is_valid_interface());
 
     // Dataset subcube border size.
-    mi::Sint32 subcube_border = m_cluster_properties->get_config_settings()->get_subcube_border();
+    mi::Sint32 subcube_border = pv_config_settings->get_subcube_border();
 
     // Print cluster details in ParaView's console.
     m_cluster_properties->print_info();
@@ -322,8 +247,7 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
     vtknvindex_regular_volume_properties* regular_volume_properties =
       m_cluster_properties->get_regular_volume_properties();
 
-    std::string scalar_type;
-    regular_volume_properties->get_scalar_type(scalar_type);
+    const std::string scalar_type = regular_volume_properties->get_scalar_type();
 
     // Scene contains a regular volume.
     if (volume_type == VOLUME_TYPE_REGULAR)
@@ -332,8 +256,9 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
       regular_volume_properties->get_volume_size(volume_size);
 
       // Create shared memory regular volume data importer.
-      vtknvindex_sparse_volume_importer* volume_importer =
-        new vtknvindex_sparse_volume_importer(volume_size, subcube_border, scalar_type);
+      vtknvindex_sparse_volume_importer* volume_importer = new vtknvindex_sparse_volume_importer(
+        volume_size, subcube_border, regular_volume_properties->get_ghost_levels(), scalar_type,
+        regular_volume_properties->get_scalar_components());
 
       assert(volume_importer);
 
@@ -377,7 +302,7 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
 
       // Create shared memory irregular volume data importer.
       vtknvindex_irregular_volume_importer* volume_importer =
-        new vtknvindex_irregular_volume_importer(subcube_border, scalar_type);
+        new vtknvindex_irregular_volume_importer(scalar_type);
 
       assert(volume_importer);
 
@@ -495,6 +420,14 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
             break;
           }
 
+          case RTC_KERNELS_CUSTOM:
+          {
+            vtknvindex_custom_params custom_params;
+            rtc_program_parameters->set_buffer_data(
+              0, reinterpret_cast<void*>(&custom_params), sizeof(custom_params));
+            break;
+          }
+
           default:
             rtc_program->set_enabled(false);
             rtc_program_parameters->set_enabled(false);
@@ -508,7 +441,7 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
           case RTC_KERNELS_ISOSURFACE:
           {
             vtknvindex_ivol_isosurface_params iso_params;
-            iso_params.rh = m_cluster_properties->get_config_settings()->get_ivol_step_size();
+            iso_params.rh = pv_config_settings->get_ivol_step_size();
             rtc_program->set_program_source(KERNEL_IRREGULAR_ISOSURFACE_STRING);
             rtc_program_parameters->set_buffer_data(
               0, reinterpret_cast<void*>(&iso_params), sizeof(iso_params));
@@ -518,7 +451,7 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
           case RTC_KERNELS_DEPTH_ENHANCEMENT:
           {
             vtknvindex_ivol_depth_enhancement_params depth_params;
-            depth_params.rh = m_cluster_properties->get_config_settings()->get_ivol_step_size();
+            depth_params.rh = pv_config_settings->get_ivol_step_size();
             rtc_program->set_program_source(KERNEL_IRREGULAR_DEPTH_ENHANCEMENT_STRING);
             rtc_program_parameters->set_buffer_data(
               0, reinterpret_cast<void*>(&depth_params), sizeof(depth_params));
@@ -528,13 +461,21 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
           case RTC_KERNELS_EDGE_ENHANCEMENT:
           {
             vtknvindex_ivol_edge_enhancement_params edge_params;
-            edge_params.rh = m_cluster_properties->get_config_settings()->get_ivol_step_size();
+            edge_params.rh = pv_config_settings->get_ivol_step_size();
             rtc_program->set_program_source(KERNEL_IRREGULAR_EDGE_ENHANCEMENT_STRING);
             rtc_program_parameters->set_buffer_data(
               0, reinterpret_cast<void*>(&edge_params), sizeof(edge_params));
             break;
           }
 
+          case RTC_KERNELS_CUSTOM:
+          {
+            vtknvindex_ivol_custom_params custom_params;
+            rtc_program_parameters->set_buffer_data(
+              0, reinterpret_cast<void*>(&custom_params), sizeof(custom_params));
+            break;
+          }
+
           default:
             rtc_program->set_enabled(false);
             rtc_program_parameters->set_enabled(false);
@@ -559,20 +500,15 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
           scene->create_attribute<nv::index::IIrregular_volume_rendering_properties>());
         assert(vol_render_properties.is_valid_interface());
 
-        nv::index::IIrregular_volume_rendering_properties::Rendering render_properties;
-        vol_render_properties->get_rendering(render_properties);
+        vol_render_properties->set_sampling_mode(
+          (m_volume_rtc_kernel.rtc_kernel == RTC_KERNELS_NONE) ? 0 : 1);
 
-        render_properties.sampling_mode =
-          (m_volume_rtc_kernel.rtc_kernel == RTC_KERNELS_NONE) ? 0 : 1;
+        vol_render_properties->set_sampling_segment_length(
+          pv_config_settings->get_ivol_step_size() * pv_config_settings->get_step_size());
 
-        render_properties.sampling_segment_length =
-          m_cluster_properties->get_config_settings()->get_ivol_step_size() *
-          m_cluster_properties->get_config_settings()->get_step_size();
-
-        render_properties.sampling_reference_segment_length = calculate_volume_reference_step_size(
-          vol, pv_config_settings->get_opacity_mode(), pv_config_settings->get_opacity_reference());
-
-        vol_render_properties->set_rendering(render_properties);
+        vol_render_properties->set_sampling_reference_segment_length(
+          calculate_volume_reference_step_size(vol, pv_config_settings->get_opacity_mode(),
+            pv_config_settings->get_opacity_reference()));
 
         m_vol_properties_tag =
           dice_transaction->store_for_reference_counting(vol_render_properties.get());
@@ -588,7 +524,8 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
         regular_volume_properties->get_volume_size(volume_size);
 
         mi::base::Handle<vtknvindex_volume_compute> vol_compute(new vtknvindex_volume_compute(
-          volume_size, subcube_border, scalar_type, m_cluster_properties));
+          volume_size, subcube_border, regular_volume_properties->get_ghost_levels(), scalar_type,
+          regular_volume_properties->get_scalar_components(), m_cluster_properties));
         assert(vol_compute.is_valid_interface());
 
         vol_compute->set_enabled(false);
@@ -605,10 +542,7 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
         assert(sparse_volume_render_properties.is_valid_interface());
 
         // filter mode
-        const nv::index::Sparse_volume_filter_mode filter_mode =
-          static_cast<nv::index::Sparse_volume_filter_mode>(pv_config_settings->get_filter_mode());
-
-        sparse_volume_render_properties->set_filter_mode(filter_mode);
+        sparse_volume_render_properties->set_filter_mode(pv_config_settings->get_filter_mode());
 
         // use pre-integration
         const vtknvindex_rtc_kernels rtc_kernel = pv_config_settings->get_rtc_kernel();
@@ -737,33 +671,6 @@ void vtknvindex_scene::create_scene(vtkRenderer* ren, vtkVolume* vol,
       scene->set_camera(m_index_instance->get_parallel_camera());
     else
       scene->set_camera(m_index_instance->get_perspective_camera());
-
-    // Set global scene transform (only required for regular volumes).
-    mi::math::Matrix<mi::Float32, 4, 4> scene_rotation_matrix(1.0f);
-    mi::math::Vector_struct<mi::Float32, 3> scene_translate_vec;
-    mi::math::Vector_struct<mi::Float32, 3> scene_scaling_vec;
-
-    if (volume_type == VOLUME_TYPE_REGULAR)
-    {
-      mi::math::Vector<mi::Float32, 3> translation, scaling;
-      regular_volume_properties->get_volume_translation(translation);
-      regular_volume_properties->get_volume_scaling(scaling);
-
-      // Need to translate if the volume doesn't start at [0,0,0].
-      scene_translate_vec.x = translation.x;
-      scene_translate_vec.y = translation.y;
-      scene_translate_vec.z = translation.z;
-
-      scene_scaling_vec.x = scaling.x;
-      scene_scaling_vec.y = scaling.y;
-      scene_scaling_vec.z = scaling.z;
-    }
-    else
-    {
-      scene_translate_vec.x = scene_translate_vec.y = scene_translate_vec.z = 0.0f;
-      scene_scaling_vec.x = scene_scaling_vec.y = scene_scaling_vec.z = 1.0f;
-    }
-    scene->set_transform_matrix(scene_translate_vec, scene_rotation_matrix, scene_scaling_vec);
   }
 
   // Commit transaction.
@@ -807,17 +714,6 @@ void vtknvindex_scene::update_volume(
     }
   }
 
-  // Set the affinity information.
-  mi::base::Handle<vtknvindex_affinity> affinity = m_cluster_properties->get_affinity();
-
-  std::ostringstream s;
-  affinity->scene_dump_affinity_info(s);
-  INFO_LOG << s.str();
-
-  // NVIDIA IndeX session takes ownership of the affinity.
-  affinity->retain();
-  m_index_instance->m_iindex_session->set_affinity_information(affinity.get());
-
   // Create and setup the scene.
   {
     // Access the session instance from the database.
@@ -839,8 +735,7 @@ void vtknvindex_scene::update_volume(
     vtknvindex_regular_volume_properties* regular_volume_properties =
       m_cluster_properties->get_regular_volume_properties();
 
-    std::string scalar_type;
-    regular_volume_properties->get_scalar_type(scalar_type);
+    const std::string scalar_type = regular_volume_properties->get_scalar_type();
 
     // Remove previous volume.
     mi::base::Handle<nv::index::IStatic_scene_group> static_group_edit(
@@ -858,8 +753,9 @@ void vtknvindex_scene::update_volume(
       regular_volume_properties->get_volume_size(volume_size);
 
       // Create shared memory regular volume data importer.
-      vtknvindex_sparse_volume_importer* volume_importer =
-        new vtknvindex_sparse_volume_importer(volume_size, subcube_border, scalar_type);
+      vtknvindex_sparse_volume_importer* volume_importer = new vtknvindex_sparse_volume_importer(
+        volume_size, subcube_border, regular_volume_properties->get_ghost_levels(), scalar_type,
+        regular_volume_properties->get_scalar_components());
       assert(volume_importer);
 
       volume_importer->set_cluster_properties(m_cluster_properties);
@@ -908,7 +804,7 @@ void vtknvindex_scene::update_volume(
 
       // Create shared memory irregular volume data importer.
       vtknvindex_irregular_volume_importer* volume_importer =
-        new vtknvindex_irregular_volume_importer(subcube_border, scalar_type);
+        new vtknvindex_irregular_volume_importer(scalar_type);
 
       assert(volume_importer);
 
@@ -952,6 +848,38 @@ void vtknvindex_scene::update_scene(vtkRenderer* ren, vtkVolume* vol,
   // Update colormap.
   update_colormap(vol, dice_transaction, m_cluster_properties->get_regular_volume_properties());
 
+  {
+    // Detect changed region of interest (cropping).
+    mi::base::Handle<const nv::index::ISession> session(
+      dice_transaction->access<nv::index::ISession>(m_index_instance->m_session_tag));
+    mi::base::Handle<const nv::index::IScene> scene(
+      dice_transaction->access<nv::index::IScene>(session->get_scene()));
+
+    const mi::math::Bbox<mi::Float32, 3> roi_new =
+      m_cluster_properties->get_config_settings()->get_region_of_interest();
+
+    const mi::math::Bbox<mi::Float32, 3> roi_old = scene->get_clipped_bounding_box();
+    if (roi_new != roi_old)
+    {
+      config_settings_changed = true; // scene will be updated with new ROI below
+    }
+
+    // Performance logging.
+    vtknvindex_global_settings* settings = vtknvindex_global_settings::GetInstance();
+    mi::base::Handle<const nv::index::IConfig_settings> config_settings(
+      dice_transaction->access<nv::index::IConfig_settings>(session->get_config()));
+    if (config_settings->is_monitor_performance_values() != settings->GetOutputPerformanceValues())
+    {
+      config_settings_changed = true;
+    }
+
+    // Dump internal state.
+    if (settings->GetExportSession())
+    {
+      export_session(settings->GetExportSessionFilename());
+    }
+  }
+
   // Update config settings.
   if (config_settings_changed)
     update_config_settings(dice_transaction);
@@ -1003,23 +931,23 @@ void vtknvindex_scene::update_rtc_kernel(
       switch (rtc_param_buffer.rtc_kernel)
       {
         case RTC_KERNELS_ISOSURFACE:
-          rtc_program->set_program_source(KERNEL_ISOSURFACE_STRING);
-          rtc_program->set_enabled(true);
-          break;
-
         case RTC_KERNELS_DEPTH_ENHANCEMENT:
-          rtc_program->set_program_source(KERNEL_DEPTH_ENHANCEMENT_STRING);
-          rtc_program->set_enabled(true);
-          break;
-
         case RTC_KERNELS_EDGE_ENHANCEMENT:
-          rtc_program->set_program_source(KERNEL_EDGE_ENHANCEMENT_STRING);
+        case RTC_KERNELS_GRADIENT:
+          rtc_program->set_program_source(rtc_param_buffer.kernel_program.c_str());
           rtc_program->set_enabled(true);
           break;
-
-        case RTC_KERNELS_GRADIENT:
-          rtc_program->set_program_source(KERNEL_GRADIENT_STRING);
-          rtc_program->set_enabled(true);
+        case RTC_KERNELS_CUSTOM:
+          // use default program in case the custom kernel doesn't exist yet.
+          if (rtc_param_buffer.kernel_program.empty())
+          {
+            rtc_program->set_enabled(false);
+          }
+          else
+          {
+            rtc_program->set_program_source(rtc_param_buffer.kernel_program.c_str());
+            rtc_program->set_enabled(true);
+          }
           break;
 
         case RTC_KERNELS_NONE:
@@ -1033,18 +961,22 @@ void vtknvindex_scene::update_rtc_kernel(
       switch (rtc_param_buffer.rtc_kernel)
       {
         case RTC_KERNELS_ISOSURFACE:
-          rtc_program->set_program_source(KERNEL_IRREGULAR_ISOSURFACE_STRING);
-          rtc_program->set_enabled(true);
-          break;
-
         case RTC_KERNELS_DEPTH_ENHANCEMENT:
-          rtc_program->set_program_source(KERNEL_IRREGULAR_DEPTH_ENHANCEMENT_STRING);
+        case RTC_KERNELS_EDGE_ENHANCEMENT:
+          rtc_program->set_program_source(rtc_param_buffer.kernel_program.c_str());
           rtc_program->set_enabled(true);
           break;
-
-        case RTC_KERNELS_EDGE_ENHANCEMENT:
-          rtc_program->set_program_source(KERNEL_IRREGULAR_EDGE_ENHANCEMENT_STRING);
-          rtc_program->set_enabled(true);
+        case RTC_KERNELS_CUSTOM:
+          // use default program in case the custom kernel doesn't exist yet.
+          if (rtc_param_buffer.kernel_program.empty())
+          {
+            rtc_program->set_enabled(false);
+          }
+          else
+          {
+            rtc_program->set_program_source(rtc_param_buffer.kernel_program.c_str());
+            rtc_program->set_enabled(true);
+          }
           break;
 
         case RTC_KERNELS_NONE:
@@ -1111,6 +1043,16 @@ void vtknvindex_scene::update_rtc_kernel(
         }
         break;
 
+        case RTC_KERNELS_CUSTOM:
+        {
+          vtknvindex_ivol_custom_params custom_params = *(
+            reinterpret_cast<const vtknvindex_ivol_custom_params*>(rtc_param_buffer.params_buffer));
+
+          rtc_program_parameters->set_buffer_data(0, &custom_params, rtc_param_buffer.buffer_size);
+          rtc_program_parameters->set_enabled(true);
+        }
+        break;
+
         case RTC_KERNELS_NONE:
         default:
           rtc_program_parameters->set_buffer_data(
@@ -1133,12 +1075,8 @@ void vtknvindex_scene::update_rtc_kernel(
         m_vol_properties_tag));
     assert(vol_render_properties.is_valid_interface());
 
-    nv::index::IIrregular_volume_rendering_properties::Rendering render_properties;
-    vol_render_properties->get_rendering(render_properties);
-
-    render_properties.sampling_mode = (rtc_param_buffer.rtc_kernel == RTC_KERNELS_NONE) ? 0 : 1;
-
-    vol_render_properties->set_rendering(render_properties);
+    vol_render_properties->set_sampling_mode(
+      (rtc_param_buffer.rtc_kernel == RTC_KERNELS_NONE) ? 0 : 1);
   }
 }
 
@@ -1250,9 +1188,7 @@ void vtknvindex_scene::update_config_settings(
   vtknvindex_config_settings* pv_config_settings = m_cluster_properties->get_config_settings();
 
   // Set region of interest.
-  mi::math::Bbox_struct<mi::Float32, 3> region_of_interest;
-  pv_config_settings->get_region_of_interest(region_of_interest);
-  scene->set_clipped_bounding_box(region_of_interest);
+  scene->set_clipped_bounding_box(pv_config_settings->get_region_of_interest());
 
   // Access (edit mode) the global configurations.
   mi::base::Handle<nv::index::IConfig_settings> config_settings(
@@ -1272,10 +1208,7 @@ void vtknvindex_scene::update_config_settings(
     assert(sparse_volume_render_properties.is_valid_interface());
 
     // filter mode
-    const nv::index::Sparse_volume_filter_mode filter_mode =
-      static_cast<nv::index::Sparse_volume_filter_mode>(pv_config_settings->get_filter_mode());
-
-    sparse_volume_render_properties->set_filter_mode(filter_mode);
+    sparse_volume_render_properties->set_filter_mode(pv_config_settings->get_filter_mode());
 
     // use pre-integration
     bool use_preintegration = rtc_kernel == RTC_KERNELS_NONE &&
@@ -1306,8 +1239,7 @@ void vtknvindex_scene::update_config_settings(
     mi::Uint32 subcube_border_size = pv_config_settings->get_subcube_border();
 
     // Subcube size
-    mi::math::Vector_struct<mi::Uint32, 3> subcube_size;
-    pv_config_settings->get_subcube_size(subcube_size);
+    mi::math::Vector<mi::Uint32, 3> subcube_size = pv_config_settings->get_subcube_size();
 
     // Adding padding to subcube size in order to build a
     // subcube size multiple of the volume size when border size is present.
@@ -1373,26 +1305,17 @@ void vtknvindex_scene::update_config_settings(
     config_settings->set_data_transfer_config(data_transfer_config);
   }
 
-  // Logging performance values.
-  if (m_cluster_properties->get_config_settings()->is_log_performance())
-    config_settings->set_monitor_performance_values(true);
-  else
-    config_settings->set_monitor_performance_values(false);
-
-  // Dump internal state.
-  if (pv_config_settings->is_dump_internal_state())
-    export_session();
+  // Enable generation of performance values if needed.
+  config_settings->set_monitor_performance_values(
+    vtknvindex_global_settings::GetInstance()->GetOutputPerformanceValues());
 }
 
 //-------------------------------------------------------------------------------------------------
 void vtknvindex_scene::update_volume_opacity(
   vtkVolume* vol, const mi::base::Handle<mi::neuraylib::IDice_transaction>& dice_transaction)
 {
-  mi::base::Handle<const mi::neuraylib::IElement> vol_elem(
-    dice_transaction->access<mi::neuraylib::IElement>(m_volume_tag));
-
   mi::base::Handle<const nv::index::ISparse_volume_scene_element> sparse_vol_elem(
-    vol_elem->get_interface<nv::index::ISparse_volume_scene_element>());
+    dice_transaction->access<nv::index::ISparse_volume_scene_element>(m_volume_tag));
 
   // Is regular volume?
   vtknvindex_config_settings* pv_config_settings = m_cluster_properties->get_config_settings();
@@ -1421,17 +1344,13 @@ void vtknvindex_scene::update_volume_opacity(
         m_vol_properties_tag));
     assert(vol_render_properties.is_valid_interface());
 
-    nv::index::IIrregular_volume_rendering_properties::Rendering render_properties;
-    vol_render_properties->get_rendering(render_properties);
-
-    render_properties.sampling_segment_length =
+    vol_render_properties->set_sampling_segment_length(
       m_cluster_properties->get_config_settings()->get_ivol_step_size() *
-      m_cluster_properties->get_config_settings()->get_step_size();
+      m_cluster_properties->get_config_settings()->get_step_size());
 
-    render_properties.sampling_reference_segment_length = calculate_volume_reference_step_size(
-      vol, pv_config_settings->get_opacity_mode(), pv_config_settings->get_opacity_reference());
-
-    vol_render_properties->set_rendering(render_properties);
+    vol_render_properties->set_sampling_reference_segment_length(
+      calculate_volume_reference_step_size(
+        vol, pv_config_settings->get_opacity_mode(), pv_config_settings->get_opacity_reference()));
   }
 }
 
@@ -1490,7 +1409,7 @@ void vtknvindex_scene::set_cluster_properties(vtknvindex_cluster_properties* clu
 }
 
 //-------------------------------------------------------------------------------------------------
-void vtknvindex_scene::export_session()
+void vtknvindex_scene::export_session(const char* filename)
 {
   // TODO: Add scene lock here before accessing the export file.
   mi::base::Handle<mi::neuraylib::IDice_transaction> dice_transaction(
@@ -1512,9 +1431,11 @@ void vtknvindex_scene::export_session()
     std::ostringstream s;
     s << str->get_c_str();
 
-    std::string output_filename = "nvindex_pvplugin.prj";
-    if (output_filename.empty() || output_filename == "stdout")
+    std::string output_filename = (filename ? filename : "");
+    if (output_filename.empty())
     {
+      WARN_LOG << "Exporting NVIDIA IndeX session to standard output. This can be disabled in the "
+                  "'Settings' dialog.";
       std::cout << "\n"
                 << "----------------8<-------------[ cut here ]------------------\n"
                 << s.str() << "----------------8<-------------[ cut here ]------------------\n"
@@ -1522,18 +1443,17 @@ void vtknvindex_scene::export_session()
     }
     else
     {
-      std::vector<std::string> path_components;
-      path_components.push_back(vtksys::SystemTools::GetCurrentWorkingDirectory() + "/");
-      path_components.push_back(output_filename);
+      WARN_LOG << "Exporting NVIDIA IndeX session to file '" << output_filename
+               << "'. This can be disabled in the 'Settings' dialog.";
 
-      INFO_LOG << "Writing export session to file '"
-               << vtksys::SystemTools::JoinPath(path_components) << "'";
-
-      std::ofstream f(output_filename.c_str());
+      vtksys::ofstream f(output_filename.c_str());
       f << s.str();
+
+      // Add affinity information.
       std::ostringstream af;
-      m_cluster_properties->get_affinity()->scene_dump_affinity_info(af);
+      m_cluster_properties->scene_dump_affinity_info(af);
       f << af.str();
+
       f.close();
     }
   }
