@@ -50,9 +50,9 @@ pqBlotShell::pqBlotShell(QWidget* p)
   QObject::connect(this->Console, SIGNAL(executeCommand(const QString&)), this,
     SLOT(executeBlotCommand(const QString&)));
 
-  this->ActiveServer = NULL;
+  this->ActiveServer = nullptr;
   this->VTKConnect = vtkEventQtSlotConnect::New();
-  this->Interpretor = NULL;
+  this->Interpretor = nullptr;
 }
 
 pqBlotShell::~pqBlotShell()
@@ -97,7 +97,7 @@ void pqBlotShell::initialize()
     QString("servermanager.ActiveConnection = servermanager.Connection(%1)\n")
       .arg(this->ActiveServer->GetConnectionID()));
   this->executePythonCommand(QString("servermanager.ActiveConnection.SetHost(\"%1\",0)\n")
-                               .arg(this->ActiveServer->getResource().toURI()));
+                               .arg(this->ActiveServer->getResource().schemeHostsPorts().toURI()));
   this->executePythonCommand("servermanager.ToggleProgressPrinting()\n");
   this->executePythonCommand("servermanager.fromGUI = True\n");
   this->executePythonCommand("import paraview.simple\n");
@@ -127,7 +127,7 @@ void pqBlotShell::destroyInterpretor()
   this->Console->setFormat(format);
 
   this->Interpretor->Delete();
-  this->Interpretor = NULL;
+  this->Interpretor = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -135,7 +135,7 @@ void pqBlotShell::executePythonCommand(const QString& command)
 {
   Q_EMIT this->executing(true);
   // this->printMessage(command);
-  this->Interpretor->RunSimpleString(command.toLocal8Bit().data());
+  this->Interpretor->RunSimpleString(command.toUtf8().data());
   Q_EMIT this->executing(false);
 }
 
