@@ -39,29 +39,29 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqTimer.h"
 
 /**
-* @ingroup Behaviors
-* pqAlwaysConnectedBehavior ensures that the client always remains connected
-* to a server.
-*/
+ * @ingroup Behaviors
+ * pqAlwaysConnectedBehavior ensures that the client always remains connected
+ * to a server.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqAlwaysConnectedBehavior : public QObject
 {
   Q_OBJECT
   typedef QObject Superclass;
 
 public:
-  pqAlwaysConnectedBehavior(QObject* parent = 0);
+  pqAlwaysConnectedBehavior(QObject* parent = nullptr);
   ~pqAlwaysConnectedBehavior() override;
 
   /**
-  * Get/Set the default server resource to connect to.
-  */
+   * Get/Set the default server resource to connect to.
+   */
   void setDefaultServer(const pqServerResource& resource) { this->DefaultServer = resource; }
   const pqServerResource& defaultServer() const { return this->DefaultServer; }
 
 protected Q_SLOTS:
   void serverCheck();
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   pqServerResource DefaultServer;
   pqTimer Timer;
 
