@@ -52,17 +52,17 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqAnimationShortcutDecorator : public pqPro
 
 public:
   /**
-  * Constructor that modify the widget if conditions are met.
-  */
+   * Constructor that modify the widget if conditions are met.
+   */
   pqAnimationShortcutDecorator(pqPropertyWidget* parent);
-  virtual ~pqAnimationShortcutDecorator();
+  ~pqAnimationShortcutDecorator() override;
 
   /**
    * Return true if the widget is considered valid by this decorator
    */
   static bool accept(pqPropertyWidget* widget);
 
-protected slots:
+protected Q_SLOTS:
   /**
    * Called when general settings has changed
    * to hide/show the widget if necessary
