@@ -82,16 +82,14 @@ pqAnimationShortcutWidget::pqAnimationShortcutWidget(
 }
 
 //-----------------------------------------------------------------------------
-pqAnimationShortcutWidget::~pqAnimationShortcutWidget()
-{
-}
+pqAnimationShortcutWidget::~pqAnimationShortcutWidget() = default;
 
 //-----------------------------------------------------------------------------
 void pqAnimationShortcutWidget::setScene(pqAnimationScene* scene)
 {
   if (this->Scene)
   {
-    QObject::disconnect(this->Scene, 0, this, 0);
+    QObject::disconnect(this->Scene, nullptr, this, nullptr);
   }
   this->Scene = scene;
   if (scene)
@@ -109,10 +107,9 @@ void pqAnimationShortcutWidget::updateMenu()
 
   popupMenu->clear();
 
-  pqAnimationCue* cue = this->Scene
-    ? pqPVApplicationCore::instance()->animationManager()->getCue(
-        this->Scene, this->Proxy, this->Property->GetXMLName(), 0)
-    : nullptr;
+  pqAnimationCue* cue = this->Scene ? pqPVApplicationCore::instance()->animationManager()->getCue(
+                                        this->Scene, this->Proxy, this->Property->GetXMLName(), 0)
+                                    : nullptr;
   if (!cue)
   {
     QAction* playAction = new QAction(
@@ -179,7 +176,7 @@ void pqAnimationShortcutWidget::onTriggered(QAction* action)
   pqLineEdit* animationLineEdit = new pqLineEdit(dialog);
   animationLineEdit->setValidator(
     new QIntValidator(1, static_cast<int>(~0u >> 1), animationLineEdit));
-  QLabel* label = NULL;
+  QLabel* label = nullptr;
   if (mode == "Sequence")
   {
     label = new QLabel(tr("No. frames:"), dialog);
