@@ -40,30 +40,30 @@ class pqAnimationTimeWidget;
 class pqAnimationScene;
 
 /**
-* pqAnimationTimeToolbar is a QToolBar containing a pqAnimationTimeWidget.
-* pqAnimationTimeToolbar also ensures that the pqAnimationTimeWidget is
-* tracking the animation scene on the active session.
-*/
+ * pqAnimationTimeToolbar is a QToolBar containing a pqAnimationTimeWidget.
+ * pqAnimationTimeToolbar also ensures that the pqAnimationTimeWidget is
+ * tracking the animation scene on the active session.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqAnimationTimeToolbar : public QToolBar
 {
   Q_OBJECT
   typedef QToolBar Superclass;
 
 public:
-  pqAnimationTimeToolbar(const QString& _title, QWidget* _parent = 0)
+  pqAnimationTimeToolbar(const QString& _title, QWidget* _parent = nullptr)
     : Superclass(_title, _parent)
   {
     this->constructor();
   }
-  pqAnimationTimeToolbar(QWidget* _parent = 0)
+  pqAnimationTimeToolbar(QWidget* _parent = nullptr)
     : Superclass(_parent)
   {
     this->constructor();
   }
 
   /**
-  * Provides access to the pqAnimationTimeWidget used.
-  */
+   * Provides access to the pqAnimationTimeWidget used.
+   */
   pqAnimationTimeWidget* animationTimeWidget() const;
 private Q_SLOTS:
   void setAnimationScene(pqAnimationScene* scene);
@@ -73,7 +73,7 @@ private Q_SLOTS:
    */
   void updateTimeDisplay();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqAnimationTimeToolbar)
   void constructor();
   QPointer<pqAnimationTimeWidget> AnimationTimeWidget;
