@@ -35,25 +35,25 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqReaction.h"
 
 /**
-* @ingroup Reactions
-* Reaction for enabling/disabling auto-apply.
-*/
+ * @ingroup Reactions
+ * Reaction for enabling/disabling auto-apply.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqAutoApplyReaction : public pqReaction
 {
   Q_OBJECT
   typedef pqReaction Superclass;
 
 public:
-  pqAutoApplyReaction(QAction* parent = 0);
+  pqAutoApplyReaction(QAction* parent = nullptr);
 
   /**
-  * Set the status of auto-apply.
-  */
+   * Set the status of auto-apply.
+   */
   static void setAutoApply(bool);
 
   /**
-  * Get the status of auto-apply.
-  */
+   * Get the status of auto-apply.
+   */
   static bool autoApply();
 
 protected Q_SLOTS:
