@@ -41,6 +41,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMRenderViewProxy.h"
 #include "vtkSMTrace.h"
 
+#include <cmath>
+
 class pqAxesToolbar::pqInternals : public Ui::pqAxesToolbar
 {
 public:
@@ -54,8 +56,8 @@ void pqAxesToolbar::constructor()
   this->Internals = new pqInternals();
   this->Internals->setupUi(this);
 
-  QObject::connect(&pqActiveObjects::instance(), SIGNAL(viewChanged(pqView*)), this,
-    SLOT(setView(pqView*)), Qt::QueuedConnection);
+  QObject::connect(
+    &pqActiveObjects::instance(), SIGNAL(viewChanged(pqView*)), this, SLOT(setView(pqView*)));
   QObject::connect(&pqActiveObjects::instance(), SIGNAL(viewChanged(pqView*)), this,
     SLOT(updateEnabledState()), Qt::QueuedConnection);
 
@@ -76,7 +78,7 @@ void pqAxesToolbar::constructor()
 
   pqRenderViewSelectionReaction* selectionReaction =
     new pqRenderViewSelectionReaction(this->Internals->actionPickCenter,
-      NULL /* track active view*/, pqRenderViewSelectionReaction::SELECT_CUSTOM_BOX);
+      nullptr /* track active view*/, pqRenderViewSelectionReaction::SELECT_CUSTOM_BOX);
   QObject::connect(selectionReaction, SIGNAL(selectedCustomBox(int, int, int, int)), this,
     SLOT(pickCenterOfRotation(int, int)));
 
@@ -87,7 +89,7 @@ void pqAxesToolbar::constructor()
 pqAxesToolbar::~pqAxesToolbar()
 {
   delete this->Internals;
-  this->Internals = 0;
+  this->Internals = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -117,10 +119,10 @@ void pqAxesToolbar::setView(pqView* view)
 void pqAxesToolbar::updateEnabledState()
 {
   pqRenderView* renderView = qobject_cast<pqRenderView*>(pqActiveObjects::instance().activeView());
-  this->Internals->actionShowOrientationAxes->setEnabled(renderView != NULL);
-  this->Internals->actionShowCenterAxes->setEnabled(renderView != NULL);
+  this->Internals->actionShowOrientationAxes->setEnabled(renderView != nullptr);
+  this->Internals->actionShowCenterAxes->setEnabled(renderView != nullptr);
   this->Internals->actionResetCenter->setEnabled(
-    pqActiveObjects::instance().activeRepresentation() != NULL);
+    pqActiveObjects::instance().activeRepresentation() != nullptr);
 }
 
 //-----------------------------------------------------------------------------
@@ -190,13 +192,14 @@ void pqAxesToolbar::pickCenterOfRotation(int posx, int posy)
   if (rm)
   {
     int posxy[2] = { posx, posy };
-    double center[3];
+    double center[3], normal[3];
 
     vtkSMRenderViewProxy* proxy = rm->getRenderViewProxy();
     SM_SCOPED_TRACE(PropertiesModified)
       .arg("proxy", proxy)
       .arg("comment", " update center of rotation");
-    if (proxy->ConvertDisplayToPointOnSurface(posxy, center))
+    proxy->ConvertDisplayToPointOnSurface(posxy, center, normal);
+    if (!std::isnan(center[0]) || !std::isnan(center[1]) || !std::isnan(center[2]))
     {
       rm->setCenterOfRotation(center);
       rm->render();
