@@ -32,7 +32,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqBoxPropertyWidget.h"
 #include "ui_pqBoxPropertyWidget.h"
 
+#include "pqActiveObjects.h"
 #include "pqUndoStack.h"
+
 #include "vtkSMNewWidgetRepresentationProxy.h"
 #include "vtkSMPropertyGroup.h"
 #include "vtkSMUncheckedPropertyHelper.h"
@@ -164,13 +166,13 @@ pqBoxPropertyWidget::pqBoxPropertyWidget(
     ui.zmin->hide();
     ui.zmax->hide();
 
-    // if `ReferenceBounds` or `UseReferenceBounds` is not present, which is the
-    // case for `Transform`, the box is providing params relative to the input
-    // bounds.
+    // if `ReferenceBounds` or `UseReferenceBounds` is not present,
+    // the box is either using the input bounds as reference (e.g. Transform) or
+    // isn't i.e relative to unit box.  To determine that, let's if "Input" is part
+    // of the property group.
+    this->BoxIsRelativeToInput = (smgroup->GetProperty("Input") != nullptr);
     vtkSMPropertyHelper(wdgProxy, "UseReferenceBounds").Set(0);
     wdgProxy->UpdateVTKObjects();
-
-    this->BoxIsRelativeToInput = true;
   }
 
   if (hideReferenceBounds)
@@ -231,15 +233,18 @@ pqBoxPropertyWidget::pqBoxPropertyWidget(
     }
     wdgProxy->UpdateVTKObjects();
     Q_EMIT this->changeAvailable();
-    this->placeWidget();
+    if (this->PlaceWidgetConnection)
+    {
+      QObject::disconnect(this->PlaceWidgetConnection);
+    }
+    this->PlaceWidgetConnection = QObject::connect(&pqActiveObjects::instance(),
+      &pqActiveObjects::dataUpdated, this, &pqBoxPropertyWidget::placeWidget);
     this->render();
   });
 }
 
 //-----------------------------------------------------------------------------
-pqBoxPropertyWidget::~pqBoxPropertyWidget()
-{
-}
+pqBoxPropertyWidget::~pqBoxPropertyWidget() = default;
 
 //-----------------------------------------------------------------------------
 void pqBoxPropertyWidget::placeWidget()
