@@ -38,9 +38,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqView;
 
 /**
-* @ingroup Reactions
-* Reaction for camera undo or redo.
-*/
+ * @ingroup Reactions
+ * Reaction for camera undo or redo.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqCameraUndoRedoReaction : public pqReaction
 {
   Q_OBJECT
@@ -48,30 +48,30 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqCameraUndoRedoReaction : public pqReactio
 
 public:
   /**
-  * Constructor parent cannot be NULL. When undo is true, acts as
-  * undo-reaction, else acts as redo reaction.
-  * If \c view ==NULL then active view is used.
-  */
-  pqCameraUndoRedoReaction(QAction* parent, bool undo, pqView* view = 0);
+   * Constructor parent cannot be nullptr. When undo is true, acts as
+   * undo-reaction, else acts as redo reaction.
+   * If \c view ==nullptr then active view is used.
+   */
+  pqCameraUndoRedoReaction(QAction* parent, bool undo, pqView* view = nullptr);
 
   /**
-  * undo.
-  */
+   * undo.
+   */
   static void undo(pqView* view);
 
   /**
-  * redo.
-  */
+   * redo.
+   */
   static void redo(pqView* view);
 
 protected Q_SLOTS:
   void setEnabled(bool enable) { this->parentAction()->setEnabled(enable); }
   void setActiveView(pqView*);
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * Called when the action is triggered.
-  */
+   * Called when the action is triggered.
+   */
   void onTriggered() override;
 
 private:
