@@ -38,11 +38,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqLiveInsituVisualizationManager;
 
 /**
-* Reaction for setting a breakpoint to Catalyst CoProcessing Engine
-* for Live-Data Visualization.
-* @ingroup Reactions
-* @ingroup LiveInsitu
-*/
+ * Reaction for setting a breakpoint to Catalyst CoProcessing Engine
+ * for Live-Data Visualization.
+ * @ingroup Reactions
+ * @ingroup LiveInsitu
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqCatalystContinueReaction
   : public pqCatalystPauseSimulationReaction
 {
@@ -50,12 +50,12 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqCatalystContinueReaction
   typedef pqCatalystPauseSimulationReaction Superclass;
 
 public:
-  pqCatalystContinueReaction(QAction* parentTemp = 0)
+  pqCatalystContinueReaction(QAction* parentTemp = nullptr)
     : Superclass(parentTemp)
   {
   }
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   void updateEnableState() override
   {
     pqCatalystPauseSimulationReaction::updateEnableState(CONTINUE);
@@ -63,8 +63,8 @@ public Q_SLOTS:
 
 protected:
   /**
-  * Called when the action is triggered.
-  */
+   * Called when the action is triggered.
+   */
   void onTriggered() override { this->setPauseSimulation(false); }
 
 private:
