@@ -64,9 +64,7 @@ pqCatalystExportReaction::pqCatalystExportReaction(QAction* parentObject)
 }
 
 //-----------------------------------------------------------------------------
-pqCatalystExportReaction::~pqCatalystExportReaction()
-{
-}
+pqCatalystExportReaction::~pqCatalystExportReaction() = default;
 
 //-----------------------------------------------------------------------------
 QString pqCatalystExportReaction::exportScript()
@@ -120,7 +118,7 @@ bool pqCatalystExportReaction::exportScript(const QString& filename)
     return false;
   }
   vtkSmartPyObject name(PyString_FromString("save_catalyst_state"));
-  vtkSmartPyObject pyfilename(PyString_FromString(filename.toLocal8Bit().data()));
+  vtkSmartPyObject pyfilename(PyString_FromString(filename.toUtf8().data()));
   vtkSmartPyObject pyproxy(vtkPythonUtil::GetObjectFromPointer(proxy));
   vtkSmartPyObject result(PyObject_CallMethodObjArgs(
     module, name, pyfilename.GetPointer(), pyproxy.GetPointer(), nullptr));
