@@ -36,9 +36,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqReaction.h"
 
 /**
-* @ingroup Reactions
-* Reaction to export a Catalyst script that will produce configured catalyst data products.
-*/
+ * @ingroup Reactions
+ * Reaction to export a Catalyst script that will produce configured catalyst data products.
+ */
 
 class PQAPPLICATIONCOMPONENTS_EXPORT pqCatalystExportReaction : public pqReaction
 {
@@ -47,7 +47,7 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqCatalystExportReaction : public pqReactio
 
 public:
   pqCatalystExportReaction(QAction* parent);
-  ~pqCatalystExportReaction();
+  ~pqCatalystExportReaction() override;
 
   /**
    * Export a Catalyst script. Returns true on success.
@@ -62,8 +62,8 @@ public:
 
 protected Q_SLOTS:
   /**
-  * Called when the action is triggered.
-  */
+   * Called when the action is triggered.
+   */
   void onTriggered() override { this->exportScript(); }
 
 private:
