@@ -40,17 +40,23 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqDataRepresentation.h"
 #include "pqOpacityTableModel.h"
 #include "pqPipelineRepresentation.h"
+#include "pqPresetGroupsManager.h"
+#include "pqPresetToPixmap.h"
 #include "pqPropertiesPanel.h"
 #include "pqPropertyWidgetDecorator.h"
 #include "pqResetScalarRangeReaction.h"
 #include "pqSettings.h"
+#include "pqSignalsBlocker.h"
 #include "pqTimer.h"
 #include "pqTransferFunctionWidget.h"
 #include "pqUndoStack.h"
 #include "vtkCommand.h"
 #include "vtkDiscretizableColorTransferFunction.h"
 #include "vtkEventQtSlotConnect.h"
+#include "vtkImageData.h"
 #include "vtkNew.h"
+#include "vtkPVTransferFunction2D.h"
+#include "vtkPVTransferFunction2DBox.h"
 #include "vtkPVXMLElement.h"
 #include "vtkPiecewiseFunction.h"
 #include "vtkSMCoreUtilities.h"
@@ -60,15 +66,23 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMPropertyHelper.h"
 #include "vtkSMRenderViewProxy.h"
 #include "vtkSMSessionProxyManager.h"
+#include "vtkSMTransferFunction2DProxy.h"
 #include "vtkSMTransferFunctionPresets.h"
 #include "vtkSMTransferFunctionProxy.h"
 #include "vtkTable.h"
+#include "vtkTransferFunctionBoxItem.h"
+#include "vtkTransferFunctionChartHistogram2D.h"
 #include "vtkVector.h"
 #include "vtkWeakPointer.h"
 #include "vtk_jsoncpp.h"
 
+#include <QColorDialog>
 #include <QMessageBox>
+#include <QPainter>
 #include <QPointer>
+#include <QStandardItem>
+#include <QStandardItemModel>
+#include <QStyledItemDelegate>
 #include <QTimer>
 #include <QVBoxLayout>
 #include <QtDebug>
@@ -92,7 +106,7 @@ public:
     , Hidden(false)
   {
   }
-  ~pqColorOpacityEditorWidgetDecorator() override {}
+  ~pqColorOpacityEditorWidgetDecorator() override = default;
 
   void setHidden(bool val)
   {
@@ -112,6 +126,73 @@ private:
   Q_DISABLE_COPY(pqColorOpacityEditorWidgetDecorator)
 };
 
+class pqColorMapDelegate : public QStyledItemDelegate
+{
+public:
+  pqColorMapDelegate(QObject* parent = nullptr)
+    : QStyledItemDelegate(parent)
+  {
+  }
+
+  void paint(
+    QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override
+  {
+    painter->save();
+    auto opt = option;
+    this->initStyleOption(&opt, index);
+
+    // The pixmap takes 3/4 of the height and 1/2 of the width of the item, and the text takes 1/2
+    // of the height and 1/2 of the width of the item
+    int const pixmapHorizontalMargins = 5;
+    auto const pixmapRect =
+      QRect(opt.rect.x() + pixmapHorizontalMargins, opt.rect.y() + 0.125 * opt.rect.height(),
+        opt.rect.width() / 2 - 2 * pixmapHorizontalMargins, opt.rect.height() * 0.75);
+    auto const textRect = QRect(
+      opt.rect.x() + opt.rect.width() / 2, opt.rect.y(), opt.rect.width() / 2, opt.rect.height());
+
+    if (opt.state & QStyle::State_Selected)
+    {
+      // Fill the background of the selected item with a blue color
+      painter->fillRect(opt.rect, opt.palette.color(QPalette::Highlight));
+
+      QPen pen = painter->pen();
+
+      pen.setColor(opt.palette.color(QPalette::HighlightedText));
+      painter->setPen(pen);
+    }
+    else
+    {
+      painter->fillRect(opt.rect, painter->brush());
+    }
+
+    // First element is used as a placeholder, so drawing is different
+    if (index.row() != 0)
+    {
+      painter->drawText(QRectF(textRect), Qt::AlignVCenter, index.data().toString());
+
+      auto transferFunctionPresets = vtkSMTransferFunctionPresets::GetInstance();
+      QPixmap pixmap = PresetToPixmap.render(
+        transferFunctionPresets->GetPreset(index.data(Qt::UserRole).toInt()), opt.rect.size());
+
+      painter->drawPixmap(pixmapRect, pixmap);
+    }
+    else
+    {
+      painter->drawText(opt.rect, Qt::AlignVCenter, index.data().toString());
+    }
+
+    painter->restore();
+  }
+
+  QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex&) const override
+  {
+    return QSize{ option.rect.width(), option.fontMetrics.height() * 2 };
+  }
+
+private:
+  pqPresetToPixmap PresetToPixmap;
+};
+
 } // end anonymous namespace
 
 //-----------------------------------------------------------------------------
@@ -124,16 +205,22 @@ public:
   QPointer<pqColorOpacityEditorWidgetDecorator> Decorator;
   vtkWeakPointer<vtkSMPropertyGroup> PropertyGroup;
   vtkWeakPointer<vtkSMProxy> ScalarOpacityFunctionProxy;
+  vtkWeakPointer<vtkSMProxy> TransferFunction2DProxy;
+  vtkWeakPointer<vtkSMProxy> TransferFunction2DRepProxy;
   QScopedPointer<QAction> TempAction;
   QScopedPointer<pqChooseColorPresetReaction> ChoosePresetReaction;
+  QScopedPointer<pqSignalsBlocker> SignalsBlocker;
 
   // We use this pqPropertyLinks instance to simply monitor smproperty changes.
   pqPropertyLinks LinksForMonitoringChanges;
   vtkNew<vtkEventQtSlotConnect> TransferFunctionConnector;
+  vtkNew<vtkEventQtSlotConnect> TransferFunctionModifiedConnector;
   vtkNew<vtkEventQtSlotConnect> RangeConnector;
   vtkNew<vtkEventQtSlotConnect> ConsumerConnector;
+  vtkNew<vtkEventQtSlotConnect> TransferFunction2DConnector;
 
   pqTimer HistogramTimer;
+  pqTimer Histogram2DTimer;
   bool HistogramOutdated = true;
 
   pqInternals(pqColorOpacityEditorWidget* self, vtkSMPropertyGroup* group)
@@ -142,6 +229,7 @@ public:
     , PropertyGroup(group)
     , TempAction(new QAction(self))
     , ChoosePresetReaction(new pqChooseColorPresetReaction(this->TempAction.data(), false))
+    , SignalsBlocker(new pqSignalsBlocker(self))
   {
     this->Ui.setupUi(self);
     this->Ui.mainLayout->setMargin(pqPropertiesPanel::suggestedMargin());
@@ -160,10 +248,24 @@ public:
 
     QObject::connect(this->ChoosePresetReaction.data(), SIGNAL(presetApplied(const QString&)), self,
       SLOT(presetApplied()));
+    QObject::connect(this->ChoosePresetReaction.data(), &pqChooseColorPresetReaction::presetApplied,
+      [=](const QString& presetName) {
+        auto& defaultPresetsComboBox = this->Ui.DefaultPresetsComboBox;
+        int newIndex = defaultPresetsComboBox->findText(presetName);
+        this->SignalsBlocker->blockSignals(true);
+        defaultPresetsComboBox->blockSignals(true);
+        defaultPresetsComboBox->setCurrentIndex(newIndex != -1 ? newIndex : 0);
+        defaultPresetsComboBox->blockSignals(false);
+        this->SignalsBlocker->blockSignals(false);
+      });
 
     this->HistogramTimer.setSingleShot(true);
     this->HistogramTimer.setInterval(1);
     QObject::connect(&this->HistogramTimer, SIGNAL(timeout()), self, SLOT(realShowDataHistogram()));
+
+    this->Histogram2DTimer.setSingleShot(true);
+    this->Histogram2DTimer.setInterval(1);
+    QObject::connect(&this->Histogram2DTimer, SIGNAL(timeout()), self, SLOT(realShow2DHistogram()));
   }
 
   void render()
@@ -208,10 +310,38 @@ pqColorOpacityEditorWidget::pqColorOpacityEditorWidget(
   QObject::connect(&pqActiveObjects::instance(), SIGNAL(viewChanged(pqView*)), this,
     SLOT(representationOrViewChanged()));
 
+  ui.DefaultPresetsComboBox->setItemDelegate(new pqColorMapDelegate(ui.DefaultPresetsComboBox));
+  this->updateDefaultPresetsList();
+
+  QObject::connect(
+    ui.DefaultPresetsComboBox, &QComboBox::currentTextChanged, [=](const QString& presetName) {
+      if (ui.DefaultPresetsComboBox->currentIndex() == 0)
+      {
+        return;
+      }
+      this->Internals->SignalsBlocker->blockSignals(true);
+      bool presetApplied =
+        vtkSMTransferFunctionProxy::ApplyPreset(smproxy, presetName.toStdString().c_str());
+      this->Internals->SignalsBlocker->blockSignals(false);
+      if (presetApplied)
+      {
+        Q_EMIT this->presetApplied();
+      }
+    });
+
+  auto groupManager = qobject_cast<pqPresetGroupsManager*>(
+    pqApplicationCore::instance()->manager("PRESET_GROUP_MANAGER"));
+  this->connect(groupManager, &pqPresetGroupsManager::groupsUpdated, this,
+    &pqColorOpacityEditorWidget::updateDefaultPresetsList);
+
   // To avoid color editor widget movement when hidden
-  QSizePolicy sp_retain = ui.OpacityEditor->sizePolicy();
-  sp_retain.setRetainSizeWhenHidden(true);
-  ui.OpacityEditor->setSizePolicy(sp_retain);
+  // QSizePolicy sp_retain = ui.OpacityEditor->sizePolicy();
+  // sp_retain.setRetainSizeWhenHidden(true);
+  // ui.OpacityEditor->setSizePolicy(sp_retain);
+
+  // QSizePolicy sp2d_retain = ui.Transfer2DEditor->sizePolicy();
+  // sp2d_retain.setRetainSizeWhenHidden(true);
+  // ui.Transfer2DEditor->setSizePolicy(sp2d_retain);
 
   QObject::connect(ui.OpacityEditor, SIGNAL(currentPointChanged(vtkIdType)), this,
     SLOT(opacityCurrentChanged(vtkIdType)));
@@ -253,8 +383,18 @@ pqColorOpacityEditorWidget::pqColorOpacityEditorWidget(
 
   QObject::connect(ui.ChoosePreset, SIGNAL(clicked()), this, SLOT(choosePreset()));
   QObject::connect(ui.SaveAsPreset, SIGNAL(clicked()), this, SLOT(saveAsPreset()));
-  QObject::connect(
-    ui.ComputeDataHistogram, SIGNAL(clicked()), this, SLOT(showDataHistogramClicked()));
+  QObject::connect(ui.ComputeDataHistogram, &QAbstractButton::clicked, this, [=]() {
+    if (ui.Use2DTransferFunction->isChecked())
+    {
+      this->show2DHistogram(true);
+    }
+    else
+    {
+      this->showDataHistogramClicked(true);
+    }
+  });
+  QObject::connect(ui.ChooseBoxColor, &QAbstractButton::clicked, this,
+    &pqColorOpacityEditorWidget::chooseBoxColorAlpha);
   QObject::connect(ui.AdvancedButton, SIGNAL(clicked()), this, SLOT(updatePanel()));
 
   QObject::connect(
@@ -271,6 +411,12 @@ pqColorOpacityEditorWidget::pqColorOpacityEditorWidget(
   QObject::connect(
     ui.CurrentDataValue, SIGNAL(textChangedAndEditingFinished()), this, SLOT(currentDataEdited()));
 
+  // if the user edits the 2D transfer function item
+  QObject::connect(
+    ui.Transfer2DEditor, SIGNAL(transferFunctionModified()), this, SLOT(transfer2DChanged()));
+  QObject::connect(ui.Transfer2DEditor, SIGNAL(transferFunctionModified()), this,
+    SIGNAL(transfer2DBoxesChanged()));
+
   vtkSMProperty* smproperty = smgroup->GetProperty("XRGBPoints");
   if (smproperty)
   {
@@ -363,13 +509,41 @@ pqColorOpacityEditorWidget::pqColorOpacityEditorWidget(
     ui.DataHistogramNumberOfBins->hide();
   }
 
+  ui.Transfer2DEditor->hide();
+  smproperty = smgroup->GetProperty("TransferFunction2D");
+  if (smproperty)
+  {
+    this->addPropertyLink(
+      this, "transferFunction2DProxy", SIGNAL(transferFunction2DProxyChanged()), smproperty);
+  }
+
+  smproperty = smgroup->GetProperty("Use2DTransferFunction");
+  if (smproperty)
+  {
+    this->addPropertyLink(
+      this, "use2DTransferFunction", SIGNAL(use2DTransferFunctionChanged()), smproperty);
+    QObject::connect(ui.Use2DTransferFunction, &QCheckBox::toggled, this,
+      &pqColorOpacityEditorWidget::show2DHistogram);
+  }
+  else
+  {
+    ui.Use2DTransferFunction->hide();
+  }
+
   // Manage histogram computation if enabled
   // When creating the widget, we consider that the cost of recomputing the histogram table
   // can be paid systematically
   // We hide it to avoid seeing it before the timer ends and triggers the actual computation
-  this->updateDataHistogramEnableState();
-  this->Internals->Ui.OpacityEditor->setVisible(!ui.ShowDataHistogram->isChecked());
-  this->showDataHistogramClicked(ui.ShowDataHistogram->isChecked());
+  if (this->Internals->Ui.Use2DTransferFunction->isChecked())
+  {
+    this->show2DHistogram(true);
+  }
+  else
+  {
+    this->updateDataHistogramEnableState();
+    this->Internals->Ui.OpacityEditor->setVisible(!ui.ShowDataHistogram->isChecked());
+    this->showDataHistogramClicked(ui.ShowDataHistogram->isChecked());
+  }
 
   // if proxy has a property named IndexedLookup, we hide this entire widget
   // when IndexedLookup is ON.
@@ -404,6 +578,14 @@ pqColorOpacityEditorWidget::pqColorOpacityEditorWidget(
       settings->value("showAdvancedPropertiesColorOpacityEditorWidget", false).toBool());
   }
 
+  // Connect with the SignalsBlocker in between to be able to call QObject::blockSignals on it
+  // because otherwise no QObject would be emiting a signal, meaning it could not be blocked
+  // to avoid loops
+  this->Internals->TransferFunctionModifiedConnector->Connect(
+    stc, vtkCommand::ModifiedEvent, this->Internals->SignalsBlocker.get(), SIGNAL(passSignal()));
+  QObject::connect(this->Internals->SignalsBlocker.get(), &pqSignalsBlocker::passSignal, this,
+    &pqColorOpacityEditorWidget::resetColorMapComboBox);
+
   this->updateCurrentData();
   this->updatePanel();
 }
@@ -454,7 +636,7 @@ void pqColorOpacityEditorWidget::setScalarOpacityFunctionProxy(pqSMProxy sofProx
   if (internals.ScalarOpacityFunctionProxy)
   {
     pqDataRepresentation* repr = pqActiveObjects::instance().activeRepresentation();
-    vtkSMPVRepresentationProxy* proxy = static_cast<vtkSMPVRepresentationProxy*>(repr->getProxy());
+    vtkSMPVRepresentationProxy* proxy = vtkSMPVRepresentationProxy::SafeDownCast(repr->getProxy());
 
     // When representation changes, we have to initialize the opacity widget when
     // "MultiComponentsMapping" is modified
@@ -490,7 +672,7 @@ void pqColorOpacityEditorWidget::setScalarOpacityFunctionProxy(pqSMProxy sofProx
       internals.ScalarOpacityFunctionProxy,
       internals.ScalarOpacityFunctionProxy->GetProperty("UseLogScale"));
   }
-  ui.OpacityEditor->setVisible(newSofProxy != nullptr);
+  ui.OpacityEditor->setVisible(newSofProxy != nullptr && !ui.Use2DTransferFunction->isChecked());
 }
 
 //-----------------------------------------------------------------------------
@@ -499,6 +681,94 @@ pqSMProxy pqColorOpacityEditorWidget::scalarOpacityFunctionProxy() const
   return this->Internals->ScalarOpacityFunctionProxy.GetPointer();
 }
 
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::setTransferFunction2DProxy(pqSMProxy tf2dProxy)
+{
+  pqInternals& internals = (*this->Internals);
+  // Ui::ColorOpacityEditorWidget& ui = internals.Ui;
+
+  vtkSMProxy* newtf2dProxy = nullptr;
+  vtkPVTransferFunction2D* tf2d =
+    tf2dProxy ? vtkPVTransferFunction2D::SafeDownCast(tf2dProxy->GetClientSideObject()) : nullptr;
+  if (tf2dProxy && tf2d)
+  {
+    newtf2dProxy = tf2dProxy;
+  }
+  if (internals.TransferFunction2DProxy == newtf2dProxy)
+  {
+    return;
+  }
+  if (internals.TransferFunction2DProxy)
+  {
+    // cleanup old property links.
+    this->links().removePropertyLink(this, "transfer2DBoxes", SIGNAL(transfer2DBoxesChanged()),
+      internals.TransferFunction2DProxy, internals.TransferFunction2DProxy->GetProperty("Boxes"));
+  }
+  if (internals.TransferFunction2DRepProxy)
+  {
+    this->links().removePropertyLink(this, "use2DTransferFunction",
+      SIGNAL(use2DTransferFunctionChanged()), internals.TransferFunction2DRepProxy,
+      internals.TransferFunction2DRepProxy->GetProperty("UseTransfer2D"));
+  }
+  internals.TransferFunction2DProxy = newtf2dProxy;
+  if (internals.TransferFunction2DProxy)
+  {
+    pqDataRepresentation* repr = pqActiveObjects::instance().activeRepresentation();
+    vtkSMPVRepresentationProxy* reprProxy =
+      vtkSMPVRepresentationProxy::SafeDownCast(repr->getProxy());
+
+    this->Internals->TransferFunction2DConnector->Disconnect();
+    vtkSMProperty* colorArray2Property = reprProxy->GetProperty("ColorArray2Name");
+    if (colorArray2Property)
+    {
+      this->Internals->TransferFunction2DConnector->Connect(colorArray2Property,
+        vtkCommand::ModifiedEvent, this, SLOT(updateTransferFunction2DProxy()));
+    }
+    vtkSMProperty* gradProperty = reprProxy->GetProperty("UseGradientForTransfer2D");
+    if (gradProperty)
+    {
+      this->Internals->TransferFunction2DConnector->Connect(
+        gradProperty, vtkCommand::ModifiedEvent, this, SLOT(updateTransferFunction2DProxy()));
+    }
+
+    this->initializeTransfer2DEditor(tf2d);
+
+    // add new property links.
+    this->links().addPropertyLink(this, "transfer2DBoxes", SIGNAL(transfer2DBoxesChanged()),
+      internals.TransferFunction2DProxy, internals.TransferFunction2DProxy->GetProperty("Boxes"));
+    vtkSMProperty* useTF2DProperty = reprProxy->GetProperty("UseTransfer2D");
+    if (useTF2DProperty)
+    {
+      internals.TransferFunction2DRepProxy = reprProxy;
+      this->links().addPropertyLink(this, "use2DTransferFunction",
+        SIGNAL(use2DTransferFunctionChanged()), internals.TransferFunction2DRepProxy,
+        useTF2DProperty);
+    }
+  }
+}
+
+//-----------------------------------------------------------------------------
+pqSMProxy pqColorOpacityEditorWidget::transferFunction2DProxy() const
+{
+  return this->Internals->TransferFunction2DProxy.GetPointer();
+}
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::updateTransferFunction2DProxy()
+{
+  pqDataRepresentation* repr = pqActiveObjects::instance().activeRepresentation();
+  vtkSMPVRepresentationProxy* reprProxy =
+    vtkSMPVRepresentationProxy::SafeDownCast(repr->getProxy());
+  vtkSMProperty* colorArrayProperty = reprProxy->GetProperty("ColorArrayName");
+  if (colorArrayProperty)
+  {
+    vtkSMPropertyHelper colorArrayHelper(colorArrayProperty);
+    std::string arrayName(colorArrayHelper.GetInputArrayNameToProcess());
+    int association = colorArrayHelper.GetInputArrayAssociation();
+    vtkSMPVRepresentationProxy::SetScalarColoring(reprProxy, arrayName.c_str(), association);
+  }
+}
+
 //-----------------------------------------------------------------------------
 void pqColorOpacityEditorWidget::updateIndexedLookupState()
 {
@@ -514,7 +784,7 @@ void pqColorOpacityEditorWidget::multiComponentsMappingChanged(vtkObject* vtkNot
   unsigned long vtkNotUsed(event), void* clientData, void* vtkNotUsed(callData))
 {
   pqDataRepresentation* repr = pqActiveObjects::instance().activeRepresentation();
-  vtkSMPVRepresentationProxy* proxy = static_cast<vtkSMPVRepresentationProxy*>(repr->getProxy());
+  vtkSMPVRepresentationProxy* proxy = vtkSMPVRepresentationProxy::SafeDownCast(repr->getProxy());
 
   if (proxy->GetVolumeIndependentRanges())
   {
@@ -540,7 +810,7 @@ void pqColorOpacityEditorWidget::initializeOpacityEditor(vtkPiecewiseFunction* p
 {
   Ui::ColorOpacityEditorWidget& ui = this->Internals->Ui;
   pqDataRepresentation* repr = pqActiveObjects::instance().activeRepresentation();
-  vtkSMPVRepresentationProxy* proxy = static_cast<vtkSMPVRepresentationProxy*>(repr->getProxy());
+  vtkSMPVRepresentationProxy* proxy = vtkSMPVRepresentationProxy::SafeDownCast(repr->getProxy());
   vtkScalarsToColors* stc = nullptr;
   vtkSMProperty* separateProperty = proxy->GetProperty("UseSeparateColorMap");
   bool sepEnabled = vtkSMPropertyHelper(separateProperty).GetAsInt() != 0;
@@ -860,6 +1130,7 @@ void pqColorOpacityEditorWidget::resetRangeToData()
   // passing in nullptr ensure pqResetScalarRangeReaction simply uses active representation.
   if (pqResetScalarRangeReaction::resetScalarRangeToData(nullptr))
   {
+    this->setHistogramOutdated();
     this->Internals->render();
     Q_EMIT this->changeFinished();
   }
@@ -930,6 +1201,7 @@ void pqColorOpacityEditorWidget::resetRangeToCustom()
 
   if (changed)
   {
+    this->setHistogramOutdated();
     this->Internals->render();
     Q_EMIT this->changeFinished();
   }
@@ -963,6 +1235,36 @@ void pqColorOpacityEditorWidget::presetApplied()
   Q_EMIT this->xvmsPointsChanged();
 }
 
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::updateDefaultPresetsList()
+{
+  auto& defaultPresetsComboBox = this->Internals->Ui.DefaultPresetsComboBox;
+  auto transferFunctionPresets = vtkSMTransferFunctionPresets::GetInstance();
+  auto groupManager = qobject_cast<pqPresetGroupsManager*>(
+    pqApplicationCore::instance()->manager("PRESET_GROUP_MANAGER"));
+  QString const currentPreset = defaultPresetsComboBox->currentText();
+  defaultPresetsComboBox->blockSignals(true);
+  defaultPresetsComboBox->clear();
+  // QComboBox::setPlaceHolder is a Qt5.15 function, so until the
+  // minimum version is upgraded, we have to do this workaround.
+  defaultPresetsComboBox->addItem("Select a color map from default presets", -1);
+  QStandardItemModel* model = qobject_cast<QStandardItemModel*>(defaultPresetsComboBox->model());
+  QStandardItem* item = model->item(0);
+  // Disable the "placeholder"
+  item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
+  for (unsigned int index = 0; index < transferFunctionPresets->GetNumberOfPresets(); ++index)
+  {
+    auto presetName = QString::fromStdString(transferFunctionPresets->GetPresetName(index));
+    if (groupManager->presetRankInGroup(presetName, "Default") != -1)
+    {
+      defaultPresetsComboBox->addItem(presetName, index);
+    }
+  }
+  int currentPresetIndex = defaultPresetsComboBox->findText(currentPreset);
+  defaultPresetsComboBox->setCurrentIndex(currentPresetIndex == -1 ? 0 : currentPresetIndex);
+  defaultPresetsComboBox->blockSignals(false);
+}
+
 //-----------------------------------------------------------------------------
 void pqColorOpacityEditorWidget::saveAsPreset()
 {
@@ -999,10 +1301,20 @@ void pqColorOpacityEditorWidget::saveAsPreset()
 
   std::string presetName;
   auto presets = vtkSMTransferFunctionPresets::GetInstance();
-  presetName = presets->AddUniquePreset(preset, qPrintable(ui.presetName->text()));
+  presetName = presets->AddUniquePreset(preset, ui.presetName->text().toUtf8().data());
+  auto groupManager = qobject_cast<pqPresetGroupsManager*>(
+    pqApplicationCore::instance()->manager("PRESET_GROUP_MANAGER"));
+  groupManager->addToGroup("Default", QString::fromStdString(presetName));
+  groupManager->addToGroup("User", QString::fromStdString(presetName));
   this->choosePreset(presetName.c_str());
 }
 
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::resetColorMapComboBox()
+{
+  this->Internals->Ui.DefaultPresetsComboBox->setCurrentIndex(0);
+}
+
 //-----------------------------------------------------------------------------
 bool pqColorOpacityEditorWidget::showDataHistogram() const
 {
@@ -1042,6 +1354,53 @@ void pqColorOpacityEditorWidget::setDataHistogramNumberOfBins(int val)
   ui.DataHistogramNumberOfBins->setValue(val);
 }
 
+//-----------------------------------------------------------------------------
+bool pqColorOpacityEditorWidget::use2DTransferFunction() const
+{
+  return this->Internals->Ui.Use2DTransferFunction->isChecked();
+}
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::setUse2DTransferFunction(bool val)
+{
+  Ui::ColorOpacityEditorWidget& ui = this->Internals->Ui;
+  ui.Use2DTransferFunction->setChecked(val);
+}
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::show2DHistogram(bool show)
+{
+  if (show)
+  {
+    this->Internals->Histogram2DTimer.start();
+  }
+  else
+  {
+    this->Internals->Ui.Transfer2DEditor->setHistogram(nullptr);
+  }
+  Ui::ColorOpacityEditorWidget& ui = this->Internals->Ui;
+  ui.ColorEditor->setVisible(!show);
+  ui.ColorTable->setEnabled(!show);
+  ui.OpacityTable->setEnabled(!show);
+  ui.OpacityEditor->setVisible(!show);
+  ui.UseLogScale->setEnabled(!show);
+  ui.UseLogScaleOpacity->setEnabled(!show);
+  ui.UseOpacityControlPointsFreehandDrawing->setEnabled(!show);
+  ui.EnableOpacityMapping->setEnabled(!show);
+  ui.ChoosePreset->setEnabled(!show);
+  ui.SaveAsPreset->setEnabled(!show);
+  ui.InvertTransferFunctions->setEnabled(!show);
+  ui.ChooseBoxColor->setVisible(show);
+
+  ui.AutomaticDataHistogramComputation->setEnabled(show);
+  ui.Transfer2DEditor->setVisible(show);
+  ui.ShowDataHistogram->setEnabled(!show);
+  ui.DataHistogramNumberOfBins->setEnabled(show);
+  ui.ComputeDataHistogram->setEnabled(!ui.AutomaticDataHistogramComputation->isChecked());
+
+  Q_EMIT this->use2DTransferFunctionChanged();
+}
+
 //-----------------------------------------------------------------------------
 void pqColorOpacityEditorWidget::showDataHistogramClicked(bool showDataHistogram)
 {
@@ -1071,8 +1430,8 @@ void pqColorOpacityEditorWidget::realShowDataHistogram()
     // No cache or we are outdated, compute the histogram
     this->Internals->Ui.ComputeDataHistogram->clear();
     vtkSMTransferFunctionProxy* tfProxy = vtkSMTransferFunctionProxy::SafeDownCast(this->proxy());
-    histoTable =
-      tfProxy->ComputeDataHistogramTable(this->Internals->Ui.DataHistogramNumberOfBins->value());
+    Q_ASSERT(tfProxy);
+    histoTable = tfProxy->ComputeDataHistogramTable(this->dataHistogramNumberOfBins());
     this->Internals->Ui.OpacityEditor->setHistogramTable(histoTable);
 
     // Add all consumers, even non-visible, to the consumer connnector
@@ -1095,12 +1454,58 @@ void pqColorOpacityEditorWidget::realShowDataHistogram()
   this->Internals->Ui.OpacityEditor->setHistogramTable(histoTable);
 }
 
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::realShow2DHistogram()
+{
+  this->Internals->Ui.Transfer2DEditor->show();
+
+  vtkImageData* hist2D =
+    vtkSMTransferFunction2DProxy::GetHistogram2DCache(this->transferFunction2DProxy());
+  if (!hist2D || this->Internals->HistogramOutdated)
+  {
+    this->Internals->Ui.ComputeDataHistogram->clear();
+    vtkSMTransferFunction2DProxy* tfProxy =
+      vtkSMTransferFunction2DProxy::SafeDownCast(this->transferFunction2DProxy());
+    Q_ASSERT(tfProxy);
+    hist2D = tfProxy->ComputeDataHistogram2D(this->dataHistogramNumberOfBins());
+    this->Internals->Ui.Transfer2DEditor->setHistogram(hist2D);
+
+    // Add all consumers, even non-visible, to the consumer connnector
+    // so the histogram can be set outdated correctly
+    this->Internals->ConsumerConnector->Disconnect();
+    std::set<vtkSMProxy*> usedProxy;
+    for (unsigned int cc = 0, max = tfProxy->GetNumberOfConsumers(); cc < max; ++cc)
+    {
+      vtkSMProxy* proxy = tfProxy->GetConsumerProxy(cc);
+      proxy = proxy ? proxy->GetTrueParentProxy() : nullptr;
+      vtkSMPVRepresentationProxy* consumer = vtkSMPVRepresentationProxy::SafeDownCast(proxy);
+      if (consumer && usedProxy.find(consumer) == usedProxy.end())
+      {
+        this->Internals->ConsumerConnector->Connect(consumer->GetProperty("Visibility"),
+          vtkCommand::ModifiedEvent, this, SLOT(setHistogramOutdated()));
+        usedProxy.insert(consumer);
+      }
+    }
+  }
+  else
+  {
+    this->Internals->Ui.Transfer2DEditor->setHistogram(hist2D);
+  }
+}
+
 //-----------------------------------------------------------------------------
 void pqColorOpacityEditorWidget::automaticDataHistogramComputationClicked(bool val)
 {
   if (val)
   {
-    this->showDataHistogramClicked(true);
+    if (this->Internals->Ui.Use2DTransferFunction->isChecked())
+    {
+      this->show2DHistogram(true);
+    }
+    else
+    {
+      this->showDataHistogramClicked(true);
+    }
   }
   this->updateDataHistogramEnableState();
   Q_EMIT this->automaticDataHistogramComputationChanged();
@@ -1119,7 +1524,14 @@ void pqColorOpacityEditorWidget::setHistogramOutdated()
   this->Internals->HistogramOutdated = true;
   if (this->Internals->Ui.AutomaticDataHistogramComputation->isChecked())
   {
-    this->showDataHistogramClicked(this->showDataHistogram());
+    if (this->Internals->Ui.Use2DTransferFunction->isChecked())
+    {
+      this->show2DHistogram(true);
+    }
+    else
+    {
+      this->showDataHistogramClicked(this->showDataHistogram());
+    }
   }
   else
   {
@@ -1130,6 +1542,10 @@ void pqColorOpacityEditorWidget::setHistogramOutdated()
 //-----------------------------------------------------------------------------
 void pqColorOpacityEditorWidget::updateDataHistogramEnableState()
 {
+  if (this->Internals->Ui.Use2DTransferFunction->isChecked())
+  {
+    return;
+  }
   bool showDataHistogram = this->Internals->Ui.ShowDataHistogram->isChecked();
   this->Internals->Ui.AutomaticDataHistogramComputation->setEnabled(showDataHistogram);
   this->Internals->Ui.DataHistogramNumberOfBins->setEnabled(showDataHistogram);
@@ -1146,6 +1562,92 @@ void pqColorOpacityEditorWidget::onRangeHandlesRangeChanged(double rangeMin, dou
 
   vtkSMTransferFunctionProxy::RescaleTransferFunction(colorProxy, range);
   vtkSMTransferFunctionProxy::RescaleTransferFunction(opacityProxy, range);
+  vtkSMTransferFunction2DProxy::RescaleTransferFunction(
+    this->transferFunction2DProxy(), range[0], range[1], range[0], range[1]);
   this->Internals->render();
   Q_EMIT this->changeFinished();
 }
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::initializeTransfer2DEditor(vtkPVTransferFunction2D* tf2d)
+{
+  Ui::ColorOpacityEditorWidget& ui = this->Internals->Ui;
+  ui.Transfer2DEditor->initialize(tf2d);
+}
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::transfer2DChanged()
+{
+  this->Internals->render();
+}
+
+//-----------------------------------------------------------------------------
+QList<QVariant> pqColorOpacityEditorWidget::transfer2DBoxes() const
+{
+  vtkPVTransferFunction2D* tf2d = vtkPVTransferFunction2D::SafeDownCast(
+    this->Internals->TransferFunction2DProxy->GetClientSideObject());
+  QList<QVariant> values;
+  if (tf2d == nullptr || !this->Internals->Ui.Transfer2DEditor->isInitialized())
+  {
+    return values;
+  }
+  std::vector<vtkSmartPointer<vtkPVTransferFunction2DBox>> boxes = tf2d->GetBoxes();
+  for (auto it = boxes.cbegin(); it < boxes.cend(); ++it)
+  {
+    vtkPVTransferFunction2DBox* box = (*it);
+    if (!box)
+    {
+      continue;
+    }
+    const vtkRectd r = box->GetBox();
+    for (int j = 0; j < 4; ++j)
+    {
+      values.push_back(r[j]);
+    }
+    const double* color = box->GetColor();
+    for (int j = 0; j < 4; ++j)
+    {
+      values.push_back(color[j]);
+    }
+  }
+  return values;
+}
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::setTransfer2DBoxes(const QList<QVariant>& values)
+{
+  Q_UNUSED(values);
+  // Since the vtkPVTransferFunction2D connected to the widget is directly obtained
+  // from the proxy, we don't need to do anything here. The widget will be
+  // updated when the proxy updates.
+}
+
+//-----------------------------------------------------------------------------
+void pqColorOpacityEditorWidget::chooseBoxColorAlpha()
+{
+  Ui::ColorOpacityEditorWidget& ui = this->Internals->Ui;
+  vtkTransferFunctionChartHistogram2D* chart =
+    vtkTransferFunctionChartHistogram2D::SafeDownCast(ui.Transfer2DEditor->chart());
+  if (!chart->IsInitialized())
+  {
+    return;
+  }
+  auto activeBox = chart->GetActiveBox();
+  if (!activeBox)
+  {
+    vtkGenericWarningMacro("No transfer function box selected. Click on a box to select it.");
+    return;
+  }
+  double color[4];
+  activeBox->GetBoxColor(color);
+
+  QColor initialColor;
+  initialColor.setRgbF(color[0], color[1], color[2], color[3]);
+  // Avoid using native color dialog because QtTesting fails to choose color on mac
+  QColor c = QColorDialog::getColor(initialColor, this, tr("Choose box color"),
+    QColorDialog::ShowAlphaChannel | QColorDialog::DontUseNativeDialog);
+  if (c.isValid())
+  {
+    chart->SetActiveBoxColorAlpha(c.redF(), c.greenF(), c.blueF(), c.alphaF());
+  }
+}
