@@ -31,6 +31,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ========================================================================*/
 #include "pqColorPaletteSelectorWidget.h"
 
+#include "vtkLogger.h"
 #include "vtkPVProxyDefinitionIterator.h"
 #include "vtkSMProxy.h"
 #include "vtkSMProxyDefinitionManager.h"
@@ -41,7 +42,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QComboBox>
 #include <QVBoxLayout>
 
+#include <array>
 #include <cassert>
+#include <string>
 
 //-----------------------------------------------------------------------------
 pqColorPaletteSelectorWidget::pqColorPaletteSelectorWidget(
@@ -57,16 +60,39 @@ pqColorPaletteSelectorWidget::pqColorPaletteSelectorWidget(
   vtkSMSessionProxyManager* pxm = smproxy->GetSessionProxyManager();
   vtkSMProxyDefinitionManager* pdmgr = pxm->GetProxyDefinitionManager();
 
+  QComboBox* cbbox = new QComboBox(this);
+  cbbox->setObjectName("ComboBox");
+
+  // Palette ordering / ban list can be found in issue #20707
+  std::array<std::string, 7> mainPalettes = { "BlueGrayBackground", "WarmGrayBackground",
+    "NeutralGrayBackground", "LightGrayBackground", "WhiteBackground", "BlackBackground",
+    "GradientBackground" };
+
+  for (const std::string& str : mainPalettes)
+  {
+    if (vtkSMProxy* prototype = pxm->GetPrototypeProxy("palettes", str.c_str()))
+    {
+      cbbox->addItem(prototype->GetXMLLabel(), str.c_str());
+    }
+    else
+    {
+      vtkLog(WARNING, "Missing palette: " << str.c_str());
+    }
+  }
+
   assert(pdmgr);
   vtkSmartPointer<vtkPVProxyDefinitionIterator> iter;
   iter.TakeReference(pdmgr->NewSingleGroupIterator("palettes"));
 
-  QComboBox* cbbox = new QComboBox(this);
-  cbbox->setObjectName("ComboBox");
+  // If there were any other available palettes, we append them in alphabetical order.
   for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
   {
     vtkSMProxy* prototype = pxm->GetPrototypeProxy("palettes", iter->GetProxyName());
-    cbbox->addItem(prototype->GetXMLLabel(), prototype->GetXMLName());
+    if (std::find(mainPalettes.cbegin(), mainPalettes.cend(), iter->GetProxyName()) ==
+      mainPalettes.cend())
+    {
+      cbbox->addItem(prototype->GetXMLLabel(), prototype->GetXMLName());
+    }
   }
 
   if (cbbox->count() > 0)
@@ -98,9 +124,7 @@ pqColorPaletteSelectorWidget::pqColorPaletteSelectorWidget(
 }
 
 //-----------------------------------------------------------------------------
-pqColorPaletteSelectorWidget::~pqColorPaletteSelectorWidget()
-{
-}
+pqColorPaletteSelectorWidget::~pqColorPaletteSelectorWidget() = default;
 
 //-----------------------------------------------------------------------------
 QString pqColorPaletteSelectorWidget::paletteName() const
@@ -135,7 +159,7 @@ void pqColorPaletteSelectorWidget::loadPalette(int index)
   QString name = this->ComboBox->itemData(index).toString();
 
   vtkSMSessionProxyManager* pxm = smproxy->GetSessionProxyManager();
-  vtkSMProxy* paletteProxy = pxm->GetPrototypeProxy("palettes", name.toLocal8Bit().data());
+  vtkSMProxy* paletteProxy = pxm->GetPrototypeProxy("palettes", name.toUtf8().data());
   assert(paletteProxy);
 
   smproxy->Copy(paletteProxy);
