@@ -30,29 +30,29 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =========================================================================*/
 
-#ifndef _pqColorSelectorPropertyWidget_h
-#define _pqColorSelectorPropertyWidget_h
+#ifndef pqColorSelectorPropertyWidget_h
+#define pqColorSelectorPropertyWidget_h
 
 #include "pqApplicationComponentsModule.h"
 
 #include "pqPropertyWidget.h"
 
 /**
-* A property widget with a tool button for selecting a single color.
-*
-* To use this widget for a property add the 'panel_widget="color_selector"' attribute
-* to the property's XML. To use this widget for a property whose color might possibly
-* come from the global color palette, add the 'panel_widget="color_selector_with_palette"'
-* attribute to the property's XML.
-*/
+ * A property widget with a tool button for selecting a single color.
+ *
+ * To use this widget for a property add the 'panel_widget="color_selector"' attribute
+ * to the property's XML. To use this widget for a property whose color might possibly
+ * come from the global color palette, add the 'panel_widget="color_selector_with_palette"'
+ * attribute to the property's XML.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqColorSelectorPropertyWidget : public pqPropertyWidget
 {
   Q_OBJECT
 
 public:
   pqColorSelectorPropertyWidget(
-    vtkSMProxy* proxy, vtkSMProperty* property, bool withPalette, QWidget* parent = 0);
+    vtkSMProxy* proxy, vtkSMProperty* property, bool withPalette, QWidget* parent = nullptr);
   ~pqColorSelectorPropertyWidget() override;
 };
 
-#endif // _pqColorSelectorPropertyWidget_h
+#endif // pqColorSelectorPropertyWidget_h
