@@ -74,7 +74,7 @@ public:
 
   const QString& settingsKey() const { return this->FullKey; }
 
-  const QKeySequence keySequence() const { return this->KeySequence; }
+  QKeySequence keySequence() const { return this->KeySequence; }
 
   void setKeySequence(const QKeySequence& shortcut)
   {
@@ -181,7 +181,7 @@ public:
     this->RootItem = treeItem;
   }
 
-  ~pqCustomizeShortcutsModel() { delete this->RootItem; }
+  ~pqCustomizeShortcutsModel() override { delete this->RootItem; }
 
   QModelIndex index(int row, int column, const QModelIndex& parentIndex) const override
   {
@@ -369,7 +369,7 @@ public:
   {
   }
 
-  ~FilterLeavesProxyModel() = default;
+  ~FilterLeavesProxyModel() override = default;
 
   bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const override
   {
@@ -441,15 +441,13 @@ pqCustomizeShortcutsDialog::pqCustomizeShortcutsDialog(QWidget* parentObject)
   this->onSelectionChanged();
 }
 
-pqCustomizeShortcutsDialog::~pqCustomizeShortcutsDialog()
-{
-}
+pqCustomizeShortcutsDialog::~pqCustomizeShortcutsDialog() = default;
 
 void pqCustomizeShortcutsDialog::onEditingFinished()
 {
   auto selectionModel = this->Internals->Ui.treeView->selectionModel();
   auto selectedList = selectionModel->selectedRows(1);
-  if (selectedList.size() == 0)
+  if (selectedList.empty())
   {
     return;
   }
@@ -475,7 +473,7 @@ void pqCustomizeShortcutsDialog::onSelectionChanged()
   };
   auto selectionModel = this->Internals->Ui.treeView->selectionModel();
   auto selectedList = selectionModel->selectedRows(1);
-  if (selectedList.size() == 0)
+  if (selectedList.empty())
   {
     setEnabled(false);
     return;
@@ -512,7 +510,7 @@ void pqCustomizeShortcutsDialog::onClearShortcut()
 {
   auto selectionModel = this->Internals->Ui.treeView->selectionModel();
   auto selectedList = selectionModel->selectedRows(1);
-  if (selectedList.size() == 0)
+  if (selectedList.empty())
   {
     return;
   }
@@ -532,7 +530,7 @@ void pqCustomizeShortcutsDialog::onResetShortcut()
 {
   auto selectionModel = this->Internals->Ui.treeView->selectionModel();
   auto selectedList = selectionModel->selectedRows(1);
-  if (selectedList.size() == 0)
+  if (selectedList.empty())
   {
     return;
   }
