@@ -32,7 +32,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqCylinderPropertyWidget.h"
 #include "ui_pqCylinderPropertyWidget.h"
 
+#include "pqActiveObjects.h"
 #include "pqRenderView.h"
+
 #include "vtkCamera.h"
 #include "vtkMath.h"
 #include "vtkSMNewWidgetRepresentationProxy.h"
@@ -153,13 +155,12 @@ pqCylinderPropertyWidget::pqCylinderPropertyWidget(
   this->AdvancedPropertyWidgets[0] = ui.scaling;
   this->AdvancedPropertyWidgets[1] = ui.outlineTranslation;
 
-  this->placeWidget();
+  QObject::connect(&pqActiveObjects::instance(), &pqActiveObjects::dataUpdated, this,
+    &pqCylinderPropertyWidget::placeWidget);
 }
 
 //-----------------------------------------------------------------------------
-pqCylinderPropertyWidget::~pqCylinderPropertyWidget()
-{
-}
+pqCylinderPropertyWidget::~pqCylinderPropertyWidget() = default;
 
 //-----------------------------------------------------------------------------
 void pqCylinderPropertyWidget::placeWidget()
@@ -233,7 +234,7 @@ void pqCylinderPropertyWidget::resetCameraToAxis()
 void pqCylinderPropertyWidget::useCameraAxis()
 {
   vtkSMRenderViewProxy* viewProxy =
-    this->view() ? vtkSMRenderViewProxy::SafeDownCast(this->view()->getProxy()) : NULL;
+    this->view() ? vtkSMRenderViewProxy::SafeDownCast(this->view()->getProxy()) : nullptr;
   if (viewProxy)
   {
     vtkCamera* camera = viewProxy->GetActiveCamera();
