@@ -38,22 +38,22 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqPipelineSource;
 
 /**
-* @ingroup Behaviors
-* pqDataTimeStepBehavior ensures that whenever a file is opened with more
-* than 1 timestep, the application time >= the time for the last timestep.
-*/
+ * @ingroup Behaviors
+ * pqDataTimeStepBehavior ensures that whenever a file is opened with more
+ * than 1 timestep, the application time >= the time for the last timestep.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqDataTimeStepBehavior : public QObject
 {
   Q_OBJECT
   typedef QObject Superclass;
 
 public:
-  pqDataTimeStepBehavior(QObject* parent = 0);
+  pqDataTimeStepBehavior(QObject* parent = nullptr);
 
 protected Q_SLOTS:
   /**
-  * called when a reader is created.
-  */
+   * called when a reader is created.
+   */
   void onReaderCreated(pqPipelineSource* reader);
 
 private:
