@@ -42,18 +42,18 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqServer;
 
 /**
-* @ingroup Behaviors
-* pqDefaultViewBehavior ensures that when a new server connection is made,
-* the default view of the user-specified type is automatically created.
-* This also has the logic to warn before server connection timesout.
-*/
+ * @ingroup Behaviors
+ * pqDefaultViewBehavior ensures that when a new server connection is made,
+ * the default view of the user-specified type is automatically created.
+ * This also has the logic to warn before server connection timesout.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqDefaultViewBehavior : public QObject
 {
   Q_OBJECT
   typedef QObject Superclass;
 
 public:
-  pqDefaultViewBehavior(QObject* parent = 0);
+  pqDefaultViewBehavior(QObject* parent = nullptr);
 
 protected Q_SLOTS:
   void onServerCreation(pqServer*);
