@@ -36,11 +36,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqPropertyWidget.h"
 
 /**
-* pqImageCompressorWidget is a pqPropertyWidget designed to be used
-* for "CompressorConfig" property on "RenderView" or  "RenderViewSettings"
-* proxy. It works with a string property that expects the config in
-* a predetermined format (refer to the code for details on the format).
-*/
+ * pqImageCompressorWidget is a pqPropertyWidget designed to be used
+ * for "CompressorConfig" property on "RenderView" or  "RenderViewSettings"
+ * proxy. It works with a string property that expects the config in
+ * a predetermined format (refer to the code for details on the format).
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqImageCompressorWidget : public pqPropertyWidget
 {
   Q_OBJECT;
@@ -48,12 +48,12 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqImageCompressorWidget : public pqProperty
   Q_PROPERTY(QString compressorConfig READ compressorConfig WRITE setCompressorConfig);
 
 public:
-  pqImageCompressorWidget(vtkSMProxy* proxy, vtkSMProperty* smproperty, QWidget* parent = 0);
+  pqImageCompressorWidget(vtkSMProxy* proxy, vtkSMProperty* smproperty, QWidget* parent = nullptr);
   ~pqImageCompressorWidget() override;
 
   QString compressorConfig() const;
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   void setCompressorConfig(const QString&);
 
 Q_SIGNALS:
@@ -62,7 +62,7 @@ private Q_SLOTS:
   void currentIndexChanged(int);
   void setConfigurationDefault(int);
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqImageCompressorWidget)
   class pqInternals;
   pqInternals* Internals;
