@@ -38,18 +38,18 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class QMenu;
 
 /**
-* @ingroup Reactions
-* pqLoadPaletteReaction is used to setup an action that allows the user to
-* load a palette. It setups up menu on the parent action which is populated
-* with available palettes.
-*/
+ * @ingroup Reactions
+ * pqLoadPaletteReaction is used to setup an action that allows the user to
+ * load a palette. It setups up menu on the parent action which is populated
+ * with available palettes.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqLoadPaletteReaction : public pqReaction
 {
   Q_OBJECT
   typedef pqReaction Superclass;
 
 public:
-  pqLoadPaletteReaction(QAction* parent = 0);
+  pqLoadPaletteReaction(QAction* parent = nullptr);
   ~pqLoadPaletteReaction() override;
 
 protected:
@@ -59,7 +59,7 @@ private Q_SLOTS:
   void populateMenu();
   void actionTriggered(QAction* actn);
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqLoadPaletteReaction)
   QPointer<QMenu> Menu;
 };
