@@ -70,9 +70,7 @@ pqMainWindowEventBehavior::pqMainWindowEventBehavior(QObject* parentObject)
 }
 
 //-----------------------------------------------------------------------------
-pqMainWindowEventBehavior::~pqMainWindowEventBehavior()
-{
-}
+pqMainWindowEventBehavior::~pqMainWindowEventBehavior() = default;
 
 //-----------------------------------------------------------------------------
 void pqMainWindowEventBehavior::onClose(QCloseEvent*)
@@ -90,9 +88,7 @@ void pqMainWindowEventBehavior::onClose(QCloseEvent*)
 }
 
 //-----------------------------------------------------------------------------
-void pqMainWindowEventBehavior::onShow(QShowEvent*)
-{
-}
+void pqMainWindowEventBehavior::onShow(QShowEvent*) {}
 
 //-----------------------------------------------------------------------------
 void pqMainWindowEventBehavior::onDragEnter(QDragEnterEvent* event)
@@ -109,9 +105,9 @@ void pqMainWindowEventBehavior::onDrop(QDropEvent* event)
     return;
   }
 
-  QList<QString> files;
+  QStringList files;
 
-  foreach (QUrl url, urls)
+  Q_FOREACH (QUrl url, urls)
   {
     if (!url.toLocalFile().isEmpty())
     {
@@ -132,5 +128,5 @@ void pqMainWindowEventBehavior::onDrop(QDropEvent* event)
   {
     return;
   }
-  pqLoadDataReaction::loadData(files);
+  pqLoadDataReaction::loadFilesForSupportedTypes({ files });
 }
