@@ -56,9 +56,7 @@ pqObjectPickingBehavior::pqObjectPickingBehavior(QObject* parentObject)
 }
 
 //-----------------------------------------------------------------------------
-pqObjectPickingBehavior::~pqObjectPickingBehavior()
-{
-}
+pqObjectPickingBehavior::~pqObjectPickingBehavior() = default;
 
 //-----------------------------------------------------------------------------
 void pqObjectPickingBehavior::onViewAdded(pqView* view)
@@ -78,7 +76,18 @@ bool pqObjectPickingBehavior::eventFilter(QObject* caller, QEvent* e)
     QMouseEvent* me = static_cast<QMouseEvent*>(e);
     if (me->button() & Qt::LeftButton)
     {
-      this->Position = me->pos();
+      pqRenderView* view = qobject_cast<pqRenderView*>(pqActiveObjects::instance().activeView());
+      if (view)
+      {
+        int mode = vtkSMPropertyHelper(view->getProxy(), "InteractionMode").GetAsInt();
+        // check if the view is currently doing a selection, in that case,
+        // ignore the "pick".
+        if (mode == vtkPVRenderView::INTERACTION_MODE_3D ||
+          mode == vtkPVRenderView::INTERACTION_MODE_2D)
+        {
+          this->Position = me->pos();
+        }
+      }
     }
   }
   else if (e->type() == QEvent::MouseButtonRelease)
@@ -89,7 +98,7 @@ bool pqObjectPickingBehavior::eventFilter(QObject* caller, QEvent* e)
       QPoint newPos = static_cast<QMouseEvent*>(e)->pos();
       QPoint delta = newPos - this->Position;
       QWidget* senderWidget = qobject_cast<QWidget*>(caller);
-      if (delta.manhattanLength() < 3.0 && senderWidget != NULL)
+      if (delta.manhattanLength() < 3.0 && senderWidget != nullptr)
       {
         pqRenderView* view = qobject_cast<pqRenderView*>(pqActiveObjects::instance().activeView());
         if (view)
