@@ -45,13 +45,13 @@ class pqOpacityTableModel : public QAbstractTableModel
   typedef QAbstractTableModel Superclass;
 
 public:
-  pqOpacityTableModel(pqColorOpacityEditorWidget* widget, QObject* parentObject = 0);
+  pqOpacityTableModel(pqColorOpacityEditorWidget* widget, QObject* parentObject = nullptr);
 
-  ~pqOpacityTableModel() override {}
+  ~pqOpacityTableModel() override;
 
   /**
-  * All columns are editable.
-  */
+   * All columns are editable.
+   */
   Qt::ItemFlags flags(const QModelIndex& idx) const override;
 
   bool setData(const QModelIndex& idx, const QVariant& value, int role = Qt::EditRole) override;
