@@ -36,16 +36,16 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqApplicationComponentsModule.h"
 
 /**
-* pqPVAnimationWidget is subclass of pqAnimationViewWidget that connects with
-* the pqAnimationManager maintained by pqPVApplicationCore.
-*/
+ * pqPVAnimationWidget is subclass of pqAnimationViewWidget that connects with
+ * the pqAnimationManager maintained by pqPVApplicationCore.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqPVAnimationWidget : public pqAnimationViewWidget
 {
   Q_OBJECT
   typedef pqAnimationViewWidget Superclass;
 
 public:
-  pqPVAnimationWidget(QWidget* parent = 0);
+  pqPVAnimationWidget(QWidget* parent = nullptr);
 
 private:
   Q_DISABLE_COPY(pqPVAnimationWidget)
