@@ -30,12 +30,14 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ========================================================================*/
 #include "pqParaViewMenuBuilders.h"
-#include "vtkPVConfig.h"
 
 #include "ui_pqEditMenuBuilder.h"
 #include "ui_pqFileMenuBuilder.h"
 
+#include "pqQtConfig.h"
+
 #include "pqAboutDialogReaction.h"
+#include "pqAnimatedExportReaction.h"
 #include "pqAnimationTimeToolbar.h"
 #include "pqApplicationCore.h"
 #include "pqApplicationSettingsReaction.h"
@@ -51,6 +53,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqCatalystRemoveBreakpointReaction.h"
 #include "pqCatalystSetBreakpointReaction.h"
 #include "pqCategoryToolbarsBehavior.h"
+#include "pqChangeFileNameReaction.h"
 #include "pqChangePipelineInputReaction.h"
 #include "pqColorToolbar.h"
 #include "pqCopyReaction.h"
@@ -68,6 +71,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqHelpReaction.h"
 #endif
 #include "pqIgnoreSourceTimeReaction.h"
+#include "pqLightToolbar.h"
 #include "pqLinkSelectionReaction.h"
 #include "pqLoadDataReaction.h"
 #include "pqLoadMaterialsReaction.h"
@@ -76,6 +80,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqLogViewerReaction.h"
 #include "pqMainControlsToolbar.h"
 #include "pqManageCustomFiltersReaction.h"
+#include "pqManageExpressionsReaction.h"
 #include "pqManageFavoritesReaction.h"
 #include "pqManageLinksReaction.h"
 #include "pqManagePluginsReaction.h"
@@ -109,8 +114,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #if VTK_MODULE_ENABLE_ParaView_pqPython
 #include "pqMacroReaction.h"
-#include "pqPythonManager.h"
 #include "pqTraceReaction.h"
+
+#include <pqPythonMacroSupervisor.h>
+#include <pqPythonManager.h>
+#include <pqPythonScriptEditorReaction.h>
+#include <pqPythonTabWidget.h>
 #endif
 
 #include <QApplication>
@@ -124,17 +133,19 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QSysInfo>
 
 #include "vtkPVFileInformation.h"
+#include "vtkPVVersion.h"
 #include "vtkSMProxyManager.h"
 
 //-----------------------------------------------------------------------------
 class pqActiveDisabledStyle : public QProxyStyle
 {
 public:
-  int styleHint(StyleHint hint, const QStyleOption* option = 0, const QWidget* widget = 0,
-    QStyleHintReturn* returnData = 0) const override
+  int styleHint(StyleHint hint, const QStyleOption* option = nullptr,
+    const QWidget* widget = nullptr, QStyleHintReturn* returnData = nullptr) const override
   {
-    return hint == QStyle::SH_Menu_AllowActiveAndDisabled ? 1 : QProxyStyle::styleHint(
-                                                                  hint, option, widget, returnData);
+    return hint == QStyle::SH_Menu_AllowActiveAndDisabled
+      ? 1
+      : QProxyStyle::styleHint(hint, option, widget, returnData);
   }
 };
 
@@ -176,6 +187,11 @@ void pqParaViewMenuBuilders::buildFileMenu(QMenu& menu)
   new pqSaveAnimationGeometryReaction(ui.actionFileSaveGeometry);
 
   new pqExportReaction(ui.actionExport);
+#if VTK_MODULE_ENABLE_ParaView_pqPython
+  new pqAnimatedExportReaction(ui.actionAnimatedExport);
+#else
+  ui.actionAnimatedExport->setEnabled(false);
+#endif
   new pqSaveExtractsReaction(ui.actionFileSaveExtracts);
   new pqSaveDataReaction(ui.actionFileSaveData);
 
@@ -197,10 +213,12 @@ void pqParaViewMenuBuilders::buildEditMenu(QMenu& menu, pqPropertiesPanel* prope
   new pqCameraUndoRedoReaction(ui.actionEditCameraUndo, true);
   new pqCameraUndoRedoReaction(ui.actionEditCameraRedo, false);
   new pqChangePipelineInputReaction(ui.actionChangeInput);
+  new pqChangeFileNameReaction(ui.actionChangeFile);
   new pqIgnoreSourceTimeReaction(ui.actionIgnoreTime);
   new pqDeleteReaction(ui.actionDelete);
   ui.actionDelete->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D));
-  new pqDeleteReaction(ui.actionDelete_All, true);
+  new pqDeleteReaction(ui.actionDeleteTree, pqDeleteReaction::DeleteModes::TREE);
+  new pqDeleteReaction(ui.actionDelete_All, pqDeleteReaction::DeleteModes::ALL);
   new pqShowHideAllReaction(ui.actionShow_All, pqShowHideAllReaction::ActionType::Show);
   new pqShowHideAllReaction(ui.actionHide_All, pqShowHideAllReaction::ActionType::Hide);
   new pqSaveScreenshotReaction(ui.actionCopyScreenshotToClipboard, true);
@@ -245,7 +263,9 @@ void pqParaViewMenuBuilders::buildFiltersMenu(
   QMenu& menu, QMainWindow* mainWindow, bool hideDisabled, bool quickLaunchable)
 {
   // Make sure disabled actions are still considered active
-  menu.setStyle(new pqActiveDisabledStyle);
+  auto* style = new pqActiveDisabledStyle;
+  style->setParent(&menu);
+  menu.setStyle(style);
 
   pqProxyGroupMenuManager* mgr =
     new pqProxyGroupMenuManager(&menu, "ParaViewFilters", quickLaunchable);
@@ -277,7 +297,9 @@ void pqParaViewMenuBuilders::buildExtractorsMenu(
   QMenu& menu, QMainWindow* mainWindow, bool hideDisabled, bool quickLaunchable)
 {
   // Make sure disabled actions are still considered active
-  menu.setStyle(new pqActiveDisabledStyle);
+  auto* style = new pqActiveDisabledStyle;
+  style->setParent(&menu);
+  menu.setStyle(style);
 
   pqProxyGroupMenuManager* mgr =
     new pqProxyGroupMenuManager(&menu, "ParaViewExtractWriters", quickLaunchable);
@@ -327,6 +349,9 @@ void pqParaViewMenuBuilders::buildToolsMenu(QMenu& menu)
   new pqCustomizeShortcutsReaction(
     menu.addAction("Customize Shortcuts...") << pqSetName("actionCustomize"));
 
+  new pqManageExpressionsReaction(
+    menu.addAction("Manage Expressions") << pqSetName("actionToolsManageExpressions"));
+
   menu.addSeparator(); // --------------------------------------------------
 
   //<addaction name="actionToolsDumpWidgetNames" />
@@ -347,6 +372,9 @@ void pqParaViewMenuBuilders::buildToolsMenu(QMenu& menu)
   menu.addSeparator(); // --------------------------------------------------
   new pqTraceReaction(menu.addAction("Start Trace") << pqSetName("actionToolsStartStopTrace"),
     "Start Trace", "Stop Trace");
+  menu.addSeparator();
+  new pqPythonScriptEditorReaction(
+    menu.addAction("Python Script Editor") << pqSetName("actionToolsOpenScriptEditor"));
 #endif
 }
 
@@ -454,6 +482,15 @@ void pqParaViewMenuBuilders::buildPipelineBrowserContextMenu(QMenu& menu, QMainW
     "Reload data files in case they were changed externally.", Q_NULLPTR));
 #endif // QT_NO_TOOLTIP
 
+  QAction* actionPBChangeFile = new QAction(menu.parent());
+  actionPBChangeFile->setObjectName(QStringLiteral("actionPBChangeFile"));
+  actionPBChangeFile->setText(
+    QApplication::translate("pqPipelineBrowserContextMenu", "Change File", Q_NULLPTR));
+#ifndef QT_NO_STATUSTIP
+  actionPBChangeFile->setStatusTip(
+    QApplication::translate("pqPipelineBrowserContextMenu", "Change File", Q_NULLPTR));
+#endif // QT_NO_STATUSTIP
+
   QAction* actionPBIgnoreTime = new QAction(menu.parent());
   actionPBIgnoreTime->setObjectName(QStringLiteral("actionPBIgnoreTime"));
   actionPBIgnoreTime->setCheckable(true);
@@ -489,6 +526,16 @@ void pqParaViewMenuBuilders::buildPipelineBrowserContextMenu(QMenu& menu, QMainW
       menu.parent(), SIGNAL(deleteKey()), actionPBDelete, SLOT(trigger()), Qt::QueuedConnection);
   }
 
+  QAction* actionPBDeleteTree = new QAction(menu.parent());
+  actionPBDeleteTree->setObjectName(QStringLiteral("actionPBDeleteTree"));
+  actionPBDeleteTree->setIcon(icon);
+  actionPBDeleteTree->setText(QApplication::translate(
+    "pqPipelineBrowserContextMenu", "Delete Downstream Pipeline", Q_NULLPTR));
+#ifndef QT_NO_STATUSTIP
+  actionPBDeleteTree->setStatusTip(QApplication::translate(
+    "pqPipelineBrowserContextMenu", "Delete selection and all downstream filters", Q_NULLPTR));
+#endif // QT_NO_STATUSTIP
+
   QAction* actionPBCreateCustomFilter = new QAction(menu.parent());
   actionPBCreateCustomFilter->setObjectName(QStringLiteral("actionPBCreateCustomFilter"));
   actionPBCreateCustomFilter->setText(
@@ -526,8 +573,10 @@ void pqParaViewMenuBuilders::buildPipelineBrowserContextMenu(QMenu& menu, QMainW
   menu.addAction(actionPBPaste);
   menu.addSeparator();
   menu.addAction(actionPBDelete);
+  menu.addAction(actionPBDeleteTree);
   menu.addAction(actionPBRename);
   menu.addAction(actionPBReloadFiles);
+  menu.addAction(actionPBChangeFile);
   menu.addAction(actionPBIgnoreTime);
   menu.addSeparator();
   menu.addAction(actionPBChangeInput);
@@ -549,9 +598,11 @@ void pqParaViewMenuBuilders::buildPipelineBrowserContextMenu(QMenu& menu, QMainW
   new pqReloadFilesReaction(actionPBReloadFiles);
   new pqIgnoreSourceTimeReaction(actionPBIgnoreTime);
   new pqDeleteReaction(actionPBDelete);
+  new pqDeleteReaction(actionPBDeleteTree, pqDeleteReaction::DeleteModes::TREE);
   new pqCreateCustomFilterReaction(actionPBCreateCustomFilter);
   new pqLinkSelectionReaction(actionPBLinkSelection);
   new pqRenameProxyReaction(actionPBRename, mainWindow);
+  new pqChangeFileNameReaction(actionPBChangeFile);
 }
 
 //-----------------------------------------------------------------------------
@@ -564,8 +615,26 @@ void pqParaViewMenuBuilders::buildMacrosMenu(QMenu& menu)
   if (manager)
   {
     new pqMacroReaction(menu.addAction("Import new macro...") << pqSetName("actionMacroCreate"));
-    QMenu* editMenu = menu.addMenu("Edit...");
-    QMenu* deleteMenu = menu.addMenu("Delete...");
+    QMenu* editMenu = menu.addMenu("Edit...") << pqSetName("menuMacroEdit");
+    QMenu* deleteMenu = menu.addMenu("Delete...") << pqSetName("menuMacroDelete");
+    QAction* deleteAllAction = menu.addAction(QObject::tr("Delete All"));
+    QObject::connect(deleteAllAction, &QAction::triggered, []() {
+      QMessageBox::StandardButton ret = QMessageBox::question(
+        pqCoreUtilities::mainWidget(), "Delete All", "All macros will be deleted. Are you sure?");
+      if (ret == QMessageBox::StandardButton::Yes)
+      {
+        // The script editor shows macros about to be deleted. remove those tabs.
+        pqPythonTabWidget* const tWidget =
+          pqPythonScriptEditor::getUniqueInstance()->findChild<pqPythonTabWidget*>();
+        for (int i = tWidget->count() - 1; i >= 0; --i)
+        {
+          Q_EMIT tWidget->tabCloseRequested(i);
+        }
+        // remove user Macros dir
+        pqCoreUtilities::removeRecursively(pqPythonScriptEditor::getMacrosDir());
+        pqPVApplicationCore::instance()->pythonManager()->updateMacroList();
+      }
+    });
     menu.addSeparator();
     manager->addWidgetForRunMacros(&menu);
     manager->addWidgetForEditMacros(editMenu);
@@ -583,7 +652,7 @@ void pqParaViewMenuBuilders::buildHelpMenu(QMenu& menu)
   // Getting Started with ParaView
   new pqDesktopServicesReaction(QUrl::fromLocalFile(paraViewGettingStartedFile),
     (menu.addAction(QIcon(":/pqWidgets/Icons/pdf.png"), "Getting Started with ParaView")
-                                  << pqSetName("actionGettingStarted")));
+      << pqSetName("actionGettingStarted")));
 
   QString versionString = QString("%1.%2.%3")
                             .arg(vtkSMProxyManager::GetVersionMajor())
@@ -621,19 +690,19 @@ void pqParaViewMenuBuilders::buildHelpMenu(QMenu& menu)
   menu.addSeparator();
 
   // ParaView Tutorial
-  QString tutorialURL = QString("https://www.paraview.org/paraview-downloads/"
-                                "download.php?submit=Download&version=v%1.%2&type=binary&os="
-                                "Sources&downloadFile=ParaViewTutorial-%1.%2.%3.pdf")
-                          .arg(vtkSMProxyManager::GetVersionMajor())
-                          .arg(vtkSMProxyManager::GetVersionMinor())
-                          .arg(vtkSMProxyManager::GetVersionPatch());
-  new pqDesktopServicesReaction(
-    QUrl(tutorialURL), (menu.addAction(QIcon(":/pqWidgets/Icons/pdf.png"), "ParaView Tutorial")
-                         << pqSetName("actionTutorialNotes")));
+  QString selfDirectedTutorialURL =
+    QString("https://docs.paraview.org/en/v%1/Tutorials/SelfDirectedTutorial/index.html")
+      .arg(versionString);
+  new pqDesktopServicesReaction(QUrl(selfDirectedTutorialURL),
+    (menu.addAction("ParaView Self-directed Tutorial")
+      << pqSetName("actionSelfDirectedTutorialNotes")));
 
-  // Sandia National Labs Tutorials
-  new pqDesktopServicesReaction(QUrl("http://www.paraview.org/Wiki/SNL_ParaView_4_Tutorials"),
-    (menu.addAction("Sandia National Labs Tutorials") << pqSetName("actionSNLTutorial")));
+  // Classroom Tutorials by Sandia National Laboratories
+  QString classroomTutorialsURL =
+    QString("https://docs.paraview.org/en/v%1/Tutorials/ClassroomTutorials/index.html")
+      .arg(versionString);
+  new pqDesktopServicesReaction(QUrl(classroomTutorialsURL),
+    (menu.addAction("ParaView Classroom Tutorials") << pqSetName("actionClassroomTutorials")));
 
   // Example Data Sets
 
@@ -653,7 +722,7 @@ void pqParaViewMenuBuilders::buildHelpMenu(QMenu& menu)
     (menu.addAction("ParaView Wiki") << pqSetName("actionWiki")));
 
   // ParaView Community Support
-  new pqDesktopServicesReaction(QUrl("http://www.paraview.org/community-support/"),
+  new pqDesktopServicesReaction(QUrl("https://discourse.paraview.org/c/paraview-support"),
     (menu.addAction("ParaView Community Support") << pqSetName("actionCommunitySupport")));
 
   // ParaView Release Notes
@@ -741,6 +810,10 @@ void pqParaViewMenuBuilders::buildToolbars(QMainWindow& mainWindow)
   axesToolbar->layout()->setSpacing(0);
   mainWindow.addToolBar(Qt::TopToolBarArea, axesToolbar);
 
+  QToolBar* lightingToolbar = new pqLightToolbar(&mainWindow) << pqSetName("lightingToolbar");
+  lightingToolbar->layout()->setSpacing(0);
+  mainWindow.addToolBar(Qt::TopToolBarArea, lightingToolbar);
+
 #if VTK_MODULE_ENABLE_ParaView_pqPython
   // Give the macros menu to the pqPythonMacroSupervisor
   pqPythonManager* manager =
