@@ -36,18 +36,18 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QObject>
 
 /**
-* @ingroup Behaviors
-* pqPluginSettingsBehavior adds support for adding application settings from plugins
-*/
+ * @ingroup Behaviors
+ * pqPluginSettingsBehavior adds support for adding application settings from plugins
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqPluginSettingsBehavior : public QObject
 {
   Q_OBJECT
   typedef QObject Superclass;
 
 public:
-  pqPluginSettingsBehavior(QObject* parent = 0);
+  pqPluginSettingsBehavior(QObject* parent = nullptr);
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   void updateSettings();
 };
 
