@@ -36,6 +36,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkWeakPointer.h"
 #include <QCursor>
 #include <QPointer>
+#include <QShortcut>
+#include <QString>
 #include <QTimer>
 
 class pqDataRepresentation;
@@ -46,13 +48,13 @@ class vtkObject;
 class vtkSMPVRepresentationProxy;
 
 /**
-* pqRenderViewSelectionReaction handles various selection modes available on
-* RenderViews. Simply create multiple instances of
-* pqRenderViewSelectionReaction to handle selection modes for that RenderView.
-* pqRenderViewSelectionReaction uses internal static members to ensure that
-* at most 1 view (and 1 type of selection) is in selection-mode at any given
-* time.
-*/
+ * pqRenderViewSelectionReaction handles various selection modes available on
+ * RenderViews. Simply create multiple instances of
+ * pqRenderViewSelectionReaction to handle selection modes for that RenderView.
+ * pqRenderViewSelectionReaction uses internal static members to ensure that
+ * at most 1 view (and 1 type of selection) is in selection-mode at any given
+ * time.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqRenderViewSelectionReaction : public pqSelectionReaction
 {
   Q_OBJECT
@@ -83,11 +85,11 @@ public:
   };
 
   /**
-  * If \c view is NULL, this reaction will track the active-view maintained by
-  * pqActiveObjects.
-  */
+   * If \c view is nullptr, this reaction will track the active-view maintained by
+   * pqActiveObjects.
+   */
   pqRenderViewSelectionReaction(QAction* parentAction, pqRenderView* view, SelectionMode mode,
-    QActionGroup* modifierGroup = NULL);
+    QActionGroup* modifierGroup = nullptr);
   ~pqRenderViewSelectionReaction() override;
 
 Q_SIGNALS:
@@ -97,11 +99,11 @@ Q_SIGNALS:
 
 private Q_SLOTS:
   /**
-  * For checkable actions, this calls this->beginSelection() or
-  * this->endSelection() is val is true or false, respectively. For
-  * non-checkable actions, this call this->beginSelection() and
-  * this->endSelection() in that order.
-  */
+   * For checkable actions, this calls this->beginSelection() or
+   * this->endSelection() is val is true or false, respectively. For
+   * non-checkable actions, this call this->beginSelection() and
+   * this->endSelection() in that order.
+   */
   virtual void actionTriggered(bool val);
 
   /**
@@ -111,61 +113,62 @@ private Q_SLOTS:
   void updateEnableState() override;
 
   /**
-  * Called when this object was created with NULL as the view and the active
-  * view changes.
-  */
+   * Called when this object was created with nullptr as the view and the active
+   * view changes.
+   */
   void setView(pqView* view);
 
   /**
-  * Called when the active representation changes.
-  */
+   * Called when the active representation changes.
+   */
   void setRepresentation(pqDataRepresentation* representation);
 
   /**
-  * starts the selection i.e. setup render view in selection mode.
-  */
+   * starts the selection i.e. setup render view in selection mode.
+   */
   void beginSelection();
 
   /**
-  * finishes the selection. Doesn't cause the selection, just returns the
-  * render view to previous interaction mode.
-  */
+   * finishes the selection. Doesn't cause the selection, just returns the
+   * render view to previous interaction mode.
+   */
   void endSelection();
 
   /**
-  * makes the pre-selection.
-  */
+   * makes the pre-selection.
+   */
   void preSelection();
 
   /**
-  * makes fast pre-selection.
-  */
+   * makes fast pre-selection.
+   */
   void fastPreSelection();
 
   /**
-  * callback called for mouse stop events when in 'interactive selection'
-  * modes.
-  */
+   * callback called for mouse stop events when in 'interactive selection'
+   * modes.
+   */
   void onMouseStop();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * callback called when the vtkPVRenderView is done with selection.
-  */
+   * callback called when the vtkPVRenderView is done with selection.
+   */
   void selectionChanged(vtkObject*, unsigned long, void* calldata);
 
   /**
-  * callback called for mouse move events when in 'interactive selection'
-  * modes.
-  */
+   * callback called for mouse move events when in 'interactive selection'
+   * modes.
+   */
   void onMouseMove();
 
   /**
-  * callback called for click events when in 'interactive selection'
-  * modes.
-  */
+   * callback called for click events when in 'interactive selection' modes.
+   */
   void onLeftButtonRelease();
   void onWheelRotate();
+  void onRightButtonPressed();
+  void onRightButtonRelease();
 
   // Get the current state of selection modifier
   int getSelectionModifier() override;
@@ -176,27 +179,28 @@ private:
   // Display/hide the tooltip of the selected point in mode SELECT_SURFACE_POINTS_TOOLTIP.
   void UpdateTooltip();
 
-private:
   Q_DISABLE_COPY(pqRenderViewSelectionReaction)
   QPointer<pqRenderView> View;
   QPointer<pqDataRepresentation> Representation;
   QMetaObject::Connection RepresentationConnection;
   SelectionMode Mode;
-  bool DisableSelectionModifiers;
   int PreviousRenderViewMode;
   vtkWeakPointer<vtkObject> ObservedObject;
-  unsigned long ObserverIds[4];
+  unsigned long ObserverIds[6];
   QCursor ZoomCursor;
   QTimer MouseMovingTimer;
   bool MouseMoving;
   int MousePosition[2];
+  bool DisablePreSelection = false;
   vtkSMPVRepresentationProxy* CurrentRepresentation = nullptr;
+  QShortcut* CopyToolTipShortcut = nullptr;
+  QString PlainTooltipText;
 
   static QPointer<pqRenderViewSelectionReaction> ActiveReaction;
 
   /**
-  * cleans up observers.
-  */
+   * cleans up observers.
+   */
   void cleanupObservers();
 };
 
