@@ -57,10 +57,12 @@ pqServerDisconnectReaction::pqServerDisconnectReaction(QAction* parentObject)
   this->updateState();
 
   // needed to disable server disconnection while an animation is playing
-  QObject::connect(pqPVApplicationCore::instance()->animationManager(), SIGNAL(beginPlay()), this,
-    SLOT(updateState()));
-  QObject::connect(pqPVApplicationCore::instance()->animationManager(), SIGNAL(endPlay()), this,
-    SLOT(updateState()));
+  QObject::connect(pqPVApplicationCore::instance()->animationManager(),
+    QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::beginPlay), this,
+    &pqServerDisconnectReaction::updateState);
+  QObject::connect(pqPVApplicationCore::instance()->animationManager(),
+    QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::endPlay), this,
+    &pqServerDisconnectReaction::updateState);
 }
 
 //-----------------------------------------------------------------------------
@@ -70,13 +72,14 @@ bool pqServerDisconnectReaction::disconnectFromServerWithWarning()
   pqServerManagerModel* smmodel = core->getServerManagerModel();
   pqServer* server = pqActiveObjects::instance().activeServer();
 
-  if (server && smmodel->findItems<pqPipelineSource*>(server).size() > 0)
+  if (server && !smmodel->findItems<pqPipelineSource*>(server).empty())
   {
-    int ret = QMessageBox::warning(pqCoreUtilities::mainWidget(),
-      tr("Disconnect from current server?"), tr("The current connection will be closed and \n"
-                                                "the state will be discarded.\n\n"
-                                                "Are you sure you want to continue?"),
-      QMessageBox::Yes | QMessageBox::No);
+    int ret =
+      QMessageBox::warning(pqCoreUtilities::mainWidget(), tr("Disconnect from current server?"),
+        tr("The current connection will be closed and \n"
+           "the state will be discarded.\n\n"
+           "Are you sure you want to continue?"),
+        QMessageBox::Yes | QMessageBox::No);
     if (ret == QMessageBox::No)
     {
       return false;
@@ -90,11 +93,23 @@ bool pqServerDisconnectReaction::disconnectFromServerWithWarning()
 //-----------------------------------------------------------------------------
 void pqServerDisconnectReaction::disconnectFromServer()
 {
+  auto& activeObjects = pqActiveObjects::instance();
   pqApplicationCore* core = pqApplicationCore::instance();
-  pqServer* server = pqActiveObjects::instance().activeServer();
+  pqServer* server = activeObjects.activeServer();
   if (server)
   {
     core->getObjectBuilder()->removeServer(server);
+
+    // set some other server active.
+    if (activeObjects.activeServer() == nullptr)
+    {
+      auto smmodel = core->getServerManagerModel();
+      auto allServers = smmodel->findItems<pqServer*>();
+      if (!allServers.isEmpty())
+      {
+        pqActiveObjects::instance().setActiveServer(allServers[0]);
+      }
+    }
   }
 }
 
@@ -107,7 +122,7 @@ void pqServerDisconnectReaction::updateState()
   }
   else
   {
-    this->parentAction()->setEnabled(pqActiveObjects::instance().activeServer() != NULL);
+    this->parentAction()->setEnabled(pqActiveObjects::instance().activeServer() != nullptr);
   }
 }
 
