@@ -98,7 +98,7 @@ pqSpherePropertyWidget::pqSpherePropertyWidget(
     qCritical("Missing required property for function 'Radius'.");
   }
 
-  if (smgroup->GetProperty("Input") == NULL)
+  if (smgroup->GetProperty("Input") == nullptr)
   {
     this->connect(ui.centerOnBounds, SIGNAL(clicked()), SLOT(centerOnBounds()));
   }
@@ -114,22 +114,18 @@ pqSpherePropertyWidget::pqSpherePropertyWidget(
 
   pqPointPickingHelper* pickHelper = new pqPointPickingHelper(QKeySequence(tr("P")), false, this);
   pickHelper->connect(this, SIGNAL(viewChanged(pqView*)), SLOT(setView(pqView*)));
-  pickHelper->connect(this, SIGNAL(widgetVisibilityUpdated(bool)), SLOT(setShortcutEnabled(bool)));
   this->connect(
     pickHelper, SIGNAL(pick(double, double, double)), SLOT(setCenter(double, double, double)));
 
   pqPointPickingHelper* pickHelper2 =
     new pqPointPickingHelper(QKeySequence(tr("Ctrl+P")), true, this);
   pickHelper2->connect(this, SIGNAL(viewChanged(pqView*)), SLOT(setView(pqView*)));
-  pickHelper2->connect(this, SIGNAL(widgetVisibilityUpdated(bool)), SLOT(setShortcutEnabled(bool)));
   this->connect(
     pickHelper2, SIGNAL(pick(double, double, double)), SLOT(setCenter(double, double, double)));
 }
 
 //-----------------------------------------------------------------------------
-pqSpherePropertyWidget::~pqSpherePropertyWidget()
-{
-}
+pqSpherePropertyWidget::~pqSpherePropertyWidget() = default;
 
 //-----------------------------------------------------------------------------
 void pqSpherePropertyWidget::placeWidget()
