@@ -29,8 +29,8 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =========================================================================*/
-#ifndef _pqStandardPropertyWidgetInterface_h
-#define _pqStandardPropertyWidgetInterface_h
+#ifndef pqStandardPropertyWidgetInterface_h
+#define pqStandardPropertyWidgetInterface_h
 
 #include "pqApplicationComponentsModule.h"
 #include "pqPropertyWidgetInterface.h"
@@ -41,19 +41,19 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * of the custom widgets and decorators used by ParaView's Properties Panel.
  */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqStandardPropertyWidgetInterface
-  : public QObject,
-    public pqPropertyWidgetInterface
+  : public QObject
+  , public pqPropertyWidgetInterface
 {
   Q_OBJECT
   Q_INTERFACES(pqPropertyWidgetInterface)
 public:
-  pqStandardPropertyWidgetInterface(QObject* p = 0);
+  pqStandardPropertyWidgetInterface(QObject* p = nullptr);
   ~pqStandardPropertyWidgetInterface() override;
 
   /**
    * Given a proxy and its property, create a widget for the same, if possible.
    * For unsupported/unknown proxies/properties, implementations should simply
-   * return NULL without raising any errors (or messages).
+   * return nullptr without raising any errors (or messages).
    * Supported types are:
    * \li \c calculator : pqCalculatorWidget
    * \li \c camera_manipulator : pqCameraManipulatorWidget
@@ -76,7 +76,9 @@ public:
    * \li \c viewtype_selector: pqViewTypePropertyWidget
    * \li \c view_resolution: pqViewResolutionPropertyWidget
    * \li \c pause_livesource: pqPauseLiveSourcePropertyWidget
-   * \li \c data_assembly: pqDataAssemblyPropertyWidget
+   * \li \c data_assembly_editor: pqDataAssemblyPropertyWidget
+   * \li \c selection_query : pqSelectionQueryPropertyWidget
+   * \li \c file_list : pqFileListPropertyWidget
    */
   pqPropertyWidget* createWidgetForProperty(
     vtkSMProxy* proxy, vtkSMProperty* property, QWidget* parentWidget) override;
@@ -84,7 +86,7 @@ public:
   /**
    * Given a proxy and its property group, create a widget for the same, of possible.
    * For unsupported/unknown proxies/property-groups, implementations should simply
-   * return NULL without raising any errors (or messages).
+   * return nullptr without raising any errors (or messages).
    * Supported types are:
    * \li \c AnnotationsEditor : pqColorAnnotationsPropertyWidget
    * \li \c ArrayStatus : pqArrayStatusPropertyWidget
@@ -93,7 +95,8 @@ public:
    * \li \c ColorOpacityEditor : pqColorOpacityEditorWidget
    * \li \c FontEditor : pqFontPropertyWidget
    * \li \c SeriesEditor : pqSeriesEditorPropertyWidget
-   * \li \c InteractivePlane : pqImplicitPlanePropertyWidget
+   * \li \c InteractivePlane : pqDisplaySizedImplicitPlanePropertyWidget
+   * \li \c InteractivePlane2 : pqImplicitPlanePropertyWidget
    * \li \c InteractiveBox: pqBoxPropertyWidget
    * \li \c InteractiveHandle: pqHandlePropertyWidget
    * \li \c InteractiveLine: pqLinePropertyWidget
@@ -106,6 +109,8 @@ public:
    * \li \c PropertyCollection : pqPropertyCollectionWidget
    * \li \c DataAssemblyEditor: pqDataAssemblyPropertyWidget
    * \li \c CheckableProperty : pqCheckableProperty
+   * \li \c EqualizerPropertyWidget : pqEqualizerPropertyWidget
+   * \li \c MetaDataPropertyWidget : pqMetaDataPropertyWidget
    */
   pqPropertyWidget* createWidgetForPropertyGroup(
     vtkSMProxy* proxy, vtkSMPropertyGroup* group, QWidget* parentWidget) override;
@@ -113,7 +118,7 @@ public:
   /**
    * Given the type of the decorator and the pqPropertyWidget that needs to be
    * decorated, create the pqPropertyWidgetDecorator instance, if possible.
-   * For unsupported/unknown, implementations should simply return NULL without
+   * For unsupported/unknown, implementations should simply return nullptr without
    * raising any errors (or messages).
    * Supported types are:
    * \li \c CTHArraySelectionDecorator : pqCTHArraySelectionDecorator
@@ -124,6 +129,7 @@ public:
    * \li \c OSPRayHidingDecorator: pqOSPRayHidingDecorator
    * \li \c MultiComponentsDecorator: pqMultiComponentsDecorator
    * \li \c CompositeDecorator: pqCompositePropertyWidgetDecorator
+   * \li \c SessionTypeDecorator: pqSessionTypeDecorator
    */
   pqPropertyWidgetDecorator* createWidgetDecorator(
     const QString& type, vtkPVXMLElement* config, pqPropertyWidget* widget) override;
@@ -136,4 +142,4 @@ public:
   void createDefaultWidgetDecorators(pqPropertyWidget* widget) override;
 };
 
-#endif // _pqStandardPropertyWidgetInterface_h
+#endif // pqStandardPropertyWidgetInterface_h
