@@ -49,8 +49,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * `pqParaViewBehaviors::enableStandardRecentlyUsedResourceLoader` is false.
  */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqStandardRecentlyUsedResourceLoaderImplementation
-  : public QObject,
-    public pqRecentlyUsedResourceLoaderInterface
+  : public QObject
+  , public pqRecentlyUsedResourceLoaderInterface
 {
   Q_OBJECT
   Q_INTERFACES(pqRecentlyUsedResourceLoaderInterface)
@@ -58,7 +58,7 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqStandardRecentlyUsedResourceLoaderImpleme
   typedef QObject Superclass;
 
 public:
-  pqStandardRecentlyUsedResourceLoaderImplementation(QObject* parent = 0);
+  pqStandardRecentlyUsedResourceLoaderImplementation(QObject* parent = nullptr);
   ~pqStandardRecentlyUsedResourceLoaderImplementation() override;
 
   bool canLoad(const pqServerResource& resource) override;
