@@ -36,6 +36,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqApplicationCore.h"
 #include "pqCameraUndoRedoReaction.h"
 #include "pqChartSelectionReaction.h"
+#include "pqColorOverlay.h"
 #include "pqContextView.h"
 #include "pqCoreUtilities.h"
 #include "pqDataQueryReaction.h"
@@ -69,11 +70,14 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QGuiApplication>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QPropertyAnimation>
 #include <QPushButton>
 #include <QSet>
 #include <QShortcut>
 #include <QStyle>
+#include <QToolTip>
 
+#include <algorithm>
 #include <cassert>
 
 namespace
@@ -91,6 +95,26 @@ T findParent(QObject* obj)
   }
   return nullptr;
 }
+
+QAction* findActiveAction(const QString& name)
+{
+  pqView* activeView = pqActiveObjects::instance().activeView();
+  if (activeView && activeView->widget() && activeView->widget()->parentWidget() &&
+    activeView->widget()->parentWidget()->parentWidget())
+  {
+    return activeView->widget()->parentWidget()->parentWidget()->findChild<QAction*>(name);
+  }
+  return nullptr;
+}
+
+void triggerAction(const QString& name)
+{
+  QAction* atcn = findActiveAction(name);
+  if (atcn)
+  {
+    atcn->trigger();
+  }
+}
 }
 
 //-----------------------------------------------------------------------------
@@ -104,6 +128,8 @@ pqStandardViewFrameActionsImplementation::pqStandardViewFrameActionsImplementati
   this->ShortCutFrustumCells = new QShortcut(QKeySequence(tr("f")), mainWindow);
   this->ShortCutFrustumPoints = new QShortcut(QKeySequence(tr("g")), mainWindow);
   this->ShortCutBlocks = new QShortcut(QKeySequence("b"), mainWindow);
+  this->ShortCutGrow = new QShortcut(QKeySequence("+"), mainWindow);
+  this->ShortCutShrink = new QShortcut(QKeySequence("-"), mainWindow);
 
   QObject::connect(
     this->ShortCutSurfaceCells, SIGNAL(activated()), this, SLOT(selectSurfaceCellsTriggered()));
@@ -114,6 +140,10 @@ pqStandardViewFrameActionsImplementation::pqStandardViewFrameActionsImplementati
   QObject::connect(
     this->ShortCutFrustumPoints, SIGNAL(activated()), this, SLOT(selectFrustumPointsTriggered()));
   QObject::connect(this->ShortCutBlocks, SIGNAL(activated()), this, SLOT(selectBlocksTriggered()));
+  QObject::connect(this->ShortCutGrow.data(), &QShortcut::activated,
+    []() { triggerAction("actionGrowSelection"); });
+  QObject::connect(this->ShortCutShrink.data(), &QShortcut::activated,
+    []() { triggerAction("actionShrinkSelection"); });
 
   this->ShortCutEsc = new QShortcut(QKeySequence(Qt::Key_Escape), mainWindow);
   this->ShortCutEsc->setEnabled(false);
@@ -133,8 +163,8 @@ pqStandardViewFrameActionsImplementation::~pqStandardViewFrameActionsImplementat
 //-----------------------------------------------------------------------------
 void pqStandardViewFrameActionsImplementation::frameConnected(pqViewFrame* frame, pqView* view)
 {
-  assert(frame != NULL);
-  if (view == NULL)
+  assert(frame != nullptr);
+  if (view == nullptr)
   {
     // Setup the UI shown when no view is present in the frame.
     QWidget* empty_frame = new QWidget(frame);
@@ -177,7 +207,7 @@ void pqStandardViewFrameActionsImplementation::addContextViewActions(
   if (this->isButtonVisible("SelectPolygon", chart_view))
   {
     QAction* chartSelectPolygonAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSelectChartPolygon16.png"), "Polygon Selection (d)");
+      QIcon(":/pqWidgets/Icons/pqSelectChartPolygon.svg"), "Polygon Selection (d)");
     chartSelectPolygonAction->setObjectName("actionChartSelectPolygon");
     chartSelectPolygonAction->setCheckable(true);
     chartSelectPolygonAction->setData(QVariant(vtkChart::SELECT_POLYGON));
@@ -190,7 +220,7 @@ void pqStandardViewFrameActionsImplementation::addContextViewActions(
   if (this->isButtonVisible("SelectRectangle", chart_view))
   {
     QAction* chartSelectRectangularAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSelectChart16.png"), "Rectangle Selection (s)");
+      QIcon(":/pqWidgets/Icons/pqSelectChart.svg"), "Rectangle Selection (s)");
     chartSelectRectangularAction->setObjectName("actionChartSelectRectangle");
     chartSelectRectangularAction->setCheckable(true);
     chartSelectRectangularAction->setData(QVariant(vtkChart::SELECT_RECTANGLE));
@@ -215,16 +245,16 @@ QActionGroup* pqStandardViewFrameActionsImplementation::addSelectionModifierActi
   assert(view);
   assert(frame);
 
-  QAction* toggleAction = NULL;
-  QAction* minusAction = NULL;
-  QAction* plusAction = NULL;
+  QAction* toggleAction = nullptr;
+  QAction* minusAction = nullptr;
+  QAction* plusAction = nullptr;
 
   this->addSeparator(frame, view);
 
   if (this->isButtonVisible("AddSelection", view))
   {
     plusAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSelectPlus16.png"), tr("Add selection (Ctrl)"));
+      QIcon(":/pqWidgets/Icons/pqSelectPlus.svg"), tr("Add selection (Ctrl)"));
     plusAction->setObjectName("actionAddSelection");
     plusAction->setCheckable(true);
     plusAction->setData(QVariant(pqView::PV_SELECTION_ADDITION));
@@ -233,7 +263,7 @@ QActionGroup* pqStandardViewFrameActionsImplementation::addSelectionModifierActi
   if (this->isButtonVisible("SubtractSelection", view))
   {
     minusAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSelectMinus16.png"), tr("Subtract selection (Shift)"));
+      QIcon(":/pqWidgets/Icons/pqSelectMinus.svg"), tr("Subtract selection (Shift)"));
     minusAction->setObjectName("actionSubtractSelection");
     minusAction->setCheckable(true);
     minusAction->setData(QVariant(pqView::PV_SELECTION_SUBTRACTION));
@@ -242,7 +272,7 @@ QActionGroup* pqStandardViewFrameActionsImplementation::addSelectionModifierActi
   if (this->isButtonVisible("ToggleSelection", view))
   {
     toggleAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSelectToggle16.png"), tr("Toggle selection (Ctrl+Shift)"));
+      QIcon(":/pqWidgets/Icons/pqSelectToggle.svg"), tr("Toggle selection (Ctrl+Shift)"));
     toggleAction->setObjectName("actionToggleSelection");
     toggleAction->setCheckable(true);
     toggleAction->setData(QVariant(pqView::PV_SELECTION_TOGGLE));
@@ -290,7 +320,7 @@ void pqStandardViewFrameActionsImplementation::addGenericActions(pqViewFrame* fr
   /// Add convert-to menu.
   frame->contextMenu()->addSeparator();
   QAction* renameAction = frame->contextMenu()->addAction("Rename");
-  new pqRenameProxyReaction(renameAction, view);
+  new pqRenameProxyReaction(renameAction, view, view->widget());
 
   QMenu* convertMenu = frame->contextMenu()->addMenu("Convert To ...");
   QObject::connect(convertMenu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowConvertMenu()));
@@ -302,7 +332,7 @@ void pqStandardViewFrameActionsImplementation::addGenericActions(pqViewFrame* fr
     if (this->isButtonVisible("BackButton", view))
     {
       QAction* backAction =
-        frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqUndoCamera24.png"), "Camera Undo");
+        frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqUndoCamera.svg"), "Camera Undo");
       backAction->setObjectName("actionBackButton");
       new pqCameraUndoRedoReaction(backAction, true, view);
     }
@@ -310,7 +340,7 @@ void pqStandardViewFrameActionsImplementation::addGenericActions(pqViewFrame* fr
     if (this->isButtonVisible("ForwardButton", view))
     {
       QAction* forwardAction =
-        frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqRedoCamera24.png"), "Camera Redo");
+        frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqRedoCamera.svg"), "Camera Redo");
       forwardAction->setObjectName("actionForwardButton");
       new pqCameraUndoRedoReaction(forwardAction, false, view);
     }
@@ -323,9 +353,9 @@ void pqStandardViewFrameActionsImplementation::addGenericActions(pqViewFrame* fr
     if (this->isButtonVisible("captureViewAction", view))
     {
       QAction* captureViewAction = frame->addTitleBarAction(
-        QIcon(":/pqWidgets/Icons/pqCaptureScreenshot24.png"), "Capture to Clipboard or File");
+        QIcon(":/pqWidgets/Icons/pqCaptureScreenshot.svg"), "Capture to Clipboard or File");
       captureViewAction->setObjectName("actionCaptureView");
-      captureViewAction->setToolTip("Capture screenshot to the clipboard or to a file if a "
+      captureViewAction->setToolTip("Capture screenshot to a file or to the clipboard if a "
                                     "modifier key (Ctrl, Alt or Shift) is pressed.");
       this->connect(captureViewAction, SIGNAL(triggered(bool)), SLOT(captureViewTriggered()));
     }
@@ -344,7 +374,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("ToggleInteractionMode", renderView))
   {
     QAction* toggleInteractionModeAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqInteractionMode3D16.png"), "Change Interaction Mode");
+      QIcon(":/pqWidgets/Icons/pqInteractionMode3D.svg"), "Change Interaction Mode");
     toggleInteractionModeAction->setObjectName("actionToggleInteractionMode");
     new pqToggleInteractionViewMode(toggleInteractionModeAction, renderView);
   }
@@ -352,7 +382,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("AdjustCamera", renderView))
   {
     QAction* adjustCameraAction =
-      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqEditCamera16.png"), "Adjust Camera");
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqEditCamera.svg"), "Adjust Camera");
     adjustCameraAction->setObjectName("actionAdjustCamera");
     new pqEditCameraReaction(adjustCameraAction, renderView);
   }
@@ -364,7 +394,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectSurfaceCells", renderView))
   {
     QAction* selectSurfaceCellsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSurfaceSelectionCell24.png"), "Select Cells On (s)");
+      QIcon(":/pqWidgets/Icons/pqSurfaceSelectionCell.svg"), "Select Cells On (s)");
     selectSurfaceCellsAction->setObjectName("actionSelectSurfaceCells");
     selectSurfaceCellsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(selectSurfaceCellsAction, renderView,
@@ -376,7 +406,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectSurfacePoints", renderView))
   {
     QAction* selectSurfacePointsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSurfaceSelectionPoint24.png"), "Select Points On (d)");
+      QIcon(":/pqWidgets/Icons/pqSurfaceSelectionPoint.svg"), "Select Points On (d)");
     selectSurfacePointsAction->setObjectName("actionSelectSurfacePoints");
     selectSurfacePointsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(selectSurfacePointsAction, renderView,
@@ -388,7 +418,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectFrustumCells", renderView))
   {
     QAction* selectFrustumCellsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqFrustumSelectionCell24.png"), "Select Cells Through (f)");
+      QIcon(":/pqWidgets/Icons/pqFrustumSelectionCell.svg"), "Select Cells Through (f)");
     selectFrustumCellsAction->setObjectName("actionSelectFrustumCells");
     selectFrustumCellsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(selectFrustumCellsAction, renderView,
@@ -400,7 +430,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectFrustumPoints", renderView))
   {
     QAction* selectFrustumPointsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqFrustumSelectionPoint24.png"), "Select Points Through (g)");
+      QIcon(":/pqWidgets/Icons/pqFrustumSelectionPoint.svg"), "Select Points Through (g)");
     selectFrustumPointsAction->setObjectName("actionSelectFrustumPoints");
     selectFrustumPointsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(selectFrustumPointsAction, renderView,
@@ -412,7 +442,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectPolygonSelectionCells", renderView))
   {
     QAction* selectionPolygonCellsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqPolygonSelectSurfaceCell24.png"), "Select Cells With Polygon");
+      QIcon(":/pqWidgets/Icons/pqPolygonSelectSurfaceCell.svg"), "Select Cells With Polygon");
     selectionPolygonCellsAction->setObjectName("actionPolygonSelectionCells");
     selectionPolygonCellsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(selectionPolygonCellsAction, renderView,
@@ -424,7 +454,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectPolygonSelectionPoints", renderView))
   {
     QAction* selectionPolygonPointsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqPolygonSelectSurfacePoint24.png"), "Select Points With Polygon");
+      QIcon(":/pqWidgets/Icons/pqPolygonSelectSurfacePoint.svg"), "Select Points With Polygon");
     selectionPolygonPointsAction->setObjectName("actionPolygonSelectionPoints");
     selectionPolygonPointsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(selectionPolygonPointsAction, renderView,
@@ -436,7 +466,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("SelectBlock", renderView))
   {
     QAction* selectBlockAction =
-      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSelectBlock24.png"), "Select Block (b)");
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSelectBlock.svg"), "Select Block (b)");
     selectBlockAction->setObjectName("actionSelectBlock");
     selectBlockAction->setCheckable(true);
     new pqRenderViewSelectionReaction(
@@ -444,10 +474,41 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
     this->connect(selectBlockAction, SIGNAL(toggled(bool)), SLOT(escapeableActionToggled(bool)));
   }
 
+  if (this->isButtonVisible("InteractiveSelectSurfaceCellData", renderView))
+  {
+    QAction* interactiveSelectSurfaceCellDataAction =
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceSelectionCellDataInteractive.svg"),
+        "Interactive Select Cell Data On");
+    interactiveSelectSurfaceCellDataAction->setObjectName("actionInteractiveSelectSurfaceCellData");
+    interactiveSelectSurfaceCellDataAction->setCheckable(true);
+    new pqRenderViewSelectionReaction(interactiveSelectSurfaceCellDataAction, renderView,
+      pqRenderViewSelectionReaction::SELECT_SURFACE_CELLDATA_INTERACTIVELY, modeGroup);
+    this->connect(interactiveSelectSurfaceCellDataAction, SIGNAL(toggled(bool)),
+      SLOT(escapeableActionToggled(bool)));
+    this->connect(interactiveSelectSurfaceCellDataAction, SIGNAL(toggled(bool)),
+      SLOT(interactiveSelectionToggled(bool)));
+  }
+
+  if (this->isButtonVisible("InteractiveSelectSurfacePointData", renderView))
+  {
+    QAction* interactiveSelectSurfacePointDataAction = frame->addTitleBarAction(
+      QIcon(":/pqWidgets/Icons/pqSurfaceSelectionPointDataInteractive.svg"),
+      "Interactive Select Point Data On");
+    interactiveSelectSurfacePointDataAction->setObjectName(
+      "actionInteractiveSelectSurfacePointData");
+    interactiveSelectSurfacePointDataAction->setCheckable(true);
+    new pqRenderViewSelectionReaction(interactiveSelectSurfacePointDataAction, renderView,
+      pqRenderViewSelectionReaction::SELECT_SURFACE_POINTDATA_INTERACTIVELY, modeGroup);
+    this->connect(interactiveSelectSurfacePointDataAction, SIGNAL(toggled(bool)),
+      SLOT(escapeableActionToggled(bool)));
+    this->connect(interactiveSelectSurfacePointDataAction, SIGNAL(toggled(bool)),
+      SLOT(interactiveSelectionToggled(bool)));
+  }
+
   if (this->isButtonVisible("InteractiveSelectSurfaceCells", renderView))
   {
     QAction* interactiveSelectSurfaceCellsAction =
-      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceSelectionCellInteractive.png"),
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceSelectionCellInteractive.svg"),
         "Interactive Select Cells On");
     interactiveSelectSurfaceCellsAction->setObjectName("actionInteractiveSelectSurfaceCells");
     interactiveSelectSurfaceCellsAction->setCheckable(true);
@@ -462,7 +523,7 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
   if (this->isButtonVisible("InteractiveSelectSurfacePoints", renderView))
   {
     QAction* interactiveSelectSurfacePointsAction =
-      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceSelectionPointInteractive.png"),
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceSelectionPointInteractive.svg"),
         "Interactive Select Points On");
     interactiveSelectSurfacePointsAction->setObjectName("actionInteractiveSelectSurfacePoints");
     interactiveSelectSurfacePointsAction->setCheckable(true);
@@ -474,10 +535,26 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
       SLOT(interactiveSelectionToggled(bool)));
   }
 
+  if (this->isButtonVisible("HoveringSurfaceCells", renderView))
+  {
+    QAction* hoveringSurfaceCellsAction =
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceHoveringCell.svg"),
+        "Hover Cells On. Use Ctrl-C/Cmd-C to copy the content to clipboard.");
+    hoveringSurfaceCellsAction->setObjectName("actionHoveringSurfaceCells");
+    hoveringSurfaceCellsAction->setCheckable(true);
+    new pqRenderViewSelectionReaction(hoveringSurfaceCellsAction, renderView,
+      pqRenderViewSelectionReaction::SELECT_SURFACE_CELLS_TOOLTIP);
+    this->connect(
+      hoveringSurfaceCellsAction, SIGNAL(toggled(bool)), SLOT(escapeableActionToggled(bool)));
+    this->connect(
+      hoveringSurfaceCellsAction, SIGNAL(toggled(bool)), SLOT(interactiveSelectionToggled(bool)));
+  }
+
   if (this->isButtonVisible("HoveringSurfacePoints", renderView))
   {
-    QAction* hoveringSurfacePointsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSurfaceHoveringPoint.png"), "Hover Points On");
+    QAction* hoveringSurfacePointsAction =
+      frame->addTitleBarAction(QIcon(":/pqWidgets/Icons/pqSurfaceHoveringPoint.svg"),
+        "Hover Points On. Use Ctrl-C/Cmd-C to copy the content to clipboard.");
     hoveringSurfacePointsAction->setObjectName("actionHoveringSurfacePoints");
     hoveringSurfacePointsAction->setCheckable(true);
     new pqRenderViewSelectionReaction(hoveringSurfacePointsAction, renderView,
@@ -488,18 +565,22 @@ void pqStandardViewFrameActionsImplementation::addRenderViewActions(
       hoveringSurfacePointsAction, SIGNAL(toggled(bool)), SLOT(interactiveSelectionToggled(bool)));
   }
 
-  if (this->isButtonVisible("HoveringSurfaceCells", renderView))
+  if (this->isButtonVisible("Grow Selection", renderView))
   {
-    QAction* hoveringSurfaceCellsAction = frame->addTitleBarAction(
-      QIcon(":/pqWidgets/Icons/pqSurfaceHoveringCell.png"), "Hover Cells On");
-    hoveringSurfaceCellsAction->setObjectName("actionHoveringSurfaceCells");
-    hoveringSurfaceCellsAction->setCheckable(true);
-    new pqRenderViewSelectionReaction(hoveringSurfaceCellsAction, renderView,
-      pqRenderViewSelectionReaction::SELECT_SURFACE_CELLS_TOOLTIP);
-    this->connect(
-      hoveringSurfaceCellsAction, SIGNAL(toggled(bool)), SLOT(escapeableActionToggled(bool)));
-    this->connect(
-      hoveringSurfaceCellsAction, SIGNAL(toggled(bool)), SLOT(interactiveSelectionToggled(bool)));
+    QAction* growAction =
+      frame->addTitleBarAction(QIcon(":/QtWidgets/Icons/pqPlus.svg"), "Grow selection");
+    growAction->setObjectName("actionGrowSelection");
+    new pqRenderViewSelectionReaction(
+      growAction, renderView, pqRenderViewSelectionReaction::GROW_SELECTION);
+  }
+
+  if (this->isButtonVisible("Shrink Selection", renderView))
+  {
+    auto shrinkAction =
+      frame->addTitleBarAction(QIcon(":/QtWidgets/Icons/pqMinus.svg"), "Shrink selection");
+    shrinkAction->setObjectName("actionShrinkSelection");
+    new pqRenderViewSelectionReaction(
+      shrinkAction, renderView, pqRenderViewSelectionReaction::SHRINK_SELECTION);
   }
 
   if (this->isButtonVisible("ClearSelection", renderView))
@@ -552,7 +633,7 @@ bool pqStandardViewFrameActionsImplementation::isButtonVisible(
     {
       // Turn all actions off *unless* the button has been
       // explicitly enabled by listing them as child elements
-      isVisible = isVisible && buttonElement != NULL;
+      isVisible = isVisible && buttonElement != nullptr;
     }
   }
 
@@ -603,7 +684,8 @@ pqStandardViewFrameActionsImplementation::availableViewTypes()
       views.push_back(info);
     }
   }
-  qSort(views.begin(), views.end(), pqStandardViewFrameActionsImplementation::ViewTypeComparator);
+  std::sort(
+    views.begin(), views.end(), pqStandardViewFrameActionsImplementation::ViewTypeComparator);
   return views;
 }
 
@@ -619,11 +701,12 @@ void pqStandardViewFrameActionsImplementation::aboutToShowConvertMenu()
     assert(viewframe != nullptr);
 
     QList<ViewType> views = this->availableViewTypes();
-    foreach (const ViewType& type, views)
+    Q_FOREACH (const ViewType& type, views)
     {
       QAction* view_action = new QAction(type.Label, menu);
       menu->addAction(view_action);
-      QObject::connect(view_action, &QAction::triggered, this,
+      QObject::connect(
+        view_action, &QAction::triggered, this,
         [viewframe, type, this](bool) { this->invoked(viewframe, type, "Convert To"); },
         Qt::QueuedConnection);
     }
@@ -640,11 +723,12 @@ void pqStandardViewFrameActionsImplementation::setupEmptyFrame(QWidget* frame)
   assert(viewframe != nullptr);
 
   QList<ViewType> views = this->availableViewTypes();
-  foreach (const ViewType& type, views)
+  Q_FOREACH (const ViewType& type, views)
   {
     QPushButton* button = new QPushButton(type.Label, ui.ConvertActionsFrame);
     button->setObjectName(type.Name);
-    QObject::connect(button, &QPushButton::clicked, this,
+    QObject::connect(
+      button, &QPushButton::clicked, this,
       [viewframe, type, this]() { this->invoked(viewframe, type, "Create"); },
       Qt::QueuedConnection);
     ui.ConvertActionsFrame->layout()->addWidget(button);
@@ -697,30 +781,6 @@ pqView* pqStandardViewFrameActionsImplementation::handleCreateView(
   return nullptr;
 }
 
-//-----------------------------------------------------------------------------
-namespace
-{
-QAction* findActiveAction(const QString& name)
-{
-  pqView* activeView = pqActiveObjects::instance().activeView();
-  if (activeView && activeView->widget() && activeView->widget()->parentWidget() &&
-    activeView->widget()->parentWidget()->parentWidget())
-  {
-    return activeView->widget()->parentWidget()->parentWidget()->findChild<QAction*>(name);
-  }
-  return NULL;
-}
-
-void triggerAction(const QString& name)
-{
-  QAction* atcn = findActiveAction(name);
-  if (atcn)
-  {
-    atcn->trigger();
-  }
-}
-}
-
 //-----------------------------------------------------------------------------
 void pqStandardViewFrameActionsImplementation::selectSurfaceCellsTriggered()
 {
@@ -797,7 +857,7 @@ void pqStandardViewFrameActionsImplementation::manageGroupExclusivity(QAction* c
   }
 
   QActionGroup* group = qobject_cast<QActionGroup*>(this->sender());
-  foreach (QAction* groupAction, group->actions())
+  Q_FOREACH (QAction* groupAction, group->actions())
   {
     if (groupAction != curAction && groupAction->isChecked())
     {
@@ -858,7 +918,30 @@ void pqStandardViewFrameActionsImplementation::captureViewTriggered()
   {
     // If a modifier key is enabled, let's save screenshot to a file, otherwise
     // copy the screenshot to the clipboard.
-    bool clipboardMode = QGuiApplication::queryKeyboardModifiers() == 0;
-    pqSaveScreenshotReaction::saveScreenshot(clipboardMode);
+    bool clipboardMode = QGuiApplication::queryKeyboardModifiers() != Qt::NoModifier;
+    bool captured = pqSaveScreenshotReaction::saveScreenshot(clipboardMode);
+    if (clipboardMode && captured)
+    {
+      auto viewWidget = pqActiveObjects::instance().activeView()->widget();
+      auto overlay = new pqColorOverlay(viewWidget);
+      overlay->resize(viewWidget->size());
+      // Light blue
+      overlay->setRgb(171, 223, 255);
+      overlay->show();
+
+      // Makes the overlay appear then disappear quickly to indicate a screenshot was taken
+      auto animation = new QPropertyAnimation(overlay, "opacity");
+
+      animation->setEasingCurve(QEasingCurve::OutQuad);
+      animation->setDuration(250);
+
+      animation->setKeyValueAt(0, 0);
+      animation->setKeyValueAt(0.1, 192);
+      animation->setKeyValueAt(1, 0);
+
+      animation->start();
+
+      this->connect(animation, &QPropertyAnimation::finished, [=] { overlay->deleteLater(); });
+    }
   }
 }
