@@ -29,8 +29,8 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =========================================================================*/
-#ifndef _pqTransferFunctionWidgetPropertyWidget_h
-#define _pqTransferFunctionWidgetPropertyWidget_h
+#ifndef pqTransferFunctionWidgetPropertyWidget_h
+#define pqTransferFunctionWidgetPropertyWidget_h
 
 #include "pqApplicationComponentsModule.h" // for export macros
 #include "pqPropertyWidget.h"
@@ -41,11 +41,11 @@ class vtkSMRangedTransferFunctionDomain;
 class pqTransferFunctionWidgetPropertyDialog;
 
 /**
-* A property widget for editing a transfer function.
-*
-* To use this widget for a property add the
-* 'panel_widget="transfer_function_editor"' to the property's XML.
-*/
+ * A property widget for editing a transfer function.
+ *
+ * To use this widget for a property add the
+ * 'panel_widget="transfer_function_editor"' to the property's XML.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqTransferFunctionWidgetPropertyWidget
   : public pqPropertyWidget
 {
@@ -53,7 +53,7 @@ class PQAPPLICATIONCOMPONENTS_EXPORT pqTransferFunctionWidgetPropertyWidget
 
 public:
   explicit pqTransferFunctionWidgetPropertyWidget(
-    vtkSMProxy* proxy, vtkSMProperty* property, QWidget* parent = 0);
+    vtkSMProxy* proxy, vtkSMProperty* property, QWidget* parent = nullptr);
   ~pqTransferFunctionWidgetPropertyWidget() override;
 
   friend pqTransferFunctionWidgetPropertyDialog;
@@ -64,7 +64,7 @@ Q_SIGNALS:
 protected:
   void UpdateProperty();
 
-protected Q_SLOTS:
+protected Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   void editButtonClicked();
   void propagateProxyPointsProperty();
   void resetRangeToDomainDefault();
@@ -89,4 +89,4 @@ private:
   const QScopedPointer<pqInternals> Internals;
 };
 
-#endif // _pqTransferFunctionWidgetPropertyWidget_h
+#endif // pqTransferFunctionWidgetPropertyWidget_h
