@@ -38,22 +38,22 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqVCRController;
 
 /**
-* pqVCRToolbar is the toolbar with VCR controls.
-* Simply instantiate this and put it in your application UI file or
-* QMainWindow to use it.
-*/
+ * pqVCRToolbar is the toolbar with VCR controls.
+ * Simply instantiate this and put it in your application UI file or
+ * QMainWindow to use it.
+ */
 class PQAPPLICATIONCOMPONENTS_EXPORT pqVCRToolbar : public QToolBar
 {
   Q_OBJECT
   typedef QToolBar Superclass;
 
 public:
-  pqVCRToolbar(const QString& title, QWidget* parentObject = 0)
+  pqVCRToolbar(const QString& title, QWidget* parentObject = nullptr)
     : Superclass(title, parentObject)
   {
     this->constructor();
   }
-  pqVCRToolbar(QWidget* parentObject = 0)
+  pqVCRToolbar(QWidget* parentObject = nullptr)
     : Superclass(parentObject)
   {
     this->constructor();
@@ -62,7 +62,7 @@ public:
 
 protected Q_SLOTS:
   void setTimeRanges(double, double);
-  void onPlaying(bool);
+  void onPlaying(bool, bool);
 
 private:
   Q_DISABLE_COPY(pqVCRToolbar)
