@@ -91,7 +91,7 @@ public:
   }
 
   QPointer<pqServer> ActiveServer;
-  typedef QMap<pqServer*, QPointer<pqAnimationScene> > SceneMap;
+  typedef QMap<pqServer*, QPointer<pqAnimationScene>> SceneMap;
   SceneMap Scenes;
 
   QSize OldMaxSize;
@@ -111,8 +111,12 @@ pqAnimationManager::pqAnimationManager(QObject* _parent /*=0*/)
   QObject::connect(smmodel, SIGNAL(proxyAdded(pqProxy*)), this, SLOT(onProxyAdded(pqProxy*)));
   QObject::connect(smmodel, SIGNAL(proxyRemoved(pqProxy*)), this, SLOT(onProxyRemoved(pqProxy*)));
 
-  QObject::connect(this, SIGNAL(beginPlay()), this, SLOT(onBeginPlay()));
-  QObject::connect(this, SIGNAL(endPlay()), this, SLOT(onEndPlay()));
+  QObject::connect(this,
+    QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::beginPlay), this,
+    QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::onBeginPlay));
+  QObject::connect(this,
+    QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::endPlay), this,
+    QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::onEndPlay));
 }
 
 //-----------------------------------------------------------------------------
@@ -163,8 +167,12 @@ void pqAnimationManager::onActiveServerChanged(pqServer* server)
   pqAnimationScene* activeScene = this->getActiveScene();
   if (activeScene)
   {
-    QObject::disconnect(activeScene, SIGNAL(beginPlay()), this, SIGNAL(beginPlay()));
-    QObject::disconnect(activeScene, SIGNAL(endPlay()), this, SIGNAL(endPlay()));
+    QObject::disconnect(activeScene,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationScene::beginPlay), this,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::beginPlay));
+    QObject::disconnect(activeScene,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationScene::endPlay), this,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::endPlay));
   }
 
   this->Internals->ActiveServer = server;
@@ -174,8 +182,12 @@ void pqAnimationManager::onActiveServerChanged(pqServer* server)
 
   if (activeScene)
   {
-    QObject::connect(activeScene, SIGNAL(beginPlay()), this, SIGNAL(beginPlay()));
-    QObject::connect(activeScene, SIGNAL(endPlay()), this, SIGNAL(endPlay()));
+    QObject::connect(activeScene,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationScene::beginPlay), this,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::beginPlay));
+    QObject::connect(activeScene,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationScene::endPlay), this,
+      QOverload<vtkObject*, unsigned long, void*, void*>::of(&pqAnimationManager::endPlay));
   }
 }
 
@@ -192,14 +204,14 @@ pqAnimationScene* pqAnimationManager::getScene(pqServer* server) const
   {
     return this->Internals->Scenes.value(server);
   }
-  return 0;
+  return nullptr;
 }
 
 //-----------------------------------------------------------------------------
 pqAnimationCue* pqAnimationManager::getCue(
   pqAnimationScene* scene, vtkSMProxy* proxy, const char* propertyname, int index) const
 {
-  return (scene ? scene->getCue(proxy, propertyname, index) : 0);
+  return (scene ? scene->getCue(proxy, propertyname, index) : nullptr);
 }
 
 //-----------------------------------------------------------------------------
@@ -218,13 +230,13 @@ bool pqAnimationManager::saveGeometry(const QString& filename, pqView* view)
 
   SM_SCOPED_TRACE(CallFunction)
     .arg("WriteAnimationGeometry")
-    .arg(filename.toLocal8Bit().data())
+    .arg(filename.toUtf8().data())
     .arg("view", view->getProxy())
     .arg("comment", "save animation geometry from a view");
 
   vtkSMProxy* sceneProxy = scene->getProxy();
   vtkSMAnimationSceneGeometryWriter* writer = vtkSMAnimationSceneGeometryWriter::New();
-  writer->SetFileName(filename.toLocal8Bit().data());
+  writer->SetFileName(filename.toUtf8().data());
   writer->SetAnimationScene(sceneProxy);
   writer->SetViewModule(view->getProxy());
   bool status = writer->Save();
@@ -250,6 +262,20 @@ void pqAnimationManager::onEndPlay()
   this->Internals->AnimationPlaying = false;
 }
 
+//-----------------------------------------------------------------------------
+void pqAnimationManager::onBeginPlay(
+  vtkObject* /*caller*/, unsigned long /*event_id*/, void*, void* /*reversed*/)
+{
+  this->Internals->AnimationPlaying = true;
+}
+
+//-----------------------------------------------------------------------------
+void pqAnimationManager::onEndPlay(
+  vtkObject* /*caller*/, unsigned long /*event_id*/, void*, void* /*reversed*/)
+{
+  this->Internals->AnimationPlaying = false;
+}
+
 //-----------------------------------------------------------------------------
 bool pqAnimationManager::animationPlaying() const
 {
