@@ -61,7 +61,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqComboBoxDomain.h"
 #include "pqCoreUtilities.h"
 #include "pqKeyFrameEditor.h"
-#include "pqOrbitCreatorDialog.h"
 #include "pqPipelineTimeKeyFrameEditor.h"
 #include "pqPropertyLinks.h"
 #include "pqRenderView.h"
@@ -75,7 +74,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqUndoStack.h"
 
 #include "vtkCamera.h"
-#include "vtkPVConfig.h"
 #include "vtkPVGeneralSettings.h"
 #include "vtkSMProperty.h"
 #include "vtkSMPropertyHelper.h"
@@ -176,6 +174,13 @@ public:
   {
     if (this->cameraCue(cue))
     {
+      vtkSMProxy* pxy = cue->getAnimatedProxy();
+      pqServerManagerModel* model = pqApplicationCore::instance()->getServerManagerModel();
+      if (pqProxy* animation_pqproxy = model->findItem<pqProxy*>(pxy))
+      {
+        return QString("Camera - %1").arg(animation_pqproxy->getSMName());
+      }
+
       return "Camera";
     }
     else if (this->pythonCue(cue))
@@ -493,7 +498,7 @@ void pqAnimationViewWidget::onSceneCuesChanged()
   pqInternal::TrackMapType::iterator iter;
 
   // add new tracks
-  foreach (pqAnimationCue* cue, cues)
+  Q_FOREACH (pqAnimationCue* cue, cues)
   {
     if (cue == nullptr)
     {
@@ -653,6 +658,7 @@ void pqAnimationViewWidget::setKeyFrameTime(
 
   if (i < keyFrames.size())
   {
+    SM_SCOPED_TRACE(PropertiesModified).arg(keyFrames[i]);
     QPair<double, double> timeRange = this->Internal->Scene->getClockTimeRange();
     double normTime = (time - timeRange.first) / (timeRange.second - timeRange.first);
     pqSMAdaptor::setElementProperty(keyFrames[i]->GetProperty("KeyTime"), normTime);
@@ -735,7 +741,14 @@ void pqAnimationViewWidget::trackSelected(pqAnimationTrack* track)
 
       l->addWidget(editor);
 
+      auto apply = buttons->addButton(QDialogButtonBox::Apply);
+
       connect(this->Internal->Editor, SIGNAL(accepted()), editor, SLOT(writeKeyFrameData()));
+      QObject::connect(apply, &QPushButton::clicked, editor, &pqKeyFrameEditor::writeKeyFrameData);
+
+      QObject::connect(apply, &QPushButton::clicked, [=]() { apply->setEnabled(false); });
+      QObject::connect(editor, &pqKeyFrameEditor::modified, [=]() { apply->setEnabled(true); });
+
       this->Internal->Editor->setWindowTitle(tr("Animation Keyframes"));
       this->Internal->Editor->resize(600, 400);
     }
@@ -824,7 +837,7 @@ void pqAnimationViewWidget::updatePlayMode()
       SIGNAL(editingFinished()), this->Internal->Scene->getProxy(),
       this->Internal->Scene->getProxy()->GetProperty("NumberOfFrames"));
     this->Internal->Stride->setText(QString::number(this->Internal->SequenceStrideCache));
-    emit this->Internal->Stride->editingFinished();
+    Q_EMIT this->Internal->Stride->editingFinished();
   }
   else if (mode == "Snap To TimeSteps")
   {
@@ -849,7 +862,7 @@ void pqAnimationViewWidget::updatePlayMode()
     this->Internal->EndTime->setEnabled(false);
 
     this->Internal->Stride->setText(QString::number(this->Internal->TimestepStrideCache));
-    emit this->Internal->Stride->editingFinished();
+    Q_EMIT this->Internal->Stride->editingFinished();
   }
   else
   {
@@ -907,6 +920,7 @@ void pqAnimationViewWidget::toggleTrackEnabled(pqAnimationTrack* track)
     return;
   }
   BEGIN_UNDO_SET("Toggle Animation Track");
+  SM_SCOPED_TRACE(PropertiesModified).arg(cue->getProxy());
   cue->setEnabled(!track->isEnabled());
   END_UNDO_SET();
 }
@@ -920,6 +934,7 @@ void pqAnimationViewWidget::deleteTrack(pqAnimationTrack* track)
     return;
   }
   BEGIN_UNDO_SET("Remove Animation Track");
+  SM_SCOPED_TRACE(Delete).arg(cue->getProxy());
   this->Internal->Scene->removeCue(cue);
   END_UNDO_SET();
 }
@@ -956,13 +971,9 @@ void pqAnimationViewWidget::setCurrentProxy(vtkSMProxy* pxy)
     this->Internal->CreateProperty->setSourceWithoutProperties(pxy);
     // add camera animation modes as properties for creating the camera
     // animation track.
-    this->Internal->CreateProperty->addSMProperty("Orbit", "orbit", 0);
     this->Internal->CreateProperty->addSMProperty("Follow Path", "path", 0);
     this->Internal->CreateProperty->addSMProperty("Follow Data", "data", 0);
-    this->Internal->CreateProperty->addSMProperty(
-      "Interpolate camera locations (spline)", "camera", 0);
-    this->Internal->CreateProperty->addSMProperty(
-      "Interpolate camera locations (linear)", "linearCamera", 0);
+    this->Internal->CreateProperty->addSMProperty("Interpolate cameras", "camera", 0);
   }
   else
   {
@@ -1003,7 +1014,7 @@ void pqAnimationViewWidget::createTrack()
   }
 
   // check that we don't already have one
-  foreach (pqAnimationCue* cue, this->Internal->TrackMap.keys())
+  Q_FOREACH (pqAnimationCue* cue, this->Internal->TrackMap.keys())
   {
     if (cue->getAnimatedProxy() == nullptr)
     {
@@ -1017,20 +1028,6 @@ void pqAnimationViewWidget::createTrack()
     }
   }
 
-  pqOrbitCreatorDialog creator(this);
-
-  // if mode=="orbit" show up a dialog allowing the user to customize the
-  // orbit.
-  if (ren && mode == "orbit")
-  {
-    creator.setNormal(ren->GetActiveCamera()->GetViewUp());
-    creator.setOrigin(ren->GetActiveCamera()->GetPosition());
-    if (creator.exec() != QDialog::Accepted)
-    {
-      return;
-    }
-  }
-
   BEGIN_UNDO_SET("Add Animation Track");
 
   // This will create the cue and initialize it with default keyframes.
@@ -1041,7 +1038,7 @@ void pqAnimationViewWidget::createTrack()
 
   if (ren)
   {
-    if (mode == "path" || mode == "orbit")
+    if (mode == "path")
     {
       // Setup default animation to revolve around the selected objects (if any)
       // in a plane normal to the current view-up vector.
@@ -1066,21 +1063,9 @@ void pqAnimationViewWidget::createTrack()
       pqSMAdaptor::setElementProperty(
         cue->getProxy()->GetProperty("Mode"), 0); // non-PATH-based animation.
 
-      pqSMAdaptor::setElementProperty(
-        cue->getProxy()->GetProperty("Interpolation"), (mode == "camera") ? 1 : 0);
+      pqSMAdaptor::setElementProperty(cue->getProxy()->GetProperty("Interpolation"), 1);
     }
     cue->getProxy()->UpdateVTKObjects();
-
-    if (mode == "orbit")
-    {
-      // update key frame parameters based on the orbit points.
-      vtkSMProxy* kf = cue->getKeyFrame(0);
-      pqSMAdaptor::setMultipleElementProperty(
-        kf->GetProperty("PositionPathPoints"), creator.orbitPoints(7));
-      pqSMAdaptor::setMultipleElementProperty(kf->GetProperty("FocalPathPoints"), creator.center());
-      pqSMAdaptor::setElementProperty(kf->GetProperty("ClosedPositionPath"), 1);
-      kf->UpdateVTKObjects();
-    }
   }
 
   END_UNDO_SET();
@@ -1157,6 +1142,7 @@ void pqAnimationViewWidget::onStrideChanged()
 {
   int strideValue = this->Internal->Stride->text().toInt();
   vtkSMProxy* proxy = this->Internal->Scene->getProxy();
+  SM_SCOPED_TRACE(PropertiesModified).arg(proxy);
   vtkSMPropertyHelper(proxy->GetProperty("Stride"), false).Set(strideValue);
   proxy->UpdateProperty("Stride");
 
