@@ -41,14 +41,14 @@ class vtkSMProxy;
 class vtkSMDomain;
 
 /**
-* pqArrayListDomain is used to connect a widget showing a selection of arrays
-* with its vtkSMArrayListDomain. Whenever the vtkSMArrayListDomain changes,
-* the widget is "reset" to update using the property's new domain. This is
-* useful for DescriptiveStatistics panel, for example. Whenever the attribute
-* selection changes (i.e. user switches from cell-data to point-data), we need
-* to update the widget's contents to show the list of array in the
-* corresponding attribute. This class takes care of that.
-*/
+ * pqArrayListDomain is used to connect a widget showing a selection of arrays
+ * with its vtkSMArrayListDomain. Whenever the vtkSMArrayListDomain changes,
+ * the widget is "reset" to update using the property's new domain. This is
+ * useful for DescriptiveStatistics panel, for example. Whenever the attribute
+ * selection changes (i.e. user switches from cell-data to point-data), we need
+ * to update the widget's contents to show the list of array in the
+ * corresponding attribute. This class takes care of that.
+ */
 class PQCOMPONENTS_EXPORT pqArrayListDomain : public QObject
 {
   Q_OBJECT
@@ -62,7 +62,7 @@ public:
 private Q_SLOTS:
   void domainChanged();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqArrayListDomain)
   class pqInternals;
   pqInternals* Internals;
