@@ -35,6 +35,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqActiveObjects.h"
 #include "pqApplicationCore.h"
 #include "pqProxyWidget.h"
+#include "pqSMAdaptor.h"
 #include "pqServer.h"
 #include "vtkCamera.h"
 #include "vtkPVSession.h"
@@ -61,7 +62,7 @@ public:
   vtkSmartPointer<vtkSMProxy> FSplineProxy;
   QPointer<pqProxyWidget> FSplineWidget;
   double Data[3];
-  pqInternal() {}
+  pqInternal() = default;
 
   void setupValidators(QObject* parent)
   {
@@ -162,7 +163,7 @@ pqCameraKeyFrameWidget::pqCameraKeyFrameWidget(QWidget* parentObject)
 
   // hide the header for the tree widget.
   this->Internal->leftPane->header()->hide();
-  this->Internal->leftPane->setCurrentItem(0);
+  this->Internal->leftPane->setCurrentItem(nullptr);
 
   this->connect(this->Internal->leftPane,
     SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this,
@@ -185,6 +186,7 @@ pqCameraKeyFrameWidget::pqCameraKeyFrameWidget(QWidget* parentObject)
 
   this->Internal->PSplineProxy.TakeReference(pxm->NewProxy("parametric_functions", "Spline"));
   this->Internal->PSplineProxy->SetLocation(vtkPVSession::CLIENT);
+  vtkSMPropertyHelper(this->Internal->PSplineProxy, "Closed").Set(1);
   this->Internal->PSplineProxy->UpdateVTKObjects();
 
   this->Internal->PSplineWidget = new pqProxyWidget(this->Internal->PSplineProxy, this);
@@ -229,6 +231,38 @@ bool pqCameraKeyFrameWidget::usePathBasedMode() const
   return (this->Internal->stackedWidgetMode->currentIndex() == 0);
 }
 
+//-----------------------------------------------------------------------------
+void pqCameraKeyFrameWidget::setPositionPoints(const std::vector<double>& positions)
+{
+  this->Internal->setPosition(positions.data());
+
+  QList<QVariant> varPos;
+  for (auto pos : positions)
+  {
+    varPos << pos;
+  }
+  pqSMAdaptor::setMultipleElementProperty(
+    this->Internal->PSplineProxy->GetProperty("Points"), varPos);
+
+  this->Internal->PSplineProxy->UpdateVTKObjects();
+}
+
+//-----------------------------------------------------------------------------
+void pqCameraKeyFrameWidget::setFocalPoints(const std::vector<double>& focals)
+{
+  this->Internal->setFocalPoint(focals.data());
+
+  QList<QVariant> varFocus;
+  for (auto focus : focals)
+  {
+    varFocus << focus;
+  }
+  pqSMAdaptor::setMultipleElementProperty(
+    this->Internal->FSplineProxy->GetProperty("FocalPoints"), varFocus);
+
+  this->Internal->FSplineProxy->UpdateVTKObjects();
+}
+
 //-----------------------------------------------------------------------------
 /// Initialize the widget using the values from the key frame proxy.
 void pqCameraKeyFrameWidget::initializeUsingKeyFrame(vtkSMProxy* keyFrame)
@@ -342,5 +376,5 @@ void pqCameraKeyFrameWidget::showEvent(QShowEvent* anEvent)
 void pqCameraKeyFrameWidget::hideEvent(QHideEvent* anEvent)
 {
   this->Superclass::hideEvent(anEvent);
-  this->Internal->leftPane->setCurrentItem(0);
+  this->Internal->leftPane->setCurrentItem(nullptr);
 }
