@@ -39,38 +39,38 @@ class vtkSMProxy;
 class vtkCamera;
 
 /**
-* pqCameraKeyFrameWidget is the widget that is shown to edit the value of a
-* single camera key frame. This class is based on pqCameraWidget and hence has
-* sections of code borrowed from there.
-*/
+ * pqCameraKeyFrameWidget is the widget that is shown to edit the value of a
+ * single camera key frame. This class is based on pqCameraWidget and hence has
+ * sections of code borrowed from there.
+ */
 class PQCOMPONENTS_EXPORT pqCameraKeyFrameWidget : public QWidget
 {
   Q_OBJECT
   typedef QWidget Superclass;
 
 public:
-  pqCameraKeyFrameWidget(QWidget* parent = 0);
+  pqCameraKeyFrameWidget(QWidget* parent = nullptr);
   ~pqCameraKeyFrameWidget() override;
 
   bool usePathBasedMode() const;
 
 Q_SIGNALS:
   /**
-  * Fired when user requests the use of the current camera as the value for
-  * the key frame.
-  */
+   * Fired when user requests the use of the current camera as the value for
+   * the key frame.
+   */
   void useCurrentCamera();
   void updateCurrentCamera();
 
 public Q_SLOTS:
   /**
-  * Initialize the widget using the values from the key frame proxy.
-  */
+   * Initialize the widget using the values from the key frame proxy.
+   */
   void initializeUsingKeyFrame(vtkSMProxy* keyframeProxy);
 
   /**
-  * Initialize the widget using the camera.
-  */
+   * Initialize the widget using the camera.
+   */
   void initializeUsingCamera(vtkCamera* camera);
 
   /**
@@ -79,18 +79,28 @@ public Q_SLOTS:
   void applyToCamera(vtkCamera* camera);
 
   /**
-  * The camera keyframes have 2 modes either interpolate vtkCamera's using the
-  * camera interpolator or use path-based. This mode is not defined on
-  * per-keyframe basis, but on the entire animation track. Hence, we provide
-  * this slot to choose which mode should the widget operate in.
-  */
+   * The camera keyframes have 2 modes either interpolate vtkCamera's using the
+   * camera interpolator or use path-based. This mode is not defined on
+   * per-keyframe basis, but on the entire animation track. Hence, we provide
+   * this slot to choose which mode should the widget operate in.
+   */
   void setUsePathBasedMode(bool);
 
   /**
-  * Write the user chosen values for this key frame to the proxy.
-  */
+   * Write the user chosen values for this key frame to the proxy.
+   */
   void saveToKeyFrame(vtkSMProxy* keyframeProxy);
 
+  /**
+   * Set the positions points for path-based keyframe.
+   */
+  void setPositionPoints(const std::vector<double>&);
+
+  /**
+   * Set the focal points for path-based keyframe.
+   */
+  void setFocalPoints(const std::vector<double>&);
+
 protected:
   // Overridden to update the 3D widget's visibility states.
   void showEvent(QShowEvent*) override;
@@ -98,11 +108,11 @@ protected:
 
 private Q_SLOTS:
   /**
-  * called when the user clicks on an item in the left pane.
-  */
+   * called when the user clicks on an item in the left pane.
+   */
   void changeCurrentPage();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqCameraKeyFrameWidget)
 
   class pqInternal;
