@@ -42,22 +42,22 @@ class vtkSMComparativeAnimationCueProxy;
 class vtkSMProxy;
 
 /**
-* pqComparativeCueWidget is designed to be used by
-* pqComparativeVisPanel to show/edit the values for an
-* vtkSMComparativeAnimationCueProxy.
-*/
+ * pqComparativeCueWidget is designed to be used by
+ * pqComparativeVisPanel to show/edit the values for an
+ * vtkSMComparativeAnimationCueProxy.
+ */
 class PQCOMPONENTS_EXPORT pqComparativeCueWidget : public QTableWidget
 {
   Q_OBJECT
   typedef QTableWidget Superclass;
 
 public:
-  pqComparativeCueWidget(QWidget* parent = 0);
+  pqComparativeCueWidget(QWidget* parent = nullptr);
   ~pqComparativeCueWidget() override;
 
   /**
-  * Get/Set the cue that is currently being shown/edited by this widget.
-  */
+   * Get/Set the cue that is currently being shown/edited by this widget.
+   */
   void setCue(vtkSMProxy*);
   vtkSMComparativeAnimationCueProxy* cue() const;
 
@@ -66,10 +66,10 @@ public:
   // Returns if this cue can accept more than 1 value as a parameter value.
   bool acceptsMultipleValues() const;
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * Set the comparative grid size.
-  */
+   * Set the comparative grid size.
+   */
   void setSize(int w, int h)
   {
     this->Size = QSize(w, h);
@@ -82,8 +82,8 @@ Q_SIGNALS:
 
 protected Q_SLOTS:
   /**
-  * refreshes the GUI with values from the proxy.
-  */
+   * refreshes the GUI with values from the proxy.
+   */
   void updateGUI();
 
   void updateGUIOnIdle() { this->IdleUpdateTimer.start(); }
@@ -92,11 +92,11 @@ protected Q_SLOTS:
 
   void onCellChanged(int x, int y);
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * called when mouse is released. We use this to popup the range editing
-  * dialog if the selection changed.
-  */
+   * called when mouse is released. We use this to popup the range editing
+   * dialog if the selection changed.
+   */
   void mouseReleaseEvent(QMouseEvent* evt) override;
 
   void editRange();
