@@ -95,12 +95,12 @@ class pqDisplayColorWidget::PropertyLinksConnection : public pqPropertyLinksConn
 public:
   PropertyLinksConnection(QObject* qobject, const char* qproperty, const char* qsignal,
     vtkSMProxy* smproxy, vtkSMProperty* smproperty, int smindex, bool use_unchecked_modified_event,
-    QObject* parentObject = 0)
+    QObject* parentObject = nullptr)
     : Superclass(qobject, qproperty, qsignal, smproxy, smproperty, smindex,
         use_unchecked_modified_event, parentObject)
   {
   }
-  ~PropertyLinksConnection() override {}
+  ~PropertyLinksConnection() override = default;
 
   // Methods to convert between ValueType and QVariant. Since QVariant doesn't
   // support == operations of non-default Qt types, we are forced to convert the
@@ -147,7 +147,7 @@ protected:
     vtkSMProxy* oldLutProxy = vtkSMPropertyHelper(reprProxy, "LookupTable", true).GetAsProxy();
 
     vtkSMPVRepresentationProxy::SetScalarColoring(
-      reprProxy, arrayName.toLocal8Bit().data(), association);
+      reprProxy, arrayName.toUtf8().data(), association);
 
     vtkNew<vtkSMTransferFunctionManager> tmgr;
     pqDisplayColorWidget* widget = qobject_cast<pqDisplayColorWidget*>(this->objectQt());
@@ -165,22 +165,7 @@ protected:
 
     if (!arrayName.isEmpty())
     {
-      // we could now respect some application setting to determine if the LUT is
-      // to be reset.
-      vtkSMPVRepresentationProxy::RescaleTransferFunctionToDataRange(
-        reprProxy, /*extend*/ true, /*force*/ false);
-
-      /// BUG #0011858. Users often do silly things!
-      bool reprVisibility =
-        vtkSMPropertyHelper(reprProxy, "Visibility", /*quiet*/ true).GetAsInt() == 1;
-
-      // now show used scalar bars if applicable.
-      if (reprVisibility &&
-        gsettings->GetScalarBarMode() ==
-          vtkPVGeneralSettings::AUTOMATICALLY_SHOW_AND_HIDE_SCALAR_BARS)
-      {
-        vtkSMPVRepresentationProxy::SetScalarBarVisibility(reprProxy, view, true);
-      }
+      pqDisplayColorWidget::updateScalarBarVisibility(view, reprProxy);
     }
     END_UNDO_SET();
   }
@@ -219,6 +204,28 @@ private:
   Q_DISABLE_COPY(PropertyLinksConnection)
 };
 
+//-----------------------------------------------------------------------------
+void pqDisplayColorWidget::updateScalarBarVisibility(vtkSMViewProxy* view, vtkSMProxy* reprProxy)
+{
+  // we could now respect some application setting to determine if the LUT is
+  // to be reset.
+  vtkSMPVRepresentationProxy::RescaleTransferFunctionToDataRange(
+    reprProxy, /*extend*/ true, /*force*/ false);
+
+  /// BUG #0011858. Users often do silly things!
+  bool reprVisibility =
+    vtkSMPropertyHelper(reprProxy, "Visibility", /*quiet*/ true).GetAsInt() == 1;
+
+  vtkPVGeneralSettings* gsettings = vtkPVGeneralSettings::GetInstance();
+
+  // now show used scalar bars if applicable.
+  if (reprVisibility &&
+    gsettings->GetScalarBarMode() == vtkPVGeneralSettings::AUTOMATICALLY_SHOW_AND_HIDE_SCALAR_BARS)
+  {
+    vtkSMPVRepresentationProxy::SetScalarBarVisibility(reprProxy, view, true);
+  }
+}
+
 //=============================================================================
 class pqDisplayColorWidget::pqInternals
 {
@@ -237,7 +244,7 @@ public:
 //-----------------------------------------------------------------------------
 pqDisplayColorWidget::pqDisplayColorWidget(QWidget* parentObject)
   : Superclass(parentObject)
-  , CachedRepresentation(NULL)
+  , CachedRepresentation(nullptr)
   , Internals(new pqDisplayColorWidget::pqInternals())
 {
   this->CellDataIcon = new QIcon(":/pqWidgets/Icons/pqCellData.svg");
@@ -298,7 +305,7 @@ vtkSMViewProxy* pqDisplayColorWidget::viewProxy() const
   {
     return this->Representation->getViewProxy();
   }
-  return NULL;
+  return nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -312,19 +319,19 @@ void pqDisplayColorWidget::setRepresentation(pqDataRepresentation* repr)
   if (this->Representation)
   {
     this->disconnect(this->Representation);
-    this->Representation = NULL;
+    this->Representation = nullptr;
   }
   if (this->ColorTransferFunction)
   {
     this->disconnect(this->ColorTransferFunction);
     this->ColorTransferFunction->disconnect(this);
-    this->ColorTransferFunction = NULL;
+    this->ColorTransferFunction = nullptr;
   }
   this->Variables->setEnabled(false);
   this->Components->setEnabled(false);
   this->Internals->Links.clear();
   this->Internals->Connector->Disconnect();
-  this->Internals->Domain = NULL;
+  this->Internals->Domain = nullptr;
   this->Variables->clear();
   this->Components->clear();
   this->Internals->OutOfDomainEntryIndex = -1;
@@ -333,8 +340,8 @@ void pqDisplayColorWidget::setRepresentation(pqDataRepresentation* repr)
   this->CachedRepresentation = repr;
   this->Representation = repr;
 
-  vtkSMProxy* proxy = repr ? repr->getProxy() : NULL;
-  bool can_color = (proxy != NULL && proxy->GetProperty("ColorArrayName") != NULL);
+  vtkSMProxy* proxy = repr ? repr->getProxy() : nullptr;
+  bool can_color = (proxy != nullptr && proxy->GetProperty("ColorArrayName") != nullptr);
   if (!can_color)
   {
     return;
@@ -532,8 +539,7 @@ void pqDisplayColorWidget::setComponentNumber(int val)
       this->Components->blockSignals(false);
 
       index = this->Components->findData(val);
-      qDebug() << "Component " << val << " is not currently known. "
-                                         "Will add a new entry for it.";
+      qDebug() << "Component " << val << " is not currently known. Will add a new entry for it.";
     }
     assert(index != -1);
     this->Components->blockSignals(true);
@@ -558,15 +564,15 @@ void pqDisplayColorWidget::componentNumberChanged()
     { // To make sure the trace is done before other calls.
       SM_SCOPED_TRACE(SetScalarColoring)
         .arg("display", this->Representation->getProxy())
-        .arg("arrayname", arrayName.toLatin1().data())
+        .arg("arrayname", arrayName.toUtf8().data())
         .arg("attribute_type", association)
-        .arg("component", this->Components->itemText(number + 1).toLatin1().data())
+        .arg("component", this->Components->itemText(number + 1).toUtf8().data())
         .arg("lut", this->ColorTransferFunction->getProxy());
     }
 
     // we could now respect some application setting to determine if the LUT is
     // to be reset.
-    vtkSMProxy* reprProxy = this->Representation ? this->Representation->getProxy() : NULL;
+    vtkSMProxy* reprProxy = this->Representation ? this->Representation->getProxy() : nullptr;
     vtkSMPVRepresentationProxy::RescaleTransferFunctionToDataRange(
       reprProxy, /*extend*/ false, /*force*/ false);
 
@@ -597,12 +603,12 @@ void pqDisplayColorWidget::refreshComponents()
 
   vtkPVDataInformation* dataInfo = this->Representation->getInputDataInformation();
   vtkPVArrayInformation* arrayInfo =
-    dataInfo ? dataInfo->GetArrayInformation(arrayName.toLocal8Bit().data(), association) : NULL;
+    dataInfo ? dataInfo->GetArrayInformation(arrayName.toUtf8().data(), association) : nullptr;
   if (!arrayInfo)
   {
     vtkPVDataInformation* reprInfo = this->Representation->getRepresentedDataInformation();
     arrayInfo =
-      reprInfo ? reprInfo->GetArrayInformation(arrayName.toLocal8Bit().data(), association) : NULL;
+      reprInfo ? reprInfo->GetArrayInformation(arrayName.toUtf8().data(), association) : nullptr;
   }
 
   if (!arrayInfo || arrayInfo->GetNumberOfComponents() <= 1)
