@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile$
+   Module:  pqFindDataCurrentSelectionFrame.h
 
    Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -38,12 +38,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqOutputPort;
 
 /**
-* pqFindDataCurrentSelectionFrame is designed to be used by pqFindDataDialog.
-* pqFindDataDialog uses this class to show the current selection in a
-* spreadsheet view. This class encapsulates the logic to monitor the current
-* selection by tracking the pqSelectionManager and then showing the results in
-* the spreadsheet.
-*/
+ * pqFindDataCurrentSelectionFrame is designed to be used by pqFindDataDialog.
+ * pqFindDataDialog uses this class to show the current selection in a
+ * spreadsheet view. This class encapsulates the logic to monitor the current
+ * selection by tracking the pqSelectionManager and then showing the results in
+ * the spreadsheet.
+ */
 class PQCOMPONENTS_EXPORT pqFindDataCurrentSelectionFrame : public QWidget
 {
   Q_OBJECT
@@ -54,42 +54,42 @@ public:
   ~pqFindDataCurrentSelectionFrame() override;
 
   /**
-  * return the port from which this frame is showing the selected data, if
-  * any.
-  */
+   * return the port from which this frame is showing the selected data, if
+   * any.
+   */
   pqOutputPort* showingPort() const;
 
 Q_SIGNALS:
   /**
-  * signal fired to indicate the selected port that currently being shown in
-  * the frame.
-  */
+   * signal fired to indicate the selected port that currently being shown in
+   * the frame.
+   */
   void showing(pqOutputPort*);
 
 private Q_SLOTS:
   /**
-  * show the selected data from the given output port in the frame.
-  */
+   * show the selected data from the given output port in the frame.
+   */
   void showSelectedData(pqOutputPort*);
 
   /**
-  * update the field-type set of the internal spreadsheet view based on the
-  * value in the combo-box.
-  */
+   * update the field-type set of the internal spreadsheet view based on the
+   * value in the combo-box.
+   */
   void updateFieldType();
 
   /**
-  * set the value for the "invert selection" property on the extract-selection
-  * source to the one specified.
-  */
+   * set the value for the "invert selection" property on the extract-selection
+   * source to the one specified.
+   */
   void invertSelection(bool);
 
   /**
-  * update the data shown in the spreadsheet aka render the spreadsheet.
-  */
+   * update the data shown in the spreadsheet aka render the spreadsheet.
+   */
   void updateSpreadSheet();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqFindDataCurrentSelectionFrame)
 
   class pqInternals;
