@@ -44,19 +44,19 @@ class QGroupBox;
 class QVBoxLayout;
 
 /**
-* pqIndexSelectionWidget displays a list of labels and slider widgets,
-* intended to be used for selecting an index into a zero-based enumeration.
-*/
+ * pqIndexSelectionWidget displays a list of labels and slider widgets,
+ * intended to be used for selecting an index into a zero-based enumeration.
+ */
 class PQCOMPONENTS_EXPORT pqIndexSelectionWidget : public pqPropertyWidget
 {
   Q_OBJECT
   typedef pqPropertyWidget Superclass;
 
 public:
-  pqIndexSelectionWidget(vtkSMProxy* proxy, vtkSMProperty* property, QWidget* parent = 0);
+  pqIndexSelectionWidget(vtkSMProxy* proxy, vtkSMProperty* property, QWidget* parent = nullptr);
   ~pqIndexSelectionWidget() override;
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   void setHeaderLabel(const QString& str);
   void setPushPropertyName(const QByteArray& pName);
 
@@ -69,20 +69,20 @@ protected Q_SLOTS:
   void currentChanged(); // pqLineEdit::textChangedAndEditingFinished() handler
 
   /**
-  * Start a timer that calls updatePropertyImpl. This slot is triggered when
-  * a widget is modified.
-  */
+   * Start a timer that calls updatePropertyImpl. This slot is triggered when
+   * a widget is modified.
+   */
   void updateProperty();
   /**
-  * Update the Qt property with current widget state. Emits widgetModified.
-  */
+   * Update the Qt property with current widget state. Emits widgetModified.
+   */
   void updatePropertyImpl();
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   bool eventFilter(QObject* obj, QEvent* e) override;
   /**
-  * Update the widget state from the PropertyLink Qt property.
-  */
+   * Update the widget state from the PropertyLink Qt property.
+   */
   void propertyChanged();
 
 private:
@@ -92,8 +92,8 @@ private:
   void addRow(const QString& key, int current, int size);
 
   /**
-  * The names of the Qt properties used to sync with the vtkSMProperty.
-  */
+   * The names of the Qt properties used to sync with the vtkSMProperty.
+   */
   QByteArray PushPropertyName;
 
   bool PropertyUpdatePending;     // Only update the property once per 250 ms.
