@@ -30,6 +30,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =========================================================================*/
 
+// Hide PARAVIEW_DEPRECATED_IN_5_10_0() warnings for this class.
+#define PARAVIEW_DEPRECATION_LEVEL 0
+
 #include "pqIntRangeWidget.h"
 
 // Qt includes
@@ -48,8 +51,8 @@ pqIntRangeWidget::pqIntRangeWidget(QWidget* p)
   this->Value = 0;
   this->Minimum = 0;
   this->Maximum = 1;
-  this->Domain = 0;
-  this->DomainConnection = 0;
+  this->Domain = nullptr;
+  this->DomainConnection = nullptr;
   this->InteractingWithSlider = false;
   this->DeferredValueEdited = false;
 
@@ -149,36 +152,30 @@ void pqIntRangeWidget::setMinimum(int val)
 //-----------------------------------------------------------------------------
 void pqIntRangeWidget::updateValidator()
 {
-#if !defined(VTK_LEGACY_REMOVE)
   if (this->StrictRange)
   {
     this->LineEdit->setValidator(
       new QIntValidator(this->minimum(), this->maximum(), this->LineEdit));
   }
   else
-#endif
   {
     this->LineEdit->setValidator(new QIntValidator(this->LineEdit));
   }
 }
 
-#if !defined(VTK_LEGACY_REMOVE)
 //-----------------------------------------------------------------------------
 bool pqIntRangeWidget::strictRange() const
 {
   const QIntValidator* dv = qobject_cast<const QIntValidator*>(this->LineEdit->validator());
   return dv->bottom() == this->minimum() && dv->top() == this->maximum();
 }
-#endif
 
-#if !defined(VTK_LEGACY_REMOVE)
 //-----------------------------------------------------------------------------
 void pqIntRangeWidget::setStrictRange(bool s)
 {
   this->StrictRange = s;
   this->updateValidator();
 }
-#endif
 
 //-----------------------------------------------------------------------------
 void pqIntRangeWidget::setDomain(vtkSMIntRangeDomain* domain)
@@ -195,7 +192,7 @@ void pqIntRangeWidget::setDomain(vtkSMIntRangeDomain* domain)
     if (this->DomainConnection)
     {
       this->DomainConnection->Delete();
-      this->DomainConnection = 0;
+      this->DomainConnection = nullptr;
     }
 
     this->DomainConnection = vtkEventQtSlotConnect::New();
