@@ -33,7 +33,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define pqIntRangeWidget_h
 
 #include "pqComponentsModule.h"
-#include "vtkSetGet.h" // for VTK_LEGACY
+#include "vtkParaViewDeprecation.h" // for PARAVIEW_DEPRECATED_IN_5_10_0
 #include "vtkSmartPointer.h"
 #include <QWidget>
 
@@ -43,28 +43,27 @@ class vtkSMIntRangeDomain;
 class vtkEventQtSlotConnect;
 
 /**
-* a widget with a tied slider and line edit for editing a int property
-*/
+ * a widget with a tied slider and line edit for editing a int property
+ */
 class PQCOMPONENTS_EXPORT pqIntRangeWidget : public QWidget
 {
   Q_OBJECT
   Q_PROPERTY(int value READ value WRITE setValue USER true)
   Q_PROPERTY(int minimum READ minimum WRITE setMinimum)
   Q_PROPERTY(int maximum READ maximum WRITE setMaximum)
-#if !defined(VTK_LEGACY_REMOVE)
+  // PARAVIEW_DEPRECATED_IN_5_10_0("Removed; it did not work as intended")
   Q_PROPERTY(bool strictRange READ strictRange WRITE setStrictRange);
-#endif
 
 public:
   /**
-  * constructor requires the proxy, property
-  */
-  pqIntRangeWidget(QWidget* parent = NULL);
+   * constructor requires the proxy, property
+   */
+  pqIntRangeWidget(QWidget* parent = nullptr);
   ~pqIntRangeWidget() override;
 
   /**
-  * get the value
-  */
+   * get the value
+   */
   int value() const;
 
   // get the min range value
@@ -75,7 +74,8 @@ public:
   /**
    * @deprecated strictRange is deprecated and is not working as intended
    */
-  VTK_LEGACY(bool strictRange() const);
+  PARAVIEW_DEPRECATED_IN_5_10_0("Removed; it did not work as intended")
+  bool strictRange() const;
 
   // Sets the range domain to monitor. This will automatically update
   // the widgets range when the domain changes.
@@ -83,22 +83,21 @@ public:
 
 Q_SIGNALS:
   /**
-  * signal the value changed
-  */
+   * signal the value changed
+   */
   void valueChanged(int);
 
   /**
-  * signal the value was edited
-  * this means the user is done changing text
-  * or the user is done moving the slider. It implies
-  * value was changed and editing has finished.
-  */
+   * signal the value was edited
+   * this means the user is done changing text or the user is done moving the
+   * slider. It implies value was changed and editing has finished.
+   */
   void valueEdited(int);
 
 public Q_SLOTS:
   /**
-  * set the value
-  */
+   * set the value
+   */
   void setValue(int);
 
   // set the min range value
@@ -106,12 +105,11 @@ public Q_SLOTS:
   // set the max range value
   void setMaximum(int);
 
-#if !defined(VTK_LEGACY_REMOVE)
   /**
    * @deprecated strictRange is deprecated and is not working as intended
    */
+  PARAVIEW_DEPRECATED_IN_5_10_0("Removed; it did not work as intended")
   void setStrictRange(bool);
-#endif
 
 private Q_SLOTS:
   void sliderChanged(int);
@@ -124,16 +122,15 @@ private Q_SLOTS:
   void sliderPressed();
   void sliderReleased();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   int Value;
   int Minimum;
   int Maximum;
   QSlider* Slider;
   pqLineEdit* LineEdit;
   bool BlockUpdate;
-#if !defined(VTK_LEGACY_REMOVE)
+  PARAVIEW_DEPRECATED_IN_5_10_0("Removed; it did not work as intended")
   bool StrictRange = false;
-#endif
   vtkSmartPointer<vtkSMIntRangeDomain> Domain;
   vtkEventQtSlotConnect* DomainConnection;
   bool InteractingWithSlider;
