@@ -30,8 +30,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =========================================================================*/
 
-#ifndef _pqKeyFrameEditor_h
-#define _pqKeyFrameEditor_h
+#ifndef pqKeyFrameEditor_h
+#define pqKeyFrameEditor_h
 
 #include "pqComponentsModule.h"
 #include <QDialog>
@@ -39,10 +39,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 class pqAnimationCue;
 class pqAnimationScene;
+class QStandardItem;
 
 /**
-* editor for editing animation key frames
-*/
+ * editor for editing animation key frames
+ */
 class PQCOMPONENTS_EXPORT pqKeyFrameEditor : public QWidget
 {
   typedef QWidget Superclass;
@@ -54,32 +55,45 @@ public:
   ~pqKeyFrameEditor() override;
 
   /**
-  * The keyframe editor can be set in a mode where the user can only edit the
-  * key frame values or keyframe interpolation and not add/delete keyframes
-  * or change key time. To enable this mode, set this to true (false by
-  * default).
-  */
+   * The keyframe editor can be set in a mode where the user can only edit the
+   * key frame values or keyframe interpolation and not add/delete keyframes
+   * or change key time. To enable this mode, set this to true (false by
+   * default).
+   */
   void setValuesOnly(bool);
   bool valuesOnly() const;
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * read the key frame data and display it
-  */
+   * read the key frame data and display it
+   */
   void readKeyFrameData();
   /**
-  * write the key frame data as edited by the user to the server manager
-  */
+   * write the key frame data as edited by the user to the server manager
+   */
   void writeKeyFrameData();
 
+Q_SIGNALS:
+  void modified();
+
 private Q_SLOTS:
   void newKeyFrame();
   void deleteKeyFrame();
   void deleteAllKeyFrames();
-  void useCurrentCamera(QObject*);
-  void updateCurrentCamera(QObject*);
 
-private:
+  void updateButtons();
+
+  /**
+   * Specific to Camera Cues.
+   */
+  void useCurrentCamera(QStandardItem* item);
+  void useCurrentCameraForSelected();
+  void updateCurrentCamera(QStandardItem* item);
+  void updateCurrentCameraWithSelected();
+  void createOrbitalKeyFrame();
+  void updateSplineMode();
+
+private: // NOLINT(readability-redundant-access-specifiers)
   class pqInternal;
   pqInternal* Internal;
 };
