@@ -36,8 +36,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QDialog>
 
 /**
-* Dialog used to ask the user what resolution to lock the views to.
-*/
+ * Dialog used to ask the user what resolution to lock the views to.
+ */
 class PQCOMPONENTS_EXPORT pqLockViewSizeCustomDialog : public QDialog
 {
   Q_OBJECT;
@@ -48,24 +48,24 @@ public:
   ~pqLockViewSizeCustomDialog() override;
 
   /**
-  * The custom resolution currently entered by the user.
-  */
+   * The custom resolution currently entered by the user.
+   */
   QSize customResolution() const;
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * Sets the view size to the displayed resolution.
-  */
+   * Sets the view size to the displayed resolution.
+   */
   virtual void apply();
 
   /**
-  * Applies the resolution and accepts the dialog.
-  */
+   * Applies the resolution and accepts the dialog.
+   */
   void accept() override;
 
   /**
-  * Unlocks the size on the view.
-  */
+   * Unlocks the size on the view.
+   */
   virtual void unlock();
 
 private:
