@@ -138,6 +138,9 @@ void pqPipelineBrowserWidget::configureModel()
   // are added.
   QObject::connect(this->PipelineModel, SIGNAL(firstChildAdded(const QModelIndex&)), this,
     SLOT(expandWithModelIndexTranslation(const QModelIndex&)));
+
+  QObject::connect(this->PipelineModel, SIGNAL(childWithChildrenAdded(const QModelIndex&)), this,
+    SLOT(expandWithModelIndexTranslation(const QModelIndex&)));
 }
 
 //-----------------------------------------------------------------------------
@@ -203,7 +206,7 @@ void pqPipelineBrowserWidget::handleIndexClicked(const QModelIndex& index_)
       bool new_visibility_state = !cur_state;
       bool is_selected = false;
       QModelIndexList indexes = this->getSelectionModel()->selectedIndexes();
-      foreach (QModelIndex selIndex_, indexes)
+      Q_FOREACH (QModelIndex selIndex_, indexes)
       {
         // Convert index to pqPipelineModel
         QModelIndex selIndex = this->pipelineModelIndex(selIndex_);
@@ -256,7 +259,7 @@ void pqPipelineBrowserWidget::setVisibility(bool visible, const QModelIndexList&
 {
   bool begun_undo_set = false;
 
-  foreach (QModelIndex index_, indexes)
+  Q_FOREACH (QModelIndex index_, indexes)
   {
     // Get object relative to pqPipelineModel
     const pqPipelineModel* model = this->getPipelineModel(index_);
