@@ -41,15 +41,15 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class QModelIndex;
 
 /**
-* pqPresetDialog is the dialog used by to show the user with a choice of color
-* maps/opacity maps/presets to choose from. The Dialog can be customized to
-* show only indexed (or non-indexed) color maps using pqPresetDialog::Modes.
-* Application code should observe the pqPresetDialog::applyPreset() signal to
-* perform the applying of the preset to a specific transfer function proxy.
-* This class works with vtkSMTransferFunctionPresets, which acts as the preset
-* manager for the application with support to inspect existing presets as well
-* as updating them.
-*/
+ * pqPresetDialog is the dialog used by to show the user with a choice of color
+ * maps/opacity maps/presets to choose from. The Dialog can be customized to
+ * show only indexed (or non-indexed) color maps using pqPresetDialog::Modes.
+ * Application code should observe the pqPresetDialog::applyPreset() signal to
+ * perform the applying of the preset to a specific transfer function proxy.
+ * This class works with vtkSMTransferFunctionPresets, which acts as the preset
+ * manager for the application with support to inspect existing presets as well
+ * as updating them.
+ */
 class PQCOMPONENTS_EXPORT pqPresetDialog : public QDialog
 {
   Q_OBJECT
@@ -57,9 +57,9 @@ class PQCOMPONENTS_EXPORT pqPresetDialog : public QDialog
 
 public:
   /**
-  * Used to control what kinds of presets are shown in the dialog.
-  * This merely affects the presets that are hidden from the view.
-  */
+   * Used to control what kinds of presets are shown in the dialog.
+   * This merely affects the presets that are hidden from the view.
+   */
   enum Modes
   {
     SHOW_ALL,
@@ -67,40 +67,39 @@ public:
     SHOW_NON_INDEXED_COLORS_ONLY
   };
 
-  pqPresetDialog(QWidget* parent = 0, Modes mode = SHOW_ALL);
+  pqPresetDialog(QWidget* parent = nullptr, Modes mode = SHOW_ALL);
   ~pqPresetDialog() override;
 
   /**
-  * Set the current mode (which type of presets are displayed)
-  */
+   * Set the current mode (which type of presets are displayed)
+   */
   void setMode(Modes mode);
 
   /**
-  * Set the current preset using its name.
-  */
+   * Set the current preset using its name.
+   */
   void setCurrentPreset(const char* presetName);
 
   /**
-  * Return current preset, if any.
-  */
+   * Return current preset, if any.
+   */
   const Json::Value& currentPreset();
 
   /**
-  * Returns true if the user requested to load colors for the
-  * current preset.
-  */
+   * Returns true if the user requested to load colors for the current preset.
+   */
   bool loadColors() const;
 
   /**
-  * Returns true if the user requested to load opacities for the current
-  * preset.
-  */
+   * Returns true if the user requested to load opacities for the current
+   * preset.
+   */
   bool loadOpacities() const;
 
   /**
-  * Returns true if the user requested to load annotations for the current
-  * preset.
-  */
+   * Returns true if the user requested to load annotations for the current
+   * preset.
+   */
   bool loadAnnotations() const;
 
   /**
@@ -109,20 +108,20 @@ public:
   QRegularExpression regularExpression();
 
   /**
-  * Returns true if the user requested to preserve/use the preset data range.
-  * If false, the user is expecting the current transfer function range to be
-  * maintained.
-  */
+   * Returns true if the user requested to preserve/use the preset data range.
+   * If false, the user is expecting the current transfer function range to be
+   * maintained.
+   */
   bool usePresetRange() const;
 
   /**
-  * Set when user can choose to load colors along with the default state.
-  */
+   * Set when user can choose to load colors along with the default state.
+   */
   void setCustomizableLoadColors(bool state, bool defaultValue = true);
 
   /**
-  * Set when user can choose to load annotations along with the default state.
-  */
+   * Set when user can choose to load annotations along with the default state.
+   */
   void setCustomizableLoadAnnotations(bool state, bool defaultValue = true);
 
   /**
@@ -131,13 +130,13 @@ public:
   void setCustomizableAnnotationsRegexp(bool state, bool defaultValue = false);
 
   /**
-  * Set when user can choose to load opacities along with the default state.
-  */
+   * Set when user can choose to load opacities along with the default state.
+   */
   void setCustomizableLoadOpacities(bool state, bool defaultValue = true);
 
   /**
-  * Set when user can choose to load usePresetRange along with the default state.
-  */
+   * Set when user can choose to load usePresetRange along with the default state.
+   */
   void setCustomizableUsePresetRange(bool state, bool defaultValue = false);
 
 Q_SIGNALS:
@@ -153,14 +152,11 @@ protected Q_SLOTS:
 
   void setPresetIsAdvanced(int newState);
 
-protected:
-  void showEvent(QShowEvent* e) override;
-  void closeEvent(QCloseEvent* e) override;
-
 private Q_SLOTS:
   void updateGroups();
+  void updateFiltering();
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqPresetDialog)
   class pqInternals;
   const QScopedPointer<pqInternals> Internals;
