@@ -49,6 +49,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkCollection.h"
 #include "vtkCommand.h"
 #include "vtkEventQtSlotConnect.h"
+#include "vtkLegacy.h"
 #include "vtkNew.h"
 #include "vtkPVGeneralSettings.h"
 #include "vtkPVLogger.h"
@@ -116,7 +117,7 @@ public:
 
   void show(QWidget* parentWdg)
   {
-    assert(parentWdg != NULL);
+    assert(parentWdg != nullptr);
 
     delete parentWdg->layout();
     QVBoxLayout* layout = new QVBoxLayout(parentWdg);
@@ -158,9 +159,6 @@ private:
 unsigned long pqProxyWidgets::Counter = 0;
 };
 
-bool pqPropertiesPanel::AutoApply = false;
-int pqPropertiesPanel::AutoApplyDelay = 0; // in msec
-
 //*****************************************************************************
 class pqPropertiesPanel::pqInternals
 {
@@ -168,12 +166,12 @@ public:
   Ui::propertiesPanel Ui;
   QPointer<pqView> View;
   QPointer<pqProxy> Source;
+  int SourcePort;
   QPointer<pqDataRepresentation> Representation;
-  QMap<void*, QPointer<pqProxyWidgets> > SourceWidgets;
+  QMap<void*, QPointer<pqProxyWidgets>> SourceWidgets;
   QPointer<pqProxyWidgets> DisplayWidgets;
   QPointer<pqProxyWidgets> ViewWidgets;
   bool ReceivedChangeAvailable;
-  pqTimer AutoApplyTimer;
   vtkNew<vtkSMProxyClipboard> SourceClipboard;
   vtkNew<vtkSMProxyClipboard> DisplayClipboard;
   vtkNew<vtkSMProxyClipboard> ViewClipboard;
@@ -182,7 +180,8 @@ public:
 
   //---------------------------------------------------------------------------
   pqInternals(pqPropertiesPanel* panel)
-    : ReceivedChangeAvailable(false)
+    : SourcePort(-1)
+    , ReceivedChangeAvailable(false)
   {
     this->Ui.setupUi(panel);
 
@@ -226,18 +225,12 @@ public:
     this->Ui.ViewButtons->layout()->setSpacing(pqPropertiesPanel::suggestedHorizontalSpacing());
 
     // change the apply button palette so it is green when it is enabled.
-    QPalette applyPalette = this->Ui.Accept->palette();
-    applyPalette.setColor(QPalette::Active, QPalette::Button, QColor(161, 213, 135));
-    applyPalette.setColor(QPalette::Inactive, QPalette::Button, QColor(161, 213, 135));
-    this->Ui.Accept->setPalette(applyPalette);
-
-    this->AutoApplyTimer.setSingleShot(true);
-    panel->connect(&this->AutoApplyTimer, SIGNAL(timeout()), SLOT(apply()));
+    pqCoreUtilities::initializeClickMeButton(this->Ui.Accept);
   }
 
   ~pqInternals()
   {
-    foreach (pqProxyWidgets* widgets, this->SourceWidgets)
+    Q_FOREACH (pqProxyWidgets* widgets, this->SourceWidgets)
     {
       delete widgets;
     }
@@ -246,14 +239,11 @@ public:
     delete this->ViewWidgets;
   }
 
-  void triggerAutoApply() { this->AutoApplyTimer.start(pqPropertiesPanel::autoApplyDelay()); }
-
   //---------------------------------------------------------------------------
   void updateInformationAndDomains()
   {
     if (this->Source)
     {
-      // this->Source->updatePipeline();
       vtkSMProxy* proxy = this->Source->getProxy();
       if (vtkSMSourceProxy* sourceProxy = vtkSMSourceProxy::SafeDownCast(proxy))
       {
@@ -273,14 +263,6 @@ pqPropertiesPanel::pqPropertiesPanel(QWidget* parentObject)
   , Internals(new pqInternals(this))
   , PanelMode(pqPropertiesPanel::ALL_PROPERTIES)
 {
-  // Get AutoApply setting from GeneralSettings object.
-  vtkPVGeneralSettings* generalSettings = vtkPVGeneralSettings::GetInstance();
-  pqPropertiesPanel::AutoApply = generalSettings->GetAutoApply();
-
-  // every time the settings change, we need to update our auto-apply status.
-  pqCoreUtilities::connect(
-    generalSettings, vtkCommand::ModifiedEvent, this, SLOT(generalSettingsChanged()));
-
   //---------------------------------------------------------------------------
   // Listen to various signals from the application indicating changes in active
   // source/view/representation, etc.
@@ -349,7 +331,7 @@ pqPropertiesPanel::pqPropertiesPanel(QWidget* parentObject)
 pqPropertiesPanel::~pqPropertiesPanel()
 {
   delete this->Internals;
-  this->Internals = 0;
+  this->Internals = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -405,35 +387,40 @@ void pqPropertiesPanel::setPanelMode(int val)
   this->updatePanel();
 }
 
-//-----------------------------------------------------------------------------
-void pqPropertiesPanel::generalSettingsChanged()
-{
-  vtkPVGeneralSettings* generalSettings = vtkPVGeneralSettings::GetInstance();
-  pqPropertiesPanel::AutoApply = generalSettings->GetAutoApply();
-}
-
 //-----------------------------------------------------------------------------
 void pqPropertiesPanel::setAutoApply(bool enabled)
 {
-  pqPropertiesPanel::AutoApply = enabled;
+  VTK_LEGACY_REPLACED_BODY(
+    pqPropertiesPanel::setAutoApply, "ParaView 5.11", vtkPVGeneralSettings::SetAutoApply());
+  vtkPVGeneralSettings* generalSettings = vtkPVGeneralSettings::GetInstance();
+  generalSettings->SetAutoApply(enabled);
 }
 
 //-----------------------------------------------------------------------------
 bool pqPropertiesPanel::autoApply()
 {
-  return pqPropertiesPanel::AutoApply;
+  VTK_LEGACY_REPLACED_BODY(
+    pqPropertiesPanel::autoApply, "ParaView 5.11", vtkPVGeneralSettings::GetAutoApply());
+  vtkPVGeneralSettings* generalSettings = vtkPVGeneralSettings::GetInstance();
+  return generalSettings->GetAutoApply();
 }
 
 //-----------------------------------------------------------------------------
 void pqPropertiesPanel::setAutoApplyDelay(int delay)
 {
-  pqPropertiesPanel::AutoApplyDelay = delay;
+  VTK_LEGACY_REPLACED_BODY(pqPropertiesPanel::setAutoApplyDelay, "ParaView 5.11",
+    vtkPVGeneralSettings::SetAutoApplyDelay());
+  vtkPVGeneralSettings* generalSettings = vtkPVGeneralSettings::GetInstance();
+  return generalSettings->SetAutoApplyDelay(delay);
 }
 
 //-----------------------------------------------------------------------------
 int pqPropertiesPanel::autoApplyDelay()
 {
-  return pqPropertiesPanel::AutoApplyDelay;
+  VTK_LEGACY_REPLACED_BODY(
+    pqPropertiesPanel::autoApplyDelay, "ParaView 5.11", vtkPVGeneralSettings::GetAutoApplyDelay());
+  vtkPVGeneralSettings* generalSettings = vtkPVGeneralSettings::GetInstance();
+  return generalSettings->GetAutoApplyDelay();
 }
 
 //-----------------------------------------------------------------------------
@@ -456,23 +443,23 @@ void pqPropertiesPanel::setView(pqView* pqview)
   this->updateButtonState();
 }
 
-//-----------------------------------------------------------------------------
-#if !defined(VTK_LEGACY_REMOVE)
-void pqPropertiesPanel::setOutputPort(pqOutputPort* port)
-{
-  VTK_LEGACY_REPLACED_BODY(
-    pqPropertiesPanel::setOutputPort, "ParaView 5.9", pqPropertiesPanel::setPipelineProxy);
-  this->setPipelineProxy(port);
-}
-#endif
-
 //-----------------------------------------------------------------------------
 void pqPropertiesPanel::setPipelineProxy(pqProxy* proxy)
 {
   if (auto port = qobject_cast<pqOutputPort*>(proxy))
   {
+    this->Internals->SourcePort = port->getPortNumber();
     proxy = port->getSource();
   }
+  else if (proxy)
+  {
+    this->Internals->SourcePort = 0;
+  }
+  else
+  {
+    this->Internals->SourcePort = -1;
+  }
+
   this->updatePropertiesPanel(proxy);
   this->updateButtonState();
 }
@@ -481,33 +468,23 @@ void pqPropertiesPanel::setPipelineProxy(pqProxy* proxy)
 void pqPropertiesPanel::updatePanel()
 {
   auto& internals = (*this->Internals);
+  if (!internals.Source.isNull() && internals.SourcePort < 0)
+  {
+    internals.SourcePort = 0;
+  }
+
   this->updatePropertiesPanel(internals.Source);
   this->updateDisplayPanel(internals.Representation);
   this->updateViewPanel(internals.View);
   this->updateButtonState();
 }
 
-//-----------------------------------------------------------------------------
-#if !defined(VTK_LEGACY_REMOVE)
-void pqPropertiesPanel::updatePanel(pqOutputPort* port)
-{
-  VTK_LEGACY_BODY(pqPropertiesPanel::updatePanel, "ParaView 5.9");
-
-  // Determine if the proxy/repr has changed. If so, we have to recreate the
-  // entire panel, else we simply update the widgets.
-  this->setPipelineProxy(port);
-  this->updateDisplayPanel(port ? port->getRepresentation(this->view()) : NULL);
-  this->updateViewPanel(this->view());
-  this->updateButtonState();
-}
-#endif
-
 //-----------------------------------------------------------------------------
 void pqPropertiesPanel::updatePropertiesPanel(pqProxy* source)
 {
   if ((this->PanelMode & SOURCE_PROPERTIES) == 0)
   {
-    source = NULL;
+    source = nullptr;
   }
 
   if (this->Internals->Source != source)
@@ -541,16 +518,20 @@ void pqPropertiesPanel::updatePropertiesPanel(pqProxy* source)
   // update widgets.
   if (source)
   {
+    auto sourceWidgets = this->Internals->SourceWidgets[source];
+
     this->Internals->Ui.PropertiesButton->setText(
       tr("Properties") + QString(" (%1)").arg(source->getSMName()));
-    this->Internals->SourceWidgets[source]->showWidgets(
-      this->Internals->Ui.SearchBox->isAdvancedSearchActive(),
+    sourceWidgets->showWidgets(this->Internals->Ui.SearchBox->isAdvancedSearchActive(),
       this->Internals->Ui.SearchBox->text());
 
-    if (pqPropertiesPanel::AutoApply)
+    // update interactive widgets specifically
+    if (this->Internals->SourcePort >= 0)
     {
-      this->Internals->triggerAutoApply();
+      sourceWidgets->Panel->showLinkedInteractiveWidget(this->Internals->SourcePort, true);
     }
+
+    Q_EMIT this->modified();
   }
   else
   {
@@ -570,13 +551,13 @@ void pqPropertiesPanel::updateDisplayPanel(pqDataRepresentation* repr)
 {
   if ((this->PanelMode & pqPropertiesPanel::DISPLAY_PROPERTIES) == 0)
   {
-    repr = NULL;
+    repr = nullptr;
   }
 
-  // since this->Internals->Representation is QPointer, it can go NULL (e.g. during
+  // since this->Internals->Representation is QPointer, it can go nullptr (e.g. during
   // disconnect) before we get the chance to clear the panel's widgets. Hence we
-  // do the block of code if (repr==NULL) event if nothing has changed.
-  if (this->Internals->Representation != repr || repr == NULL)
+  // do the block of code if (repr==nullptr) event if nothing has changed.
+  if (this->Internals->Representation != repr || repr == nullptr)
   {
     // Representation has changed, destroy the current display panel and create
     // a new one. Unlike properties panels, display panels are not cached.
@@ -627,7 +608,7 @@ void pqPropertiesPanel::updateViewPanel(pqView* argView)
   pqView* _view = argView;
   if ((this->PanelMode & pqPropertiesPanel::VIEW_PROPERTIES) == 0)
   {
-    _view = NULL;
+    _view = nullptr;
   }
 
   if (this->Internals->View != argView)
@@ -660,7 +641,7 @@ void pqPropertiesPanel::updateViewPanel(pqView* argView)
     vtkSMViewProxy* proxy = _view->getViewProxy();
     const char* label = proxy->GetXMLLabel();
     this->Internals->Ui.ViewButton->setText(
-      tr("View") + QString(" (%1)").arg(label != 0 ? label : _view->getViewType()));
+      tr("View") + QString(" (%1)").arg(label != nullptr ? label : _view->getViewType()));
     this->Internals->ViewWidgets->showWidgets(
       this->Internals->Ui.SearchBox->isAdvancedSearchActive(),
       this->Internals->Ui.SearchBox->text());
@@ -700,10 +681,9 @@ void pqPropertiesPanel::sourcePropertyChanged(bool change_finished /*=true*/)
   }
   if (change_finished && !this->Internals->ReceivedChangeAvailable)
   {
-    vtkVLogF(PARAVIEW_LOG_APPLICATION_VERBOSITY(), "received `changeFinished` signal without "
-                                                   "receiving a `changeAvailable` signal from "
-                                                   "`%s`'s proxy-widget;"
-                                                   "ignoring it!",
+    vtkVLogF(PARAVIEW_LOG_APPLICATION_VERBOSITY(),
+      "received `changeFinished` signal without receiving a `changeAvailable` "
+      "signal from `%s`'s proxy-widget; ignoring it!",
       proxyLabel.c_str());
     return;
   }
@@ -714,9 +694,9 @@ void pqPropertiesPanel::sourcePropertyChanged(bool change_finished /*=true*/)
   {
     this->Internals->Source->setModifiedState(pqProxy::MODIFIED);
   }
-  if (pqPropertiesPanel::AutoApply && change_finished)
+  if (change_finished)
   {
-    this->Internals->triggerAutoApply();
+    Q_EMIT this->modified();
   }
   this->updateButtonState();
 }
@@ -730,13 +710,13 @@ void pqPropertiesPanel::updateButtonState()
 
   ui.Accept->setEnabled(false);
   ui.Reset->setEnabled(false);
-  ui.Help->setEnabled(this->Internals->Source != NULL);
+  ui.Help->setEnabled(this->Internals->Source != nullptr);
   ui.Delete->setEnabled(isDeletable(this->Internals->Source));
 
-  foreach (const pqProxyWidgets* widgets, this->Internals->SourceWidgets)
+  Q_FOREACH (const pqProxyWidgets* widgets, this->Internals->SourceWidgets)
   {
     pqProxy* proxy = widgets->Proxy;
-    if (proxy == NULL)
+    if (proxy == nullptr)
     {
       continue;
     }
@@ -789,16 +769,17 @@ void pqPropertiesPanel::updateButtonEnableState()
   // Update PropertiesSaveAsDefaults and PropertiesRestoreDefaults state.
   // If the source's properties are yet to be applied, we disable the two
   // buttons (see BUG #15338).
-  bool canSaveRestoreSourcePropertyDefaults =
-    internals.Source != NULL ? (internals.Source->modifiedState() == pqProxy::UNMODIFIED) : false;
+  bool canSaveRestoreSourcePropertyDefaults = internals.Source != nullptr
+    ? (internals.Source->modifiedState() == pqProxy::UNMODIFIED)
+    : false;
   ui.PropertiesSaveAsDefaults->setEnabled(canSaveRestoreSourcePropertyDefaults);
   ui.PropertiesRestoreDefaults->setEnabled(canSaveRestoreSourcePropertyDefaults);
 
-  ui.DisplayRestoreDefaults->setEnabled(internals.DisplayWidgets != NULL);
-  ui.DisplaySaveAsDefaults->setEnabled(internals.DisplayWidgets != NULL);
+  ui.DisplayRestoreDefaults->setEnabled(internals.DisplayWidgets != nullptr);
+  ui.DisplaySaveAsDefaults->setEnabled(internals.DisplayWidgets != nullptr);
 
-  ui.ViewRestoreDefaults->setEnabled(internals.ViewWidgets != NULL);
-  ui.ViewSaveAsDefaults->setEnabled(internals.ViewWidgets != NULL);
+  ui.ViewRestoreDefaults->setEnabled(internals.ViewWidgets != nullptr);
+  ui.ViewSaveAsDefaults->setEnabled(internals.ViewWidgets != nullptr);
 
   // Now update copy-paste button state as well.
   if (internals.Source)
@@ -841,7 +822,6 @@ void pqPropertiesPanel::apply()
   vtkVLogScopeFunction(PARAVIEW_LOG_APPLICATION_VERBOSITY());
 
   vtkTimerLog::MarkStartEvent("PropertiesPanel::Apply");
-  this->Internals->AutoApplyTimer.stop();
 
   BEGIN_UNDO_SET("Apply");
 
@@ -850,7 +830,7 @@ void pqPropertiesPanel::apply()
   if (onlyApplyCurrentPanel)
   {
     pqProxyWidgets* widgets =
-      this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : NULL;
+      this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : nullptr;
     if (widgets)
     {
       widgets->apply(this->view());
@@ -859,7 +839,7 @@ void pqPropertiesPanel::apply()
   }
   else
   {
-    foreach (pqProxyWidgets* widgets, this->Internals->SourceWidgets)
+    Q_FOREACH (pqProxyWidgets* widgets, this->Internals->SourceWidgets)
     {
       widgets->apply(this->view());
       Q_EMIT this->applied(widgets->Proxy);
@@ -877,13 +857,11 @@ void pqPropertiesPanel::apply()
 //-----------------------------------------------------------------------------
 void pqPropertiesPanel::reset()
 {
-  this->Internals->AutoApplyTimer.stop();
-
   bool onlyApplyCurrentPanel = vtkPVGeneralSettings::GetInstance()->GetAutoApplyActiveOnly();
   if (onlyApplyCurrentPanel)
   {
     pqProxyWidgets* widgets =
-      this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : NULL;
+      this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : nullptr;
     if (widgets)
     {
       widgets->reset();
@@ -891,11 +869,12 @@ void pqPropertiesPanel::reset()
   }
   else
   {
-    foreach (pqProxyWidgets* widgets, this->Internals->SourceWidgets)
+    Q_FOREACH (pqProxyWidgets* widgets, this->Internals->SourceWidgets)
     {
       widgets->reset();
     }
   }
+  Q_EMIT this->resetDone();
 
   this->Internals->updateInformationAndDomains();
   this->updateButtonState();
@@ -926,7 +905,7 @@ void pqPropertiesPanel::showHelp()
 void pqPropertiesPanel::propertiesRestoreDefaults()
 {
   pqProxyWidgets* widgets =
-    this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : NULL;
+    this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : nullptr;
   if (widgets && widgets->Panel)
   {
     if (widgets->Panel->restoreDefaults())
@@ -945,7 +924,7 @@ void pqPropertiesPanel::propertiesRestoreDefaults()
 void pqPropertiesPanel::propertiesSaveAsDefaults()
 {
   pqProxyWidgets* widgets =
-    this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : NULL;
+    this->Internals->Source ? this->Internals->SourceWidgets[this->Internals->Source] : nullptr;
   if (widgets && widgets->Panel)
   {
     widgets->Panel->saveAsDefaults();
