@@ -42,10 +42,10 @@ class vtkSMProperty;
 class pqView;
 
 /**
-* pqPropertyWidget that can be used for any proxy with a vtkSMProxyListDomain.
-* pqProxyPropertyWidget automatically creates this widget when it encounters a
-* property with vtkSMProxyListDomain.
-*/
+ * pqPropertyWidget that can be used for any proxy with a vtkSMProxyListDomain.
+ * pqProxyPropertyWidget automatically creates this widget when it encounters a
+ * property with vtkSMProxyListDomain.
+ */
 class PQCOMPONENTS_EXPORT pqProxySelectionWidget : public pqPropertyWidget
 {
   Q_OBJECT
@@ -54,22 +54,22 @@ class PQCOMPONENTS_EXPORT pqProxySelectionWidget : public pqPropertyWidget
 
 public:
   /**
-  * constructor requires the proxy, property. Note that this will abort if the
-  * property does not have a ProxyListDomain.
-  */
-  pqProxySelectionWidget(vtkSMProperty* property, vtkSMProxy* proxy, QWidget* parent = 0);
+   * constructor requires the proxy, property. Note that this will abort if the
+   * property does not have a ProxyListDomain.
+   */
+  pqProxySelectionWidget(vtkSMProperty* property, vtkSMProxy* proxy, QWidget* parent = nullptr);
   ~pqProxySelectionWidget() override;
 
   /**
-  * get the selected proxy
-  */
+   * get the selected proxy
+   */
   vtkSMProxy* chosenProxy() const;
   void setChosenProxy(vtkSMProxy* proxy);
 
   /**
-  * Overridden to forward the call to the internal pqProxyWidget maintained
-  * for the chosen proxy.
-  */
+   * Overridden to forward the call to the internal pqProxyWidget maintained
+   * for the chosen proxy.
+   */
   void apply() override;
   void reset() override;
   void select() override;
@@ -80,19 +80,19 @@ public:
 
 Q_SIGNALS:
   /**
-  * Signal fired by setChosenProxy() when the proxy changes.
-  */
+   * Signal fired by setChosenProxy() when the proxy changes.
+   */
   void chosenProxyChanged();
 
 private Q_SLOTS:
   /**
-  * Called when the current index in the combo-box is changed from the UI.
-  * This calls setChosenProxy() with the argument as the proxy corresponding
-  * to the \c idx from the domain.
-  */
+   * Called when the current index in the combo-box is changed from the UI.
+   * This calls setChosenProxy() with the argument as the proxy corresponding
+   * to the \c idx from the domain.
+   */
   void currentIndexChanged(int);
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   class pqInternal;
   const QScopedPointer<pqInternal> Internal;
 
