@@ -57,7 +57,7 @@ namespace rfm
 bool canLoad(
   const QList<pqRecentlyUsedResourceLoaderInterface*>& ifaces, const pqServerResource& resource)
 {
-  // using foreach here was causing failures on VS
+  // using Q_FOREACH here was causing failures on VS
   for (int cc = 0, max = ifaces.size(); cc < max; ++cc)
   {
     pqRecentlyUsedResourceLoaderInterface* iface = ifaces[cc];
@@ -72,7 +72,7 @@ bool canLoad(
 bool iconAndLabel(const QList<pqRecentlyUsedResourceLoaderInterface*>& ifaces,
   const pqServerResource& resource, QIcon& icon, QString& label)
 {
-  // using foreach here was causing failures on VS
+  // using Q_FOREACH here was causing failures on VS
   for (int cc = 0, max = ifaces.size(); cc < max; ++cc)
   {
     pqRecentlyUsedResourceLoaderInterface* iface = ifaces[cc];
@@ -89,7 +89,7 @@ bool iconAndLabel(const QList<pqRecentlyUsedResourceLoaderInterface*>& ifaces,
 bool load(const QList<pqRecentlyUsedResourceLoaderInterface*>& ifaces,
   const pqServerResource& resource, pqServer* server)
 {
-  // using foreach here was causing failures on VS
+  // using Q_FOREACH here was causing failures on VS
   for (int cc = 0, max = ifaces.size(); cc < max; ++cc)
   {
     pqRecentlyUsedResourceLoaderInterface* iface = ifaces[cc];
@@ -146,14 +146,19 @@ void pqRecentFilesMenu::buildMenu()
       const pqServerConfiguration& config = resource.configuration();
       if (config.isNameDefault())
       {
-        pqServerResource hostResource = (resource.scheme() == "session")
-          ? resource.sessionServer().schemeHostsPorts()
-          : resource.schemeHostsPorts();
-        key = hostResource.toURI();
+        QString serverName = resource.serverName();
+        if (!serverName.isEmpty())
+        {
+          key = serverName;
+        }
+        else
+        {
+          key = resource.schemeHostsPorts().toURI();
+        }
       }
       else
       {
-        key = resource.configuration().URI();
+        key = resource.configuration().name();
       }
     }
     clusteredResources[key].push_back(resource);
@@ -201,20 +206,28 @@ void pqRecentFilesMenu::onOpenResource(QAction* action)
   QString data = action ? action->data().toString() : QString();
   if (!data.isEmpty())
   {
-    this->onOpenResource(pqServerResource(action->data().toString()));
+    this->onOpenResource(pqServerResource(data));
   }
 }
 
 //-----------------------------------------------------------------------------
 void pqRecentFilesMenu::onOpenResource(const pqServerResource& resource)
 {
-  const pqServerResource server = resource.scheme() == "session"
-    ? resource.sessionServer().schemeHostsPorts()
-    : resource.schemeHostsPorts();
-
   pqServerManagerModel* smModel = pqApplicationCore::instance()->getServerManagerModel();
-  pqServer* pq_server = smModel->findServer(server);
-  if (!pq_server)
+  pqServer* server;
+
+  // If a server name is set, use it to find the server, if not, use the schemehostsports instead
+  if (resource.serverName().isEmpty())
+  {
+    const pqServerResource serverResource = resource.schemeHostsPorts();
+    server = smModel->findServer(serverResource);
+  }
+  else
+  {
+    server = smModel->findServer(resource.serverName());
+  }
+
+  if (!server)
   {
     int ret =
       QMessageBox::warning(pqCoreUtilities::mainWidget(), tr("Disconnect from current server?"),
@@ -228,19 +241,19 @@ void pqRecentFilesMenu::onOpenResource(const pqServerResource& resource)
     }
     pqServerConfiguration config_to_connect;
     if (pqServerConnectDialog::selectServer(
-          config_to_connect, pqCoreUtilities::mainWidget(), server))
+          config_to_connect, pqCoreUtilities::mainWidget(), resource))
     {
       QScopedPointer<pqServerLauncher> launcher(pqServerLauncher::newInstance(config_to_connect));
       if (launcher->connectToServer())
       {
-        pq_server = launcher->connectedServer();
+        server = launcher->connectedServer();
       }
     }
   }
 
-  if (pq_server)
+  if (server)
   {
-    this->open(pq_server, resource);
+    this->open(server, resource);
   }
 }
 
