@@ -28,10 +28,10 @@ public:
 
   int GetModified() { return this->Modified; }
 
-private slots:
+private Q_SLOTS:
   void SetModified() { ++this->Modified; }
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   int Modified;
   pqRemoteCommandTemplateDialogUI* Ui;
 };
