@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    pqSelectionInputWidget.h
+   Module:  pqSelectionInputWidget.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -38,9 +38,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqSMProxy.h" // For property.
 
 /**
-* pqSelectionInputWidget is a custom widget used for specifying
-* the selection to use on filters that have a selection as input.
-*/
+ * pqSelectionInputWidget is a custom widget used for specifying
+ * the selection to use on filters that have a selection as input.
+ */
 class PQCOMPONENTS_EXPORT pqSelectionInputWidget : public QWidget
 {
   Q_OBJECT
@@ -48,26 +48,26 @@ class PQCOMPONENTS_EXPORT pqSelectionInputWidget : public QWidget
   typedef QWidget Superclass;
 
 public:
-  pqSelectionInputWidget(QWidget* parent = 0);
+  pqSelectionInputWidget(QWidget* parent = nullptr);
   ~pqSelectionInputWidget() override;
 
-  virtual pqSMProxy selection() { return this->SelectionSource; }
+  virtual pqSMProxy selection() { return this->AppendSelections; }
 
-public Q_SLOTS:
-  virtual void setSelection(pqSMProxy selection);
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
+  virtual void setSelection(pqSMProxy newAppendSelections);
 
   /**
-  * This must be connected to the panel-accept signal to ensure that the new
-  * selection source object gets registered for undo-redo/state to work. This
-  * method also gets rid of any obsolete selection_sources.
-  */
+   * This must be connected to the panel-accept signal to ensure that the new
+   * selection source object gets registered for undo-redo/state to work. This
+   * method also gets rid of any obsolete selection_sources.
+   */
   virtual void preAccept();
   virtual void postAccept();
 
 Q_SIGNALS:
   /**
-  * Signal that the selection proxy changed.
-  */
+   * Signal that the selection proxy changed.
+   */
   void selectionChanged(pqSMProxy);
 
 protected Q_SLOTS:
@@ -78,14 +78,14 @@ protected Q_SLOTS:
 
   void updateLabels();
 
-protected:
-  pqSMProxy SelectionSource;
+protected: // NOLINT(readability-redundant-access-specifiers)
+  pqSMProxy AppendSelections;
 
 private:
   Q_DISABLE_COPY(pqSelectionInputWidget)
 
-  class UI;
-  UI* ui;
+  class pqUi;
+  pqUi* Ui;
 };
 
 #endif
