@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: ParaView
-  Module:    pqSelectionManager.cxx
+  Module:  pqSelectionManager.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -14,52 +14,45 @@
 =========================================================================*/
 #include "pqSelectionManager.h"
 
-#include <QtDebug>
-
 #include "pqActiveObjects.h"
 #include "pqApplicationCore.h"
 #include "pqLinksModel.h"
 #include "pqOutputPort.h"
 #include "pqPipelineSource.h"
-#include "pqRenderView.h"
-#include "pqSMAdaptor.h"
-#include "pqServer.h"
 #include "pqServerManagerModel.h"
 #include "pqTimeKeeper.h"
+
 #include "vtkAlgorithm.h"
 #include "vtkCollection.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkPVDataInformation.h"
-#include "vtkProcessModule.h"
 #include "vtkSMInputProperty.h"
 #include "vtkSMPropertyHelper.h"
-#include "vtkSMProxyManager.h"
 #include "vtkSMRenderViewProxy.h"
-#include "vtkSMSelectionHelper.h"
 #include "vtkSMSelectionLink.h"
 #include "vtkSMSessionProxyManager.h"
 #include "vtkSMSourceProxy.h"
 #include "vtkSMStringVectorProperty.h"
 #include "vtkSMTrace.h"
-#include "vtkSelection.h"
-#include "vtkSelectionNode.h"
 #include "vtkSmartPointer.h"
 
+#include <QtDebug>
+
 //-----------------------------------------------------------------------------
 class pqSelectionManagerImplementation
 {
 public:
-  pqSelectionManagerImplementation() {}
+  pqSelectionManagerImplementation() = default;
 
-  ~pqSelectionManagerImplementation() {}
+  ~pqSelectionManagerImplementation() = default;
 
   QSet<pqOutputPort*> SelectedPorts;
   QPointer<pqView> ActiveView;
 };
 
 //-----------------------------------------------------------------------------
-pqSelectionManager::pqSelectionManager(QObject* _parent /*=null*/)
+pqSelectionManager::pqSelectionManager(QObject* _parent /*=nullptr*/)
   : QObject(_parent)
 {
   this->Implementation = new pqSelectionManagerImplementation;
@@ -110,7 +103,7 @@ void pqSelectionManager::setActiveView(pqView* view)
 {
   if (this->Implementation->ActiveView)
   {
-    QObject::disconnect(this->Implementation->ActiveView, 0, this, 0);
+    QObject::disconnect(this->Implementation->ActiveView, nullptr, this, nullptr);
   }
   this->Implementation->ActiveView = view;
 
@@ -124,13 +117,13 @@ void pqSelectionManager::setActiveView(pqView* view)
 void pqSelectionManager::onItemRemoved(pqServerManagerModelItem* item)
 {
   // return if removed item is not a pqPipelineSource
-  if (qobject_cast<pqPipelineSource*>(item) == NULL)
+  if (qobject_cast<pqPipelineSource*>(item) == nullptr)
   {
     return;
   }
 
   // Search for the source output ports in the SelectedPorts set
-  foreach (pqOutputPort* port, this->Implementation->SelectedPorts)
+  Q_FOREACH (pqOutputPort* port, this->Implementation->SelectedPorts)
   {
     if (port->getSource() == item)
     {
@@ -142,15 +135,24 @@ void pqSelectionManager::onItemRemoved(pqServerManagerModelItem* item)
 }
 
 //-----------------------------------------------------------------------------
-void pqSelectionManager::expandSelection(int layers)
+void pqSelectionManager::expandSelection(int layers, bool removeSeed, bool removeIntermediateLayers)
 {
   for (auto port : this->Implementation->SelectedPorts)
   {
-    if (auto selsource = port->getSelectionInput())
+    if (auto appendSelections = port->getSelectionInput())
     {
-      vtkSMPropertyHelper helper(selsource, "NumberOfLayers");
-      helper.Set(helper.GetAsInt() + layers);
-      selsource->UpdateVTKObjects();
+      unsigned int numInputs = vtkSMPropertyHelper(appendSelections, "Input").GetNumberOfElements();
+      for (unsigned int i = 0; i < numInputs; ++i)
+      {
+        auto selectionSource =
+          vtkSMPropertyHelper(appendSelections->GetProperty("Input")).GetAsProxy(i);
+        vtkSMPropertyHelper numberOfLayersHelper(selectionSource, "NumberOfLayers");
+        numberOfLayersHelper.Set(numberOfLayersHelper.GetAsInt() + layers);
+        vtkSMPropertyHelper(selectionSource, "RemoveSeed").Set(removeSeed);
+        vtkSMPropertyHelper(selectionSource, "RemoveIntermediateLayers")
+          .Set(removeIntermediateLayers);
+        selectionSource->UpdateVTKObjects();
+      }
     }
     port->renderAllViews();
     Q_EMIT this->selectionChanged(port);
@@ -160,7 +162,7 @@ void pqSelectionManager::expandSelection(int layers)
 //-----------------------------------------------------------------------------
 void pqSelectionManager::clearSelection(pqOutputPort* outputPort)
 {
-  if (outputPort == NULL)
+  if (outputPort == nullptr)
   {
     // Clear all selection
     if (this->Implementation->SelectedPorts.count() > 0)
@@ -169,7 +171,7 @@ void pqSelectionManager::clearSelection(pqOutputPort* outputPort)
       src->CleanSelectionInputs((*this->Implementation->SelectedPorts.begin())->getPortNumber());
 
       // Render all cleaned output ports
-      foreach (pqOutputPort* opport, this->Implementation->SelectedPorts)
+      Q_FOREACH (pqOutputPort* opport, this->Implementation->SelectedPorts)
       {
         if (opport)
         {
@@ -183,7 +185,7 @@ void pqSelectionManager::clearSelection(pqOutputPort* outputPort)
       SM_SCOPED_TRACE(CallFunction).arg("ClearSelection").arg("comment", "clear all selections");
 
       // inform selection have changed
-      Q_EMIT this->selectionChanged(static_cast<pqOutputPort*>(0));
+      Q_EMIT this->selectionChanged(static_cast<pqOutputPort*>(nullptr));
     }
   }
   else
@@ -217,7 +219,7 @@ pqOutputPort* pqSelectionManager::getSelectedPort() const
   }
   else
   {
-    return NULL;
+    return nullptr;
   }
 }
 
@@ -253,7 +255,7 @@ void pqSelectionManager::select(pqOutputPort* selectedPort)
   // hence some selection cleared without our knowing
   else
   {
-    foreach (pqOutputPort* port, this->Implementation->SelectedPorts)
+    Q_FOREACH (pqOutputPort* port, this->Implementation->SelectedPorts)
     {
       port->renderAllViews(false);
     }
@@ -262,9 +264,8 @@ void pqSelectionManager::select(pqOutputPort* selectedPort)
   // Cleanup the set, before filling it again
   this->Implementation->SelectedPorts.clear();
 
-  if (selectedPort != NULL)
+  if (selectedPort != nullptr)
   {
-
     // Insert the selected port and render it
     this->Implementation->SelectedPorts.insert(selectedPort);
     selectedPort->renderAllViews(false);
@@ -288,7 +289,7 @@ void pqSelectionManager::select(pqOutputPort* selectedPort)
       // check it is a selection link
       vtkSMSelectionLink* selectionLink =
         vtkSMSelectionLink::SafeDownCast(selectionLinks->GetItemAsObject(i));
-      if (selectionLink != NULL)
+      if (selectionLink != nullptr)
       {
         for (unsigned int j = 0; j < selectionLink->GetNumberOfLinkedObjects(); j++)
         {
@@ -310,7 +311,7 @@ void pqSelectionManager::select(pqOutputPort* selectedPort)
             pqPipelineSource* linkedSource = psmm->findItem<pqPipelineSource*>(proxy);
 
             // Check it is valid
-            if (linkedSource != NULL &&
+            if (linkedSource != nullptr &&
               linkedSource->getNumberOfOutputPorts() > selectedPort->getPortNumber())
             {
               // Recover the corresponding outputport
@@ -366,13 +367,13 @@ void pqSelectionManager::onLinkRemoved()
 {
   // When removing a link, the set of selected port became invalid
   // We have to look for a potential selection in the set of selected port
-  foreach (pqOutputPort* port, this->Implementation->SelectedPorts)
+  Q_FOREACH (pqOutputPort* port, this->Implementation->SelectedPorts)
   {
     vtkSMSourceProxy* proxy = port->getSourceProxy();
     for (unsigned int i = 0; i < proxy->GetNumberOfOutputPorts(); i++)
     {
       // if the port contains a selection
-      if (port->getSourceProxy()->GetSelectionInput(i) != NULL)
+      if (port->getSourceProxy()->GetSelectionInput(i) != nullptr)
       {
         // Reupdate current selection with the found selected port
         this->select(port);
@@ -391,7 +392,7 @@ void pqSelectionManager::onLinkRemoved()
 vtkBoundingBox pqSelectionManager::selectedDataBounds() const
 {
   vtkBoundingBox bbox;
-  foreach (pqOutputPort* port, this->Implementation->SelectedPorts)
+  Q_FOREACH (pqOutputPort* port, this->Implementation->SelectedPorts)
   {
     double bds[6] = { 0, -1, 0, -1, 0, -1 };
     port->getSelectedDataInformation()->GetBounds(bds);
