@@ -44,16 +44,16 @@ class QListWidgetItem;
 class QNetworkReply;
 
 /**
-* pqServerConnectDialog is a dialog that can be used to show the user a
-* selection of server configurations to connect to a server. This dialog can
-* show all the server-configurations known to pqApplicationCore or show only a
-* subset of those depending on whether a \c selector was specified in the
-* constructor.
-*
-* On successful completion, this dialog provides access to the
-* server-configuration selected by the user. It does not make an real attempts
-* to connect to that server.
-*/
+ * pqServerConnectDialog is a dialog that can be used to show the user a
+ * selection of server configurations to connect to a server. This dialog can
+ * show all the server-configurations known to pqApplicationCore or show only a
+ * subset of those depending on whether a \c selector was specified in the
+ * constructor.
+ *
+ * On successful completion, this dialog provides access to the
+ * server-configuration selected by the user. It does not make an real attempts
+ * to connect to that server.
+ */
 class PQCOMPONENTS_EXPORT pqServerConnectDialog : public QDialog
 {
   Q_OBJECT
@@ -61,27 +61,28 @@ class PQCOMPONENTS_EXPORT pqServerConnectDialog : public QDialog
 
 public:
   /**
-  * If \c selector is specified, only those server-configurations that match the
-  * selector's scheme and hostname are shown.
-  */
-  pqServerConnectDialog(QWidget* parent = 0, const pqServerResource& selector = pqServerResource());
+   * If \c selector is specified, only those server-configurations that match the
+   * selector's scheme and hostname are shown.
+   */
+  pqServerConnectDialog(
+    QWidget* parent = nullptr, const pqServerResource& selector = pqServerResource());
   ~pqServerConnectDialog() override;
 
   /**
-  * returns the configuration to connect to. This returns a valid response
-  * only when pqServerConnectDialog::exec() returns QDialog::Accepted.
-  */
+   * returns the configuration to connect to. This returns a valid response
+   * only when pqServerConnectDialog::exec() returns QDialog::Accepted.
+   */
   const pqServerConfiguration& configurationToConnect() const;
 
   /**
-  * convenience method to determine which server to connect. If the selector
-  * is specified and matches a single server, then the user is not presented
-  * with a dialog, otherwise the user can choose the configuration to use to
-  * connect to the server. When the method returns true,
-  * selected_configuration will be set to the chosen configuration.
-  */
+   * convenience method to determine which server to connect. If the selector
+   * is specified and matches a single server, then the user is not presented
+   * with a dialog, otherwise the user can choose the configuration to use to
+   * connect to the server. When the method returns true,
+   * selected_configuration will be set to the chosen configuration.
+   */
   static bool selectServer(pqServerConfiguration& selected_configuration,
-    QWidget* dialogParent = NULL, const pqServerResource& selector = pqServerResource());
+    QWidget* dialogParent = nullptr, const pqServerResource& selector = pqServerResource());
 
 Q_SIGNALS:
 
@@ -97,23 +98,23 @@ Q_SIGNALS:
 
 protected Q_SLOTS:
   /**
-  * called to update the shown server configurations.
-  */
+   * called to update the shown server configurations.
+   */
   void updateConfigurations();
 
   /**
-  * called when user selects a server.
-  */
+   * called when user selects a server.
+   */
   void onServerSelected();
 
   /**
-  * called when user clicks "edit-server"
-  */
+   * called when user clicks "edit-server"
+   */
   void editServer();
 
   /**
-  * called when user clicks "add-server"
-  */
+   * called when user clicks "add-server"
+   */
   void addServer();
 
   /**
@@ -122,28 +123,28 @@ protected Q_SLOTS:
   void updateButtons();
 
   /**
-  * called when user changes the server-type.
-  */
+   * called when user changes the server-type.
+   */
   void updateServerType();
 
   /**
-  * called to cancel .
-  */
+   * called to cancel .
+   */
   void goToFirstPage();
 
   /**
-  * called when user accepts the configuration page #1.
-  */
+   * called when user accepts the configuration page #1.
+   */
   void acceptConfigurationPage1();
 
   /**
-  * called when user accepts the configuration page #2.
-  */
+   * called when user accepts the configuration page #2.
+   */
   void acceptConfigurationPage2();
 
   /**
-  * called to proceed to page that allows the user to edit the startup.
-  */
+   * called to proceed to page that allows the user to edit the startup.
+   */
   void editServerStartup();
 
   // called when the "name" on the edit server page changes. We ensure that the
@@ -151,67 +152,69 @@ protected Q_SLOTS:
   void onNameChanged();
 
   /**
-  * called to delete a server.
-  */
+   * called to delete one or all servers.
+   */
   void deleteServer();
+  void deleteAllServers();
 
   /**
-  * called to load/save servers.
-  */
+   * called to load/save servers.
+   */
   void loadServers();
   void saveServers();
 
   /**
-  * called to connect to selected server.
-  */
+   * called to connect to selected server.
+   */
   void connect();
 
   /**
-  * called when the main-stacked widget's active page changes. We update the
-  * dialog;s title text to match the page being displayed.
-  */
+   * called when the main-stacked widget's active page changes. We update the
+   * dialog;s title text to match the page being displayed.
+   */
   void updateDialogTitle(int page_number);
 
   /**
-  * called when user clicks "Fetch Servers".
-  */
+   * called when user clicks "Fetch Servers".
+   */
   void fetchServers();
 
   /**
-  * called when the importer needs authentication from the user.
-  */
+   * called when the importer needs authentication from the user.
+   */
   void authenticationRequired(QNetworkReply*, QAuthenticator*);
 
   /**
-  * called update importable configs.
-  */
+   * called update importable configs.
+   */
   void updateImportableConfigurations();
 
   /**
-  * called to report error from importer.
-  */
+   * called to report error from importer.
+   */
   void importError(const QString& message);
 
   /**
-  * called when user selects some servers to import.
-  */
+   * called when user selects some servers to import.
+   */
   void importServersSelectionChanged();
 
   /**
-  * called to import selected configurations.
-  */
+   * called to import selected configurations.
+   */
   void importServers();
 
   /**
-  * called to edit the sources url.
-  */
+   * called to edit the sources url.
+   */
   void editSources();
 
   void saveSourcesList();
   void cancelEditSources();
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   void editConfiguration(const pqServerConfiguration&);
+  bool serverNameExists(const QString& name);
 
 private:
   Q_DISABLE_COPY(pqServerConnectDialog)
