@@ -42,12 +42,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqServerResource.h"
 #include "pqSettings.h"
 #include "vtkCommand.h"
-#include "vtkMath.h"
+#include "vtkMinimalStandardRandomSequence.h"
 #include "vtkNetworkAccessManager.h"
-#include "vtkPVConfig.h"
-#include "vtkPVOptions.h"
+#include "vtkPVVersion.h"
 #include "vtkPVXMLElement.h"
 #include "vtkProcessModule.h"
+#include "vtkRemotingCoreConfiguration.h"
 #include "vtkTimerLog.h"
 
 #include <QCheckBox>
@@ -70,7 +70,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <cassert>
 
 //----------------------------------------------------------------------------
-const QMetaObject* pqServerLauncher::DefaultServerLauncherType = NULL;
+const QMetaObject* pqServerLauncher::DefaultServerLauncherType = nullptr;
 const QMetaObject* pqServerLauncher::setServerDefaultLauncherType(const QMetaObject* other)
 {
   const QMetaObject* old = pqServerLauncher::DefaultServerLauncherType;
@@ -112,7 +112,7 @@ public:
   QWidget* Widget;
   bool ToSave;
   pqWidget()
-    : Widget(NULL)
+    : Widget(nullptr)
     , ToSave(false)
   {
   }
@@ -122,15 +122,15 @@ public:
     , ToSave(false)
   {
   }
-  ~pqWidget() override {}
+  ~pqWidget() override = default;
 
   virtual QVariant get() const
   {
-    return this->Widget->property(this->PropertyName.toLocal8Bit().data());
+    return this->Widget->property(this->PropertyName.toUtf8().data());
   }
   virtual void set(const QVariant& value)
   {
-    this->Widget->setProperty(this->PropertyName.toLocal8Bit().data(), value);
+    this->Widget->setProperty(this->PropertyName.toUtf8().data(), value);
   }
 
 private:
@@ -201,7 +201,7 @@ QProcessEnvironment getDefaultEnvironment(const pqServerConfiguration& configura
 
   // Now append the pre-defined runtime environment to this.
   options.insert("PV_CLIENT_HOST", QHostInfo::localHostName());
-  options.insert("PV_CONNECTION_URI", resource.toURI());
+  options.insert("PV_CONNECTION_URI", resource.schemeHostsPorts().toURI());
   options.insert("PV_CONNECTION_SCHEME", resource.scheme());
   options.insert("PV_VERSION_MAJOR", QString::number(PARAVIEW_VERSION_MAJOR));
   options.insert("PV_VERSION_MINOR", QString::number(PARAVIEW_VERSION_MINOR));
@@ -228,6 +228,8 @@ QProcessEnvironment getDefaultEnvironment(const pqServerConfiguration& configura
   options.insert("PV_CLIENT_PLATFORM", "Unknown");
 #endif
 
+  options.insert("PV_APPLICATION_DIR", QCoreApplication::applicationDirPath());
+  options.insert("PV_APPLICATION_NAME", QCoreApplication::applicationName());
   return options;
 }
 
@@ -239,7 +241,7 @@ bool createWidgets(QMap<QString, pqWidget*>& widgets, QDialog& dialog,
   const pqServerConfiguration& configuration, QProcessEnvironment& options)
 {
   vtkPVXMLElement* optionsXML = configuration.optionsXML();
-  assert(optionsXML != NULL);
+  assert(optionsXML != nullptr);
 
   QFormLayout* formLayout = new QFormLayout();
   dialog.setLayout(formLayout);
@@ -251,7 +253,7 @@ bool createWidgets(QMap<QString, pqWidget*>& widgets, QDialog& dialog,
   for (unsigned int cc = 0; cc < optionsXML->GetNumberOfNestedElements(); cc++)
   {
     vtkPVXMLElement* node = optionsXML->GetNestedElement(cc);
-    if (node->GetName() == NULL)
+    if (node->GetName() == nullptr)
     {
       continue;
     }
@@ -263,7 +265,7 @@ bool createWidgets(QMap<QString, pqWidget*>& widgets, QDialog& dialog,
     else if (strcmp(node->GetName(), "Option") == 0)
     {
       vtkPVXMLElement* typeNode = node->GetNestedElement(0);
-      if (typeNode == NULL || typeNode->GetName() == NULL)
+      if (typeNode == nullptr || typeNode->GetName() == nullptr)
       {
         continue;
       }
@@ -303,8 +305,9 @@ bool createWidgets(QMap<QString, pqWidget*>& widgets, QDialog& dialog,
         {
           rseed += tc[ic];
         }
-        vtkMath::RandomSeed(rseed);
-        noise = vtkMath::Random();
+        vtkNew<vtkMinimalStandardRandomSequence> rand;
+        rand->Initialize(rseed);
+        noise = rand->GetValue();
       }
 
       // obtain default value from settings if available.
@@ -318,7 +321,7 @@ bool createWidgets(QMap<QString, pqWidget*>& widgets, QDialog& dialog,
         QString min = typeNode->GetAttributeOrDefault("min", "0");
         QString max = typeNode->GetAttributeOrDefault("max", "99999999999");
         QString step = typeNode->GetAttributeOrDefault("step", "1");
-        QWidget* widget = NULL;
+        QWidget* widget = nullptr;
         if (strcmp(typeNode->GetAttributeOrDefault("type", "int"), "int") == 0)
         {
           widget = new QSpinBox(&dialog);
@@ -373,8 +376,7 @@ bool createWidgets(QMap<QString, pqWidget*>& widgets, QDialog& dialog,
           if (QString(child->GetName()) == "Entry")
           {
             QString xml_value = child->GetAttribute("value");
-            QString xml_label =
-              child->GetAttributeOrDefault("label", xml_value.toLocal8Bit().data());
+            QString xml_label = child->GetAttributeOrDefault("label", xml_value.toUtf8().data());
             widget->addItem(xml_label, xml_value);
           }
         }
@@ -421,7 +423,7 @@ void updateEnvironment(const QMap<QString, pqWidget*>& widgets,
 {
   pqSettings* settings = pqApplicationCore::instance()->settings();
   pqServerResource resource = configuration.resource();
-  foreach (const pqWidget* item, widgets)
+  Q_FOREACH (const pqWidget* item, widgets)
   {
     QString name = item->Widget->objectName();
     QVariant chosen_value = item->get();
@@ -511,9 +513,8 @@ void handleSwitchCases(const pqServerConfiguration& configuration, QProcessEnvir
     }
     if (!handled)
     {
-      qWarning() << "Case '" << value << "' not handled in 'Switch' for variable "
-                                         "'"
-                 << variable << "'";
+      qWarning() << "Case '" << value << "' not handled in 'Switch' for variable '" << variable
+                 << "'";
     }
   }
 }
@@ -543,7 +544,7 @@ pqServerLauncher::pqServerLauncher(
 pqServerLauncher::~pqServerLauncher()
 {
   delete this->Internals;
-  this->Internals = NULL;
+  this->Internals = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -553,7 +554,7 @@ pqServerConfiguration& pqServerLauncher::configuration() const
 }
 
 //-----------------------------------------------------------------------------
-bool pqServerLauncher::connectToServer()
+bool pqServerLauncher::connectToServer(bool showConnectionDialog)
 {
   pqServerConfiguration::StartupType startupType = this->Internals->Configuration.startupType();
   if (startupType != pqServerConfiguration::MANUAL && startupType != pqServerConfiguration::COMMAND)
@@ -591,51 +592,79 @@ bool pqServerLauncher::connectToServer()
 
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   vtkNetworkAccessManager* nam = pm->GetNetworkAccessManager();
-  vtkPVOptions* options = pm->GetOptions();
+  vtkRemotingCoreConfiguration* config = vtkRemotingCoreConfiguration::GetInstance();
   QDialog dialog(pqCoreUtilities::mainWidget(), Qt::WindowStaysOnTopHint);
   Ui::pqConnectIdDialog ui;
   ui.setupUi(&dialog);
   ui.connectId->setMaximum(VTK_INT_MAX);
-  ui.connectId->setValue(options->GetConnectID());
+  ui.connectId->setValue(config->GetConnectID());
 
   pqObjectBuilder* builder = pqApplicationCore::instance()->getObjectBuilder();
   bool force = builder->forceWaitingForConnection(true);
   bool launched = false;
-  while (!(launched = this->connectToPrelaunchedServer()) && nam->GetWrongConnectID() &&
-    dialog.exec() == QDialog::Accepted)
+  while (!(launched = this->connectToPrelaunchedServer(showConnectionDialog)) &&
+    nam->GetWrongConnectID() && dialog.exec() == QDialog::Accepted)
   {
-    options->SetConnectID(ui.connectId->value());
+    config->SetConnectID(ui.connectId->value());
   }
   builder->forceWaitingForConnection(force);
   return launched;
 }
 
 //-----------------------------------------------------------------------------
-bool pqServerLauncher::connectToPrelaunchedServer()
+bool pqServerLauncher::connectToPrelaunchedServer(bool showConnectionDialog)
 {
   pqObjectBuilder* builder = pqApplicationCore::instance()->getObjectBuilder();
 
-  QDialog dialog(pqCoreUtilities::mainWidget(), Qt::WindowStaysOnTopHint);
-  QObject::connect(&dialog, SIGNAL(rejected()), builder, SLOT(abortPendingConnections()));
+  //  default timeout of reverse connection is infinite, 60s otherwise
+  int timeout =
+    this->Internals->Configuration.connectionTimeout(this->isReverseConnection() ? -1 : 60);
 
-  Ui::pqServerLauncherDialog ui;
-  ui.setupUi(&dialog);
-  ui.message->setText(QString("Establishing connection to '%1' \n"
-                              "Waiting for server to connect.")
-                        .arg(this->Internals->Configuration.name()));
-  dialog.setWindowTitle("Waiting for Server Connection");
-  if (this->isReverseConnection())
+  vtkNetworkAccessManager::ConnectionResult result;
+  do
   {
-    // using reverse connect, popup the dialog.
-    dialog.show();
-    dialog.raise();
-    dialog.activateWindow();
-  }
+    QDialog dialog(pqCoreUtilities::mainWidget(), Qt::WindowStaysOnTopHint);
+    if (showConnectionDialog)
+    {
+      QObject::connect(&dialog, SIGNAL(rejected()), builder, SLOT(abortPendingConnections()));
 
-  const pqServerResource& resource = this->Internals->Configuration.actualResource();
-  this->Internals->Server =
-    builder->createServer(resource, this->Internals->Configuration.connectionTimeout());
-  return this->Internals->Server != NULL;
+      Ui::pqServerLauncherDialog ui;
+      ui.setupUi(&dialog);
+
+      if (timeout < 0)
+      {
+        ui.message->setText(QString("Establishing connection to '%1' \n"
+                                    "Waiting for server to connect.")
+                              .arg(this->Internals->Configuration.name()));
+        dialog.setWindowTitle("Waiting for Server Connection");
+      }
+      else
+      {
+        ui.message->setText(QString("Establishing connection to '%1' \n"
+                                    "Waiting %2 seconds for connection to server.")
+                              .arg(this->Internals->Configuration.name())
+                              .arg(timeout));
+        dialog.setWindowTitle("Waiting for Connection to Server");
+      }
+
+      dialog.setModal(true);
+      dialog.show();
+      dialog.raise();
+      dialog.activateWindow();
+    }
+
+    const pqServerResource& resource = this->Internals->Configuration.actualResource();
+    this->Internals->Server = builder->createServer(resource, timeout, result);
+
+    // Make sure events have been processed
+    pqEventDispatcher::processEventsAndWait(100);
+
+  } while (result == vtkNetworkAccessManager::ConnectionResult::CONNECTION_TIMEOUT &&
+    QMessageBox::question(pqCoreUtilities::mainWidget(), QString("Connection Failed"),
+      QString("Unable to connect sucessfully. Try again for %1 seconds ?").arg(timeout)) ==
+      QMessageBox::Yes);
+
+  return this->Internals->Server != nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -653,7 +682,7 @@ bool pqServerLauncher::promptOptions()
   QProcessEnvironment& options = this->Internals->Options;
   // setup the options using the default environment, in any case.
   options = getDefaultEnvironment(this->Internals->Configuration);
-  if (optionsXML == NULL)
+  if (optionsXML == nullptr)
   {
     return true;
   }
@@ -676,15 +705,12 @@ bool pqServerLauncher::promptOptions()
 
   this->updateOptionsUsingUserSelections();
 
-  // if options contains PV_CONNECT_ID. We need to update the pqOptions to
-  // give it the correct connection-id.
+  // if options contains PV_CONNECT_ID. We need to update the
+  // vtkRemotingCoreConfiguration to give it the correct connection-id.
   if (options.contains("PV_CONNECT_ID"))
   {
-    vtkPVOptions* pvoptions = vtkProcessModule::GetProcessModule()->GetOptions();
-    if (pvoptions)
-    {
-      pvoptions->SetConnectID(options.value("PV_CONNECT_ID").toInt());
-    }
+    vtkRemotingCoreConfiguration* config = vtkRemotingCoreConfiguration::GetInstance();
+    config->SetConnectID(options.value("PV_CONNECT_ID").toInt());
   }
 
   widgets.clear();
@@ -695,7 +721,7 @@ bool pqServerLauncher::promptOptions()
 //-----------------------------------------------------------------------------
 void pqServerLauncher::updateOptionsUsingUserSelections()
 {
-  if (this->Internals->ActiveWidgets.size() > 0)
+  if (!this->Internals->ActiveWidgets.empty())
   {
     /// now based on user-chosen values, update the options.
     updateEnvironment(
@@ -724,8 +750,8 @@ void pqServerLauncher::launchServerForReverseConnection()
 bool pqServerLauncher::launchServer(bool show_status_dialog)
 {
   // We need launch the server.
-  double timeout, delay;
-  QString command = this->Internals->Configuration.command(timeout, delay);
+  double processWait, delay;
+  QString command = this->Internals->Configuration.command(processWait, delay);
   if (command.isEmpty())
   {
     qCritical() << "Could not determine command to launch the server.";
@@ -757,16 +783,16 @@ bool pqServerLauncher::launchServer(bool show_status_dialog)
     command.replace(before, after);
   }
 
-  return this->processCommand(command, timeout, delay, &this->Internals->Options);
+  return this->processCommand(command, processWait, delay, &this->Internals->Options);
 }
 
 //-----------------------------------------------------------------------------
 bool pqServerLauncher::processCommand(
-  QString command, double timeout, double delay, const QProcessEnvironment* options)
+  QString command, double processWait, double delay, const QProcessEnvironment* options)
 {
   QProcess* process = new QProcess(pqApplicationCore::instance());
 
-  if (options != NULL)
+  if (options != nullptr)
   {
     process->setProcessEnvironment(*options);
   }
@@ -776,12 +802,20 @@ bool pqServerLauncher::processCommand(
   QObject::connect(process, SIGNAL(readyReadStandardError()), this, SLOT(readStandardError()));
   QObject::connect(process, SIGNAL(readyReadStandardOutput()), this, SLOT(readStandardOutput()));
 
+// QProcess::start(QString) has been deprecated in Qt 5.15
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
   process->start(command);
+#else
+  QStringList splitCommand = QProcess::splitCommand(command);
+  QString program = splitCommand.takeAt(0);
+  process->start(program, splitCommand);
+#endif
 
   // wait for process to start.
   // waitForStarted() may block until the process starts. That is generally a short
   // span of time, hence we don't worry about it too much.
-  if (process->waitForStarted(timeout > 0. ? static_cast<int>(timeout * 1000.) : -1) == false)
+  if (process->waitForStarted(processWait > 0. ? static_cast<int>(processWait * 1000.) : -1) ==
+    false)
   {
     qCritical() << "Command launch timed out.";
     process->kill();
