@@ -43,7 +43,7 @@ class PQCOMPONENTS_EXPORT pqStringVectorPropertyWidget : public pqPropertyWidget
 public:
   pqStringVectorPropertyWidget(
     vtkSMProperty* property, vtkSMProxy* proxy, QWidget* parent = nullptr);
-  virtual ~pqStringVectorPropertyWidget();
+  ~pqStringVectorPropertyWidget() override;
 
   /**
    * Factory method to instantiate a hard-coded type of pqPropertyWidget
@@ -62,4 +62,4 @@ private:
   Q_DISABLE_COPY(pqStringVectorPropertyWidget);
 };
 
-#endif // _pqStringVectorPropertyWidget_h
+#endif // pqStringVectorPropertyWidget_h
