@@ -45,15 +45,28 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMSessionProxyManager.h"
 
 // Qt Includes
+#include <QDebug>
 #include <QFileInfo>
 
-const std::string pqTextureComboBox::TEXTURES_GROUP = "textures";
-
 //-----------------------------------------------------------------------------
-pqTextureComboBox::pqTextureComboBox(vtkSMProxyGroupDomain* domain, QWidget* parent)
+pqTextureComboBox::pqTextureComboBox(
+  vtkSMProxyGroupDomain* domain, bool canLoadNew, QWidget* parent)
   : Superclass(parent)
   , Domain(domain)
+  , GroupName("")
+  , CanLoadNew(canLoadNew)
 {
+  if (!this->Domain || this->Domain->GetNumberOfGroups() != 1)
+  {
+    qCritical() << "pqTextureSelectorPropertyWidget can only be used with a ProxyProperty"
+                   " with a ProxyGroupDomain containing a single domain with a name.";
+    return;
+  }
+  else
+  {
+    this->GroupName = this->Domain->GetGroup(0);
+  }
+
   this->updateTextures();
   QObject::connect(this, SIGNAL(currentIndexChanged(int)), this, SLOT(onCurrentIndexChanged(int)));
 
@@ -67,6 +80,12 @@ pqTextureComboBox::pqTextureComboBox(vtkSMProxyGroupDomain* domain, QWidget* par
     this, SLOT(proxyUnRegistered(const QString&, const QString&, vtkSMProxy*)));
 }
 
+//-----------------------------------------------------------------------------
+pqTextureComboBox::pqTextureComboBox(vtkSMProxyGroupDomain* domain, QWidget* parent)
+  : pqTextureComboBox(domain, true, parent)
+{
+}
+
 //-----------------------------------------------------------------------------
 void pqTextureComboBox::updateFromTexture(vtkSMProxy* texture)
 {
@@ -81,8 +100,7 @@ void pqTextureComboBox::updateFromTexture(vtkSMProxy* texture)
 void pqTextureComboBox::proxyRegistered(
   const QString& group, const QString& vtkNotUsed(name), vtkSMProxy* proxy)
 {
-  if (group == QString(pqTextureComboBox::TEXTURES_GROUP.c_str()) &&
-    this->Domain->IsInDomain(proxy))
+  if (group == this->GroupName && this->Domain->IsInDomain(proxy))
   {
     this->updateTextures();
   }
@@ -92,7 +110,7 @@ void pqTextureComboBox::proxyRegistered(
 void pqTextureComboBox::proxyUnRegistered(
   const QString& group, const QString& vtkNotUsed(name), vtkSMProxy* vtkNotUsed(proxy))
 {
-  if (group == QString(pqTextureComboBox::TEXTURES_GROUP.c_str()))
+  if (group == this->GroupName)
   {
     this->updateTextures();
   }
@@ -107,7 +125,10 @@ void pqTextureComboBox::updateTextures()
 
   this->clear();
   this->addItem("None", QVariant("NONE"));
-  this->addItem("Load ...", QVariant("LOAD"));
+  if (this->CanLoadNew)
+  {
+    this->addItem("Load ...", QVariant("LOAD"));
+  }
 
   for (unsigned int i = 0; i < this->Domain->GetNumberOfProxies(); i++)
   {
@@ -122,18 +143,18 @@ void pqTextureComboBox::updateTextures()
 //-----------------------------------------------------------------------------
 void pqTextureComboBox::onCurrentIndexChanged(int index)
 {
-  switch (index)
+  if (index == 0)
   {
-    case 0:
-      Q_EMIT textureChanged(nullptr);
-      break;
-    case 1:
-      this->loadTexture();
-      break;
-    default:
-      vtkSMProxy* texture = reinterpret_cast<vtkSMProxy*>(this->currentData().value<void*>());
-      Q_EMIT textureChanged(texture);
-      break;
+    Q_EMIT textureChanged(nullptr);
+  }
+  else if (index == 1 && this->CanLoadNew)
+  {
+    this->loadTexture();
+  }
+  else
+  {
+    vtkSMProxy* texture = reinterpret_cast<vtkSMProxy*>(this->currentData().value<void*>());
+    Q_EMIT textureChanged(texture);
   }
 }
 
@@ -141,13 +162,13 @@ void pqTextureComboBox::onCurrentIndexChanged(int index)
 void pqTextureComboBox::loadTexture()
 {
   QString filters = "Image files (*.png *.jpg *.bmp *.ppm *.tiff *.hdr);;All files (*)";
-  pqFileDialog dialog(0, this, tr("Open Texture:"), QString(), filters);
+  pqFileDialog dialog(nullptr, this, tr("Open Texture:"), QString(), filters);
   dialog.setObjectName("LoadTextureDialog");
   dialog.setFileMode(pqFileDialog::ExistingFile);
   if (dialog.exec())
   {
     QStringList files = dialog.getSelectedFiles();
-    if (files.size() > 0)
+    if (!files.empty())
     {
       if (this->loadTexture(files[0]))
       {
@@ -161,6 +182,11 @@ void pqTextureComboBox::loadTexture()
 //-----------------------------------------------------------------------------
 bool pqTextureComboBox::loadTexture(const QString& filename)
 {
+  if (this->GroupName.isEmpty())
+  {
+    return false;
+  }
+
   QFileInfo finfo(filename);
   if (!finfo.isReadable())
   {
@@ -173,8 +199,8 @@ bool pqTextureComboBox::loadTexture(const QString& filename)
   vtkSMSessionProxyManager* spxm = pxm->GetActiveSessionProxyManager();
   vtkSMProxy* texture = pxm->NewProxy("textures", "ImageTexture");
   std::string proxyName = spxm->GetUniqueProxyName(
-    pqTextureComboBox::TEXTURES_GROUP.c_str(), finfo.baseName().toUtf8().data(), false);
-  pxm->RegisterProxy(pqTextureComboBox::TEXTURES_GROUP.c_str(), proxyName.c_str(), texture);
+    this->GroupName.toUtf8().data(), finfo.baseName().toUtf8().data(), false);
+  pxm->RegisterProxy(this->GroupName.toUtf8().data(), proxyName.c_str(), texture);
   vtkSMPropertyHelper(texture->GetProperty("FileName")).Set(filename.toUtf8().data());
   texture->UpdateVTKObjects();
   texture->Delete();
