@@ -37,7 +37,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkAxis.h"
 #include "vtkBoundingBox.h"
 #include "vtkChartXY.h"
-#include "vtkColorTransferControlPointsItem.h"
 #include "vtkColorTransferFunction.h"
 #include "vtkColorTransferFunctionItem.h"
 #include "vtkCompositeControlPointsItem.h"
@@ -50,6 +49,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkGenericOpenGLRenderWindow.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
+#include "vtkPVColorTransferControlPointsItem.h"
 #include "vtkPiecewiseControlPointsItem.h"
 #include "vtkPiecewiseFunction.h"
 #include "vtkPiecewiseFunctionItem.h"
@@ -167,7 +167,7 @@ protected:
     this->NeedUpdate = false;
     this->DataValid = false;
   }
-  ~vtkTransferFunctionChartXY() override {}
+  ~vtkTransferFunctionChartXY() override = default;
 
   void AdjustAxes()
   {
@@ -200,6 +200,7 @@ public:
 
   pqTimer Timer;
   pqTimer RangeTimer;
+  pqTimer EditColorPointTimer;
 
   vtkSmartPointer<vtkRangeHandlesItem> RangeHandlesItem;
   vtkSmartPointer<vtkScalarsToColorsItem> TransferFunctionItem;
@@ -219,6 +220,11 @@ public:
     this->RangeTimer.setSingleShot(true);
     this->RangeTimer.setInterval(0);
 
+    // A delay is necessary otherwise the color dialog grabs focus
+    // too quickly causing #20758.
+    this->EditColorPointTimer.setSingleShot(true);
+    this->EditColorPointTimer.setInterval(100);
+
     this->Window->SetMultiSamples(8);
 
     this->Widget->setEnableHiDPI(true);
@@ -282,6 +288,9 @@ pqTransferFunctionWidget::pqTransferFunctionWidget(QWidget* parentObject)
       renWin->Render();
     }
   });
+
+  this->connect(&this->Internals->EditColorPointTimer, SIGNAL(timeout()),
+    SLOT(editColorAtCurrentControlPoint()));
 }
 
 //-----------------------------------------------------------------------------
@@ -327,7 +336,7 @@ void pqTransferFunctionWidget::initialize(
 
     if (stc_editable)
     {
-      vtkNew<vtkColorTransferControlPointsItem> cpItem;
+      vtkNew<vtkPVColorTransferControlPointsItem> cpItem;
       cpItem->SetColorTransferFunction(ctf);
       cpItem->SetColorFill(true);
       cpItem->SetEndPointsXMovable(false);
@@ -466,12 +475,20 @@ void pqTransferFunctionWidget::initialize(
     this->Internals->ChartXY->SetTFRange(vtkVector2d(ctf->GetRange()));
   }
 
-  pqCoreUtilities::connect(
-    this->Internals->ChartXY, vtkCommand::MouseMoveEvent, this, SLOT(showUsageStatus()));
+  pqCoreUtilities::connect(this->Internals->Widget->interactor(), vtkCommand::MouseMoveEvent, this,
+    SLOT(showUsageStatus()));
 }
 
 //-----------------------------------------------------------------------------
 void pqTransferFunctionWidget::onCurrentPointEditEvent()
+{
+  // defer the invocation to avoid paraview/paraview#20758.
+  auto& internals = (*this->Internals);
+  internals.EditColorPointTimer.start();
+}
+
+//-----------------------------------------------------------------------------
+void pqTransferFunctionWidget::editColorAtCurrentControlPoint()
 {
   vtkColorTransferControlPointsItem* cpitem =
     vtkColorTransferControlPointsItem::SafeDownCast(this->Internals->ControlPointsItem);
@@ -489,6 +506,11 @@ void pqTransferFunctionWidget::onCurrentPointEditEvent()
   vtkColorTransferFunction* ctf = cpitem->GetColorTransferFunction();
   assert(ctf != nullptr);
 
+  // Disable the interactor to ignore any events that may be issues
+  // from the operating system after the dialog is shown and closed.
+  // Fixes #20758.
+  this->Internals->Widget->interactor()->Disable();
+
   double xrgbms[6];
   ctf->GetNodeValue(currentIdx, xrgbms);
   QColor color = QColorDialog::getColor(QColor::fromRgbF(xrgbms[1], xrgbms[2], xrgbms[3]), this,
@@ -502,6 +524,16 @@ void pqTransferFunctionWidget::onCurrentPointEditEvent()
 
     Q_EMIT this->controlPointsModified();
   }
+
+  // Simulate a MouseButtonReleaseEvent that can get lost when the color
+  // selector is closed. Fixes #20758.
+  vtkContextMouseEvent mouseEvent;
+  mouseEvent.SetButton(vtkContextMouseEvent::LEFT_BUTTON);
+  cpitem->MouseButtonReleaseEvent(mouseEvent);
+
+  // Re-enable the widget interactor a short time after the dialog closes.
+  // Fixes #20758.
+  QTimer::singleShot(100, [=]() { this->Internals->Widget->interactor()->Enable(); });
 }
 
 //-----------------------------------------------------------------------------
@@ -633,8 +665,9 @@ void pqTransferFunctionWidget::showUsageStatus()
   QMainWindow* mainWindow = qobject_cast<QMainWindow*>(pqCoreUtilities::mainWidget());
   if (mainWindow)
   {
-    mainWindow->statusBar()->showMessage(tr("Grab and move a handle to interactively change the "
-                                            "range. Double click on it to set custom range."),
+    mainWindow->statusBar()->showMessage(
+      tr("Drag a handle to change the range. "
+         "Double click it to set custom range. Return/Enter to edit color."),
       2000);
   }
 }
