@@ -41,25 +41,25 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqServer;
 
 /**
-* Often times we need to call certain slots on idle. However, just relying on
-* Qt's idle is not safe since progress events often result in processing of
-* pending events, which may not be a safe place for such slots to be called.
-* In that such cases this class can be used. It emits the triggered() signal
-* when the server (set using setServer()) is indeed idle. Otherwise it simply
-* reschedules the triggering of another time.
-*/
+ * Often times we need to call certain slots on idle. However, just relying on
+ * Qt's idle is not safe since progress events often result in processing of
+ * pending events, which may not be a safe place for such slots to be called.
+ * In that such cases this class can be used. It emits the triggered() signal
+ * when the server (set using setServer()) is indeed idle. Otherwise it simply
+ * reschedules the triggering of another time.
+ */
 class PQCOMPONENTS_EXPORT pqTriggerOnIdleHelper : public QObject
 {
   Q_OBJECT
   typedef QObject Superclass;
 
 public:
-  pqTriggerOnIdleHelper(QObject* parent = 0);
+  pqTriggerOnIdleHelper(QObject* parent = nullptr);
   ~pqTriggerOnIdleHelper() override;
 
   /**
-  * get the server
-  */
+   * get the server
+   */
   pqServer* server() const;
 
 Q_SIGNALS:
