@@ -14,10 +14,10 @@ class pqFileDialogTestUtility : public pqTestUtility
   Q_OBJECT
 public:
   pqFileDialogTestUtility();
-  ~pqFileDialogTestUtility();
-  virtual bool playTests(const QStringList& filenames);
-public slots:
-  void playTheTests(const QStringList&);
+  ~pqFileDialogTestUtility() override;
+  bool playTests(const QStringList& filenames) override;
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
+  void playTheTests();
 
 protected:
   void setupFiles();
@@ -33,7 +33,7 @@ public:
 
   pqTestUtility* Tester() { return &this->TestUtility; }
 
-public slots:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   void record();
   void openFileDialog();
   void emittedFiles(const QList<QStringList>& files);
