@@ -38,9 +38,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class vtkSMComparativeViewProxy;
 
 /**
-* The abstract base class for comparative chart views. It handles the layout
-* of the individual chart views in the comparative view.
-*/
+ * The abstract base class for comparative chart views. It handles the layout
+ * of the individual chart views in the comparative view.
+ */
 class PQCORE_EXPORT pqComparativeContextView : public pqContextView
 {
   Q_OBJECT
@@ -50,50 +50,49 @@ public:
   ~pqComparativeContextView() override;
 
   /**
-  * \returns the internal vtkContextView which provides the implementation for
-  * the chart rendering.
-  */
+   * \returns the internal vtkContextView which provides the implementation for
+   * the chart rendering.
+   */
   vtkContextView* getVTKContextView() const override;
 
   /**
-  * Returns the context view proxy associated with this object.
-  */
+   * Returns the context view proxy associated with this object.
+   */
   vtkSMContextViewProxy* getContextViewProxy() const override;
 
   /**
-  * \returns the comparative view proxy.
-  */
+   * \returns the comparative view proxy.
+   */
   vtkSMComparativeViewProxy* getComparativeViewProxy() const;
 
   /**
-  * Returns the proxy of the root plot view in the comparative view.
-  */
+   * Returns the proxy of the root plot view in the comparative view.
+   */
   virtual vtkSMViewProxy* getViewProxy() const;
 
 protected Q_SLOTS:
   /**
-  * Called when the layout on the comparative vis changes.
-  */
+   * Called when the layout on the comparative vis changes.
+   */
   void updateViewWidgets();
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * Create the QWidget for this view.
-  */
+   * Create the QWidget for this view.
+   */
   QWidget* createWidget() override;
 
-protected:
   /**
-  * Constructor:
-  * \c type  :- view type.
-  * \c group :- SManager registration group.
-  * \c name  :- SManager registration name.
-  * \c view  :- View proxy.
-  * \c server:- server on which the proxy is created.
-  * \c parent:- QObject parent.
-  */
+   * Constructor:
+   * \c type  :- view type.
+   * \c group :- SManager registration group.
+   * \c name  :- SManager registration name.
+   * \c view  :- View proxy.
+   * \c server:- server on which the proxy is created.
+   * \c parent:- QObject parent.
+   */
   pqComparativeContextView(const QString& type, const QString& group, const QString& name,
-    vtkSMComparativeViewProxy* view, pqServer* server, QObject* parent = NULL);
+    vtkSMComparativeViewProxy* view, pqServer* server, QObject* parent = nullptr);
 
   QPointer<QWidget> Widget;
 
