@@ -37,8 +37,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class vtkSMComparativeViewProxy;
 
 /**
-* RenderView used for comparative visualization (or film-strip visualization).
-*/
+ * RenderView used for comparative visualization (or film-strip visualization).
+ */
 class PQCORE_EXPORT pqComparativeRenderView : public pqRenderView
 {
   Q_OBJECT
@@ -54,30 +54,30 @@ public:
   // \c server:- server on which the proxy is created.
   // \c parent:- QObject parent.
   pqComparativeRenderView(const QString& group, const QString& name, vtkSMViewProxy* renModule,
-    pqServer* server, QObject* parent = NULL);
+    pqServer* server, QObject* parent = nullptr);
   ~pqComparativeRenderView() override;
 
   /**
-  * Returns the comparative view proxy.
-  */
+   * Returns the comparative view proxy.
+   */
   vtkSMComparativeViewProxy* getComparativeRenderViewProxy() const;
 
   /**
-  * Returns the root render view in the comparative view.
-  */
+   * Returns the root render view in the comparative view.
+   */
   vtkSMRenderViewProxy* getRenderViewProxy() const override;
 
 protected Q_SLOTS:
   /**
-  * Called when the layout on the comparative vis changes.
-  */
-  void updateViewWidgets(QWidget* container = NULL);
+   * Called when the layout on the comparative vis changes.
+   */
+  void updateViewWidgets(QWidget* container = nullptr);
 
-protected:
+protected: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * Creates a new instance of the QWidget subclass to be used to show this
-  * view. Default implementation creates a pqQVTKWidgetBase.
-  */
+   * Creates a new instance of the QWidget subclass to be used to show this
+   * view. Default implementation creates a pqQVTKWidgetBase.
+   */
   QWidget* createWidget() override;
 
 private:
