@@ -51,6 +51,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtksys/SystemTools.hxx"
 
 #include <cassert>
+#include <cmath>
 #include <cstdlib>
 #include <sstream>
 
@@ -67,7 +68,7 @@ bool ApplicationIsRunningInDashboard()
 //-----------------------------------------------------------------------------
 QWidget* pqCoreUtilities::findMainWindow()
 {
-  foreach (QWidget* widget, QApplication::topLevelWidgets())
+  Q_FOREACH (QWidget* widget, QApplication::topLevelWidgets())
   {
     if (widget->isWindow() && widget->isVisible() && qobject_cast<QMainWindow*>(widget))
     {
@@ -76,7 +77,7 @@ QWidget* pqCoreUtilities::findMainWindow()
   }
 
   // Find any window (even if not visible).
-  foreach (QWidget* widget, QApplication::topLevelWidgets())
+  Q_FOREACH (QWidget* widget, QApplication::topLevelWidgets())
   {
     if (widget->isWindow() && qobject_cast<QMainWindow*>(widget))
     {
@@ -128,7 +129,7 @@ QStringList pqCoreUtilities::findParaviewPaths(
 
   // Filter with only existing ones
   QStringList existingDirs;
-  foreach (QString path, allPossibleDirs)
+  Q_FOREACH (QString path, allPossibleDirs)
   {
     if (QFile::exists(path))
       existingDirs.push_back(path);
@@ -314,6 +315,44 @@ QString pqCoreUtilities::number(double value)
   return QString::fromStdString(stream.str());
 }
 
+//-----------------------------------------------------------------------------
+QString pqCoreUtilities::formatMemoryFromKiBValue(double memoryInKiB, int precision)
+{
+  QString fmt("%1 %2");
+
+  double const p210 = std::pow(2.0, 10.0);
+  double const p220 = std::pow(2.0, 20.0);
+  double const p230 = std::pow(2.0, 30.0);
+  double const p240 = std::pow(2.0, 40.0);
+  double const p250 = std::pow(2.0, 50.0);
+
+  // were dealing with kiB
+  memoryInKiB *= 1024;
+
+  if (memoryInKiB < p210)
+  {
+    return fmt.arg(memoryInKiB, 0, 'f', precision).arg("B");
+  }
+  else if (memoryInKiB < p220)
+  {
+    return fmt.arg(memoryInKiB / p210, 0, 'f', precision).arg("KiB");
+  }
+  else if (memoryInKiB < p230)
+  {
+    return fmt.arg(memoryInKiB / p220, 0, 'f', precision).arg("MiB");
+  }
+  else if (memoryInKiB < p240)
+  {
+    return fmt.arg(memoryInKiB / p230, 0, 'f', precision).arg("GiB");
+  }
+  else if (memoryInKiB < p250)
+  {
+    return fmt.arg(memoryInKiB / p240, 0, 'f', precision).arg("TiB");
+  }
+
+  return fmt.arg(memoryInKiB / p250, 0, 'f', precision).arg("PiB");
+}
+
 //-----------------------------------------------------------------------------
 void pqCoreUtilities::initializeClickMeButton(QAbstractButton* button)
 {
@@ -325,3 +364,59 @@ void pqCoreUtilities::initializeClickMeButton(QAbstractButton* button)
     button->setPalette(applyPalette);
   }
 }
+
+//-----------------------------------------------------------------------------
+void pqCoreUtilities::setPaletteHighlightToOk(QPalette& palette)
+{
+  // CDash green
+  auto okGreen = QColor::fromRgb(184, 220, 179);
+  palette.setColor(QPalette::Highlight, okGreen);
+  palette.setColor(QPalette::HighlightedText, Qt::black);
+}
+
+//-----------------------------------------------------------------------------
+void pqCoreUtilities::setPaletteHighlightToWarning(QPalette& palette)
+{
+  // CDash yellow
+  auto warningOrange = QColor::fromRgb(236, 144, 31);
+  palette.setColor(QPalette::Highlight, warningOrange);
+  palette.setColor(QPalette::HighlightedText, Qt::white);
+}
+
+//-----------------------------------------------------------------------------
+void pqCoreUtilities::setPaletteHighlightToCritical(QPalette& palette)
+{
+  // CDash red
+  auto criticalRed = QColor::fromRgb(217, 84, 84);
+  palette.setColor(QPalette::Highlight, criticalRed);
+  palette.setColor(QPalette::HighlightedText, Qt::white);
+}
+
+//-----------------------------------------------------------------------------
+void pqCoreUtilities::removeRecursively(QDir dir)
+{
+  const bool success = dir.removeRecursively();
+  if (!success)
+  {
+    QMessageBox(QMessageBox::Warning, QObject::tr("File IO Warning"),
+      QObject::tr("Unable to delete some files in %1").arg(dir.absolutePath()),
+      QMessageBox::StandardButton::Ok, pqCoreUtilities::mainWidget())
+      .exec();
+  }
+}
+
+//-----------------------------------------------------------------------------
+void pqCoreUtilities::remove(const QString& filePath)
+{
+  const auto finfo = QFileInfo(filePath);
+  QDir dir = finfo.dir();
+  const auto fileName = finfo.fileName();
+  const bool success = dir.remove(fileName);
+  if (!success)
+  {
+    QMessageBox(QMessageBox::Warning, QObject::tr("File IO Warning"),
+      QObject::tr("Unable to delete %1").arg(finfo.absoluteFilePath()),
+      QMessageBox::StandardButton::Ok, pqCoreUtilities::mainWidget())
+      .exec();
+  }
+}
