@@ -52,6 +52,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QMessageBox>
 #include <QPoint>
 #include <QScopedValueRollback>
+#include <QShortcut>
 #include <QtDebug>
 
 #include <QKeyEvent>
@@ -116,7 +117,7 @@ QStringList GetWildCardsFromFilter(const QString& filter)
 
   // add a *.ext.* for every *.ext we get to support file groups
   QStringList ret = fs;
-  foreach (QString ext, fs)
+  Q_FOREACH (QString ext, fs)
   {
     ret.append(ext + ".*");
   }
@@ -133,13 +134,16 @@ public:
   pqFileDialogModel* const Model;
   pqFileDialogFavoriteModel* const FavoriteModel;
   pqFileDialogRecentDirsModel* const RecentModel;
+  QSortFilterProxyModel* proxyFavoriteModel;
   pqFileDialogFilter FileFilter;
   QStringList FileNames; // list of file names in the FileName ui text edit
   QCompleter* Completer;
   pqFileDialog::FileMode Mode;
   Ui::pqFileDialog Ui;
   QList<QStringList> SelectedFiles;
+  int SelectedFilterIndex;
   QStringList Filters;
+  bool GroupPaths;
   bool SuppressOverwriteWarning;
   bool ShowMultipleFileHelp;
   QString FileNamesSeperator;
@@ -159,6 +163,7 @@ public:
     , FileFilter(this->Model)
     , Completer(new QCompleter(&this->FileFilter, nullptr))
     , Mode(ExistingFile)
+    , GroupPaths(true)
     , SuppressOverwriteWarning(false)
     , ShowMultipleFileHelp(false)
     , FileNamesSeperator(";")
@@ -185,10 +190,10 @@ public:
         QKeyEvent* keyEvent = static_cast<QKeyEvent*>(anEvent);
         if (keyEvent->key() == Qt::Key_Backspace || keyEvent->key() == Qt::Key_Delete)
         {
-          this->Ui.FileName->setFocus(Qt::OtherFocusReason);
+          this->Ui.EntityName->setFocus(Qt::OtherFocusReason);
           // send out a backspace event to the file name now
           QKeyEvent replicateDelete(keyEvent->type(), keyEvent->key(), keyEvent->modifiers());
-          QApplication::sendEvent(this->Ui.FileName, &replicateDelete);
+          QApplication::sendEvent(this->Ui.EntityName, &replicateDelete);
           return true;
         }
       }
@@ -216,9 +221,11 @@ public:
     return this->Model->getCurrentPath();
   }
 
-  void setCurrentPath(const QString& p, bool groupFiles = true)
+  void setGroupPaths(bool group) { this->GroupPaths = group; }
+
+  void setCurrentPath(const QString& p)
   {
-    this->Model->setCurrentPath(p, groupFiles);
+    this->Model->setCurrentPath(p, this->GroupPaths);
     pqServer* s = this->Model->server();
     if (s)
     {
@@ -301,7 +308,7 @@ pqFileDialog::pqFileDialog(pqServer* server, QWidget* p, const QString& title,
   impl.Ui.Files->installEventFilter(this->Implementation);
 
   // install the autocompleter
-  impl.Ui.FileName->setCompleter(impl.Completer);
+  impl.Ui.EntityName->setCompleter(impl.Completer);
 
   // this is the Navigate button, which is only shown when needed
   impl.Ui.Navigate->hide();
@@ -344,17 +351,24 @@ pqFileDialog::pqFileDialog(pqServer* server, QWidget* p, const QString& title,
 
   impl.Ui.Favorites->setEditTriggers(QAbstractItemView::EditTrigger::EditKeyPressed);
 
+  auto shortcutDel = new QShortcut(QKeySequence::Delete, this);
+  QObject::connect(shortcutDel, &QShortcut::activated, this,
+    &pqFileDialog::onRemoveSelectedDirectoriesFromFavorites);
+
   impl.Ui.AddCurrentDirectoryToFavorites->setIcon(QIcon(":/QtWidgets/Icons/pqPlus.svg"));
   QObject::connect(impl.Ui.AddCurrentDirectoryToFavorites, SIGNAL(clicked()), this,
     SLOT(onAddCurrentDirectoryToFavorites()));
-  impl.Ui.RemoveCurrentDirectoryFromFavorites->setIcon(QIcon(":/QtWidgets/Icons/pqMinus.svg"));
-  QObject::connect(impl.Ui.RemoveCurrentDirectoryFromFavorites, SIGNAL(clicked()), this,
-    SLOT(onRemoveCurrentDirectoryFromFavorites()));
   impl.Ui.ResetFavortiesToSystemDefault->setIcon(QIcon(":/pqWidgets/Icons/pqReset.svg"));
   QObject::connect(impl.Ui.ResetFavortiesToSystemDefault, SIGNAL(clicked()), this,
     SLOT(onResetFavoritesToSystemDefault()));
 
-  impl.Ui.Favorites->setModel(impl.FavoriteModel);
+  impl.proxyFavoriteModel = new QSortFilterProxyModel(impl.FavoriteModel);
+  impl.proxyFavoriteModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
+  impl.proxyFavoriteModel->setSourceModel(impl.FavoriteModel);
+
+  impl.Ui.Favorites->setModel(impl.proxyFavoriteModel);
+  impl.Ui.Favorites->setSelectionMode(QAbstractItemView::ExtendedSelection);
+
   impl.Ui.Recent->setModel(impl.RecentModel);
 
   this->setFileMode(ExistingFile);
@@ -368,12 +382,15 @@ pqFileDialog::pqFileDialog(pqServer* server, QWidget* p, const QString& title,
   QObject::connect(
     impl.Ui.Parents, SIGNAL(activated(const QString&)), this, SLOT(onNavigate(const QString&)));
 
-  QObject::connect(impl.Ui.FileType, SIGNAL(currentIndexChanged(const QString&)), this,
+  QObject::connect(impl.Ui.EntityType, SIGNAL(currentIndexChanged(const QString&)), this,
     SLOT(onFilterChange(const QString&)));
 
   QObject::connect(impl.Ui.Favorites, SIGNAL(clicked(const QModelIndex&)), this,
     SLOT(onClickedFavorite(const QModelIndex&)));
 
+  QObject::connect(impl.Ui.favoritesSearchBar, &QLineEdit::textChanged, this,
+    &pqFileDialog::FilterDirectoryFromFavorites);
+
   QObject::connect(impl.Ui.Recent, SIGNAL(clicked(const QModelIndex&)), this,
     SLOT(onClickedRecent(const QModelIndex&)));
 
@@ -393,7 +410,7 @@ pqFileDialog::pqFileDialog(pqServer* server, QWidget* p, const QString& title,
   QObject::connect(impl.Ui.Files, SIGNAL(doubleClicked(const QModelIndex&)), this,
     SLOT(onDoubleClickFile(const QModelIndex&)));
 
-  QObject::connect(impl.Ui.FileName, SIGNAL(textChanged(const QString&)), this,
+  QObject::connect(impl.Ui.EntityName, SIGNAL(textChanged(const QString&)), this,
     SLOT(onTextEdited(const QString&)));
 
   impl.Completer->setCaseSensitivity(Qt::CaseInsensitive);
@@ -401,15 +418,15 @@ pqFileDialog::pqFileDialog(pqServer* server, QWidget* p, const QString& title,
   QStringList filterList = MakeFilterList(nameFilter);
   if (filterList.empty())
   {
-    impl.Ui.FileType->addItem("All Files (*)");
+    impl.Ui.EntityType->addItem("All Files (*)");
     impl.Filters << "All Files (*)";
   }
   else
   {
-    impl.Ui.FileType->addItems(filterList);
+    impl.Ui.EntityType->addItems(filterList);
     impl.Filters = filterList;
   }
-  this->onFilterChange(impl.Ui.FileType->currentText());
+  this->onFilterChange(impl.Ui.EntityType->currentText());
 
   QString startPath = startDirectory;
   if (startPath.isEmpty())
@@ -417,7 +434,8 @@ pqFileDialog::pqFileDialog(pqServer* server, QWidget* p, const QString& title,
     startPath = impl.getStartPath();
   }
   impl.addHistory(startPath);
-  impl.setCurrentPath(startPath, groupFiles);
+  impl.setGroupPaths(groupFiles);
+  impl.setCurrentPath(startPath);
 
   impl.Ui.Files->resizeColumnToContents(0);
   impl.Ui.Files->setTextElideMode(Qt::ElideMiddle);
@@ -467,8 +485,8 @@ void pqFileDialog::onCreateNewFolder()
   //    actually creating a new directory but this way I could reuse code.
   QString dirName = QString("New Folder");
   int i = 0;
-  QString fullDir;
-  while (impl.Model->dirExists(dirName, fullDir))
+  QString fullpath;
+  while (impl.Model->dirExists(dirName, fullpath))
   {
     dirName = QString("New Folder%1").arg(i++);
   }
@@ -504,7 +522,7 @@ void pqFileDialog::onCreateNewFolder()
   impl.Ui.Files->selectionModel()->select(
     idx, QItemSelectionModel::Select | QItemSelectionModel::Current);
   impl.Ui.Files->edit(idx);
-  impl.Ui.FileName->clear();
+  impl.Ui.EntityName->clear();
 }
 
 //-----------------------------------------------------------------------------
@@ -605,6 +623,12 @@ void pqFileDialog::RemoveDirectoryFromFavorites(QString const& directory)
   this->Implementation->FavoriteModel->removeFromFavorites(directory);
 }
 
+//-----------------------------------------------------------------------------
+void pqFileDialog::FilterDirectoryFromFavorites(const QString& filter)
+{
+  this->Implementation->proxyFavoriteModel->setFilterRegExp(filter);
+}
+
 //-----------------------------------------------------------------------------
 void pqFileDialog::onAddCurrentDirectoryToFavorites()
 {
@@ -613,10 +637,20 @@ void pqFileDialog::onAddCurrentDirectoryToFavorites()
 }
 
 //-----------------------------------------------------------------------------
-void pqFileDialog::onRemoveCurrentDirectoryFromFavorites()
+void pqFileDialog::onRemoveSelectedDirectoriesFromFavorites()
 {
-  QString const currentPath = this->Implementation->Model->getCurrentPath();
-  this->RemoveDirectoryFromFavorites(currentPath);
+  QStringList selectedDirs;
+  for (const QModelIndex& index :
+    this->Implementation->Ui.Favorites->selectionModel()->selectedIndexes())
+  {
+    QString dirPath = this->Implementation->FavoriteModel->filePath(index);
+    selectedDirs.push_back(dirPath);
+  }
+
+  for (const QString& dir : selectedDirs)
+  {
+    this->Implementation->FavoriteModel->removeFromFavorites(dir);
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -646,7 +680,7 @@ void pqFileDialog::onFavoritesContextMenuRequested(const QPoint& menuPos)
     {
       auto removeFromFavorites = new QAction("Remove from favorites", this);
       QObject::connect(removeFromFavorites, &QAction::triggered,
-        [=] { this->Implementation->FavoriteModel->removeFromFavorites(dirPath); });
+        [=] { this->onRemoveSelectedDirectoriesFromFavorites(); });
       menu.addAction(removeFromFavorites);
 
       auto renameLabel = new QAction("Rename label", this);
@@ -683,6 +717,32 @@ void pqFileDialog::setFileMode(pqFileDialog::FileMode mode)
       selectionMode = QAbstractItemView::ExtendedSelection;
       break;
   }
+
+  impl.Model->setDirectoryItemFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+  impl.Model->setFileItemFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+  switch (mode)
+  {
+    case Directory:
+      // final selectable entities will be limited to directories.
+      impl.Ui.EntityNameLabel->setText("Directory name:");
+      impl.Ui.EntityTypeLabel->setVisible(false);
+      impl.Ui.EntityType->setVisible(false);
+      impl.Model->setFileItemFlags(Qt::NoItemFlags);
+      break;
+    case ExistingFilesAndDirectories:
+      // final selectable entities can be files or directories.
+      impl.Ui.EntityNameLabel->setText("Name:");
+      impl.Ui.EntityTypeLabel->setVisible(true);
+      impl.Ui.EntityType->setVisible(true);
+      break;
+    default:
+      // final selectable entities will be limited to files.
+      impl.Ui.EntityNameLabel->setText("File name:");
+      impl.Ui.EntityTypeLabel->setVisible(true);
+      impl.Ui.EntityType->setVisible(true);
+      break;
+  }
+
   if (setupMultipleFileHelp)
   {
     // only set the tooltip and window title the first time through
@@ -694,7 +754,8 @@ void pqFileDialog::setFileMode(pqFileDialog::FileMode mode)
 
   impl.Ui.Navigate->show();
   impl.Ui.Navigate->setEnabled(false);
-  impl.Ui.CreateFolder->setEnabled(impl.Mode == pqFileDialog::AnyFile);
+  impl.Ui.CreateFolder->setVisible(
+    impl.Mode == pqFileDialog::AnyFile || impl.Mode == pqFileDialog::Directory);
   this->updateButtonStates();
 }
 
@@ -708,14 +769,14 @@ void pqFileDialog::setRecentlyUsedExtension(const QString& fileExtension)
     // upon the initial use of any kind (e.g., data or screenshot) of dialog
     // 'fileExtension' is equal /set to an empty string.
     // In this case, no any user preferences are considered
-    impl.Ui.FileType->setCurrentIndex(0);
+    impl.Ui.EntityType->setCurrentIndex(0);
   }
   else
   {
-    int index = impl.Ui.FileType->findText(fileExtension, Qt::MatchContains);
+    int index = impl.Ui.EntityType->findText(fileExtension, Qt::MatchContains);
     // just in case the provided extension is not in the combobox list
     index = (index == -1) ? 0 : index;
-    impl.Ui.FileType->setCurrentIndex(index);
+    impl.Ui.EntityType->setCurrentIndex(index);
   }
 }
 
@@ -760,6 +821,12 @@ QStringList pqFileDialog::getSelectedFiles(int index)
   return impl.SelectedFiles[index];
 }
 
+//-----------------------------------------------------------------------------
+int pqFileDialog::getSelectedFilterIndex()
+{
+  return this->Implementation->SelectedFilterIndex;
+}
+
 //-----------------------------------------------------------------------------
 void pqFileDialog::accept()
 {
@@ -797,7 +864,7 @@ bool pqFileDialog::acceptExistingFiles()
     // attempt to use the default way
     return this->acceptDefault(true);
   }
-  foreach (filename, impl.FileNames)
+  Q_FOREACH (filename, impl.FileNames)
   {
     filename = filename.trimmed();
 
@@ -813,7 +880,7 @@ bool pqFileDialog::acceptDefault(const bool& checkForGrouping)
 {
   auto& impl = *this->Implementation;
 
-  QString filename = impl.Ui.FileName->text();
+  QString filename = impl.Ui.EntityName->text();
   filename = filename.trimmed();
 
   QString fullFilePath = impl.Model->absoluteFilePath(filename);
@@ -951,8 +1018,8 @@ void pqFileDialog::onNavigate(const QString& newpath)
   impl.addHistory(impl.Model->getCurrentPath());
   impl.setCurrentPath(path_to_navigate);
   this->updateButtonStates();
-  impl.Ui.FileName->clear();
-  impl.Ui.FileName->setFocus(Qt::OtherFocusReason);
+  impl.Ui.EntityName->clear();
+  impl.Ui.EntityName->setFocus(Qt::OtherFocusReason);
 }
 
 //-----------------------------------------------------------------------------
@@ -1008,6 +1075,11 @@ void pqFileDialog::onFilterChange(const QString& filter)
 
   // update view
   impl.FileFilter.invalidate();
+  impl.Ui.EntityType->setToolTip(impl.Ui.EntityType->currentText());
+
+  impl.SelectedFilterIndex = impl.Ui.EntityType->currentIndex();
+
+  this->updateButtonStates();
 }
 
 //-----------------------------------------------------------------------------
@@ -1039,7 +1111,7 @@ void pqFileDialog::onActivateFavorite(const QModelIndex& index)
   {
     QString file = impl.FavoriteModel->filePath(index);
     this->onNavigate(file);
-    impl.Ui.FileName->selectAll();
+    impl.Ui.EntityName->selectAll();
   }
 }
 
@@ -1049,7 +1121,7 @@ void pqFileDialog::onActivateRecent(const QModelIndex& index)
   auto& impl = *this->Implementation;
   QString file = impl.RecentModel->filePath(index);
   this->onNavigate(file);
-  impl.Ui.FileName->selectAll();
+  impl.Ui.EntityName->selectAll();
 }
 
 //-----------------------------------------------------------------------------
@@ -1127,12 +1199,12 @@ QString pqFileDialog::fixFileExtension(const QString& filename, const QString& f
     // Ensure that the extension the user added is indeed of one the supported
     // types. (BUG #7634).
     QStringList wildCards;
-    foreach (QString curfilter, impl.Filters)
+    Q_FOREACH (QString curfilter, impl.Filters)
     {
       wildCards += ::GetWildCardsFromFilter(curfilter);
     }
     bool pass = false;
-    foreach (QString wildcard, wildCards)
+    Q_FOREACH (QString wildcard, wildCards)
     {
       if (wildcard.indexOf('.') != -1)
       {
@@ -1213,7 +1285,7 @@ bool pqFileDialog::acceptInternal(const QStringList& selected_files)
       case ExistingFiles:
       case AnyFile:
         this->onNavigate(file);
-        impl.Ui.FileName->clear();
+        impl.Ui.EntityName->clear();
         break;
     }
     return false;
@@ -1223,7 +1295,7 @@ bool pqFileDialog::acceptInternal(const QStringList& selected_files)
   if (impl.Mode == pqFileDialog::AnyFile)
   {
     // If mode is a "save" dialog, we fix the extension first.
-    file = this->fixFileExtension(file, impl.Ui.FileType->currentText());
+    file = this->fixFileExtension(file, impl.Ui.EntityType->currentText());
 
     // It is very possible that after fixing the extension,
     // the new filename is an already present directory,
@@ -1231,7 +1303,7 @@ bool pqFileDialog::acceptInternal(const QStringList& selected_files)
     if (impl.Model->dirExists(file, file))
     {
       this->onNavigate(file);
-      impl.Ui.FileName->clear();
+      impl.Ui.EntityName->clear();
       return false;
     }
   }
@@ -1243,7 +1315,7 @@ bool pqFileDialog::acceptInternal(const QStringList& selected_files)
     {
       case Directory:
         // User chose a file in directory mode, do nothing
-        impl.Ui.FileName->clear();
+        impl.Ui.EntityName->clear();
         break;
       case ExistingFile:
       case ExistingFiles:
@@ -1275,14 +1347,10 @@ bool pqFileDialog::acceptInternal(const QStringList& selected_files)
       case ExistingFile:
       case ExistingFiles:
       case ExistingFilesAndDirectories:
-        impl.Ui.FileName->selectAll();
+        impl.Ui.EntityName->selectAll();
         return false;
 
       case AnyFile:
-        if (!impl.Model->dirExists(file, file))
-        {
-          qWarning() << "'" << file << "' does not exist";
-        }
         this->addToFilesSelected(QStringList(file));
         return true;
     }
@@ -1294,7 +1362,7 @@ bool pqFileDialog::acceptInternal(const QStringList& selected_files)
 void pqFileDialog::fileSelectionChanged()
 {
   auto& impl = *this->Implementation;
-  // Selection changed, update the FileName entry box
+  // Selection changed, update the EntityName entry box
   // to reflect the current selection.
   QString fileString;
   const QModelIndexList indices = impl.Ui.Files->selectionModel()->selectedIndexes();
@@ -1302,7 +1370,7 @@ void pqFileDialog::fileSelectionChanged()
 
   if (indices.isEmpty())
   {
-    // do not change the FileName text if no selections
+    // do not change the EntityName text if no selections
     return;
   }
   QStringList fileNames;
@@ -1328,9 +1396,9 @@ void pqFileDialog::fileSelectionChanged()
   }
 
   // user is currently editing a name, don't change the text
-  impl.Ui.FileName->blockSignals(true);
-  impl.Ui.FileName->setText(fileString);
-  impl.Ui.FileName->blockSignals(false);
+  impl.Ui.EntityName->blockSignals(true);
+  impl.Ui.EntityName->setText(fileString);
+  impl.Ui.EntityName->blockSignals(false);
 
   impl.FileNames = fileNames;
   this->updateButtonStates();
@@ -1360,7 +1428,7 @@ bool pqFileDialog::selectFile(const QString& f)
 
   QPointer<QDialog> diag = this;
   impl.Model->setCurrentPath(dirname.c_str());
-  impl.Ui.FileName->setText(filename.c_str());
+  impl.Ui.EntityName->setText(filename.c_str());
   impl.SuppressOverwriteWarning = true;
   this->accept();
   if (diag && diag->result() != QDialog::Accepted)
@@ -1379,7 +1447,7 @@ void pqFileDialog::showEvent(QShowEvent* _showEvent)
   // which is determined by the creation order. This means that we have
   // to explicitly state that the line edit has the focus on showing no
   // matter the tab order
-  impl.Ui.FileName->setFocus(Qt::OtherFocusReason);
+  impl.Ui.EntityName->setFocus(Qt::OtherFocusReason);
 }
 
 //-----------------------------------------------------------------------------
@@ -1448,10 +1516,13 @@ void pqFileDialog::updateButtonStates()
 {
   auto& impl = *this->Implementation;
 
-  // We disable buttons if no file in the current folder
   if (impl.FileNames.empty())
   {
-    impl.Ui.OK->setEnabled(impl.Mode == Directory || impl.Mode == ExistingFilesAndDirectories);
+    QString const currentDirName = QFileInfo(impl.Model->getCurrentPath()).fileName();
+    // Enables "Ok" only if the current directory can be opened
+    impl.Ui.OK->setEnabled((impl.Mode == Directory || impl.Mode == ExistingFilesAndDirectories) &&
+      impl.FileFilter.getWildcards().exactMatch(currentDirName));
+
     impl.Ui.Navigate->setEnabled(false);
     return;
   }
@@ -1463,14 +1534,31 @@ void pqFileDialog::updateButtonStates()
     is_dir = impl.Model->dirExists(impl.FileNames.front(), tmp);
   }
 
-  // if mode is Directory, update OK button state.
-  if (impl.Mode == Directory)
+  switch (impl.Mode)
   {
-    impl.Ui.OK->setEnabled(is_dir);
-  }
-  else
-  {
-    impl.Ui.OK->setEnabled(true);
+    case Directory:
+      // if mode is Directory, update OK button state.
+      impl.Ui.OK->setEnabled(is_dir);
+      break;
+    case AnyFile:
+      impl.Ui.OK->setEnabled(true);
+      break;
+    default:
+      // Check that the files match the selected filter
+      bool filesMatching = std::all_of(
+        impl.FileNames.begin(), impl.FileNames.end(), [&](QString const& fileOrGroupName) {
+          // Get all the files of the group if fileName is a group, else just get {fileName}
+          QStringList const fileNames = buildFileGroup(fileOrGroupName);
+          return std::all_of(fileNames.begin(), fileNames.end(), [&](QString const& fileName) {
+            QString fileNameWithoutPath =
+              QFileInfo(impl.Model->absoluteFilePath(fileName)).fileName();
+            QString unusedString;
+            return impl.FileFilter.getWildcards().exactMatch(fileNameWithoutPath) &&
+              (impl.Model->fileExists(fileName, unusedString) ||
+                impl.Model->dirExists(fileName, unusedString));
+          });
+        });
+      impl.Ui.OK->setEnabled(filesMatching);
   }
 
   // show the Navigate button.
