@@ -39,10 +39,10 @@ class pqRenderView;
 class vtkPVXMLElement;
 
 /**
-* pqInteractiveViewLink is uaed by pqLinksModel to create
-* interactive view links, which are ViewLink allowing to see a view "trough"
-* another view.
-*/
+ * pqInteractiveViewLink is uaed by pqLinksModel to create
+ * interactive view links, which are ViewLink allowing to see a view "trough"
+ * another view.
+ */
 class PQCORE_EXPORT pqInteractiveViewLink : public QObject
 {
   Q_OBJECT;
@@ -78,7 +78,7 @@ protected:
   // method to set rendered flag to true
   virtual void linkedWindowRendered();
 
-protected Q_SLOTS:
+protected Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
 
   // draw pixels on the front buffer
   virtual void finalRenderDisplayView();
