@@ -31,12 +31,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 /**
-* \file pqPipelineRepresentation.h
-* \date 4/24/2006
-*/
+ * \file pqPipelineRepresentation.h
+ * \date 4/24/2006
+ */
 
-#ifndef _pqPipelineRepresentation_h
-#define _pqPipelineRepresentation_h
+#ifndef pqPipelineRepresentation_h
+#define pqPipelineRepresentation_h
 
 #include "pqDataRepresentation.h"
 #include <QPair>
@@ -50,11 +50,11 @@ class vtkPVDataSetAttributesInformation;
 class vtkSMRepresentationProxy;
 
 /**
-* This is PQ representation for a single display. A pqRepresentation represents
-* a single vtkSMRepresentationProxy. The display can be added to
-* only one render module or more (ofcouse on the same server, this class
-* doesn't worry about that.
-*/
+ * This is PQ representation for a single display. A pqRepresentation represents
+ * a single vtkSMRepresentationProxy. The display can be added to
+ * only one render module or more (ofcouse on the same server, this class
+ * doesn't worry about that.
+ */
 class PQCORE_EXPORT pqPipelineRepresentation : public pqDataRepresentation
 {
   Q_OBJECT
@@ -68,7 +68,7 @@ public:
   // \c server:- server on which the proxy is created.
   // \c parent:- QObject parent.
   pqPipelineRepresentation(const QString& group, const QString& name, vtkSMProxy* repr,
-    pqServer* server, QObject* parent = NULL);
+    pqServer* server, QObject* parent = nullptr);
   ~pqPipelineRepresentation() override;
 
   // Get the internal display proxy.
@@ -78,7 +78,7 @@ protected:
   // Overridden to set up some additional Qt connections
   void setView(pqView* view) override;
 
-public slots:
+public Q_SLOTS:
   // If lookuptable is set up and is used for coloring,
   // then calling this method resets the table ranges to match the current
   // range of the selected array.
