@@ -45,12 +45,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class pqPropertyLinks;
 
 /**
-* pqPropertyLinksConnection is used by pqPropertyLinks to keep a QObject and
-* vtkSMProperty linked together.
-* pqPropertyLinksConnection handles most common types of connections.
-* Developers can subclass this to customize the mechanisms for copy values
-* from Qt to ServerManager and vice-versa.
-*/
+ * pqPropertyLinksConnection is used by pqPropertyLinks to keep a QObject and
+ * vtkSMProperty linked together.
+ * pqPropertyLinksConnection handles most common types of connections.
+ * Developers can subclass this to customize the mechanisms for copy values
+ * from Qt to ServerManager and vice-versa.
+ */
 class PQCORE_EXPORT pqPropertyLinksConnection : public QObject
 {
   Q_OBJECT
@@ -58,31 +58,31 @@ class PQCORE_EXPORT pqPropertyLinksConnection : public QObject
 
 public:
   /**
-  * This also sets up observers to monitor any changes. This does not change
-  * any values on either items.
-  */
+   * This also sets up observers to monitor any changes. This does not change
+   * any values on either items.
+   */
   pqPropertyLinksConnection(QObject* qobject, const char* qproperty, const char* qsignal,
     vtkSMProxy* smproxy, vtkSMProperty* smproperty, int smindex, bool use_unchecked_modified_event,
-    QObject* parentObject = 0);
+    QObject* parentObject = nullptr);
 
   ~pqPropertyLinksConnection() override;
 
   void setUseUncheckedProperties(bool useUnchecked);
 
   /**
-  * Comparison operator
-  */
+   * Comparison operator
+   */
   bool operator==(const pqPropertyLinksConnection& other) const;
 
   /**
-  * Provides access to the Qt QObject and property name.
-  */
+   * Provides access to the Qt QObject and property name.
+   */
   QObject* objectQt() const { return this->ObjectQt; }
   const QString& propertyQt() const { return this->PropertyQt; }
 
   /**
-  * Provides access to the ServerManager proxy/property/index.
-  */
+   * Provides access to the ServerManager proxy/property/index.
+   */
   vtkSMProxy* proxy() const { return this->ProxySM; }
   vtkSMProxy* proxySM() const { return this->ProxySM; }
   vtkSMProperty* propertySM() const { return this->PropertySM; }
@@ -94,24 +94,24 @@ public:
   void setTraceChanges(bool trace) { this->TraceChanges = trace; }
   bool traceChanges() const { return this->TraceChanges; }
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   /**
-  * Copy values from ServerManager to Qt. If use_unchecked is true, unchecked
-  * SMProperty values are used.
-  */
+   * Copy values from ServerManager to Qt. If use_unchecked is true, unchecked
+   * SMProperty values are used.
+   */
   void copyValuesFromServerManagerToQt(bool use_unchecked);
 
   /**
-  * Copy values from Qt to ServerManager. If use_unchecked is true, unchecked
-  * values for SMProperty are updated.
-  */
+   * Copy values from Qt to ServerManager. If use_unchecked is true, unchecked
+   * values for SMProperty are updated.
+   */
   void copyValuesFromQtToServerManager(bool use_unchecked);
 
 protected:
   /**
-  * These are the methods that subclasses can override to customize how
-  * values are updated in either directions.
-  */
+   * These are the methods that subclasses can override to customize how
+   * values are updated in either directions.
+   */
   virtual void setQtValue(const QVariant& value);
   virtual void setServerManagerValue(bool use_unchecked, const QVariant& value);
   virtual QVariant currentQtValue() const;
@@ -119,15 +119,15 @@ protected:
 
 Q_SIGNALS:
   /**
-  * Fired whenever the Qt widget changes (except in during a call to
-  * copyValuesFromServerManagerToQt()).
-  */
+   * Fired whenever the Qt widget changes (except in during a call to
+   * copyValuesFromServerManagerToQt()).
+   */
   void qtpropertyModified();
 
   /**
-  * Fired whenever the ServerManager property changes (except in during a call to
-  * copyValuesFromQtToServerManager()).
-  */
+   * Fired whenever the ServerManager property changes (except in during a call to
+   * copyValuesFromQtToServerManager()).
+   */
   void smpropertyModified();
 
 private:
