@@ -38,9 +38,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "QVTKOpenGLNativeWidget.h"
 #include "pqApplicationCore.h"
 #include "pqEventDispatcher.h"
-#include "pqOptions.h"
+#include "pqQVTKWidgetBase.h"
 #include "pqUndoStack.h"
 #include "vtkPVLogger.h"
+#include "vtkRemotingCoreConfiguration.h"
 #include "vtkRenderWindow.h"
 #include "vtkSMPropertyHelper.h"
 #include "vtkSMSession.h"
@@ -53,7 +54,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //----------------------------------------------------------------------------
 pqQVTKWidget::pqQVTKWidget(QWidget* parentObject, Qt::WindowFlags f)
   : pqQVTKWidget(
-      parentObject, f, pqApplicationCore::instance()->getOptions()->GetUseStereoRendering())
+      parentObject, f, vtkRemotingCoreConfiguration::GetInstance()->GetUseStereoRendering())
 {
 }
 
@@ -63,7 +64,6 @@ pqQVTKWidget::pqQVTKWidget(QWidget* parentObject, Qt::WindowFlags f, bool isSter
   , SizePropertyName("ViewSize")
   , useStereo(isStereo)
 {
-  auto options = pqApplicationCore::instance()->getOptions();
   auto* layout = new QVBoxLayout();
   layout->setMargin(0);
 
@@ -99,7 +99,8 @@ pqQVTKWidget::pqQVTKWidget(QWidget* parentObject, Qt::WindowFlags f, bool isSter
   }
 
   // if active stereo requested, then we need to request appropriate context.
-  if (options->GetStereoType() && strcmp(options->GetStereoType(), "Crystal Eyes") == 0)
+  auto config = vtkRemotingCoreConfiguration::GetInstance();
+  if (config->GetStereoType() == VTK_STEREO_CRYSTAL_EYES)
   {
 #if PARAVIEW_USING_QVTKOPENGLSTEREOWIDGET
     auto fmt = baseClass.value<pqQVTKWidgetBase*>()->defaultFormat(/*supports_stereo =*/true);
@@ -113,9 +114,7 @@ pqQVTKWidget::pqQVTKWidget(QWidget* parentObject, Qt::WindowFlags f, bool isSter
 }
 
 //----------------------------------------------------------------------------
-pqQVTKWidget::~pqQVTKWidget()
-{
-}
+pqQVTKWidget::~pqQVTKWidget() = default;
 
 //----------------------------------------------------------------------------
 void pqQVTKWidget::setViewProxy(vtkSMProxy* view)
@@ -322,10 +321,10 @@ void pqQVTKWidget::notifyQApplication(QMouseEvent* e)
 {
   if (this->useStereo)
   {
-// Due to QTBUG-61836 (see QVTKOpenGLStereoWidget::testingEvent()), events should
-// be propagated back to the internal QVTKOpenGLWindow when being fired
-// explicitly on the widget instance. We have to use a custom event
-// callback in this case to ensure that events are passed to the window.
+    // Due to QTBUG-61836 (see QVTKOpenGLStereoWidget::testingEvent()), events should
+    // be propagated back to the internal QVTKOpenGLWindow when being fired
+    // explicitly on the widget instance. We have to use a custom event
+    // callback in this case to ensure that events are passed to the window.
 
 #if defined(__APPLE__)
     qApp->notify(baseClass.value<QVTKOpenGLNativeWidget*>(), e);
@@ -377,6 +376,7 @@ double pqQVTKWidget::effectiveDevicePixelRatio() const
     return baseClass.value<QVTKOpenGLNativeWidget*>()->effectiveDevicePixelRatio();
   }
 }
+
 //----------------------------------------------------------------------------
 void pqQVTKWidget::setViewSize(int width, int height)
 {
@@ -392,3 +392,10 @@ void pqQVTKWidget::setViewSize(int width, int height)
     }
   }
 }
+
+//----------------------------------------------------------------------------
+QWidget* pqQVTKWidget::renderWidget() const
+{
+  return this->useStereo ? static_cast<QWidget*>(this->baseClass.value<pqQVTKWidgetBase*>())
+                         : static_cast<QWidget*>(this->baseClass.value<QVTKOpenGLNativeWidget*>());
+}
