@@ -66,7 +66,7 @@ public:
 
 //-----------------------------------------------------------------------------
 pqScalarsToColors::pqScalarsToColors(const QString& group, const QString& name, vtkSMProxy* proxy,
-  pqServer* server, QObject* _parent /*=NULL*/)
+  pqServer* server, QObject* _parent /*=nullptr*/)
   : pqProxy(group, name, proxy, server, _parent)
 {
   this->Internal = new pqScalarsToColorsInternal;
@@ -99,7 +99,7 @@ pqScalarBarRepresentation* pqScalarsToColors::getScalarBar(pqRenderViewBase* ren
   vtkSMProxy* proxy =
     vtkSMTransferFunctionProxy::FindScalarBarRepresentation(this->getProxy(), ren->getProxy());
   pqServerManagerModel* smmodel = pqApplicationCore::instance()->getServerManagerModel();
-  return proxy ? smmodel->findItem<pqScalarBarRepresentation*>(proxy) : NULL;
+  return proxy ? smmodel->findItem<pqScalarBarRepresentation*>(proxy) : nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -112,13 +112,6 @@ void pqScalarsToColors::setScalarRangeLock(bool lock)
     {
       pqSMAdaptor::setElementProperty(prop, vtkSMTransferFunctionManager::NEVER);
     }
-    else
-    {
-      // Reset the AutomaticRescaleRangeMode to the current global setting.
-      vtkSMTransferFunctionProxy* tfProxy =
-        vtkSMTransferFunctionProxy::SafeDownCast(this->getProxy());
-      tfProxy->ResetRescaleModeToGlobalSetting();
-    }
   }
   this->getProxy()->UpdateVTKObjects();
 }
@@ -146,7 +139,7 @@ void pqScalarsToColors::hideUnusedScalarBars()
   //  smmodel->findItems<pqPipelineRepresentation*>(this->getServer());
 
   // bool used_at_all = false;
-  // foreach(pqPipelineRepresentation* display, displays)
+  // Q_FOREACH(pqPipelineRepresentation* display, displays)
   //  {
   //  if (display->isVisible() &&
   //    display->getColorField(true) != pqPipelineRepresentation::solidColor() &&
@@ -158,7 +151,7 @@ void pqScalarsToColors::hideUnusedScalarBars()
   //  }
   // if (!used_at_all)
   //  {
-  //  foreach(pqScalarBarRepresentation* sb, this->Internal->ScalarBars)
+  //  Q_FOREACH(pqScalarBarRepresentation* sb, this->Internal->ScalarBars)
   //    {
   //    sb->setVisible(false);
   //    sb->renderViewEventually();
@@ -226,7 +219,7 @@ QPair<double, double> pqScalarsToColors::getScalarRange() const
     vtkSMDoubleVectorProperty::SafeDownCast(this->getProxy()->GetProperty("RGBPoints"));
   QList<QVariant> controlPoints = pqSMAdaptor::getMultipleElementProperty(dvp);
 
-  if (controlPoints.size() == 0)
+  if (controlPoints.empty())
   {
     return QPair<double, double>(0, 0);
   }
@@ -294,7 +287,7 @@ void pqScalarsToColors::updateScalarBarTitles(const QString& component)
 {
   (void)component;
   // FIXME:
-  // foreach(pqScalarBarRepresentation* sb, this->Internal->ScalarBars)
+  // Q_FOREACH(pqScalarBarRepresentation* sb, this->Internal->ScalarBars)
   //  {
   //  sb->setTitle(sb->getTitle().first, component);
   //  }
