@@ -149,7 +149,7 @@ pqServer* pqServerManagerModel::findServer(vtkIdType cid) const
 //-----------------------------------------------------------------------------
 pqServer* pqServerManagerModel::findServer(const pqServerResource& resource) const
 {
-  foreach (pqServer* server, this->Internal->Servers)
+  Q_FOREACH (pqServer* server, this->Internal->Servers)
   {
     if (server && server->getResource() == resource)
     {
@@ -159,6 +159,19 @@ pqServer* pqServerManagerModel::findServer(const pqServerResource& resource) con
   return nullptr;
 }
 
+//-----------------------------------------------------------------------------
+pqServer* pqServerManagerModel::findServer(const QString& name) const
+{
+  Q_FOREACH (pqServer* server, this->Internal->Servers)
+  {
+    if (server && server->getResource().serverName() == name)
+    {
+      return server;
+    }
+  }
+  return nullptr;
+}
+
 //-----------------------------------------------------------------------------
 pqServerManagerModelItem* pqServerManagerModel::findItemHelper(
   const pqServerManagerModel* const model, const QMetaObject& vtkNotUsed(mo), vtkSMProxy* proxy)
@@ -193,7 +206,7 @@ pqServerManagerModelItem* pqServerManagerModel::findItemHelper(
 pqServerManagerModelItem* pqServerManagerModel::findItemHelper(
   const pqServerManagerModel* const model, const QMetaObject& mo, vtkTypeUInt32 id)
 {
-  foreach (pqServerManagerModelItem* item, model->Internal->ItemList)
+  Q_FOREACH (pqServerManagerModelItem* item, model->Internal->ItemList)
   {
     if (item && mo.cast(item))
     {
@@ -212,7 +225,7 @@ pqServerManagerModelItem* pqServerManagerModel::findItemHelper(
 pqServerManagerModelItem* pqServerManagerModel::findItemHelper(
   const pqServerManagerModel* const model, const QMetaObject& mo, const QString& name)
 {
-  foreach (pqServerManagerModelItem* item, model->Internal->ItemList)
+  Q_FOREACH (pqServerManagerModelItem* item, model->Internal->ItemList)
   {
     if (item && mo.cast(item))
     {
@@ -236,7 +249,7 @@ void pqServerManagerModel::findItemsHelper(const pqServerManagerModel* const mod
     return;
   }
 
-  foreach (pqServerManagerModelItem* item, model->Internal->ItemList)
+  Q_FOREACH (pqServerManagerModelItem* item, model->Internal->ItemList)
   {
     if (item && mo.cast(item))
     {
@@ -293,7 +306,7 @@ void pqServerManagerModel::onProxyRegistered(
   pqProxy* item = nullptr;
 
   QObjectList ifaces = pqApplicationCore::instance()->interfaceTracker()->interfaces();
-  foreach (QObject* iface, ifaces)
+  Q_FOREACH (QObject* iface, ifaces)
   {
     pqServerManagerModelInterface* smi = qobject_cast<pqServerManagerModelInterface*>(iface);
     if (smi)
