@@ -38,9 +38,9 @@ class vtkSMSourceProxy;
 class pqDataRepresentation;
 
 /**
-* pqContextView subclass for "Bar Chart View". Doesn't do much expect adds
-* the API to get the chartview type and name.
-*/
+ * pqContextView subclass for "Bar Chart View". Doesn't do much expect adds
+ * the API to get the chartview type and name.
+ */
 class PQCORE_EXPORT pqXYBarChartView : public pqContextView
 {
   Q_OBJECT
@@ -50,15 +50,14 @@ public:
   static QString XYBarChartViewType() { return "XYBarChartView"; }
 
   /**
-  * Currently the bar chart view is not supporting selection.
-  */
-  virtual bool supportsSelection() const { return false; }
+   * Currently the bar chart view is not supporting selection.
+   */
+  bool supportsSelection() const override { return false; }
 
-public:
   pqXYBarChartView(const QString& group, const QString& name, vtkSMContextViewProxy* viewModule,
-    pqServer* server, QObject* parent = NULL);
+    pqServer* server, QObject* parent = nullptr);
 
-  virtual ~pqXYBarChartView();
+  ~pqXYBarChartView() override;
 
 private:
   Q_DISABLE_COPY(pqXYBarChartView)
