@@ -95,8 +95,9 @@ public:
   }
 
 protected:
-  pqPythonShellOutputWindow() {}
-  ~pqPythonShellOutputWindow() override {}
+  pqPythonShellOutputWindow() = default;
+  ~pqPythonShellOutputWindow() override = default;
+
 private:
   pqPythonShellOutputWindow(const pqPythonShellOutputWindow&) = delete;
   void operator=(const pqPythonShellOutputWindow&) = delete;
@@ -120,7 +121,6 @@ public:
 
   pqInternals(pqPythonShell* self)
     : Parent(self)
-    , Interpreter()
     , OldCapture(false)
     , ExecutionCounter(0)
     , InterpreterInitialized(false)
@@ -216,7 +216,7 @@ private:
     {
       this->Parent->prompt();
       this->Parent->printString(line + "\n");
-      this->Interpreter->Push(line.toLocal8Bit().data());
+      this->Interpreter->Push(line.toUtf8().data());
     }
     this->Parent->prompt();
 
@@ -300,7 +300,7 @@ void pqPythonShell::reset()
 void pqPythonShell::printString(const QString& text, pqPythonShell::PrintMode mode)
 {
   pqConsoleWidget* consoleWidget = this->Internals->Ui.consoleWidget;
-  QString string = text;
+  const QString& string = text;
   if (!string.isEmpty())
   {
     QTextCharFormat format = consoleWidget->getFormat();
@@ -382,7 +382,7 @@ void pqPythonShell::executeScript(const QString& script)
   command.replace("\r", "\n");
 
   this->Internals->begin();
-  this->Internals->interpreter()->RunStringWithConsoleLocals(command.toLocal8Bit().data());
+  this->Internals->interpreter()->RunStringWithConsoleLocals(command.toUtf8().data());
   this->Internals->end();
 
   CLEAR_UNDO_STACK();
@@ -399,9 +399,9 @@ void pqPythonShell::pushScript(const QString& script)
 
   this->Prompted = false;
   this->Internals->begin();
-  foreach (QString line, lines)
+  Q_FOREACH (QString line, lines)
   {
-    bool isMultilineStatement = this->Internals->interpreter()->Push(line.toLocal8Bit().data());
+    bool isMultilineStatement = this->Internals->interpreter()->Push(line.toUtf8().data());
     this->Prompt = isMultilineStatement ? pqPythonShell::PS2() : pqPythonShell::PS1();
   }
   this->Internals->end();
@@ -465,14 +465,14 @@ void pqPythonShell::runScript()
       QFile file(filename);
       if (file.open(QIODevice::ReadOnly))
       {
-        QByteArray code;
+        QString code;
         // First inject code to let the script know its own path
         code.append(QString("__file__ = r'%1'\n").arg(filename));
         // Then append the file content
         code.append(file.readAll());
         code.append("\n");
         code.append("del __file__\n");
-        this->executeScript(code.data());
+        this->executeScript(code.toUtf8().data());
       }
       else
       {
