@@ -6,7 +6,7 @@
 class HierarchicalGridLayoutTester : public QObject
 {
   Q_OBJECT;
-private slots:
+private Q_SLOTS:
 
   void addWidget();
   void addWidget_data();
