@@ -37,22 +37,21 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QColor>
 
 /**
-* pqColorDialogEventTranslator translates events on QColorDialog
-* that they can be recorded in tests in a platform independent
-* way.
-*/
+ * pqColorDialogEventTranslator translates events on QColorDialog that they can
+ * be recorded in tests in a platform independent way.
+ */
 class PQWIDGETS_EXPORT pqColorDialogEventTranslator : public pqWidgetEventTranslator
 {
   Q_OBJECT
   typedef pqWidgetEventTranslator Superclass;
 
 public:
-  pqColorDialogEventTranslator(QObject* parent = 0);
+  pqColorDialogEventTranslator(QObject* parent = nullptr);
   ~pqColorDialogEventTranslator() override;
 
   /**
-  * Overridden to handle events on QColorDialog.
-  */
+   * Overridden to handle events on QColorDialog.
+   */
   using Superclass::translateEvent;
   bool translateEvent(QObject* Object, QEvent* Event, bool& Error) override;
 
@@ -60,7 +59,7 @@ private Q_SLOTS:
   void onColorChosen(const QColor&);
   void onFinished(int);
 
-private:
+private: // NOLINT(readability-redundant-access-specifiers)
   Q_DISABLE_COPY(pqColorDialogEventTranslator)
 };
 
