@@ -103,7 +103,7 @@ public:
       text_cursor.position() < this->InteractivePosition;
 
     // Allow copying anywhere in the console ...
-    if (e->key() == Qt::Key_C && e->modifiers() == Qt::ControlModifier)
+    if (e->matches(QKeySequence::Copy))
     {
       if (selection)
       {
@@ -115,7 +115,7 @@ public:
     }
 
     // Allow cut only if the selection is limited to the interactive area ...
-    if (e->key() == Qt::Key_X && e->modifiers() == Qt::ControlModifier)
+    if (e->matches(QKeySequence::Cut))
     {
       if (selection && !history_area)
       {
@@ -127,7 +127,7 @@ public:
     }
 
     // Allow paste only if the selection is in the interactive area ...
-    if (e->key() == Qt::Key_V && e->modifiers() == Qt::ControlModifier)
+    if (e->matches(QKeySequence::Paste))
     {
       if (!history_area)
       {
@@ -275,7 +275,7 @@ public:
   /// overridden to handle middle-button click pasting in *nix
   void mouseReleaseEvent(QMouseEvent* e) override
   {
-    if (e->button() == Qt::MidButton)
+    if (e->button() == Qt::MiddleButton)
     {
       QTextEdit::mouseReleaseEvent(e);
       checkForPastedText();
@@ -289,7 +289,7 @@ public:
   void checkForPastedText()
   {
     QString pastedCommand = this->toPlainText().mid(this->InteractivePosition);
-    if (this->CommandHistory.size() > 0)
+    if (!this->CommandHistory.empty())
     {
       this->commandBuffer() = pastedCommand;
     }
@@ -397,7 +397,7 @@ public:
   {
     if (this->Completer)
     {
-      this->Completer->setWidget(0);
+      this->Completer->setWidget(nullptr);
       QObject::disconnect(this->Completer, SIGNAL(activated(const QString&)), &this->Parent,
         SLOT(insertCompletion(const QString&)));
     }
