@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef pqDiscreteDoubleWidget_H
-#define pqDiscreteDoubleWidget_H
+#ifndef pqDiscreteDoubleWidget_h
+#define pqDiscreteDoubleWidget_h
 
 #include "pqDoubleSliderWidget.h"
 
@@ -30,8 +30,8 @@ class PQWIDGETS_EXPORT pqDiscreteDoubleWidget : public pqDoubleSliderWidget
   Q_PROPERTY(double value READ value WRITE setValue USER true)
 
 public:
-  pqDiscreteDoubleWidget(QWidget* parent = NULL);
-  ~pqDiscreteDoubleWidget();
+  pqDiscreteDoubleWidget(QWidget* parent = nullptr);
+  ~pqDiscreteDoubleWidget() override;
 
   /**
    * Gets vector of allowed values
@@ -47,4 +47,4 @@ private:
   QVector<double> Values;
 };
 
-#endif // pqDiscreteDoubleWidget_H
+#endif // pqDiscreteDoubleWidget_h
