@@ -77,7 +77,7 @@ void unregister_dle_instance(pqDoubleLineEdit* dle)
 {
   assert(InstanceTracker != nullptr);
   InstanceTracker->removeOne(dle);
-  if (InstanceTracker->size() == 0)
+  if (InstanceTracker->empty())
   {
     delete InstanceTracker;
     InstanceTracker = nullptr;
@@ -89,12 +89,16 @@ void unregister_dle_instance(pqDoubleLineEdit* dle)
 class pqDoubleLineEdit::pqInternals
 {
 public:
+  bool AlwaysUseFullPrecision = false;
   int Precision = 2;
   pqDoubleLineEdit::RealNumberNotation Notation = pqDoubleLineEdit::FixedNotation;
   bool UseGlobalPrecisionAndNotation = true;
   QPointer<QLineEdit> InactiveLineEdit = nullptr;
 
-  bool useFullPrecision(const pqDoubleLineEdit* self) const { return self->hasFocus(); }
+  bool useFullPrecision(const pqDoubleLineEdit* self) const
+  {
+    return this->AlwaysUseFullPrecision || self->hasFocus();
+  }
 
   void sync(pqDoubleLineEdit* self)
   {
@@ -103,8 +107,10 @@ public:
     const auto real_notation =
       this->UseGlobalPrecisionAndNotation ? pqDoubleLineEdit::globalNotation() : this->Notation;
 
-    QString limited = pqDoubleLineEdit::formatDouble(
-      self->text().toDouble(), toTextStreamNotation(real_notation), real_precision);
+    const QString limited = self->text().isEmpty()
+      ? QString()
+      : pqDoubleLineEdit::formatDouble(
+          self->text().toDouble(), toTextStreamNotation(real_notation), real_precision);
 
     const bool changed = (limited != this->InactiveLineEdit->text());
     this->InactiveLineEdit->setText(limited);
@@ -121,6 +127,9 @@ public:
   {
     if (this->InactiveLineEdit)
     {
+      // sync some state with inactive-line edit.
+      this->InactiveLineEdit->setEnabled(self->isEnabled());
+      this->InactiveLineEdit->setPlaceholderText(self->placeholderText());
       this->InactiveLineEdit->render(self, self->mapTo(self->window(), QPoint(0, 0)));
     }
   }
@@ -306,3 +315,9 @@ QString pqDoubleLineEdit::formatDoubleUsingGlobalPrecisionAndNotation(double val
   return pqDoubleLineEdit::formatDouble(
     value, pqDoubleLineEdit::globalNotation(), pqDoubleLineEdit::globalPrecision());
 }
+
+//-----------------------------------------------------------------------------
+void pqDoubleLineEdit::setAlwaysUseFullPrecision(bool value)
+{
+  this->Internals->AlwaysUseFullPrecision = value;
+}
