@@ -68,7 +68,7 @@ class PQWIDGETS_EXPORT pqDoubleLineEdit : public pqLineEdit
   using Superclass = pqLineEdit;
 
 public:
-  pqDoubleLineEdit(QWidget* parent = 0);
+  pqDoubleLineEdit(QWidget* parent = nullptr);
   ~pqDoubleLineEdit() override;
 
   /**
@@ -136,7 +136,7 @@ public:
   static QString formatDoubleUsingGlobalPrecisionAndNotation(double value);
   //@}
 
-public Q_SLOTS:
+public Q_SLOTS: // NOLINT(readability-redundant-access-specifiers)
   /**
    * Set the notation used to display the number.
    * \sa notation()
@@ -155,6 +155,11 @@ public Q_SLOTS:
    */
   void setUseGlobalPrecisionAndNotation(bool value);
 
+  /**
+   * Set whether to always render at full precision
+   */
+  void setAlwaysUseFullPrecision(bool value);
+
 protected:
   void paintEvent(QPaintEvent* evt) override;
   void resizeEvent(QResizeEvent* event) override;
