@@ -36,21 +36,21 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QDoubleSpinBox>
 
 /**
-* QDoubleSpinBox which fires editingFinished() signal when the value is changed
-* by steps (increments).
-*/
+ * QDoubleSpinBox which fires editingFinished() signal when the value is changed
+ * by steps (increments).
+ */
 class PQWIDGETS_EXPORT pqDoubleSpinBox : public QDoubleSpinBox
 {
   Q_OBJECT
   typedef QDoubleSpinBox Superclass;
 
 public:
-  explicit pqDoubleSpinBox(QWidget* parent = 0);
+  explicit pqDoubleSpinBox(QWidget* parent = nullptr);
 
   /**
-  * Virtual function that is called whenever the user triggers a step.  We are
-  * overriding this so that we can emit editingFinished() signal
-  */
+   * Virtual function that is called whenever the user triggers a step.  We are
+   * overriding this so that we can emit editingFinished() signal
+   */
   void stepBy(int steps) override;
 
 private:
