@@ -30,6 +30,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ========================================================================*/
 #include "pqExpandableTableView.h"
+#include "pqQtDeprecated.h"
 
 #include <QAbstractItemDelegate>
 #include <QApplication>
@@ -42,14 +43,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //-----------------------------------------------------------------------------
 pqExpandableTableView::pqExpandableTableView(QWidget* parentObject)
   : Superclass(parentObject)
+  , PasteEnabled(true)
   , MoveToNextEditableItem(false)
 {
 }
 
 //-----------------------------------------------------------------------------
-pqExpandableTableView::~pqExpandableTableView()
-{
-}
+pqExpandableTableView::~pqExpandableTableView() = default;
 
 //-----------------------------------------------------------------------------
 QModelIndex pqExpandableTableView::moveCursor(
@@ -109,10 +109,16 @@ void pqExpandableTableView::closeEditor(QWidget* editor, QAbstractItemDelegate::
   }
 }
 
+//-----------------------------------------------------------------------------
+void pqExpandableTableView::setPasteEnabled(bool enabled)
+{
+  this->PasteEnabled = enabled;
+}
+
 //-----------------------------------------------------------------------------
 void pqExpandableTableView::keyPressEvent(QKeyEvent* e)
 {
-  if (e->modifiers() == Qt::ControlModifier && e->key() == Qt::Key_V)
+  if (this->PasteEnabled && e->matches(QKeySequence::Paste))
   {
     // Get text from the clipboard. Text is expected to be tabular in form,
     // delimited by arbitrary whitespace.
@@ -126,7 +132,7 @@ void pqExpandableTableView::keyPressEvent(QKeyEvent* e)
     {
       // Split the lines in the text
       QString text = mimeData->text();
-      QStringList lines = text.split("\n", QString::SkipEmptyParts);
+      QStringList lines = text.split("\n", PV_QT_SKIP_EMPTY_PARTS);
       for (int row = 0; row < std::min(lines.size(), numModelRows); ++row)
       {
         // Split within each line
