@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:  pqHelpWindowWebKit.h
+   Module:  pqHelpWindowWebEngine.h
 
    Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -29,15 +29,15 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ========================================================================*/
-#ifndef pqHelpWindowWebKit_h
-#define pqHelpWindowWebKit_h
+#ifndef pqHelpWindowWebEngine_h
+#define pqHelpWindowWebEngine_h
 
 /**
-*============================================================================
-* This is an internal header used by pqHelpWindow.
-* This header gets included when PARAVIEW_USE_QTWEBENGINE is ON.
-*============================================================================
-*/
+ *============================================================================
+ * This is an internal header used by pqHelpWindow.
+ * This header gets included when PARAVIEW_USE_QTWEBENGINE is ON.
+ *============================================================================
+ */
 
 #include <QBuffer>
 #include <QFileInfo>
@@ -61,7 +61,7 @@ public:
     : Engine(engine)
   {
   }
-  ~pqUrlSchemeHandler() {}
+  ~pqUrlSchemeHandler() = default;
 
   void requestStarted(QWebEngineUrlRequestJob* request) override
   {
@@ -85,7 +85,7 @@ public:
     buffer->setData(array);
     buffer->open(QIODevice::ReadOnly);
     connect(buffer, &QIODevice::aboutToClose, buffer, &QObject::deleteLater);
-    request->reply(content_type.toLocal8Bit(), buffer);
+    request->reply(content_type.toUtf8(), buffer);
   }
 
 private:
@@ -93,8 +93,8 @@ private:
 };
 //----------------------------------------------------------------------------------
 /**
-* Extend QWebView to support the interface expected in pqBrowserTemplate.
-*/
+ * Extend QWebView to support the interface expected in pqBrowserTemplate.
+ */
 class pqWebView : public QWebEngineView
 {
   typedef QWebEngineView Superclass;
@@ -104,7 +104,7 @@ public:
     : Superclass(parentObject)
   {
   }
-  ~pqWebView() {}
+  ~pqWebView() = default;
 
   static pqWebView* newInstance(QHelpEngine* engine, QWidget* parentObject)
   {
