@@ -54,7 +54,7 @@ class PQWIDGETS_EXPORT pqHierarchicalGridWidget : public QWidget
   typedef QWidget Superclass;
 
 public:
-  pqHierarchicalGridWidget(QWidget* parent = 0);
+  pqHierarchicalGridWidget(QWidget* parent = nullptr);
   ~pqHierarchicalGridWidget() override;
 
   //@{
@@ -71,7 +71,7 @@ public:
    */
   bool eventFilter(QObject* caller, QEvent* evt) override;
 
-signals:
+Q_SIGNALS:
   void splitterMoved(int location, double splitFraction);
 
 protected:
