@@ -16,7 +16,7 @@
  * @class   vtkAnimationPlayer
  *
  * Abstract superclass for an animation player.
-*/
+ */
 
 #ifndef vtkAnimationPlayer_h
 #define vtkAnimationPlayer_h
@@ -44,8 +44,10 @@ public:
   /**
    * Start playing the animation.
    * Fires StartEvent when play begins and EndEvent when play stops.
+   * If dir = 0, play the animation in reverse back to the beginning,
+   * else play it in the forward direction.
    */
-  void Play();
+  void Play(const int dir = 1);
 
   /**
    * Stop playing the animation.
@@ -86,6 +88,17 @@ public:
    */
   void GoToLast();
 
+  //@{
+  /**
+   * Get/Set the stride value fot the animation player. This will cause the player to skip
+   * (n - 1) when GetNextTime, GoToNext and GoToPrevious are previous are called.
+   *
+   * Stride is clamped between 1 and the number of frames of the current animation scene.
+   */
+  vtkGetMacro(Stride, int);
+  vtkSetClampMacro(Stride, int, 1, VTK_INT_MAX);
+  //@}
+
 protected:
   vtkAnimationPlayer();
   ~vtkAnimationPlayer() override;
@@ -101,6 +114,11 @@ protected:
    */
   virtual double GetNextTime(double currentime) = 0;
 
+  /**
+   * Return the previous time given the current time.
+   */
+  virtual double GetPreviousTime(double currenttime) = 0;
+
   virtual double GoToNext(double start, double end, double currenttime) = 0;
   virtual double GoToPrevious(double start, double end, double currenttime) = 0;
 
@@ -113,6 +131,7 @@ private:
   bool StopPlay;
   bool Loop;
   double CurrentTime;
+  int Stride = 1;
 };
 
 #endif
