@@ -12,24 +12,36 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
+// Hide PARAVIEW_DEPRECATED_IN_5_10_0() warnings for this class.
+#define PARAVIEW_DEPRECATION_LEVEL 0
+
 #include "vtkInitializationHelper.h"
 
+#include "vtkCLIOptions.h"
 #include "vtkClientServerInterpreter.h"
 #include "vtkClientServerInterpreterInitializer.h"
+#include "vtkMultiProcessController.h"
 #include "vtkNew.h"
 #include "vtkOutputWindow.h"
-#include "vtkPVConfig.h"
 #include "vtkPVInitializer.h"
+#include "vtkPVLogger.h"
 #include "vtkPVOptions.h"
 #include "vtkPVPluginLoader.h"
 #include "vtkPVSession.h"
+#include "vtkPVStringFormatter.h"
+#include "vtkPVVersion.h"
 #include "vtkProcessModule.h"
+#include "vtkProcessModuleConfiguration.h"
+#include "vtkRemotingCoreConfiguration.h"
 #include "vtkSMMessage.h"
 #include "vtkSMProperty.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMSettings.h"
 #include "vtkSmartPointer.h"
+#include "vtkStringList.h"
 
+#include "vtksys/SystemInformation.hxx"
 #include <sstream>
 #include <string>
 #include <vector>
@@ -37,6 +49,7 @@ PURPOSE.  See the above copyright notice for more information.
 
 // Windows-only helper functionality:
 #ifdef _WIN32
+#include <conio.h> // for getch()
 #include <windows.h>
 #endif
 
@@ -70,19 +83,20 @@ std::string ListAttachedMonitors()
   return std::string("Monitor detection only implemented for MS Windows.");
 #else  // _WIN32
   std::ostringstream str;
-  EnumDisplayMonitors(NULL, NULL, listMonitorsCallback, reinterpret_cast<LPARAM>(&str));
+  EnumDisplayMonitors(nullptr, nullptr, listMonitorsCallback, reinterpret_cast<LPARAM>(&str));
   return str.str();
 #endif // _WIN32
 }
 
 } // end anon namespace
 
+//----------------------------------------------------------------------------
+// Initialize statics.
 bool vtkInitializationHelper::LoadSettingsFilesDuringInitialization = true;
-
 bool vtkInitializationHelper::SaveUserSettingsFileDuringFinalization = false;
-
 std::string vtkInitializationHelper::OrganizationName = "ParaView";
 std::string vtkInitializationHelper::ApplicationName = "GenericParaViewApplication";
+int vtkInitializationHelper::ExitCode = 0;
 
 //----------------------------------------------------------------------------
 void vtkInitializationHelper::SetLoadSettingsFilesDuringInitialization(bool val)
@@ -130,114 +144,162 @@ const std::string& vtkInitializationHelper::GetApplicationName()
 }
 
 //----------------------------------------------------------------------------
-void vtkInitializationHelper::Initialize(const char* executable, int type)
+bool vtkInitializationHelper::Initialize(const char* executable, int type)
 {
-  vtkInitializationHelper::Initialize(executable, type, NULL);
-}
-
-//----------------------------------------------------------------------------
-void vtkInitializationHelper::Initialize(const char* executable, int type, vtkPVOptions* options)
-{
-  if (!executable)
+  if (!executable || !executable[0])
   {
-    vtkGenericWarningMacro("Executable name has to be defined.");
-    return;
-  }
-
-  // Pass the program name to make option parser happier
-  vtkSmartPointer<vtkPVOptions> newoptions = options;
-  if (!options)
-  {
-    newoptions = vtkSmartPointer<vtkPVOptions>::New();
+    vtkLogF(ERROR, "Executable name must be specified!");
+    return false;
   }
 
   std::vector<char*> argv;
   argv.push_back(vtksys::SystemTools::DuplicateString(executable));
-  if (newoptions->GetForceNoMPIInitOnClient())
-  {
-    argv.push_back(vtksys::SystemTools::DuplicateString("--no-mpi"));
-  }
-  if (newoptions->GetForceMPIInitOnClient())
-  {
-    argv.push_back(vtksys::SystemTools::DuplicateString("--mpi"));
-  }
-
   argv.push_back(nullptr);
-  vtkInitializationHelper::Initialize(
-    static_cast<int>(argv.size()) - 1, &argv[0], type, newoptions);
-
-  for (auto tofree : argv)
-  {
-    delete[] tofree;
-  }
+  return vtkInitializationHelper::Initialize(static_cast<int>(argv.size()) - 1, &argv[0], type);
 }
 
 //----------------------------------------------------------------------------
-void vtkInitializationHelper::Initialize(int argc, char** argv, int type, vtkPVOptions* options)
+void vtkInitializationHelper::Initialize(const char* executable, int type, vtkPVOptions*)
+{
+  vtkInitializationHelper::Initialize(executable, type);
+}
+
+//----------------------------------------------------------------------------
+bool vtkInitializationHelper::Initialize(vtkStringList* slist, int type)
+{
+  std::vector<char*> argv;
+  for (int cc = 0, max = slist->GetLength(); cc < max; ++cc)
+  {
+    argv.push_back(const_cast<char*>(slist->GetString(cc)));
+  }
+  argv.push_back(nullptr);
+  return vtkInitializationHelper::Initialize(static_cast<int>(argv.size()) - 1, &argv[0], type);
+}
+
+//----------------------------------------------------------------------------
+bool vtkInitializationHelper::Initialize(
+  int argc, char** argv, int type, vtkCLIOptions* options, bool addStandardArgs)
+{
+  if (!vtkInitializationHelper::InitializeOptions(argc, argv, type, options, addStandardArgs))
+  {
+    return false;
+  }
+  return vtkInitializationHelper::InitializeMiscellaneous(type);
+}
+
+//----------------------------------------------------------------------------
+bool vtkInitializationHelper::InitializeOptions(
+  int argc, char** argv, int type, vtkCLIOptions* options, bool addStandardArgs)
 {
   if (vtkProcessModule::GetProcessModule())
   {
-    vtkGenericWarningMacro("Process already initialize. Skipping.");
-    return;
+    vtkLogF(ERROR, "Process already initialize! `Initialize` should only be called once.");
+    vtkInitializationHelper::ExitCode = EXIT_FAILURE;
+    return false;
   }
 
-  if (!options)
-  {
-    vtkGenericWarningMacro("vtkPVOptions must be specified.");
-    return;
-  }
+  vtkNew<vtkCLIOptions> tmpoptions;
+  options = options ? options : tmpoptions;
+
+  const auto processType = static_cast<vtkProcessModule::ProcessTypes>(type);
 
   // Verify that the version of the library that we linked against is
   // compatible with the version of the headers we compiled against.
   GOOGLE_PROTOBUF_VERIFY_VERSION;
 
-  vtkProcessModule::Initialize(static_cast<vtkProcessModule::ProcessTypes>(type), argc, argv);
+  vtkProcessModule::Initialize(processType, argc, argv);
 
-  std::ostringstream sscerr;
-  if (argv && !options->Parse(argc, argv))
+  // Populate options (unless told otherwise).
+  auto coreConfig = vtkRemotingCoreConfiguration::GetInstance();
+  if (addStandardArgs)
   {
-    if (options->GetUnknownArgument())
+    auto pmConfig = vtkProcessModuleConfiguration::GetInstance();
+    pmConfig->PopulateOptions(options, processType);
+    coreConfig->PopulateOptions(options, processType);
+  }
+
+  auto controller = vtkMultiProcessController::GetGlobalController();
+  const auto rank0 = (controller == nullptr || controller->GetLocalProcessId() == 0);
+
+  if (!options->Parse(argc, argv))
+  {
+    if (rank0)
     {
-      sscerr << "Got unknown argument: " << options->GetUnknownArgument()
-             << ". Could you have misspelled your Python file path or name?" << endl;
+      // report error.
+      std::ostringstream str;
+      str << options->GetLastErrorMessage().c_str() << endl
+          << options->GetUsage().c_str() << "Try `--help` for more more information." << endl;
+      vtkOutputWindow::GetInstance()->DisplayText(str.str().c_str());
     }
-    if (options->GetErrorMessage())
+    vtkProcessModule::Finalize();
+    vtkInitializationHelper::ExitCode = EXIT_FAILURE;
+    return false;
+  }
+  else if (options->GetHelpRequested())
+  {
+    if (rank0)
     {
-      sscerr << "Error: " << options->GetErrorMessage() << endl;
+      std::ostringstream str;
+      str << options->GetHelp() << endl;
+
+#ifndef _WIN32
+      vtkOutputWindow::GetInstance()->DisplayText(str.str().c_str());
+#else
+      // Pop up a console and reopen stdin, stderr, stdout to it to display help
+      AllocConsole();
+      FILE* fDummy;
+      freopen_s(&fDummy, "CONIN$", "r", stdin);
+      freopen_s(&fDummy, "CONOUT$", "w", stderr);
+      freopen_s(&fDummy, "CONOUT$", "w", stdout);
+
+      std::cout << str.str() << std::endl;
+
+      // Need user input to close the console, otherwise it will close immediately
+      std::cout << "Press any key to exit" << std::endl;
+      getch();
+#endif
     }
-    options->SetHelpSelected(1);
+    vtkProcessModule::Finalize();
+    vtkInitializationHelper::ExitCode = EXIT_SUCCESS;
+    return false;
   }
-  if (options->GetHelpSelected())
+  else if (coreConfig->GetTellVersion())
   {
-    sscerr << options->GetHelp() << endl;
-    vtkOutputWindow::GetInstance()->DisplayText(sscerr.str().c_str());
-    // TODO: indicate to the caller that application must quit.
+    if (rank0)
+    {
+      std::ostringstream str;
+      str << "paraview version " << PARAVIEW_VERSION_FULL << "\n";
+      vtkOutputWindow::GetInstance()->DisplayText(str.str().c_str());
+    }
+    vtkProcessModule::Finalize();
+    vtkInitializationHelper::ExitCode = EXIT_SUCCESS;
+    return false;
   }
-
-  if (options->GetTellVersion())
+  else if (coreConfig->GetPrintMonitors())
   {
-    std::ostringstream str;
-    str << "paraview version " << PARAVIEW_VERSION_FULL << "\n";
-    vtkOutputWindow::GetInstance()->DisplayText(str.str().c_str());
-    // TODO: indicate to the caller that application must quit.
+    if (rank0)
+    {
+      const std::string monitors = ListAttachedMonitors();
+      vtkOutputWindow::GetInstance()->DisplayText(monitors.c_str());
+    }
+    vtkProcessModule::Finalize();
+    vtkInitializationHelper::ExitCode = EXIT_SUCCESS;
+    return false;
   }
+  return true;
+}
 
-  if (options->GetPrintMonitors())
-  {
-    std::string monitors = ListAttachedMonitors();
-    vtkOutputWindow::GetInstance()->DisplayText(monitors.c_str());
-    // TODO: indicate to the caller that application must quit.
-  }
-
-  vtkProcessModule::GetProcessModule()->SetOptions(options);
-
+//----------------------------------------------------------------------------
+bool vtkInitializationHelper::InitializeMiscellaneous(int type)
+{
+  auto coreConfig = vtkRemotingCoreConfiguration::GetInstance();
   // this has to happen after process module is initialized and options have
   // been set.
   paraview_initialize();
 
   // Set multi-server flag to vtkProcessModule
   vtkProcessModule::GetProcessModule()->SetMultipleSessionsSupport(
-    options->GetMultiServerMode() != 0);
+    coreConfig->GetMultiServerMode());
 
   // Make sure the ProxyManager get created...
   vtkSMProxyManager::GetProxyManager();
@@ -250,7 +312,7 @@ void vtkInitializationHelper::Initialize(int argc, char** argv, int type, vtkPVO
 
   vtkInitializationHelper::SaveUserSettingsFileDuringFinalization = false;
   // Load settings files on client-processes.
-  if (!options->GetDisableRegistry() && type != vtkProcessModule::PROCESS_SERVER &&
+  if (!coreConfig->GetDisableRegistry() && type != vtkProcessModule::PROCESS_SERVER &&
     type != vtkProcessModule::PROCESS_DATA_SERVER &&
     type != vtkProcessModule::PROCESS_RENDER_SERVER)
   {
@@ -264,6 +326,30 @@ void vtkInitializationHelper::Initialize(int argc, char** argv, int type, vtkPVO
                                     "} }",
     0.0);
 
+  const char* undefined = "Undefined";
+
+  // push the ENV argument scope which includes environment arguments
+  std::string username;
+#if defined(_WIN16) || defined(_WIN32) || defined(_WIN64)
+  username = getenv("USERNAME") != nullptr ? getenv("USERNAME") : undefined;
+#else
+  username = getenv("USER") != nullptr ? getenv("USER") : undefined;
+#endif
+  vtksys::SystemInformation sysInfo;
+  sysInfo.RunOSCheck();
+  std::string hostname = sysInfo.GetHostname() != nullptr ? sysInfo.GetHostname() : undefined;
+  std::string os = sysInfo.GetOSName() != nullptr ? sysInfo.GetOSName() : undefined;
+
+  vtkPVStringFormatter::PushScope(
+    "ENV", fmt::arg("username", username), fmt::arg("hostname", hostname), fmt::arg("os", os));
+
+  // push the GLOBAL argument scope which includes global arguments
+  std::string appVersion = PARAVIEW_VERSION_FULL;
+
+  vtkPVStringFormatter::PushScope("GLOBAL", fmt::arg("date", std::chrono::system_clock::now()),
+    fmt::arg("appname", vtkInitializationHelper::ApplicationName),
+    fmt::arg("appversion", appVersion));
+
   // until we replace PARAVIEW_SMTESTDRIVER with something cleaner, we have
   // to print this greeting out when the process is launched from
   // smTestDriver
@@ -271,6 +357,15 @@ void vtkInitializationHelper::Initialize(int argc, char** argv, int type, vtkPVO
   {
     cout << "Process started" << endl;
   }
+
+  vtkInitializationHelper::ExitCode = EXIT_SUCCESS;
+  return true;
+}
+
+//----------------------------------------------------------------------------
+void vtkInitializationHelper::Initialize(int argc, char** argv, int type, vtkPVOptions*)
+{
+  vtkInitializationHelper::Initialize(argc, argv, type);
 }
 
 //----------------------------------------------------------------------------
@@ -289,13 +384,18 @@ void vtkInitializationHelper::Finalize()
     // Write out settings file(s)
     std::string userSettingsFilePath = vtkInitializationHelper::GetUserSettingsFilePath();
     vtkSMSettings* settings = vtkSMSettings::GetInstance();
-    bool savingSucceeded = settings->SaveSettingsToFile(userSettingsFilePath.c_str());
+    bool savingSucceeded = settings->SaveSettingsToFile(userSettingsFilePath);
     if (!savingSucceeded)
     {
       vtkGenericWarningMacro(<< "Saving settings file to '" << userSettingsFilePath << "' failed");
     }
   }
 
+  // pop GLOBAL scope
+  vtkPVStringFormatter::PopScope();
+  // pop ENV scope
+  vtkPVStringFormatter::PopScope();
+
   vtkSMProxyManager::Finalize();
   vtkProcessModule::Finalize();
 
@@ -339,10 +439,7 @@ void vtkInitializationHelper::LoadSettings()
   }
 
   // Load site-level settings
-  vtkPVOptions* options = vtkProcessModule::GetProcessModule()->GetOptions();
-  const char* app_dir_p = options->GetApplicationPath();
-  std::string app_dir = app_dir_p ? app_dir_p : "";
-  app_dir = vtksys::SystemTools::GetProgramPath(app_dir.c_str());
+  const auto& app_dir = vtkProcessModule::GetProcessModule()->GetSelfDir();
 
   // If the application path ends with lib/paraview-X.X, shared
   // forwarding of the executable was used. Remove that part of the
@@ -371,12 +468,10 @@ void vtkInitializationHelper::LoadSettings()
   // On windows configuration files are in the parent directory
   pathsToSearch.push_back(installDirectory + "/../");
 
-  std::string filename = vtkInitializationHelper::GetApplicationName() + "-SiteSettings.json";
-  std::string siteSettingsFile;
-  for (size_t cc = 0; cc < pathsToSearch.size(); cc++)
+  const std::string filename = vtkInitializationHelper::GetApplicationName() + "-SiteSettings.json";
+  for (const std::string& path : pathsToSearch)
   {
-    std::string path = pathsToSearch[cc];
-    siteSettingsFile = path + "/" + filename;
+    const std::string siteSettingsFile = std::string(path).append("/").append(filename);
     if (settings->AddCollectionFromFile(siteSettingsFile, 1.0))
     {
       break;
