@@ -17,7 +17,7 @@
  *
  * When run on the process it enables a stacktrace signal handler for
  * common errors.
-*/
+ */
 
 #ifndef vtkPVDisableStackTraceSignalHandler_h
 #define vtkPVDisableStackTraceSignalHandler_h
@@ -50,8 +50,8 @@ public:
   void CopyFromStream(const vtkClientServerStream*) override {}
 
 protected:
-  vtkPVDisableStackTraceSignalHandler() {}
-  ~vtkPVDisableStackTraceSignalHandler() override {}
+  vtkPVDisableStackTraceSignalHandler() = default;
+  ~vtkPVDisableStackTraceSignalHandler() override = default;
 
 private:
   vtkPVDisableStackTraceSignalHandler(const vtkPVDisableStackTraceSignalHandler&) = delete;
