@@ -22,7 +22,7 @@
  * from a vtkPVFileInformationHelper object alone.
  * @sa
  * vtkPVFileInformationHelper
-*/
+ */
 
 #ifndef vtkPVFileInformation_h
 #define vtkPVFileInformation_h
@@ -73,12 +73,34 @@ public:
     DIRECTORY_GROUP
   };
 
+  //@{
   /**
    * Helper that returns whether a FileType is a
    * directory (DIRECTORY, DRIVE, NETWORK_ROOT, etc...)
    * Or in other words, a type that we can do a DirectoryListing on.
    */
   static bool IsDirectory(int t);
+  bool IsDirectory() const { return vtkPVFileInformation::IsDirectory(this->Type); }
+  //@}
+
+  //@{
+  /**
+   * Helper that returns true if file-type is a network related file i.e.
+   * either a FILE_GROUP or a DIRECTORY_GROUP.
+   */
+  static bool IsGroup(int type)
+  {
+    switch (type)
+    {
+      case FILE_GROUP:
+      case DIRECTORY_GROUP:
+        return true;
+      default:
+        return false;
+    }
+  }
+  bool IsGroup() const { return vtkPVFileInformation::IsGroup(this->Type); }
+  //@}
 
   /**
    * Initializes the information object.
@@ -115,6 +137,18 @@ public:
   vtkGetMacro(Hidden, bool);
   //@}
 
+  ///@{
+  /**
+   * Groups file sequences when found. A file sequence could be [foo1.png, foo2.png, foo6.png].
+   * When turned on, the series of files is grouped and our sequence example is named foo..png
+   * and original files are discarded from the listing.
+   * By default, this flag is set to true.
+   */
+  vtkGetMacro(GroupFileSequences, bool);
+  vtkSetMacro(GroupFileSequences, bool);
+  vtkBooleanMacro(GroupFileSequences, bool);
+  ///@}
+
   //@{
   /**
    * Get the Contents for this directory.
@@ -130,19 +164,24 @@ public:
   //@}
 
   /**
-  * Returns the path to the base data directory path holding various files
-  * packaged with ParaView.
-  */
+   * Fetch the directory listing to be able to use GetSize or GetContents with directories
+   */
+  void FetchDirectoryListing();
+
+  /**
+   * Returns the path to the base data directory path holding various files
+   * packaged with ParaView.
+   */
   static std::string GetParaViewSharedResourcesDirectory();
 
   /**
-  * Return the path of the example data packaged with ParaView.
-  */
+   * Return the path of the example data packaged with ParaView.
+   */
   static std::string GetParaViewExampleFilesDirectory();
 
   /**
-  * Return the path of the documents packaged with ParaView.
-  */
+   * Return the path of the documents packaged with ParaView.
+   */
   static std::string GetParaViewDocDirectory();
 
 protected:
@@ -164,8 +203,8 @@ protected:
   vtkSetStringMacro(Name);
   vtkSetStringMacro(FullPath);
 
-  void GetWindowsDirectoryListing();
-  void GetDirectoryListing();
+  void FetchWindowsDirectoryListing();
+  void FetchUnixDirectoryListing();
 
   // Goes thru the collection of vtkPVFileInformation objects
   // are creates file groups, if possible.
@@ -176,6 +215,7 @@ protected:
   void SetHiddenFlag();
   int FastFileTypeDetection;
   bool ReadDetailedFileInformation;
+  bool GroupFileSequences;
 
 private:
   vtkPVFileInformation(const vtkPVFileInformation&) = delete;
