@@ -26,14 +26,16 @@
 vtkStandardNewMacro(vtkPVFileInformationHelper);
 //-----------------------------------------------------------------------------
 vtkPVFileInformationHelper::vtkPVFileInformationHelper()
+  : Path(nullptr)
+  , WorkingDirectory(nullptr)
+  , DirectoryListing(0)
+  , SpecialDirectories(0)
+  , FastFileTypeDetection(1)
+  , GroupFileSequences(true)
+  , ReadDetailedFileInformation(false)
+  , PathSeparator(nullptr)
 {
-  this->DirectoryListing = 0;
-  this->Path = 0;
-  this->WorkingDirectory = 0;
-  this->SpecialDirectories = 0;
   this->SetPath(".");
-  this->PathSeparator = 0;
-  this->FastFileTypeDetection = 1;
 #if defined(_WIN32) && !defined(__CYGWIN__)
   this->SetPathSeparator("\\");
 #else
@@ -44,22 +46,21 @@ vtkPVFileInformationHelper::vtkPVFileInformationHelper()
 //-----------------------------------------------------------------------------
 vtkPVFileInformationHelper::~vtkPVFileInformationHelper()
 {
-  this->SetPath(0);
-  this->SetPathSeparator(0);
-  this->SetWorkingDirectory(0);
+  this->SetPath(nullptr);
+  this->SetPathSeparator(nullptr);
+  this->SetWorkingDirectory(nullptr);
 }
 
 //-----------------------------------------------------------------------------
 bool vtkPVFileInformationHelper::GetActiveFileIsReadable()
 {
-  return vtksys::SystemTools::FileExists(vtkPVFileInformationHelper::Utf8ToLocalWin32(this->Path));
+  return vtksys::SystemTools::FileExists(this->Path);
 }
 
 //-----------------------------------------------------------------------------
 bool vtkPVFileInformationHelper::GetActiveFileIsDirectory()
 {
-  return vtksys::SystemTools::FileIsDirectory(
-    vtkPVFileInformationHelper::Utf8ToLocalWin32(this->Path));
+  return vtksys::SystemTools::FileIsDirectory(this->Path);
 }
 
 //-----------------------------------------------------------------------------
@@ -76,43 +77,3 @@ void vtkPVFileInformationHelper::PrintSelf(ostream& os, vtkIndent indent)
      << endl;
   os << indent << "FastFileTypeDetection: " << this->FastFileTypeDetection << endl;
 }
-
-//-----------------------------------------------------------------------------
-std::string vtkPVFileInformationHelper::Utf8ToLocalWin32(const std::string& path)
-{
-#if defined(_WIN32)
-  int wlen = static_cast<int>(path.length()) * 2 + 1;
-  WCHAR* wpath = new WCHAR[wlen];
-  char* lpath = new char[wlen];
-  MultiByteToWideChar(CP_UTF8, 0, path.c_str(), -1, wpath, wlen);
-  WideCharToMultiByte(CP_ACP, 0, wpath, -1, lpath, wlen, NULL, NULL);
-  std::string localPath(lpath);
-  delete wpath;
-  delete lpath;
-  return localPath;
-#else
-  return path;
-#endif
-}
-
-// Transform local code page string to UTF8 string
-//-----------------------------------------------------------------------------
-std::string vtkPVFileInformationHelper::LocalToUtf8Win32(const std::string& path)
-{
-#if defined(_WIN32)
-  int wlen = static_cast<int>(path.length()) * 2 + 1;
-  WCHAR* wpath = new WCHAR[wlen];
-  char* lpath = new char[wlen];
-  // We may want a stronger implementation ,
-  // see vtksys::Encoding way of recovering converted string size
-  // TODO
-  int err = MultiByteToWideChar(CP_ACP, 0, path.c_str(), -1, wpath, wlen);
-  err = WideCharToMultiByte(CP_UTF8, 0, wpath, -1, lpath, wlen, NULL, NULL);
-  std::string utfPath(lpath);
-  delete wpath;
-  delete lpath;
-  return utfPath;
-#else
-  return path;
-#endif
-}
