@@ -24,7 +24,6 @@
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkOutputWindow.h"
-#include "vtkPVOptions.h"
 #include "vtkPVSession.h"
 #include "vtkProcessModule.h"
 #include "vtkTimerLog.h"
@@ -126,10 +125,10 @@ vtkStandardNewMacro(vtkPVProgressHandler);
 //----------------------------------------------------------------------------
 vtkPVProgressHandler::vtkPVProgressHandler()
 {
-  this->Session = 0;
+  this->Session = nullptr;
   this->Internals = new vtkInternals();
   this->LastProgress = 0;
-  this->LastProgressText = NULL;
+  this->LastProgressText = nullptr;
 
   // use higher frequency for client while lower for server (or batch).
   this->ProgressInterval =
@@ -147,16 +146,17 @@ vtkPVProgressHandler::vtkPVProgressHandler()
 //----------------------------------------------------------------------------
 vtkPVProgressHandler::~vtkPVProgressHandler()
 {
-  this->SetLastProgressText(NULL);
-  this->SetSession(0);
+  this->SetLastProgressText(nullptr);
+  this->SetSession(nullptr);
   delete this->Internals;
 }
 
 //----------------------------------------------------------------------------
 void vtkPVProgressHandler::RegisterProgressEvent(vtkObject* object, int id)
 {
-  if (object && (object->IsA("vtkAlgorithm") || object->IsA("vtkExporter") ||
-                  object->IsA("vtkSMAnimationSceneWriter")))
+  if (object &&
+    (object->IsA("vtkAlgorithm") || object->IsA("vtkExporter") ||
+      object->IsA("vtkSMAnimationSceneWriter")))
   {
     this->Internals->RegisteredObjects[object] = id;
     object->AddObserver(vtkCommand::ProgressEvent, this, &vtkPVProgressHandler::OnProgressEvent);
@@ -261,7 +261,7 @@ void vtkPVProgressHandler::CleanupPendingProgress()
   // reply back to the client saying we are done cleaning up.
   // Now, if there exists a client-controller, send reply to the client.
   vtkMultiProcessController* client_controller = this->Session->GetController(vtkPVSession::CLIENT);
-  if (client_controller != NULL)
+  if (client_controller != nullptr)
   {
     char temp = 0;
     vtkCompositeMultiProcessController* collabController =
@@ -390,7 +390,7 @@ void vtkPVProgressHandler::RefreshProgress(const char* progress_text, double pro
   this->LastProgress = static_cast<int>(progress * 100.0);
   // cout << "Progress: " << progress_text << " " << progress * 100 << endl;
   this->InvokeEvent(vtkCommand::ProgressEvent, this);
-  this->SetLastProgressText(NULL);
+  this->SetLastProgressText(nullptr);
   this->LastProgress = 0;
 }
 
@@ -485,6 +485,10 @@ void vtkPVProgressHandler::RefreshMessage(const char* message, int etype, bool i
 {
   SKIP_IF_DISABLED();
 
+  // to avoid recursive error messages.
+  const auto old_value = vtkObject::GetGlobalWarningDisplay();
+  vtkObject::GlobalWarningDisplayOff();
+
   // On server-root-nodes, send the message to the client.
   vtkMultiProcessController* client_controller = this->Session->GetController(vtkPVSession::CLIENT);
   if (client_controller != nullptr && message != nullptr)
@@ -533,4 +537,6 @@ void vtkPVProgressHandler::RefreshMessage(const char* message, int etype, bool i
         break;
     }
   }
+
+  vtkObject::SetGlobalWarningDisplay(old_value);
 }
