@@ -71,7 +71,8 @@ vtkTCPNetworkAccessManager::~vtkTCPNetworkAccessManager()
 }
 
 //----------------------------------------------------------------------------
-vtkMultiProcessController* vtkTCPNetworkAccessManager::NewConnection(const char* url)
+vtkMultiProcessController* vtkTCPNetworkAccessManager::NewConnection(
+  const char* url, vtkNetworkAccessManager::ConnectionResult& result)
 {
   vtksys::RegularExpression re_connect("^tcp://([^:]+)?:([0-9]+)\\?\?((&?[a-zA-Z0-9%]+=[^&]+)*)");
   vtksys::RegularExpression key_val("([a-zA-Z0-9%]+)=([^&]+)");
@@ -109,17 +110,14 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::NewConnection(const char*
 
     this->WrongConnectID = false;
 
-    if (parameters["listen"] == "true" && parameters["multiple"] == "true")
+    if (parameters["listen"] == "true")
     {
-      return this->WaitForConnection(port, false, handshake, parameters["nonblocking"] == "true");
-    }
-    else if (parameters["listen"] == "true")
-    {
-      return this->WaitForConnection(port, true, handshake, parameters["nonblocking"] == "true");
+      return this->WaitForConnection(port, !(parameters["multiple"] == "true"), handshake,
+        parameters["nonblocking"] == "true", result);
     }
     else
     {
-      return this->ConnectToRemote(hostname.c_str(), port, handshake, timeout_in_seconds);
+      return this->ConnectToRemote(hostname.c_str(), port, handshake, timeout_in_seconds, result);
     }
   }
   else
@@ -127,6 +125,7 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::NewConnection(const char*
     vtkErrorMacro("Malformed URL: " << (url ? url : "(empty)"));
   }
 
+  result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_FAILURE;
   return nullptr;
 }
 
@@ -366,8 +365,9 @@ void vtkTCPNetworkAccessManager::PrintHandshakeError(int errorcode, bool server_
 }
 
 //----------------------------------------------------------------------------
-vtkMultiProcessController* vtkTCPNetworkAccessManager::ConnectToRemote(
-  const char* hostname, int port, const char* handshake, int timeout_in_seconds)
+vtkMultiProcessController* vtkTCPNetworkAccessManager::ConnectToRemote(const char* hostname,
+  int port, const char* handshake, int timeout_in_seconds,
+  vtkNetworkAccessManager::ConnectionResult& result)
 {
 
   // Create client socket.
@@ -377,8 +377,19 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::ConnectToRemote(
   vtkSmartPointer<vtkClientSocket> cs = vtkSmartPointer<vtkClientSocket>::New();
   vtkSmartPointer<vtkTimerLog> timer = vtkSmartPointer<vtkTimerLog>::New();
   timer->StartTimer();
+
+  this->AbortPendingConnectionFlag = false;
   while (1)
   {
+    double progress = 0.5;
+    this->InvokeEvent(vtkCommand::ProgressEvent, &progress);
+    if (this->AbortPendingConnectionFlag)
+    {
+      vtkErrorMacro(<< "Connect aborted.");
+      result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_ABORT;
+      return nullptr;
+    }
+
     if (cs->ConnectToServer(hostname, port) != -1)
     {
       break;
@@ -389,6 +400,7 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::ConnectToRemote(
       if (timeout_in_seconds == 0 || timer->GetElapsedTime() > timeout_in_seconds)
       {
         vtkErrorMacro(<< "Connect timeout.");
+        result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_TIMEOUT;
         return nullptr;
       }
       vtkWarningMacro(<< "Connect failed. Retrying for "
@@ -396,7 +408,7 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::ConnectToRemote(
     }
     else
     {
-      vtkWarningMacro("Connect failed.  Retrying.");
+      vtkWarningMacro("Connect failed. Retrying.");
     }
     vtksys::SystemTools::Delay(1000);
   }
@@ -416,15 +428,17 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::ConnectToRemote(
     // handshake failed, must be bogus client, continue waiting (unless
     // this->AbortPendingConnectionFlag == true).
     this->PrintHandshakeError(errorcode, false);
+    result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_HANDSHAKE_ERROR;
     return nullptr;
   }
   this->Internals->Controllers.push_back(controller);
+  result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_SUCCESS;
   return controller;
 }
 
 //----------------------------------------------------------------------------
-vtkMultiProcessController* vtkTCPNetworkAccessManager::WaitForConnection(
-  int port, bool once, const char* handshake, bool nonblocking)
+vtkMultiProcessController* vtkTCPNetworkAccessManager::WaitForConnection(int port, bool once,
+  const char* handshake, bool nonblocking, vtkNetworkAccessManager::ConnectionResult& result)
 {
   vtkServerSocket* server_socket = nullptr;
   if (this->Internals->ServerSockets.find(port) != this->Internals->ServerSockets.end())
@@ -438,6 +452,7 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::WaitForConnection(
     {
       vtkErrorMacro("Failed to set up server socket.");
       server_socket->Delete();
+      result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_FAILURE;
       return nullptr;
     }
     this->Internals->ServerSockets[port] = server_socket;
@@ -473,6 +488,7 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::WaitForConnection(
     }
     if (!client_socket)
     {
+      result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_FAILURE;
       return nullptr;
     }
 
@@ -487,6 +503,7 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::WaitForConnection(
     {
       controller->Delete();
       controller = nullptr;
+      result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_HANDSHAKE_ERROR;
       this->PrintHandshakeError(errorcode, true);
       if (!once)
       {
@@ -498,6 +515,11 @@ vtkMultiProcessController* vtkTCPNetworkAccessManager::WaitForConnection(
   if (controller)
   {
     this->Internals->Controllers.push_back(controller);
+    result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_SUCCESS;
+  }
+  else if (this->AbortPendingConnectionFlag)
+  {
+    result = vtkNetworkAccessManager::ConnectionResult::CONNECTION_ABORT;
   }
 
   if (once)
