@@ -18,7 +18,7 @@
  * vtkTCPNetworkAccessManager is a concrete implementation of
  * vtkNetworkAccessManager that uses tcp/ip sockets for communication between
  * processes. It supports urls that use "tcp" as their protocol specifier.
-*/
+ */
 
 #ifndef vtkTCPNetworkAccessManager_h
 #define vtkTCPNetworkAccessManager_h
@@ -35,11 +35,14 @@ public:
   vtkTypeMacro(vtkTCPNetworkAccessManager, vtkNetworkAccessManager);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
+  //@{
   /**
    * Creates a new connection given the url.
    * This call may block until the connection can be established. To keep
    * user-interfaces responsive, one can listen to the vtkCommand::ProgressEvent
    * fired periodically by this class while waiting.
+   * The result arg provide information about the failure or sucess of the connection,
+   * see vtkNetworkAccessManager::ConnectionResult for possible values.
 
    * vtkNetworkAccessManager can  be waiting for atmost one connection at a
    * time. Calling NewConnection() while another connection is pending will
@@ -48,7 +51,7 @@ public:
    * To abort the connection and cancel the waiting, simply call
    * AbortPendingConnection() in the vtkCommand::ProgressEvent callback.
 
-   * Returns the new connection instance on success, otherwise NULL.
+   * Returns the new connection instance on success, otherwise nullptr.
 
    * URLs are of the following form:
    * \c \<transport\>://\<address\>
@@ -64,14 +67,17 @@ public:
    * multiple  :- leave server-socket open for more than 1 client to connect
    * (listen must be set to true)
    * nonblocking:- When listen is true, this will result in the call returning
-   * NULL if a client connection is not available immediately.
+   * nullptr if a client connection is not available immediately.
    * It leaves the server socket open for client to connect.
    * timeout   :- When connecting to remote i.e listen==false, specify the time
    * (in seconds) for which this call blocks to retry attempts to
    * connect to the host/port. If absent, default is 60s. 0 implies no retry attempts.
    * A negative value implies an infinite number of retries.
    */
-  vtkMultiProcessController* NewConnection(const char* url) override;
+  using vtkNetworkAccessManager::NewConnection;
+  vtkMultiProcessController* NewConnection(
+    const char* url, vtkNetworkAccessManager::ConnectionResult& result) override;
+  //@}
 
   /**
    * Used to abort pending connection creation, if any. Refer to
@@ -99,12 +105,12 @@ public:
   /**
    * Enable/disable further connections for given port.
    */
-  virtual void DisableFurtherConnections(int port, bool disable) override;
+  void DisableFurtherConnections(int port, bool disable) override;
 
   /**
    * Returns true if the last check of connect ids was wrong.
    */
-  virtual bool GetWrongConnectID() override;
+  bool GetWrongConnectID() override;
 
 protected:
   vtkTCPNetworkAccessManager();
@@ -116,14 +122,14 @@ protected:
   /**
    * Connects to remote processes.
    */
-  vtkMultiProcessController* ConnectToRemote(
-    const char* hostname, int port, const char* handshake, int timeout_in_seconds);
+  vtkMultiProcessController* ConnectToRemote(const char* hostname, int port, const char* handshake,
+    int timeout_in_seconds, vtkNetworkAccessManager::ConnectionResult& result);
 
   /**
    * Waits for connection from remote process.
    */
-  vtkMultiProcessController* WaitForConnection(
-    int port, bool once, const char* handshake, bool nonblocking);
+  vtkMultiProcessController* WaitForConnection(int port, bool once, const char* handshake,
+    bool nonblocking, vtkNetworkAccessManager::ConnectionResult& result);
 
   enum HandshakeErrors
   {
