@@ -24,19 +24,20 @@
 #include "vtkRenderer.h"
 #include "vtkRendererCollection.h"
 
+#include "vtksys/SystemTools.hxx"
+
 #include <cstdio> // for rename
 
-vtkStandardNewMacro(vtkPVGL2PSExporter)
+vtkStandardNewMacro(vtkPVGL2PSExporter);
 
-  //----------------------------------------------------------------------------
-  vtkPVGL2PSExporter::vtkPVGL2PSExporter()
+//----------------------------------------------------------------------------
+vtkPVGL2PSExporter::vtkPVGL2PSExporter()
+  : ExcludeCubeAxesActorsFromRasterization(true)
 {
 }
 
 //----------------------------------------------------------------------------
-vtkPVGL2PSExporter::~vtkPVGL2PSExporter()
-{
-}
+vtkPVGL2PSExporter::~vtkPVGL2PSExporter() = default;
 
 //----------------------------------------------------------------------------
 void vtkPVGL2PSExporter::WriteData()
@@ -51,7 +52,7 @@ void vtkPVGL2PSExporter::WriteData()
   // Setup raster exclusions if needed
   if (this->Write3DPropsAsRasterImage != 0)
   {
-    if (this->RasterExclusions == NULL)
+    if (this->RasterExclusions == nullptr)
     {
       vtkNew<vtkPropCollection> coll;
       this->SetRasterExclusions(coll.GetPointer());
@@ -109,13 +110,21 @@ void vtkPVGL2PSExporter::WriteData()
       tmpFileName += ".svg";
       break;
   }
+
+  std::string fromPath(tmpFileName);
+  std::string toPath(this->FileName);
+
   if (this->Compress)
   {
-    tmpFileName += ".gz";
+    fromPath += ".gz";
+    toPath += ".gz";
   }
 
-  int result = this->Compress ? std::rename(tmpFileName.c_str(), (this->FileName + ".gz").c_str())
-                              : std::rename(tmpFileName.c_str(), this->FileName.c_str());
+  if (vtksys::SystemTools::FileExists(toPath))
+  {
+    vtksys::SystemTools::RemoveFile(toPath);
+  }
+  int result = std::rename(fromPath.c_str(), toPath.c_str());
 
   if (result != 0)
   {
