@@ -17,7 +17,6 @@
 
 #include "vtkCell.h"
 #include "vtkCellData.h"
-#include "vtkCompositeDataIterator.h"
 #include "vtkCompositeDataSet.h"
 #include "vtkCoordinate.h"
 #include "vtkDataArray.h"
@@ -25,8 +24,9 @@
 #include "vtkInformation.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
-#include "vtkPVCompositeDataInformation.h"
 #include "vtkPVDataInformation.h"
+#include "vtkPVDataMover.h"
+#include "vtkPVDataUtilities.h"
 #include "vtkPVExtractSelection.h"
 #include "vtkPVRenderView.h"
 #include "vtkPVSelectionSource.h"
@@ -45,6 +45,7 @@
 #include "vtkSMSessionProxyManager.h"
 #include "vtkSMSourceProxy.h"
 #include "vtkSelectionNode.h"
+#include "vtkStringArray.h"
 
 #include <sstream>
 
@@ -52,7 +53,7 @@ vtkStandardNewMacro(vtkSMTooltipSelectionPipeline);
 
 //----------------------------------------------------------------------------
 vtkSMTooltipSelectionPipeline::vtkSMTooltipSelectionPipeline()
-  : MoveSelectionToClient(NULL)
+  : DataMover(nullptr)
 {
   this->PreviousSelectionId = 0;
   this->SelectionFound = false;
@@ -68,11 +69,7 @@ vtkSMTooltipSelectionPipeline::~vtkSMTooltipSelectionPipeline()
 //----------------------------------------------------------------------------
 void vtkSMTooltipSelectionPipeline::ClearCache()
 {
-  if (this->MoveSelectionToClient)
-  {
-    this->MoveSelectionToClient->Delete();
-    this->MoveSelectionToClient = NULL;
-  }
+  this->DataMover = nullptr;
   this->Superclass::ClearCache();
 }
 
@@ -138,85 +135,42 @@ bool vtkSMTooltipSelectionPipeline::GetCurrentSelectionId(
 vtkDataObject* vtkSMTooltipSelectionPipeline::ConnectPVMoveSelectionToClient(
   vtkSMSourceProxy* source, unsigned int sourceOutputPort)
 {
-  vtkSMSessionProxyManager* proxyManager =
-    vtkSMProxyManager::GetProxyManager()->GetActiveSessionProxyManager();
+  auto pxm = source->GetSessionProxyManager();
 
-  // Reduce data
-  vtkSMSourceProxy* reduceSelectionToClient =
-    vtkSMSourceProxy::SafeDownCast(proxyManager->NewProxy("filters", "ReductionFilter"));
-  // set input
-  vtkSMInputProperty* inputProperty =
-    vtkSMInputProperty::SafeDownCast(reduceSelectionToClient->GetProperty("Input"));
-  inputProperty->RemoveAllProxies();
-  inputProperty->AddInputConnection(source, sourceOutputPort);
-  // set postGatherHelperName
-  std::string postGatherHelperName;
-  if (source->GetDataInformation(sourceOutputPort)
-        ->GetCompositeDataInformation()
-        ->GetDataIsComposite())
+  if (this->DataMover == nullptr)
   {
-    postGatherHelperName = "vtkMultiBlockDataGroupFilter";
-  }
-  else if (std::string(source->GetDataInformation(sourceOutputPort)->GetDataClassName()) ==
-    std::string("vtkPolyData"))
-  {
-    postGatherHelperName = "vtkAppendPolyData";
-  }
-  else if (std::string(source->GetDataInformation(sourceOutputPort)->GetDataClassName()) ==
-    std::string("vtkRectilinearGrid"))
-  {
-    postGatherHelperName = "vtkAppendRectilinearGrid";
-  }
-  else
-  {
-    postGatherHelperName = "vtkAppendFilter";
-  }
-  vtkSMPropertyHelper(reduceSelectionToClient, "PostGatherHelperName")
-    .Set(postGatherHelperName.c_str());
-  reduceSelectionToClient->UpdateVTKObjects();
-  reduceSelectionToClient->UpdatePipeline();
-
-  // Move data to client
-  if (!this->MoveSelectionToClient)
-  {
-    this->MoveSelectionToClient =
-      vtkSMSourceProxy::SafeDownCast(proxyManager->NewProxy("filters", "ClientServerMoveData"));
+    this->DataMover = vtk::TakeSmartPointer(pxm->NewProxy("misc", "DataMover"));
+    if (this->DataMover == nullptr)
+    {
+      vtkErrorMacro("Failed to create required proxy 'DataMover'");
+      return nullptr;
+    }
   }
 
-  // set input, manually modifying VTK object so it is updated
-  vtkSMPropertyHelper(this->MoveSelectionToClient, "Input").Set(reduceSelectionToClient, 0);
-  vtkObject::SafeDownCast(this->MoveSelectionToClient->GetClientSideObject())->Modified();
-  reduceSelectionToClient->Delete();
+  vtkSMPropertyHelper(this->DataMover, "Producer").Set(source);
+  vtkSMPropertyHelper(this->DataMover, "PortNumber").Set(static_cast<int>(sourceOutputPort));
+  vtkSMPropertyHelper(this->DataMover, "SkipEmptyDataSets").Set(1);
+  this->DataMover->UpdateVTKObjects();
+  this->DataMover->InvokeCommand("Execute");
 
-  // set data type
-  vtkPVDataInformation* info = reduceSelectionToClient->GetDataInformation(0);
-  int dataType = info->GetDataSetType();
-  if (info->GetCompositeDataSetType() > 0)
+  auto dataMover = vtkPVDataMover::SafeDownCast(this->DataMover->GetClientSideObject());
+  if (dataMover->GetNumberOfDataSets() >= 1)
   {
-    dataType = info->GetCompositeDataSetType();
+    return dataMover->GetDataSetAtIndex(0);
   }
-  vtkSMPropertyHelper(this->MoveSelectionToClient, "OutputDataType").Set(dataType);
 
-  this->MoveSelectionToClient->UpdateVTKObjects();
-  this->MoveSelectionToClient->UpdatePipeline();
-  return vtkAlgorithm::SafeDownCast(this->MoveSelectionToClient->GetClientSideObject())
-    ->GetOutputDataObject(0);
+  return nullptr;
 }
-
-#ifndef VTK_LEGACY_REMOVE
-//----------------------------------------------------------------------------
-bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(
-  int association, double pos[2], std::string& tooltipText)
-{
-  VTK_LEGACY_BODY("vtkSMTooltipSelectionPipeline::GetTooltipInfo", "ParaView 5.9");
-  pos[0] = 0.0;
-  pos[1] = 0.0;
-  return this->GetTooltipInfo(association, tooltipText);
-}
-#endif
-
 //----------------------------------------------------------------------------
 bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(int association, std::string& tooltipText)
+{
+  std::string unused;
+  return this->GetTooltipInfo(association, tooltipText, unused);
+}
+
+//----------------------------------------------------------------------------
+bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(
+  int association, std::string& formatedTooltipText, std::string& plainTooltipText)
 {
   vtkSMSourceProxy* extractSource = this->ExtractInteractiveSelection;
   unsigned int extractOutputPort = extractSource->GetOutputPort((unsigned int)0)->GetPortIndex();
@@ -231,19 +185,22 @@ bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(int association, std::string&
     return false;
   }
 
-  std::ostringstream tooltipTextStream;
-
-  tooltipTextStream << "<p style='white-space:pre'>";
-
   // name of the filter which generated the selected dataset
+  std::string proxyName;
   if (this->PreviousRepresentation)
   {
     vtkSMPropertyHelper representationHelper(this->PreviousRepresentation, "Input", true);
     vtkSMSourceProxy* source = vtkSMSourceProxy::SafeDownCast(representationHelper.GetAsProxy());
     vtkSMSessionProxyManager* proxyManager = source->GetSessionProxyManager();
-    tooltipTextStream << "<b>" << proxyManager->GetProxyName("sources", source) << "</b>";
+    const char* name = proxyManager->GetProxyName("sources", source);
+    if (name)
+    {
+      proxyName = name;
+    }
   }
 
+  std::ostringstream tooltipTextStream;
+
   // composite name
   if (compositeFound)
   {
@@ -289,7 +246,7 @@ bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(int association, std::string&
 
   if (fieldData)
   {
-    // point attributes
+    // point or cell attributes
     vtkIdType nbArrays = fieldData->GetNumberOfArrays();
     for (vtkIdType i_arr = 0; i_arr < nbArrays; i_arr++)
     {
@@ -299,11 +256,12 @@ bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(int association, std::string&
         continue;
       }
       tooltipTextStream << "\n" << array->GetName() << ": ";
-      if (array->GetNumberOfComponents() > 1)
+      vtkIdType nbComps = array->GetNumberOfComponents();
+
+      if (nbComps > 1)
       {
         tooltipTextStream << "(";
       }
-      vtkIdType nbComps = array->GetNumberOfComponents();
       for (vtkIdType i_comp = 0; i_comp < nbComps; i_comp++)
       {
         tooltipTextStream << array->GetTuple(0)[i_comp];
@@ -312,16 +270,71 @@ bool vtkSMTooltipSelectionPipeline::GetTooltipInfo(int association, std::string&
           tooltipTextStream << ", ";
         }
       }
-      if (array->GetNumberOfComponents() > 1)
+      if (nbComps > 1)
       {
         tooltipTextStream << ")";
       }
     }
   }
 
-  tooltipTextStream << "</p>";
+  // Add field data arrays with one tuple
+  fieldData = ds->GetFieldData();
 
-  tooltipText = tooltipTextStream.str();
+  if (fieldData)
+  {
+    for (vtkIdType i_arr = 0; i_arr < fieldData->GetNumberOfArrays(); i_arr++)
+    {
+      vtkAbstractArray* array = fieldData->GetAbstractArray(i_arr);
+      if (!array || array->GetNumberOfTuples() != 1)
+      {
+        continue;
+      }
+
+      tooltipTextStream << "\n" << array->GetName() << ": ";
+
+      // String arrays are not data arrays
+      vtkStringArray* strArray = vtkStringArray::SafeDownCast(array);
+      vtkDataArray* dataArray = vtkDataArray::SafeDownCast(array);
+
+      if (strArray)
+      {
+        tooltipTextStream << strArray->GetValue(0);
+      }
+      else if (dataArray)
+      {
+        vtkIdType nbComps = array->GetNumberOfComponents();
+        vtkIdType maxDisplayedComp = 9;
+
+        if (nbComps > 1)
+        {
+          tooltipTextStream << "(";
+        }
+
+        for (vtkIdType i_comp = 0; i_comp < std::min(nbComps, maxDisplayedComp); i_comp++)
+        {
+          tooltipTextStream << dataArray->GetTuple(0)[i_comp];
+
+          if (i_comp + 1 < nbComps && i_comp < maxDisplayedComp)
+          {
+            tooltipTextStream << ", ";
+          }
+        }
+
+        if (nbComps > 1)
+        {
+          if (nbComps > maxDisplayedComp)
+          {
+            tooltipTextStream << "...";
+          }
+          tooltipTextStream << ")";
+        }
+      }
+    }
+  }
+
+  formatedTooltipText =
+    "<p style='white-space:pre'><b>" + proxyName + "</b>" + tooltipTextStream.str() + "</p>";
+  plainTooltipText = proxyName + tooltipTextStream.str();
 
   this->TooltipEnabled = false;
   return true;
@@ -355,7 +368,7 @@ bool vtkSMTooltipSelectionPipeline::CanDisplayTooltip(bool& showTooltip)
 vtkSMTooltipSelectionPipeline* vtkSMTooltipSelectionPipeline::GetInstance()
 {
   static vtkSmartPointer<vtkSMTooltipSelectionPipeline> Instance;
-  if (Instance.GetPointer() == NULL)
+  if (Instance.GetPointer() == nullptr)
   {
     vtkSMTooltipSelectionPipeline* pipeline = vtkSMTooltipSelectionPipeline::New();
     Instance = pipeline;
@@ -376,39 +389,21 @@ void vtkSMTooltipSelectionPipeline::PrintSelf(ostream& os, vtkIndent indent)
 vtkDataSet* vtkSMTooltipSelectionPipeline::FindDataSet(
   vtkDataObject* dataObject, bool& compositeFound, std::string& compositeName)
 {
-  vtkDataSet* ds = vtkDataSet::SafeDownCast(dataObject);
-  vtkCompositeDataSet* cd = vtkCompositeDataSet::SafeDownCast(dataObject);
-
-  // handle composite case
-  compositeFound = false;
-  if (cd)
+  auto cd = vtkCompositeDataSet::SafeDownCast(dataObject);
+  compositeFound = cd != nullptr;
+  if (!compositeFound)
   {
-    vtkCompositeDataIterator* it = cd->NewIterator();
-    it->SkipEmptyNodesOn();
-    it->InitTraversal();
-    while (!it->IsDoneWithTraversal())
-    {
-      ds = vtkDataSet::SafeDownCast(it->GetCurrentDataObject());
-      if (ds)
-      {
-        compositeFound = true;
-        std::stringstream ssname;
-        ssname << it->GetCurrentFlatIndex() - 1;
-        const char* name = it->GetCurrentMetaData()->Get(vtkCompositeDataSet::NAME());
-        if (name)
-        {
-          ssname << ": " << name;
-        }
-        compositeName = ssname.str();
-        break;
-      }
-      it->GoToNextItem();
-    }
-    it->Delete();
-    if (!compositeFound)
-    {
-      return NULL;
-    }
+    return vtkDataSet::SafeDownCast(dataObject);
   }
-  return ds;
+
+  vtkPVDataUtilities::AssignNamesToBlocks(cd);
+  auto datasets = vtkCompositeDataSet::GetDataSets(cd);
+  if (!datasets.empty())
+  {
+    auto ds = datasets.front();
+    compositeName = vtkPVDataUtilities::GetAssignedNameForBlock(ds);
+    return ds;
+  }
+
+  return nullptr;
 }
