@@ -32,13 +32,13 @@ vtkStandardNewMacro(vtkSIWriterProxy);
 //----------------------------------------------------------------------------
 vtkSIWriterProxy::vtkSIWriterProxy()
 {
-  this->FileNameMethod = NULL;
+  this->FileNameMethod = nullptr;
 }
 
 //----------------------------------------------------------------------------
 vtkSIWriterProxy::~vtkSIWriterProxy()
 {
-  this->SetFileNameMethod(NULL);
+  this->SetFileNameMethod(nullptr);
 }
 
 //----------------------------------------------------------------------------
@@ -132,6 +132,10 @@ void vtkSIWriterProxy::AddInput(int input_port, vtkAlgorithmOutput* connection,
   {
     pipeline.push_back(vtkAlgorithm::SafeDownCast(passArrays->GetVTKObject()));
   }
+  else if (auto selectExtract = this->GetSubSIProxy("SelectArraysExtractBlocks"))
+  {
+    pipeline.push_back(vtkAlgorithm::SafeDownCast(selectExtract->GetVTKObject()));
+  }
   if (auto completeArrays = this->GetSubSIProxy("CompleteArrays"))
   {
     pipeline.push_back(vtkAlgorithm::SafeDownCast(completeArrays->GetVTKObject()));
@@ -142,7 +146,7 @@ void vtkSIWriterProxy::AddInput(int input_port, vtkAlgorithmOutput* connection,
     pipeline.back()->SetInputConnection(pipeline.front()->GetOutputPort());
   }
 
-  if (pipeline.size() > 0)
+  if (!pipeline.empty())
   {
     pipeline.front()->SetInputConnection(connection);
     this->Superclass::AddInput(input_port, pipeline.back()->GetOutputPort(), method);
@@ -161,12 +165,16 @@ void vtkSIWriterProxy::CleanInputs(const char* method)
   {
     pipeline.push_back(vtkAlgorithm::SafeDownCast(passArrays->GetVTKObject()));
   }
+  else if (auto selectExtract = this->GetSubSIProxy("SelectArraysExtractBlocks"))
+  {
+    pipeline.push_back(vtkAlgorithm::SafeDownCast(selectExtract->GetVTKObject()));
+  }
   if (auto completeArrays = this->GetSubSIProxy("CompleteArrays"))
   {
     pipeline.push_back(vtkAlgorithm::SafeDownCast(completeArrays->GetVTKObject()));
   }
 
-  if (pipeline.size() > 0)
+  if (!pipeline.empty())
   {
     pipeline.front()->SetInputConnection(nullptr);
     pipeline.back()->SetInputConnection(nullptr);
