@@ -266,6 +266,7 @@ public:
   std::map<int, vtkSMMessage> LocalCameraStateCache;
   unsigned long ObserverTag;
   bool DisableFurtherConnections;
+  std::string LastReceivedMessage;
 };
 //****************************************************************************
 vtkStandardNewMacro(vtkSMCollaborationManager);
@@ -286,7 +287,7 @@ vtkSMCollaborationManager::vtkSMCollaborationManager()
 vtkSMCollaborationManager::~vtkSMCollaborationManager()
 {
   delete this->Internal;
-  this->Internal = NULL;
+  this->Internal = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -320,6 +321,11 @@ void vtkSMCollaborationManager::LoadState(
     // For Observers
     vtkSMMessage* msgCopy = new vtkSMMessage();
     msgCopy->CopyFrom(*msg);
+    if (msg->HasExtension(ChatMessage::txt))
+    {
+      this->Internal->LastReceivedMessage = msg->GetExtension(ChatMessage::txt);
+      this->InvokeEvent(LastMessageUpdated, msgCopy);
+    }
     this->InvokeEvent(CollaborationNotification, msgCopy);
   }
 }
@@ -468,7 +474,7 @@ void vtkSMCollaborationManager::UpdateUserInformations()
     vtkSMMessage msg;
     msg.CopyFrom(*this->GetFullState());
     this->PullState(&msg);
-    this->LoadState(&msg, NULL);
+    this->LoadState(&msg, nullptr);
   }
 }
 
@@ -491,3 +497,9 @@ void vtkSMCollaborationManager::SetSession(vtkSMSession* session)
   this->Superclass::SetSession(session);
   this->Internal->Init();
 }
+
+//----------------------------------------------------------------------------
+const char* vtkSMCollaborationManager::GetLastReceivedMessage() const
+{
+  return this->Internal->LastReceivedMessage.c_str();
+}
