@@ -27,6 +27,8 @@
 
 #include "vtkSMProxy.h"
 
+#include <deque> // for std::deque
+
 class vtkSMExtractsController;
 
 class VTKREMOTINGSERVERMANAGER_EXPORT vtkSMExtractTriggerProxy : public vtkSMProxy
@@ -43,11 +45,21 @@ public:
 
 protected:
   vtkSMExtractTriggerProxy();
-  ~vtkSMExtractTriggerProxy();
+  ~vtkSMExtractTriggerProxy() override;
 
 private:
   vtkSMExtractTriggerProxy(const vtkSMExtractTriggerProxy&) = delete;
   void operator=(const vtkSMExtractTriggerProxy&) = delete;
+
+  /**
+   * Queue of time values that we keep for the TimeValue trigger to keep
+   * track of the most recent time values to determine if we should
+   * output at this time step or not, based on whether or not we think
+   * we're closest to the next instance we should output.
+   */
+  std::deque<double> TimeStepLengths;
+  double LastTimeValue;
+  double LastOutputTimeValue;
 };
 
 #endif
