@@ -19,7 +19,6 @@
 #include "vtkObjectFactory.h"
 #include "vtkPVProxyDefinitionIterator.h"
 #include "vtkPVXMLElement.h"
-#include "vtkPVXMLElement.h"
 #include "vtkSMPropertyHelper.h"
 #include "vtkSMProxy.h"
 #include "vtkSMProxyDefinitionManager.h"
@@ -78,7 +77,7 @@ public:
   {
     vtkSMProxy* plproxy = this->Proxy;
     vtkPVXMLElement* proxyListElement =
-      plproxy->GetHints() ? plproxy->GetHints()->FindNestedElementByName("ProxyList") : NULL;
+      plproxy->GetHints() ? plproxy->GetHints()->FindNestedElementByName("ProxyList") : nullptr;
     if (!proxyListElement)
     {
       return;
@@ -120,9 +119,10 @@ public:
         vtkSMProxy* src_subproxy = parent->GetSubProxy(name);
         if (!src_subproxy)
         {
-          vtkErrorWithObjectMacro(parent, "Subproxy "
-              << name << " must be defined before "
-                         "its properties can be shared with another subproxy.");
+          vtkErrorWithObjectMacro(parent,
+            "Subproxy " << name
+                        << " must be defined before its properties can be "
+                           "shared with another subproxy.");
           continue;
         }
         vtkNew<vtkSMProxyLink> sharingLink;
@@ -174,7 +174,7 @@ public:
     vtkSMProxyInfo info;
     info.Proxy = proxy;
 
-    vtkSMProxy* parent = self->GetProperty() ? self->GetProperty()->GetParent() : NULL;
+    vtkSMProxy* parent = self->GetProperty() ? self->GetProperty()->GetParent() : nullptr;
     if (parent)
     {
       // Handle proxy-list hints.
@@ -237,7 +237,6 @@ public:
 
   ~vtkSMProxyListDomainInternals() { this->ClearProxies(); }
 
-public:
   std::vector<vtkSMProxyListDomain::ProxyType> ProxyTypeList;
 
 private:
@@ -269,12 +268,25 @@ const std::vector<vtkSMProxyListDomain::ProxyType>& vtkSMProxyListDomain::GetPro
 void vtkSMProxyListDomain::CreateProxies(vtkSMSessionProxyManager* pxm)
 {
   assert(pxm);
+
+  // Custom filters using proxy list domains
+  // Rely on putting the user set proxy in first position
+  // so this is needed to override the default index from the domain
+  // in that case.
+  if (this->GetNumberOfProxies() == 1)
+  {
+    this->SetDefaultIndex(0);
+  }
   for (const auto& apair : this->Internals->ProxyTypeList)
   {
-    if (vtkSMProxy* proxy = pxm->NewProxy(apair.GroupName.c_str(), apair.ProxyName.c_str()))
+    // Make sure there isn't two proxies with the same name in the domain
+    if (!this->GetProxyWithName(apair.ProxyName.c_str()))
     {
-      this->Internals->AddProxy(proxy, this);
-      proxy->FastDelete();
+      if (vtkSMProxy* proxy = pxm->NewProxy(apair.GroupName.c_str(), apair.ProxyName.c_str()))
+      {
+        this->Internals->AddProxy(proxy, this);
+        proxy->FastDelete();
+      }
     }
   }
 }
@@ -303,7 +315,7 @@ const char* vtkSMProxyListDomain::GetProxyGroup(unsigned int cc)
   if (this->GetNumberOfProxyTypes() <= cc)
   {
     vtkErrorMacro("Invalid index " << cc);
-    return NULL;
+    return nullptr;
   }
 
   return this->Internals->ProxyTypeList[cc].GroupName.c_str();
@@ -315,7 +327,7 @@ const char* vtkSMProxyListDomain::GetProxyName(unsigned int cc)
   if (this->GetNumberOfProxyTypes() <= cc)
   {
     vtkErrorMacro("Invalid index " << cc);
-    return NULL;
+    return nullptr;
   }
 
   return this->Internals->ProxyTypeList[cc].ProxyName.c_str();
@@ -324,7 +336,7 @@ const char* vtkSMProxyListDomain::GetProxyName(unsigned int cc)
 //-----------------------------------------------------------------------------
 const char* vtkSMProxyListDomain::GetProxyName(vtkSMProxy* proxy)
 {
-  return proxy ? proxy->GetXMLName() : NULL;
+  return proxy ? proxy->GetXMLName() : nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -332,7 +344,7 @@ vtkSMProxy* vtkSMProxyListDomain::GetProxyWithName(const char* pname)
 {
   vtkSMProxyListDomainInternals::VectorOfProxies::const_iterator iter;
   const vtkSMProxyListDomainInternals::VectorOfProxies& proxies = this->Internals->GetProxies();
-  for (iter = proxies.begin(); pname != NULL && iter != proxies.end(); iter++)
+  for (iter = proxies.begin(); pname != nullptr && iter != proxies.end(); iter++)
   {
     if (iter->Proxy && iter->Proxy->GetXMLName() && strcmp(iter->Proxy->GetXMLName(), pname) == 0)
     {
@@ -340,7 +352,7 @@ vtkSMProxy* vtkSMProxyListDomain::GetProxyWithName(const char* pname)
     }
   }
 
-  return NULL;
+  return nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -351,7 +363,7 @@ int vtkSMProxyListDomain::SetDefaultValues(vtkSMProperty* prop, bool use_uncheck
   {
     vtkSMPropertyHelper helper(prop);
     helper.SetUseUnchecked(use_unchecked_values);
-    vtkSMProxy* values[1] = { this->GetProxy(0) };
+    vtkSMProxy* values[1] = { this->GetProxy(this->GetDefaultIndex()) };
     helper.Set(values, 1);
     return 1;
   }
@@ -383,9 +395,10 @@ int vtkSMProxyListDomain::ReadXMLAttributes(vtkSMProperty* prop, vtkPVXMLElement
     else if (strcmp(proxyElement->GetName(), "Group") == 0)
     {
       // Recover group name
-      const char* name = proxyElement->GetAttribute("name");
+      const char* groupName = proxyElement->GetAttribute("name");
+      const char* defaultProxyName = proxyElement->GetAttributeOrEmpty("default");
 
-      if (name)
+      if (groupName)
       {
         // Browse group and recover each proxy type
         vtkSMSessionProxyManager* pxm = this->GetSessionProxyManager();
@@ -398,10 +411,17 @@ int vtkSMProxyListDomain::ReadXMLAttributes(vtkSMProperty* prop, vtkPVXMLElement
         }
         else
         {
-          vtkPVProxyDefinitionIterator* iter = pxdm->NewSingleGroupIterator(name);
+          unsigned int index = 0;
+          vtkPVProxyDefinitionIterator* iter = pxdm->NewSingleGroupIterator(groupName);
           for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
           {
-            this->AddProxy(name, iter->GetProxyName());
+            const char* proxyName = iter->GetProxyName();
+            this->AddProxy(groupName, proxyName);
+            if (defaultProxyName && (strcmp(proxyName, defaultProxyName) == 0))
+            {
+              this->SetDefaultIndex(index);
+            }
+            index++;
           }
           iter->Delete();
         }
@@ -446,7 +466,7 @@ vtkSMProxy* vtkSMProxyListDomain::GetProxy(unsigned int index)
   if (index >= proxies.size())
   {
     vtkErrorMacro("Index " << index << " greater than max " << proxies.size());
-    return 0;
+    return nullptr;
   }
   return this->Internals->GetProxies()[index].Proxy;
 }
@@ -456,7 +476,8 @@ vtkSMProxy* vtkSMProxyListDomain::FindProxy(const char* xmlgroup, const char* xm
 {
   vtkSMProxyListDomainInternals::VectorOfProxies::const_iterator iter;
   const vtkSMProxyListDomainInternals::VectorOfProxies& proxies = this->Internals->GetProxies();
-  for (iter = proxies.begin(); xmlgroup != NULL && xmlname != NULL && iter != proxies.end(); iter++)
+  for (iter = proxies.begin(); xmlgroup != nullptr && xmlname != nullptr && iter != proxies.end();
+       iter++)
   {
     if (iter->Proxy && iter->Proxy->GetXMLGroup() && iter->Proxy->GetXMLName() &&
       strcmp(iter->Proxy->GetXMLGroup(), xmlgroup) == 0 &&
@@ -465,7 +486,7 @@ vtkSMProxy* vtkSMProxyListDomain::FindProxy(const char* xmlgroup, const char* xm
       return iter->Proxy;
     }
   }
-  return NULL;
+  return nullptr;
 }
 
 //-----------------------------------------------------------------------------
