@@ -27,6 +27,7 @@
 #include "vtkSMProxyManager.h"
 #include "vtkSMSession.h"
 #include "vtkSMSessionProxyManager.h"
+#include "vtkSMSettings.h"
 #include "vtkSMSourceProxy.h"
 #include "vtkSmartPointer.h"
 #include "vtkStringList.h"
@@ -41,6 +42,9 @@
 #include <vtksys/RegularExpression.hxx>
 #include <vtksys/SystemTools.hxx>
 
+const std::string vtkSMReaderFactory::SUPPORTED_TYPES_DESCRIPTION = "Supported Types";
+const std::string vtkSMReaderFactory::ALL_FILES_DESCRIPTION = "All Files";
+
 static void string_replace(std::string& string, char c, std::string str)
 {
   size_t cc = string.find(c);
@@ -230,7 +234,7 @@ bool vtkSMReaderFactory::vtkInternals::vtkValue::ExtensionTest(
     {
       for (auto& ext : extensions)
       {
-        if (ext == hint_ext)
+        if (vtksys::SystemTools::Strucmp(ext.c_str(), hint_ext.c_str()) == 0)
         {
           return true;
         }
@@ -530,7 +534,7 @@ static std::string vtkJoin(
 const char* vtkSMReaderFactory::GetSupportedFileTypes(vtkSMSession* session)
 {
   std::ostringstream all_types;
-  all_types << "Supported Files (";
+  all_types << vtkSMReaderFactory::SUPPORTED_TYPES_DESCRIPTION << " (";
 
   auto case_insensitive_comp = [](const std::string& s1, const std::string& s2) {
     return vtksys::SystemTools::Strucmp(s1.c_str(), s2.c_str()) < 0;
@@ -583,6 +587,73 @@ const char* vtkSMReaderFactory::GetSupportedFileTypes(vtkSMSession* session)
   return this->Internals->SupportedFileTypes.c_str();
 }
 
+//----------------------------------------------------------------------------
+std::vector<FileTypeDetailed> vtkSMReaderFactory::GetSupportedFileTypesDetailed(
+  vtkSMSession* session)
+{
+  std::vector<FileTypeDetailed> result;
+  FileTypeDetailed supportedFiles;
+  supportedFiles.Description = vtkSMReaderFactory::SUPPORTED_TYPES_DESCRIPTION;
+
+  for (auto& proto : this->Internals->Prototypes)
+  {
+    if (proto.second.CanCreatePrototype(session))
+    {
+      proto.second.FillInformation(session);
+      std::string const& group = proto.second.Group;
+      std::string const& name = proto.second.Name;
+      for (auto& hint : proto.second.FileEntryHints)
+      {
+        FileTypeDetailed currentFileType;
+        for (auto const& ext : hint.Extensions)
+        {
+          currentFileType.FilenamePatterns.push_back("*." + ext);
+        }
+
+        for (auto const& pattern : hint.FilenamePatterns)
+        {
+          currentFileType.FilenamePatterns.push_back(pattern);
+        }
+
+        if (currentFileType.FilenamePatterns.empty())
+        {
+          continue;
+        }
+
+        currentFileType.Description = hint.Description;
+        std::copy(currentFileType.FilenamePatterns.begin(), currentFileType.FilenamePatterns.end(),
+          std::back_inserter(supportedFiles.FilenamePatterns));
+        currentFileType.Name = name;
+        currentFileType.Group = group;
+        result.push_back(std::move(currentFileType));
+      }
+    }
+  }
+
+  // Add custom patterns to supported files
+  auto* settings = vtkSMSettings::GetInstance();
+  char const* settingName = ".settings.RepresentedArrayListSettings.ReaderDetails";
+  unsigned int const numberOfEntries = settings->GetSettingNumberOfElements(settingName) / 3;
+  for (unsigned int entryIndex = 0; entryIndex < numberOfEntries; ++entryIndex)
+  {
+    std::string const patternsString =
+      settings->GetSettingAsString(settingName, entryIndex * 3, "");
+    vtksys::SystemTools::Split(patternsString, supportedFiles.FilenamePatterns, ' ');
+  }
+
+  std::sort(
+    result.begin(), result.end(), [](FileTypeDetailed const& lhs, FileTypeDetailed const& rhs) {
+      return vtksys::SystemTools::Strucmp(lhs.Description.c_str(), rhs.Description.c_str()) < 0;
+    });
+
+  FileTypeDetailed allFiles;
+  allFiles.Description = vtkSMReaderFactory::ALL_FILES_DESCRIPTION;
+  allFiles.FilenamePatterns = { "*" };
+  result.insert(result.begin(), { supportedFiles, allFiles });
+
+  return result;
+}
+
 //----------------------------------------------------------------------------
 bool vtkSMReaderFactory::TestFileReadability(const char* filename, vtkSMSession* session)
 {
