@@ -17,6 +17,7 @@
 // Don't include vtkAxis. Cannot add dependency on vtkChartsCore in
 // vtkPVServerManagerCore.
 // #include "vtkAxis.h"
+#include "vtkLogger.h"
 #include "vtkMath.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
@@ -25,13 +26,14 @@
 #include "vtkSMPropertyHelper.h"
 #include "vtkSMSession.h"
 #include "vtkSMSessionProxyManager.h"
+#include "vtkSelectionNode.h"
 #include "vtkWeakPointer.h"
 
 #include <algorithm>
 #include <set>
 #include <sstream>
-#include <sstream>
 #include <string>
+#include <tuple>
 #include <vector>
 #include <vtk_pugixml.h>
 
@@ -244,18 +246,7 @@ struct Process_5_4_to_5_5
       }
       else
       {
-        if (this->Session)
-        {
-          vtkSMSessionProxyManager* pxm = this->Session->GetSessionProxyManager();
-          vtkSMProxy* settingsProxy = pxm->GetProxy("settings", "GeneralSettings");
-          int globalResetMode =
-            vtkSMPropertyHelper(settingsProxy, "TransferFunctionResetMode").GetAsInt();
-          element.attribute("value").set_value(toString(globalResetMode).c_str());
-        }
-        else
-        {
-          vtkGenericWarningMacro("Could not get TransferFunctionResetMode from settings.");
-        }
+        element.attribute("value").set_value('0');
       }
     }
 
@@ -398,7 +389,7 @@ struct Process_5_4_to_5_5
       blocksNode.append_attribute("number_of_elements")
         .set_value(static_cast<int>(selectedPaths.size() * 2));
       int index = 0;
-      for (const auto spath : selectedPaths)
+      for (const auto& spath : selectedPaths)
       {
         auto eNode = blocksNode.append_child("Element");
         eNode.append_attribute("index").set_value(index++);
@@ -413,7 +404,7 @@ struct Process_5_4_to_5_5
   }
 
   /** Translate the fixed single headlight into a configurable light with the same properties
-  */
+   */
   bool HeadlightToAdditionalLight(xml_document& document)
   {
     UniqueIdGenerator generator(document);
@@ -602,47 +593,6 @@ struct Process_5_4_to_5_5
   vtkWeakPointer<vtkSMSession> Session;
 };
 
-//===========================================================================
-struct Process_5_5_to_5_6
-{
-  bool operator()(xml_document& document) { return ConvertGlyphFilter(document); }
-
-  static bool ConvertGlyphFilter(xml_document& document)
-  {
-    bool warn = false;
-    //-------------------------------------------------------------------------
-    // Convert "Glyph" to "GlyphLegacy" and "GlyphWithCustomSource" to
-    // "GlyphWithCustomSourceLegacy". We don't explicitly convert those filters to the
-    // new ones, we just create the old proxies for now.
-    //-------------------------------------------------------------------------
-    pugi::xpath_node_set glyph_elements =
-      document.select_nodes("//ServerManagerState/Proxy[@group='filters' and @type='Glyph']");
-    for (pugi::xpath_node_set::const_iterator iter = glyph_elements.begin();
-         iter != glyph_elements.end(); ++iter)
-    {
-      iter->node().attribute("type").set_value("GlyphLegacy");
-      warn = true;
-    }
-    glyph_elements = document.select_nodes(
-      "//ServerManagerState/Proxy[@group='filters' and @type='GlyphWithCustomSource']");
-    for (pugi::xpath_node_set::const_iterator iter = glyph_elements.begin();
-         iter != glyph_elements.end(); ++iter)
-    {
-      iter->node().attribute("type").set_value("GlyphWithCustomSourceLegacy");
-      warn = true;
-    }
-    if (warn)
-    {
-      vtkGenericWarningMacro(
-        "The state file uses the old 'Glyph' filter implementation. "
-        "The implementation has changed in ParaView 5.6. "
-        "Consider replacing the Glyph filter with a new Glyph filter. The old implementation "
-        "is still available as 'Glyph Legacy' and will be used for loading this state file.");
-    }
-    return true;
-  }
-};
-
 //===========================================================================
 struct Process_5_6_to_5_7
 {
@@ -799,7 +749,7 @@ struct Process_5_7_to_5_8
   {
     pugi::xpath_node_set elements =
       document.select_nodes("//ServerManagerState/Links/GlobalPropertyLink");
-    if (elements.size() == 0)
+    if (elements.empty())
     {
       return true;
     }
@@ -836,7 +786,7 @@ struct Process_5_8_to_5_9
     pugi::xpath_node_set elements =
       document.select_nodes("//ServerManagerState/Proxy[@group='sources' and "
                             "(@type='CGNSSeriesReader')]");
-    if (elements.size() == 0)
+    if (elements.empty())
     {
       return true;
     }
@@ -852,18 +802,668 @@ struct Process_5_8_to_5_9
   }
 };
 
+//===========================================================================
+struct Process_5_9_to_5_10
+{
+  bool operator()(xml_document& document)
+  {
+    return HandleSpreadsheetRepresentationCompositeDataSetIndex(document) &&
+      HandleExtractBlock(document) && HandleRepresentationBlockVisibility(document) &&
+      HandleRepresentationBlockColor(document) && HandleRepresentationBlockOpacity(document) &&
+      HandleSelectionQuerySource(document) && ConvertProbeLine(document) &&
+      HandleBackgroundColor(document) && HandleCalculatorParserType(document) &&
+      ConvertThreshold(document) && HandleGradient(document);
+  }
+
+  static std::string GetSelector(unsigned int cid)
+  {
+    return std::string("//*[@cid='") + std::to_string(cid) + "']";
+    ;
+  }
+
+  static void ConvertCompositeIdsToSelectors(pugi::xml_node& node)
+  {
+    for (auto child : node.children("Element"))
+    {
+      auto value_attribute = child.attribute("value");
+      value_attribute.set_value(GetSelector(value_attribute.as_uint()).c_str());
+    }
+  }
+
+  static bool HandleSpreadsheetRepresentationCompositeDataSetIndex(xml_document& document)
+  {
+    auto xpath_set = document.select_nodes(
+      "//ServerManagerState/Proxy[@group='representations' and "
+      "@type='SpreadSheetRepresentation']/Property[@name='CompositeDataSetIndex']");
+    for (auto xpath_node : xpath_set)
+    {
+      // convert CompositeDataSetIndex to "BlockVisibilities".
+      auto node = xpath_node.node();
+      node.attribute("name").set_value("BlockVisibilities");
+      ConvertCompositeIdsToSelectors(node);
+    }
+
+    return true;
+  }
+
+  static bool HandleExtractBlock(xml_document& document)
+  {
+    auto xpath_set = document.select_nodes("//ServerManagerState/Proxy[@group='filters' and "
+                                           "@type='ExtractBlock']/Property[@name='BlockIndices']");
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+      node.attribute("name").set_value("Selectors");
+      ConvertCompositeIdsToSelectors(node);
+    }
+    return true;
+  }
+
+  static bool HandleRepresentationBlockVisibility(xml_document& document)
+  {
+    bool warn_about_hidden_blocks = false;
+    auto xpath_set = document.select_nodes("//ServerManagerState/Proxy[@group='representations']/"
+                                           "Property[@name='BlockVisibility']");
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+      const int numElements = node.attribute("number_of_elements").as_int();
+      if (numElements == 0)
+      {
+        // if no overrides were specified, simply remove the property.
+        node.parent().remove_child(node);
+        continue;
+      }
+
+      node.attribute("name").set_value("BlockSelectors");
+
+      std::vector<std::pair<unsigned int, bool>> visibilities(numElements / 2);
+      for (auto child : node.children("Element"))
+      {
+        const int index = child.attribute("index").as_int();
+        auto& pair = visibilities.at(index / 2);
+        if (index % 2 == 0)
+        {
+          pair.first = child.attribute("value").as_uint();
+        }
+        else
+        {
+          pair.second = (child.attribute("value").as_int() == 1);
+        }
+      }
+
+      while (auto child = node.child("Element"))
+      {
+        node.remove_child(child);
+      }
+
+      // convert to selectors.
+      int index = 0;
+      for (auto& pair : visibilities)
+      {
+        if (pair.second)
+        {
+          auto child = node.append_child("Element");
+          child.append_attribute("index").set_value(index++);
+          child.append_attribute("value").set_value(GetSelector(pair.first).c_str());
+        }
+        else
+        {
+          warn_about_hidden_blocks = true;
+        }
+      }
+      node.attribute("number_of_elements").set_value(index);
+    }
+
+    if (warn_about_hidden_blocks)
+    {
+      vtkGenericWarningMacro("The state have blocks that were hidden explicitly. "
+                             "Due to changes in the way block visibilities are specified, this may "
+                             "not get loaded correctly.");
+    }
+    return true;
+  }
+
+  static bool HandleRepresentationBlockColor(xml_document& document)
+  {
+    auto xpath_set = document.select_nodes("//ServerManagerState/Proxy[@group='representations']/"
+                                           "Property[@name='BlockColor']");
+    for (auto xpath_node : xpath_set)
+    {
+      std::vector<std::tuple<unsigned int, double, double, double>> colors;
+
+      auto node = xpath_node.node();
+      node.attribute("name").set_value("BlockColors");
+      // not is the weird map property, so the XML is strange looking.
+      for (auto element : node.children("Element"))
+      {
+        const unsigned int id = element.attribute("index").as_uint();
+        double rgb[3];
+        int index = 0;
+        for (auto value : element.children("Value"))
+        {
+          assert(index < 3);
+          rgb[index++] = value.attribute("value").as_double();
+        }
+        colors.emplace_back(id, rgb[0], rgb[1], rgb[2]);
+      }
+
+      while (auto child = node.child("Element"))
+      {
+        node.remove_child(child);
+      }
+
+      int index = 0;
+      for (const auto& tuple : colors)
+      {
+        auto child = node.append_child("Element");
+        child.append_attribute("index").set_value(index++);
+        child.append_attribute("value").set_value(GetSelector(std::get<0>(tuple)).c_str());
+
+        child = node.append_child("Element");
+        child.append_attribute("index").set_value(index++);
+        child.append_attribute("value").set_value(std::get<1>(tuple));
+
+        child = node.append_child("Element");
+        child.append_attribute("index").set_value(index++);
+        child.append_attribute("value").set_value(std::get<2>(tuple));
+
+        child = node.append_child("Element");
+        child.append_attribute("index").set_value(index++);
+        child.append_attribute("value").set_value(std::get<3>(tuple));
+      }
+      node.attribute("number_of_elements").set_value(index);
+    }
+    return true;
+  }
+
+  static bool HandleRepresentationBlockOpacity(xml_document& document)
+  {
+    auto xpath_set = document.select_nodes("//ServerManagerState/Proxy[@group='representations']/"
+                                           "Property[@name='BlockOpacity']");
+    for (auto xpath_node : xpath_set)
+    {
+      std::vector<std::tuple<unsigned int, double>> opacities;
+
+      auto node = xpath_node.node();
+      node.attribute("name").set_value("BlockOpacities");
+      // not is the weird map property, so the XML is strange looking.
+      for (auto element : node.children("Element"))
+      {
+        const unsigned int id = element.attribute("index").as_uint();
+        const double alpha = element.child("Value").attribute("value").as_double();
+        opacities.emplace_back(id, alpha);
+      }
+
+      while (auto child = node.child("Element"))
+      {
+        node.remove_child(child);
+      }
+
+      int index = 0;
+      for (const auto& tuple : opacities)
+      {
+        auto child = node.append_child("Element");
+        child.append_attribute("index").set_value(index++);
+        child.append_attribute("value").set_value(GetSelector(std::get<0>(tuple)).c_str());
+
+        child = node.append_child("Element");
+        child.append_attribute("index").set_value(index++);
+        child.append_attribute("value").set_value(std::get<1>(tuple));
+      }
+      node.attribute("number_of_elements").set_value(index);
+    }
+    return true;
+  }
+
+  static bool HandleSelectionQuerySource(xml_document& document)
+  {
+    // convert CompositeIndex to Selectors
+    auto xpath_set = document.select_nodes(
+      "//ServerManagerState/Proxy[@group='sources' and @type='SelectionQuerySource']/"
+      "Property[@name='CompositeIndex']");
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+      node.attribute("name").set_value("Selectors");
+      ConvertCompositeIdsToSelectors(node);
+    }
+
+    // convert FieldType to ElementType.
+    xpath_set = document.select_nodes(
+      "//ServerManagerState/Proxy[@group='sources' and @type='SelectionQuerySource']/"
+      "Property[@name='FieldType']");
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+      node.attribute("name").set_value("ElementType");
+      auto value = node.child("Element").attribute("value");
+      value.set_value(vtkSelectionNode::ConvertSelectionFieldToAttributeType(value.as_int()));
+    }
+
+    return true;
+  }
+
+  static bool ConvertProbeLine(xml_document& document)
+  {
+    bool warn = false;
+
+    pugi::xpath_node_set xpath_set =
+      document.select_nodes("//ServerManagerState/Proxy[@group='filters' and @type='ProbeLine']");
+    for (auto& element : xpath_set)
+    {
+      bool downgrade = true;
+
+      for (auto property : element.node().children("Property"))
+      {
+        if (strcmp(property.attribute("name").as_string(), "Point1") == 0)
+        {
+          downgrade = false;
+          break;
+        }
+      }
+
+      if (downgrade)
+      {
+        element.node().attribute("type").set_value("ProbeLineLegacy");
+        warn = true;
+      }
+    }
+
+    if (warn)
+    {
+      vtkGenericWarningMacro(
+        "The state file uses the old 'ProbeLine' filter implementation. "
+        "The implementation has changed in ParaView 5.10. "
+        "Consider replacing the Probe line filter with a new Probe line filter. The old "
+        "implementation "
+        "is still available as 'Probe Line Legacy' and will be used for loading this state file.");
+    }
+    return true;
+  }
+
+  static bool HandleBackgroundColor(xml_document& document)
+  {
+    // We added a single BackgroundColorMode property that combined multiple
+    // properties that potentially conflicted causing issues.
+    auto views = document.select_nodes("//ServerManagerState/Proxy[@group='views']");
+    for (const auto& item : views)
+    {
+      auto node = item.node();
+      auto useGradienBackground =
+        node.select_node("//Property[@name='UseGradientBackground']/Element[@index='0']").node();
+      auto useTexturedBackground =
+        node.select_node("//Property[@name='UseTexturedBackground']/Element[@index='0']").node();
+      auto useSkyboxBackground =
+        node.select_node("//Property[@name='UseSkyboxBackground']/Element[@index='0']").node();
+
+      if (!useGradienBackground && !useTexturedBackground && !useSkyboxBackground)
+      {
+        continue;
+      }
+
+      int mode = 0; // vtkPVRenderView::DEFAULT;
+      if (useSkyboxBackground.attribute("value").as_int(0) == 1)
+      {
+        mode = 3; // vtkPVRenderView::SKYBOX;
+      }
+      else if (useTexturedBackground.attribute("value").as_int(0) == 1)
+      {
+        mode = 2; // vtkPVRenderView::IMAGE;
+      }
+      else if (useGradienBackground.attribute("value").as_int(0) == 1)
+      {
+        mode = 1; // vtkPVRenderView::GRADIENT;
+      }
+
+      const std::string id(node.attribute("id").value());
+      auto backgroundColorMode = node.append_child("Property");
+      backgroundColorMode.append_attribute("name").set_value("BackgroundColorMode");
+      backgroundColorMode.append_attribute("number_of_elements").set_value(1);
+      backgroundColorMode.append_attribute("id").set_value((id + ".BackgroundColorMode").c_str());
+      auto elementNode = backgroundColorMode.append_child("Element");
+      elementNode.append_attribute("index").set_value(0);
+      elementNode.append_attribute("value").set_value(mode);
+
+      node.remove_child(useGradienBackground.parent());
+      node.remove_child(useTexturedBackground.parent());
+      node.remove_child(useSkyboxBackground.parent());
+
+      // in 5.10, we added a new property that affects if background colors
+      // specified on the view is respected at all. It's tricky to determine if
+      // the user did override background in state file. Hence, we treat them as
+      // overridden to respect background color in state.
+      auto useColorPaletteForBackground = node.append_child("Property");
+      useColorPaletteForBackground.append_attribute("name").set_value(
+        "UseColorPaletteForBackground");
+      useColorPaletteForBackground.append_attribute("number_of_elements").set_value(1);
+      useColorPaletteForBackground.append_attribute("id").set_value(
+        (id + ".UseColorPaletteForBackground").c_str());
+
+      elementNode = useColorPaletteForBackground.append_child("Element");
+      elementNode.append_attribute("index").set_value(0);
+      elementNode.append_attribute("value").set_value(0);
+    }
+
+    return true;
+  }
+
+  static bool HandleCalculatorParserType(xml_document& document)
+  {
+    // ParaView 5.10's Calculator has a new function parser that differs
+    // slightly in the syntax it supports that is enabled by default.
+    // For pre-5.10 state files, we switch back to the old function parser.
+
+    auto calculators = document.select_nodes("//ServerManagerState/Proxy[@group='filters'"
+                                             "and @type='Calculator']");
+
+    for (auto xnode : calculators)
+    {
+      auto proxyNode = xnode.node();
+      std::string idString(proxyNode.attribute("id").value());
+
+      // Insert FunctionParserTypeProperty XML
+      //<Property name="FunctionParserType" id="id.FunctionParserType" number_of_elements="1">
+      //  <Element index="0" value="0"/>
+      //</Property>
+      auto propertyNode = proxyNode.append_child("Property");
+      propertyNode.append_attribute("name").set_value("FunctionParserType");
+      std::string newIDString = idString + ".FunctionParserType";
+      propertyNode.append_attribute("id").set_value(newIDString.c_str());
+      propertyNode.append_attribute("number_of_elements").set_value("1");
+      auto elementNode = propertyNode.append_child("Element");
+      elementNode.append_attribute("index").set_value("0");
+      elementNode.append_attribute("value").set_value("0");
+    }
+
+    return true;
+  }
+
+  static bool ConvertThreshold(xml_document& document)
+  {
+    // The property ThresholdBetween of the Threshold filter has been removed
+    // and replaced with:
+    //   - Property LowerThreshold for the lower threshold value
+    //   - Property UpperThreshold for the upper threshold value
+    //   - Property ThresholdMethod for the thresholding function
+    auto fixup_threshold = [](pugi::xml_node node) {
+      if (!node.select_nodes("./Property[@name='ThresholdBetween']").empty())
+      {
+        const std::string id(node.attribute("id").value());
+
+        // Retrieve threshold values
+        auto elementNode =
+          node.select_node("./Property[@name='ThresholdBetween']/Element[@index='0']").node();
+        double lower = elementNode.attribute("value").as_double();
+
+        elementNode =
+          node.select_node("./Property[@name='ThresholdBetween']/Element[@index='1']").node();
+        double upper = elementNode.attribute("value").as_double();
+
+        // Remove ThresholdBetween node
+        node.remove_child("./Property[@name='ThresholdBetween']");
+
+        // Append LowerThreshold node with lower value
+        auto thresholdNode = node.append_child("Property");
+        thresholdNode.append_attribute("name").set_value("LowerThreshold");
+        thresholdNode.append_attribute("id").set_value((id + ".LowerThreshold").c_str());
+        thresholdNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = thresholdNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(lower);
+
+        // Append UpperThreshold node with upper value
+        thresholdNode = node.append_child("Property");
+        thresholdNode.append_attribute("name").set_value("UpperThreshold");
+        thresholdNode.append_attribute("id").set_value((id + ".UpperThreshold").c_str());
+        thresholdNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = thresholdNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(upper);
+
+        // Append ThresholdMethod node
+        thresholdNode = node.append_child("Property");
+        thresholdNode.append_attribute("name").set_value("ThresholdMethod");
+        thresholdNode.append_attribute("id").set_value((id + ".ThresholdMethod").c_str());
+        thresholdNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = thresholdNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(0);
+      }
+    };
+
+    pugi::xpath_node_set xpath_set =
+      document.select_nodes("//ServerManagerState/Proxy[@group='filters' and @type='Threshold']");
+    for (auto xpath_node : xpath_set)
+    {
+      fixup_threshold(xpath_node.node());
+    }
+
+    pugi::xpath_node_set xpath_set_vtkm = document.select_nodes(
+      "//ServerManagerState/Proxy[@group='filters' and @type='VTKmThreshold']");
+    for (auto xpath_node : xpath_set_vtkm)
+    {
+      fixup_threshold(xpath_node.node());
+    }
+
+    return true;
+  }
+
+  static bool HandleGradient(xml_document& document)
+  {
+    // The filters Gradient (for vtkImageData) and Gradient Of Unstructured DataSet
+    // (UnstructuredGradient) (for vtkDataSet) have been merged and replaced with a
+    // unique Gradient filter (for vtkDataSet). This new filter is based on the previous
+    // UnstructuredGradient, to which the functionality from the previous Gradient is added.
+
+    // Replace UnstructuredGradient filters by Gradient
+    pugi::xpath_node_set xpath_set = document.select_nodes(
+      "//ServerManagerState/Proxy[@group='filters' and @type='UnstructuredGradient']");
+
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+      const std::string id(node.attribute("id").value());
+
+      // Change filter type
+      node.attribute("type").set_value("Gradient");
+
+      // Insert BoundaryMethod property
+      auto propertyNode = node.append_child("Property");
+      propertyNode.append_attribute("name").set_value("BoundaryMethod");
+      propertyNode.append_attribute("id").set_value((id + ".BoundaryMethod").c_str());
+      propertyNode.append_attribute("number_of_elements").set_value(1);
+
+      auto elementNode = propertyNode.append_child("Element");
+      elementNode.append_attribute("index").set_value(0);
+      elementNode.append_attribute("value").set_value(1);
+
+      // Insert Dimensionality property
+      propertyNode = node.append_child("Property");
+      propertyNode.append_attribute("name").set_value("Dimensionality");
+      propertyNode.append_attribute("id").set_value((id + ".Dimensionality").c_str());
+      propertyNode.append_attribute("number_of_elements").set_value(1);
+
+      elementNode = propertyNode.append_child("Element");
+      elementNode.append_attribute("index").set_value(0);
+      elementNode.append_attribute("value").set_value(3);
+    }
+
+    // Update Gradient filters with new properties
+    xpath_set =
+      document.select_nodes("//ServerManagerState/Proxy[@group='filters' and @type='Gradient']");
+
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+
+      if (node.select_nodes("./Property[@name='BoundaryMethod']").empty())
+      {
+        const std::string id(node.attribute("id").value());
+
+        // Insert BoundaryMethod property
+        auto propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("BoundaryMethod");
+        propertyNode.append_attribute("id").set_value((id + ".BoundaryMethod").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        auto elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(0);
+
+        // Insert ComputeGradient property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ComputeGradient");
+        propertyNode.append_attribute("id").set_value((id + ".ComputeGradient").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(1);
+
+        // Insert ResultArrayName property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ResultArrayName");
+        propertyNode.append_attribute("id").set_value((id + ".ResultArrayName").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value("Gradient");
+
+        // Insert FasterApproximation property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("FasterApproximation");
+        propertyNode.append_attribute("id").set_value((id + ".FasterApproximation").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(0);
+
+        // Insert ComputeDivergence property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ComputeDivergence");
+        propertyNode.append_attribute("id").set_value((id + ".ComputeDivergence").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(0);
+
+        // Insert DivergenceArrayName property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("DivergenceArrayName");
+        propertyNode.append_attribute("id").set_value((id + ".DivergenceArrayName").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value("Divergence");
+
+        // Insert ComputeVorticity property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ComputeVorticity");
+        propertyNode.append_attribute("id").set_value((id + ".ComputeVorticity").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(0);
+
+        // Insert VorticityArrayName property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("VorticityArrayName");
+        propertyNode.append_attribute("id").set_value((id + ".VorticityArrayName").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value("Vorticity");
+
+        // Insert ComputeQCriterion property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ComputeQCriterion");
+        propertyNode.append_attribute("id").set_value((id + ".ComputeQCriterion").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(0);
+
+        // Insert QCriterionArrayName property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("QCriterionArrayName");
+        propertyNode.append_attribute("id").set_value((id + ".QCriterionArrayName").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value("Q Criterion");
+
+        // Insert ContributingCellOption property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ContributingCellOption");
+        propertyNode.append_attribute("id").set_value((id + ".ContributingCellOption").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(2);
+
+        // Insert ReplacementValueOption property
+        propertyNode = node.append_child("Property");
+        propertyNode.append_attribute("name").set_value("ReplacementValueOption");
+        propertyNode.append_attribute("id").set_value((id + ".ReplacementValueOption").c_str());
+        propertyNode.append_attribute("number_of_elements").set_value(1);
+
+        elementNode = propertyNode.append_child("Element");
+        elementNode.append_attribute("index").set_value(0);
+        elementNode.append_attribute("value").set_value(1);
+      }
+    }
+
+    return true;
+  }
+};
+
+struct Process_5_10_to_5_11
+{
+  bool operator()(xml_document& document) { return HandleDataSetSurfaceFilter(document); }
+
+  static bool HandleDataSetSurfaceFilter(xml_document& document)
+  {
+    pugi::xpath_node_set xpath_set = document.select_nodes(
+      "//ServerManagerState/Proxy[@group='filters' and @type='DataSetSurfaceFilter']");
+
+    for (auto xpath_node : xpath_set)
+    {
+      auto node = xpath_node.node();
+      for (auto child : node.children())
+      {
+        // remove UseGeometryFilter flag
+        if (std::string(child.attribute("name").as_string()) == "UseGeometryFilter")
+        {
+          node.remove_child(child);
+        }
+      }
+    }
+
+    return true;
+  }
+};
+
 } // end of namespace
 
 vtkStandardNewMacro(vtkSMStateVersionController);
 //----------------------------------------------------------------------------
-vtkSMStateVersionController::vtkSMStateVersionController()
-{
-}
+vtkSMStateVersionController::vtkSMStateVersionController() = default;
 
 //----------------------------------------------------------------------------
-vtkSMStateVersionController::~vtkSMStateVersionController()
-{
-}
+vtkSMStateVersionController::~vtkSMStateVersionController() = default;
 
 //----------------------------------------------------------------------------
 bool vtkSMStateVersionController::Process(vtkPVXMLElement* parent, vtkSMSession* session)
@@ -935,13 +1535,6 @@ bool vtkSMStateVersionController::Process(vtkPVXMLElement* parent, vtkSMSession*
     version = vtkSMVersion(5, 5, 0);
   }
 
-  if (status && (version < vtkSMVersion(5, 6, 0)))
-  {
-    Process_5_5_to_5_6 converter;
-    status = converter(document);
-    version = vtkSMVersion(5, 6, 0);
-  }
-
   if (status && (version < vtkSMVersion(5, 7, 0)))
   {
     Process_5_6_to_5_7 converter;
@@ -963,6 +1556,20 @@ bool vtkSMStateVersionController::Process(vtkPVXMLElement* parent, vtkSMSession*
     version = vtkSMVersion(5, 9, 0);
   }
 
+  if (status && (version < vtkSMVersion(5, 10, 0)))
+  {
+    Process_5_9_to_5_10 converter;
+    status = converter(document);
+    version = vtkSMVersion(5, 10, 0);
+  }
+
+  if (status && (version < vtkSMVersion(5, 11, 0)))
+  {
+    Process_5_10_to_5_11 converter;
+    status = converter(document);
+    version = vtkSMVersion(5, 11, 0);
+  }
+
   if (status)
   {
     std::ostringstream stream2;
