@@ -64,6 +64,7 @@ vtkSMTrace::vtkSMTrace()
   , PropertiesToTraceOnCreate(vtkSMTrace::RECORD_MODIFIED_PROPERTIES)
   , FullyTraceSupplementalProxies(false)
   , SkipRenderingComponents(false)
+  , FullyTraceCameraAdjustments(false)
   , Internals(new vtkSMTrace::vtkInternals())
 {
 #if VTK_MODULE_ENABLE_VTK_PythonInterpreter && VTK_MODULE_ENABLE_VTK_Python &&                     \
@@ -84,15 +85,15 @@ vtkSMTrace::vtkSMTrace()
     {
       vtkErrorMacro(
         "Failed to locate the _create_trace_item_internal function in paraview.smtrace module.");
-      this->Internals->TraceModule.TakeReference(NULL);
+      this->Internals->TraceModule.TakeReference(nullptr);
     }
     this->Internals->UntraceableException.TakeReference(
       PyObject_GetAttrString(this->Internals->TraceModule, "Untraceable"));
     if (!this->Internals->UntraceableException)
     {
       vtkErrorMacro("Failed to locate the Untraceable exception class in paraview.smtrace module.");
-      this->Internals->TraceModule.TakeReference(NULL);
-      this->Internals->CreateItemFunction.TakeReference(NULL);
+      this->Internals->TraceModule.TakeReference(nullptr);
+      this->Internals->CreateItemFunction.TakeReference(nullptr);
     }
   }
 #endif
@@ -102,13 +103,13 @@ vtkSMTrace::vtkSMTrace()
 vtkSMTrace::~vtkSMTrace()
 {
   delete this->Internals;
-  this->Internals = NULL;
+  this->Internals = nullptr;
 }
 
 //----------------------------------------------------------------------------
 std::string vtkSMTrace::GetState(vtkSMProxy* options)
 {
-  if (vtkSMTrace::ActiveTracer.GetPointer() != NULL)
+  if (vtkSMTrace::ActiveTracer.GetPointer() != nullptr)
   {
     vtkGenericWarningMacro("Tracing is active. Cannot save state.");
     return std::string();
@@ -154,7 +155,7 @@ std::string vtkSMTrace::GetState(vtkSMProxy* options)
 //----------------------------------------------------------------------------
 vtkSMTrace* vtkSMTrace::StartTrace(const char* preamble)
 {
-  if (vtkSMTrace::ActiveTracer.GetPointer() == NULL)
+  if (vtkSMTrace::ActiveTracer.GetPointer() == nullptr)
   {
     vtkSMTrace::ActiveTracer = vtkSmartPointer<vtkSMTrace>::New();
 #if VTK_MODULE_ENABLE_VTK_PythonInterpreter && VTK_MODULE_ENABLE_VTK_Python &&                     \
@@ -162,13 +163,17 @@ vtkSMTrace* vtkSMTrace::StartTrace(const char* preamble)
     if (!vtkSMTrace::ActiveTracer->Internals->TraceModule)
     {
       vtkGenericWarningMacro("Trace not started since required Python modules are missing.");
-      vtkSMTrace::ActiveTracer = NULL;
+      vtkSMTrace::ActiveTracer = nullptr;
     }
     else
     {
       vtkPythonScopeGilEnsurer gilEnsurer;
       std::ostringstream str;
       str << "# trace generated using " << vtkSMProxyManager::GetParaViewSourceVersion() << "\n";
+      str << "#import paraview\n";
+      str << "#paraview.compatibility.major = " << vtkSMProxyManager::GetVersionMajor() << "\n";
+      str << "#paraview.compatibility.minor = " << vtkSMProxyManager::GetVersionMinor() << "\n";
+
       vtkSmartPyObject _start_trace_internal(PyObject_CallMethod(
         vtkSMTrace::ActiveTracer->GetTraceModule(), const_cast<char*>("_start_trace_internal"),
         const_cast<char*>("(s)"), const_cast<char*>(preamble ? preamble : str.str().c_str())));
@@ -238,7 +243,7 @@ std::string vtkSMTrace::GetCurrentTrace()
   vtkSMTrace* active = vtkSMTrace::ActiveTracer;
   vtkPythonScopeGilEnsurer gilEnsurer;
   vtkSmartPyObject get_current_trace_output(PyObject_CallMethod(
-    active->GetTraceModule(), const_cast<char*>("get_current_trace_output"), NULL));
+    active->GetTraceModule(), const_cast<char*>("get_current_trace_output"), nullptr));
   if (active->CheckForError() == false && get_current_trace_output)
   {
     // no error.
@@ -302,8 +307,8 @@ public:
   VTK_MODULE_ENABLE_VTK_WrappingPythonCore
   vtkSmartPyObject KWArgs;
   vtkSmartPyObject PositionalArgs;
-  vtkInternals() {}
-  ~vtkInternals() {}
+  vtkInternals() = default;
+  ~vtkInternals() = default;
 
   // This method will create a new PyDict is none is already
   // created for KWArgs.
@@ -375,7 +380,7 @@ vtkSMTrace::TraceItemArgs& vtkSMTrace::TraceItemArgs::arg(const char* key, const
     vtkPythonScopeGilEnsurer gilEnsurer;
     vtkSmartPyObject keyObj(PyString_FromString(key));
     vtkSmartPyObject valObj;
-    if (val == NULL)
+    if (val == nullptr)
     {
       PyObject* none = Py_None;
       Py_INCREF(none);
@@ -622,6 +627,34 @@ vtkSMTrace::TraceItemArgs& vtkSMTrace::TraceItemArgs::arg(bool val)
   return *this;
 }
 
+//----------------------------------------------------------------------------
+vtkSMTrace::TraceItemArgs& vtkSMTrace::TraceItemArgs::arg(const std::vector<std::string>& val)
+{
+  if (vtkSMTrace::GetActiveTracer())
+  {
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter && VTK_MODULE_ENABLE_VTK_Python &&                     \
+  VTK_MODULE_ENABLE_VTK_WrappingPythonCore
+    vtkPythonScopeGilEnsurer gilEnsurer;
+    vtkSmartPyObject listObj(PyList_New(0));
+    assert(listObj);
+
+    for (const std::string& item : val)
+    {
+      vtkSmartPyObject valObj(PyString_FromString(item.c_str()));
+      int ret = PyList_Append(listObj, valObj);
+      (void)ret;
+      assert(ret == 0);
+    }
+
+    int ret = PyList_Append(this->Internals->GetPositionalArgs(), listObj);
+    (void)ret;
+    assert(ret == 0);
+#endif
+  }
+  (void)val;
+  return *this;
+}
+
 //****************************************************************************
 //    vtkSMTrace::TraceItem
 //****************************************************************************
@@ -649,14 +682,14 @@ vtkSMTrace::TraceItem::~TraceItem()
   {
     vtkPythonScopeGilEnsurer gilEnsurer;
     vtkSmartPyObject reply(
-      PyObject_CallMethod(this->Internals->PyItem, const_cast<char*>("finalize"), NULL));
+      PyObject_CallMethod(this->Internals->PyItem, const_cast<char*>("finalize"), nullptr));
     tracer->CheckForError();
     tracer->InvokeEvent(vtkCommand::UpdateEvent);
   }
 #endif
 
   delete this->Internals;
-  this->Internals = NULL;
+  this->Internals = nullptr;
 
 #if VTK_MODULE_ENABLE_VTK_PythonInterpreter && VTK_MODULE_ENABLE_VTK_Python &&                     \
   VTK_MODULE_ENABLE_VTK_WrappingPythonCore
@@ -703,7 +736,7 @@ void vtkSMTrace::TraceItem::operator=(const TraceItemArgs& arguments)
       PyTuple_SET_ITEM(args.GetPointer(), 2, none);
     }
     this->Internals->PyItem.TakeReference(
-      PyObject_Call(tracer->GetCreateItemFunction(), args, NULL));
+      PyObject_Call(tracer->GetCreateItemFunction(), args, nullptr));
     tracer->CheckForError();
   }
 #endif
