@@ -12,12 +12,16 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
+// Hide PARAVIEW_DEPRECATED_IN_5_10_0() warnings for this class.
+#define PARAVIEW_DEPRECATION_LEVEL 0
+
 #include "vtkPVGeneralSettings.h"
 
+#include "vtkAlgorithm.h"
+#include "vtkLegacy.h"
 #include "vtkObjectFactory.h"
-#include "vtkPVOptions.h"
 #include "vtkProcessModule.h"
-#include "vtkProcessModuleAutoMPI.h"
 #include "vtkSISourceProxy.h"
 #include "vtkSMArraySelectionDomain.h"
 #include "vtkSMInputArrayDomain.h"
@@ -28,12 +32,17 @@
 #endif
 
 #if VTK_MODULE_ENABLE_ParaView_RemotingViews
+#include "vtkPVView.h"
 #include "vtkPVXYChartView.h"
 #include "vtkSMChartSeriesSelectionDomain.h"
 #include "vtkSMParaViewPipelineControllerWithRendering.h"
 #include "vtkSMTransferFunctionManager.h"
 #endif
 
+#if VTK_MODULE_ENABLE_VTK_AcceleratorsVTKmFilters
+#include "vtkmFilterOverrides.h"
+#endif
+
 #include <cassert>
 
 vtkSmartPointer<vtkPVGeneralSettings> vtkPVGeneralSettings::Instance;
@@ -43,7 +52,7 @@ vtkPVGeneralSettings* vtkPVGeneralSettings::New()
 {
   vtkPVGeneralSettings* instance = vtkPVGeneralSettings::GetInstance();
   assert(instance);
-  instance->Register(NULL);
+  instance->Register(nullptr);
   return instance;
 }
 
@@ -52,12 +61,7 @@ vtkPVGeneralSettings::vtkPVGeneralSettings()
   : BlockColorsDistinctValues(7)
   , AutoApply(false)
   , AutoApplyActiveOnly(false)
-  , DefaultViewType(NULL)
-#if VTK_MODULE_ENABLE_ParaView_RemotingViews
-  , TransferFunctionResetMode(vtkSMTransferFunctionManager::GROW_ON_APPLY)
-#else
-  , TransferFunctionResetMode(0)
-#endif
+  , DefaultViewType(nullptr)
   , ScalarBarMode(vtkPVGeneralSettings::AUTOMATICALLY_HIDE_SCALAR_BARS)
   , AnimationGeometryCacheLimit(0)
   , AnimationTimePrecision(6)
@@ -72,6 +76,7 @@ vtkPVGeneralSettings::vtkPVGeneralSettings()
   , ColorByBlockColorsOnApply(true)
   , AnimationTimeNotation(vtkPVGeneralSettings::MIXED)
   , EnableStreaming(false)
+  , SelectOnClickMultiBlockInspector(true)
 {
   this->SetDefaultViewType("RenderView");
 }
@@ -79,7 +84,7 @@ vtkPVGeneralSettings::vtkPVGeneralSettings()
 //----------------------------------------------------------------------------
 vtkPVGeneralSettings::~vtkPVGeneralSettings()
 {
-  this->SetDefaultViewType(NULL);
+  this->SetDefaultViewType(nullptr);
 }
 
 //----------------------------------------------------------------------------
@@ -111,34 +116,29 @@ bool vtkPVGeneralSettings::GetAutoConvertProperties()
 }
 
 //----------------------------------------------------------------------------
-void vtkPVGeneralSettings::SetEnableAutoMPI(bool val)
+void vtkPVGeneralSettings::SetEnableAutoMPI(bool)
 {
-  if (this->GetEnableAutoMPI() != val)
-  {
-    vtkProcessModuleAutoMPI::SetEnableAutoMPI(val);
-    this->Modified();
-  }
+  VTK_LEGACY_BODY(vtkPVGeneralSettings::SetEnableAutoMPI, "ParaView 5.10");
 }
 
 //----------------------------------------------------------------------------
 bool vtkPVGeneralSettings::GetEnableAutoMPI()
 {
-  return vtkProcessModuleAutoMPI::EnableAutoMPI;
+  VTK_LEGACY_BODY(vtkPVGeneralSettings::GetEnableAutoMPI, "ParaView 5.10");
+  return false;
 }
 
 //----------------------------------------------------------------------------
-void vtkPVGeneralSettings::SetAutoMPILimit(int val)
+void vtkPVGeneralSettings::SetAutoMPILimit(int)
 {
-  if (this->GetAutoMPILimit() != val && val >= 1)
-  {
-    vtkProcessModuleAutoMPI::SetNumberOfCores(val);
-  }
+  VTK_LEGACY_BODY(vtkPVGeneralSettings::SetAutoMPILimit, "ParaView 5.10");
 }
 
 //----------------------------------------------------------------------------
 int vtkPVGeneralSettings::GetAutoMPILimit()
 {
-  return vtkProcessModuleAutoMPI::NumberOfCores;
+  VTK_LEGACY_BODY(vtkPVGeneralSettings::GetAutoMPILimit, "ParaView 5.10");
+  return 1;
 }
 
 //----------------------------------------------------------------------------
@@ -280,27 +280,47 @@ void vtkPVGeneralSettings::SetEnableStreaming(bool val)
 {
   if (this->GetEnableStreaming() != val)
   {
-    vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-    if (!pm)
-    {
-      vtkErrorMacro("vtkProcessModule not initialized. Igoring streaming change.");
-      return;
-    }
-    auto options = pm->GetOptions();
-    options->SetEnableStreaming(val);
+    this->EnableStreaming = val;
+#if VTK_MODULE_ENABLE_ParaView_RemotingViews
+    vtkPVView::SetEnableStreaming(val);
+#endif
     this->Modified();
   }
 }
 
+//----------------------------------------------------------------------------
+void vtkPVGeneralSettings::SetUseAcceleratedFilters(bool val)
+{
+  static_cast<void>(val);
+
+#if VTK_MODULE_ENABLE_VTK_AcceleratorsVTKmFilters
+  if (this->GetUseAcceleratedFilters() != val)
+  {
+    vtkmFilterOverrides::SetEnabled(val);
+    this->Modified();
+  }
+#endif
+}
+
+//----------------------------------------------------------------------------
+bool vtkPVGeneralSettings::GetUseAcceleratedFilters()
+{
+#if VTK_MODULE_ENABLE_VTK_AcceleratorsVTKmFilters
+  return vtkmFilterOverrides::GetEnabled();
+#else
+  return false;
+#endif
+}
+
 //----------------------------------------------------------------------------
 void vtkPVGeneralSettings::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "AutoApply: " << this->AutoApply << "\n";
+  os << indent << "AutoApplyDelay: " << this->AutoApplyDelay << "\n";
   os << indent << "AutoApplyActiveOnly: " << this->AutoApplyActiveOnly << "\n";
   os << indent << "DefaultViewType: " << this->DefaultViewType << "\n";
-  os << indent << "TransferFunctionResetMode: " << this->TransferFunctionResetMode << "\n";
   os << indent << "ScalarBarMode: " << this->ScalarBarMode << "\n";
   os << indent << "CacheGeometryForAnimation: " << this->CacheGeometryForAnimation << "\n";
   os << indent << "AnimationGeometryCacheLimit: " << this->AnimationGeometryCacheLimit << "\n";
