@@ -47,7 +47,7 @@ inline bool IsInViewport(vtkViewport* viewport, const vtkVector2<T>& point)
 class vtkGridAxes2DActor::vtkLabels
 {
 public:
-  typedef std::vector<vtkSmartPointer<vtkBillboardTextActor3D> > TickLabelsType;
+  typedef std::vector<vtkSmartPointer<vtkBillboardTextActor3D>> TickLabelsType;
   TickLabelsType TickLabels[4];
   vtkNew<vtkBillboardTextActor3D> TitleLabels[4];
   vtkVector2i Justifications[4];
@@ -60,7 +60,7 @@ public:
     }
   }
   static void ResizeLabels(
-    TickLabelsType& labels, size_t new_size, vtkTextProperty* property = NULL)
+    TickLabelsType& labels, size_t new_size, vtkTextProperty* property = nullptr)
   {
     labels.resize(new_size);
     for (TickLabelsType::iterator iter = labels.begin(); iter != labels.end(); ++iter)
@@ -232,7 +232,7 @@ vtkGridAxes2DActor::vtkGridAxes2DActor()
 vtkGridAxes2DActor::~vtkGridAxes2DActor()
 {
   delete this->Labels;
-  this->Labels = NULL;
+  this->Labels = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -249,10 +249,9 @@ void vtkGridAxes2DActor::GetActors(vtkPropCollection* props)
         this->UpdateGeometry(vp, true);
       }
     }
+    this->PlaneActor->GetActors(props);
+    this->Labels->GetActors(props);
   }
-
-  this->PlaneActor->GetActors(props);
-  this->Labels->GetActors(props);
 }
 
 //----------------------------------------------------------------------------
@@ -332,7 +331,7 @@ vtkProperty* vtkGridAxes2DActor::GetProperty()
 //----------------------------------------------------------------------------
 void vtkGridAxes2DActor::SetTitleTextProperty(int axis, vtkTextProperty* tprop)
 {
-  if (axis >= 0 && axis < 3 && this->TitleTextProperty[axis] != tprop && tprop != NULL)
+  if (axis >= 0 && axis < 3 && this->TitleTextProperty[axis] != tprop && tprop != nullptr)
   {
     this->TitleTextProperty[axis] = tprop;
     this->Modified();
@@ -342,13 +341,13 @@ void vtkGridAxes2DActor::SetTitleTextProperty(int axis, vtkTextProperty* tprop)
 //----------------------------------------------------------------------------
 vtkTextProperty* vtkGridAxes2DActor::GetTitleTextProperty(int axis)
 {
-  return (axis >= 0 && axis < 3) ? this->TitleTextProperty[axis] : NULL;
+  return (axis >= 0 && axis < 3) ? this->TitleTextProperty[axis] : nullptr;
 }
 
 //----------------------------------------------------------------------------
 void vtkGridAxes2DActor::SetLabelTextProperty(int axis, vtkTextProperty* tprop)
 {
-  if (axis >= 0 && axis < 3 && this->LabelTextProperty[axis] != tprop && tprop != NULL)
+  if (axis >= 0 && axis < 3 && this->LabelTextProperty[axis] != tprop && tprop != nullptr)
   {
     this->LabelTextProperty[axis] = tprop;
     this->Modified();
@@ -358,7 +357,7 @@ void vtkGridAxes2DActor::SetLabelTextProperty(int axis, vtkTextProperty* tprop)
 //----------------------------------------------------------------------------
 vtkTextProperty* vtkGridAxes2DActor::GetLabelTextProperty(int axis)
 {
-  return (axis >= 0 && axis < 3) ? this->LabelTextProperty[axis] : NULL;
+  return (axis >= 0 && axis < 3) ? this->LabelTextProperty[axis] : nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -469,7 +468,7 @@ bool vtkGridAxes2DActor::Update(vtkViewport* viewport)
   this->PlaneActor->SetUserMatrix(this->GetMatrix());
 
   vtkRenderer* renderer = vtkRenderer::SafeDownCast(viewport);
-  assert(renderer != NULL);
+  assert(renderer != nullptr);
 
   // This is needed so the vtkAxis labels account for tile scaling.
   this->AxisHelperScene->SetRenderer(renderer);
