@@ -24,13 +24,16 @@
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkMath.h"
+#include "vtkMultiBlockDataSet.h"
 #include "vtkMultiBlockVolumeMapper.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkOutlineSource.h"
 #include "vtkPVLODVolume.h"
 #include "vtkPVRenderView.h"
+#include "vtkPVTransferFunction2D.h"
 #include "vtkPartitionedDataSet.h"
+#include "vtkPointData.h"
 #include "vtkPolyDataMapper.h"
 #include "vtkRectilinearGrid.h"
 #include "vtkRenderer.h"
@@ -110,7 +113,6 @@ void vtkGetNonGhostExtent(int* resultExtent, vtkImageData* dataSet)
 vtkStandardNewMacro(vtkImageVolumeRepresentation);
 //----------------------------------------------------------------------------
 vtkImageVolumeRepresentation::vtkImageVolumeRepresentation()
-  : Superclass()
 {
   this->VolumeMapper.TakeReference(vtkMultiBlockVolumeMapper::New());
 
@@ -120,6 +122,7 @@ vtkImageVolumeRepresentation::vtkImageVolumeRepresentation()
 //----------------------------------------------------------------------------
 vtkImageVolumeRepresentation::~vtkImageVolumeRepresentation()
 {
+  this->TransferFunction2D = nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -127,7 +130,7 @@ int vtkImageVolumeRepresentation::FillInputPortInformation(int, vtkInformation*
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkImageData");
   info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkRectilinearGrid");
-  info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPartitionedDataSet");
+  info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataObjectTree");
   info->Set(vtkAlgorithm::INPUT_IS_OPTIONAL(), 1);
   return 1;
 }
@@ -145,6 +148,11 @@ int vtkImageVolumeRepresentation::ProcessViewRequest(
     // pass the actual volumetric data.
     vtkPVRenderView::SetPiece(inInfo, this, this->Cache, this->DataSize, 0);
 
+    // We never want the volumetric data to be delivered to the client.
+    vtkPVRenderView::SetDeliverToClientAndRenderingProcesses(inInfo, this,
+      /*deliver_to_client*/ false,
+      /*gather_before_delivery*/ false, 0);
+
     // pass the outline data, used on ranks where the data may not be available.
     vtkPVRenderView::SetPiece(inInfo, this, this->OutlineSource->GetOutputDataObject(0), 0, 1);
 
@@ -282,13 +290,51 @@ int vtkImageVolumeRepresentation::RequestData(
             cache->SetPartition(cc, partitionRG);
           }
         }
-        cache->GetBounds(this->DataBounds);
         this->Cache = cache.GetPointer();
+
+        cache->GetBounds(this->DataBounds);
+        this->OutlineSource->SetBounds(this->DataBounds);
+        this->OutlineSource->Update();
+        this->DataSize = cache->GetActualMemorySize();
       }
     }
+    else if (auto doTree = vtkDataObjectTree::GetData(inputVector[0], 0))
+    {
+      auto images = vtkCompositeDataSet::GetDataSets(doTree);
+      images.erase(std::remove_if(images.begin(), images.end(),
+                     [](vtkDataSet* ds) {
+                       return vtkRectilinearGrid::SafeDownCast(ds) == nullptr &&
+                         vtkImageData::SafeDownCast(ds) == nullptr;
+                     }),
+        images.end());
+
+      vtkNew<vtkPartitionedDataSet> cache;
+      for (unsigned int cc = 0; cc < static_cast<unsigned int>(images.size()); ++cc)
+      {
+        auto* partition = images[cc];
+        if (this->UseSeparateOpacityArray)
+        {
+          this->AppendOpacityComponent(partition);
+        }
+        cache->SetPartition(cc, partition);
+      }
+
+      this->Cache = cache.GetPointer();
+
+      cache->GetBounds(this->DataBounds);
+      this->OutlineSource->SetBounds(this->DataBounds);
+      this->OutlineSource->Update();
+      this->DataSize = cache->GetActualMemorySize();
+    }
   }
   else
   {
+    // We just need an empty data object on the client side
+    // so that the pipelines can update properly. Since we never deliver
+    // this data to the client, we don't have to worry too much about the types
+    // matching. Just creating a vtkPartitionedDataSet does the trick
+    this->Cache = vtk::TakeSmartPointer(vtkPartitionedDataSet::New());
+
     // when no input is present, it implies that this processes is on a node
     // without the data input i.e. either client or render-server, in which case
     // we show only the outline.
@@ -400,27 +446,46 @@ void vtkImageVolumeRepresentation::UpdateMapperParameters()
       this->Property->SetIndependentComponents(false);
     }
 
-    // Update the mapper's vector mode
-    vtkColorTransferFunction* ctf = this->Property->GetRGBTransferFunction(0);
-
-    // When vtkScalarsToColors::MAGNITUDE mode is active, vtkSmartVolumeMapper
-    // uses an internally generated (single-component) dataset.  However,
-    // unchecking MapScalars (e.g. IndependentComponents == 0) requires 2C or 4C
-    // data. In that case, vtkScalarsToColors::COMPONENT is forced in order to
-    // make vtkSmartVolumeMapper use the original multiple-component dataset.
-    int const indep = this->Property->GetIndependentComponents();
-    int const mode = indep ? ctf->GetVectorMode() : vtkScalarsToColors::COMPONENT;
-    int const comp = indep ? ctf->GetVectorComponent() : 0;
-
-    if (auto smartVolumeMapper = vtkSmartVolumeMapper::SafeDownCast(this->VolumeMapper))
+    if (this->UseTransfer2D)
     {
-      smartVolumeMapper->SetVectorMode(mode);
-      smartVolumeMapper->SetVectorComponent(comp);
+      this->Property->SetTransferFunctionMode(vtkVolumeProperty::TF_2D);
+      if (auto mbMapper = vtkMultiBlockVolumeMapper::SafeDownCast(this->VolumeMapper))
+      {
+        if (!this->UseGradientForTransfer2D && !this->ColorArray2Name.empty())
+        {
+          mbMapper->SetTransfer2DYAxisArray(this->ColorArray2Name.c_str());
+        }
+        else
+        {
+          mbMapper->SetTransfer2DYAxisArray(nullptr);
+        }
+      }
     }
-    else if (auto mbMapper = vtkMultiBlockVolumeMapper::SafeDownCast(this->VolumeMapper))
+    else
     {
-      mbMapper->SetVectorMode(mode);
-      mbMapper->SetVectorComponent(comp);
+      this->Property->SetTransferFunctionMode(vtkVolumeProperty::TF_1D);
+      // Update the mapper's vector mode
+      vtkColorTransferFunction* ctf = this->Property->GetRGBTransferFunction(0);
+
+      // When vtkScalarsToColors::MAGNITUDE mode is active, vtkSmartVolumeMapper
+      // uses an internally generated (single-component) dataset.  However,
+      // unchecking MapScalars (e.g. IndependentComponents == 0) requires 2C or 4C
+      // data. In that case, vtkScalarsToColors::COMPONENT is forced in order to
+      // make vtkSmartVolumeMapper use the original multiple-component dataset.
+      int const indep = this->Property->GetIndependentComponents();
+      int const mode = indep ? ctf->GetVectorMode() : vtkScalarsToColors::COMPONENT;
+      int const comp = indep ? ctf->GetVectorComponent() : 0;
+
+      if (auto smartVolumeMapper = vtkSmartVolumeMapper::SafeDownCast(this->VolumeMapper))
+      {
+        smartVolumeMapper->SetVectorMode(mode);
+        smartVolumeMapper->SetVectorComponent(comp);
+      }
+      else if (auto mbMapper = vtkMultiBlockVolumeMapper::SafeDownCast(this->VolumeMapper))
+      {
+        mbMapper->SetVectorMode(mode);
+        mbMapper->SetVectorComponent(comp);
+      }
     }
   }
 }
@@ -433,6 +498,11 @@ void vtkImageVolumeRepresentation::PrintSelf(ostream& os, vtkIndent indent)
      << ", " << this->CroppingOrigin[2] << endl;
   os << indent << "Cropping Scale: " << this->CroppingScale[0] << ", " << this->CroppingScale[1]
      << ", " << this->CroppingScale[2] << endl;
+  os << indent << "UseTransfer2D: " << this->UseTransfer2D << endl;
+  os << indent << "UseGradientForTransfer2D: " << this->UseGradientForTransfer2D << endl;
+  os << indent << "ColorArray2Name: " << this->ColorArray2Name << endl;
+  os << indent << "ColorArray2FieldAssociation: " << this->ColorArray2FieldAssociation << endl;
+  os << indent << "ColorArray2Component: " << this->ColorArray2Component << endl;
 }
 
 //----------------------------------------------------------------------------
@@ -465,6 +535,40 @@ void vtkImageVolumeRepresentation::SetShade(bool val)
   this->Property->SetShade(val);
 }
 
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SetAnisotropy(float val)
+{
+  this->Property->SetScatteringAnisotropy(val);
+}
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SetGlobalIlluminationReach(float val)
+{
+  if (auto smartVolumeMapper = vtkSmartVolumeMapper::SafeDownCast(this->VolumeMapper))
+  {
+    smartVolumeMapper->SetGlobalIlluminationReach(val);
+  }
+  else if (auto mbMapper = vtkMultiBlockVolumeMapper::SafeDownCast(this->VolumeMapper))
+  {
+    mbMapper->SetGlobalIlluminationReach(val);
+  }
+  this->Modified();
+}
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SetVolumetricScatteringBlending(float val)
+{
+  if (auto smartVolumeMapper = vtkSmartVolumeMapper::SafeDownCast(this->VolumeMapper))
+  {
+    smartVolumeMapper->SetVolumetricScatteringBlending(val);
+  }
+  else if (auto mbMapper = vtkMultiBlockVolumeMapper::SafeDownCast(this->VolumeMapper))
+  {
+    mbMapper->SetVolumetricScatteringBlending(val);
+  }
+  this->Modified();
+}
+
 //----------------------------------------------------------------------------
 void vtkImageVolumeRepresentation::SetSliceFunction(vtkImplicitFunction* slice)
 {
@@ -508,3 +612,93 @@ void vtkImageVolumeRepresentation::SetNumberOfIsosurfaces(int number)
 {
   this->Property->GetIsoSurfaceValues()->SetNumberOfContours(number);
 }
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SetUseTransfer2D(bool value)
+{
+  if (this->UseTransfer2D != value)
+  {
+    this->UseTransfer2D = value;
+    this->MarkModified();
+  }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SetUseGradientForTransfer2D(bool value)
+{
+  if (this->UseGradientForTransfer2D != value)
+  {
+    this->UseGradientForTransfer2D = value;
+    this->MarkModified();
+  }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SelectColorArray2(
+  int, int, int, int fieldAssociation, const char* name)
+{
+  std::string newName;
+  if (name)
+  {
+    newName = std::string(name);
+  }
+
+  if (this->ColorArray2Name != newName)
+  {
+    this->ColorArray2Name = newName;
+    this->MarkModified();
+  }
+
+  if (this->ColorArray2FieldAssociation != fieldAssociation)
+  {
+    this->ColorArray2FieldAssociation = fieldAssociation;
+    this->MarkModified();
+  }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SelectColorArray2Component(int component)
+{
+  if (this->ColorArray2Component != component)
+  {
+    this->ColorArray2Component = component;
+    this->MarkModified();
+  }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageVolumeRepresentation::SetTransferFunction2D(vtkPVTransferFunction2D* transfer2D)
+{
+  if (this->TransferFunction2D == nullptr && transfer2D == nullptr)
+  {
+    return;
+  }
+  if (this->TransferFunction2D && transfer2D && this->TransferFunction2D == transfer2D)
+  {
+    return;
+  }
+
+  if (this->TransferFunction2D)
+  {
+    this->TransferFunction2D = nullptr;
+    this->Property->SetTransferFunction2D(nullptr);
+  }
+
+  if (transfer2D)
+  {
+    this->TransferFunction2D = transfer2D;
+    vtkImageData* func = this->TransferFunction2D->GetFunction();
+    if (func)
+    {
+      vtkPointData* pd = func->GetPointData();
+      if (!pd || (pd->GetScalars() == nullptr) || pd->GetScalars()->GetNumberOfComponents() != 4)
+      {
+        int* dims = this->TransferFunction2D->GetOutputDimensions();
+        func->SetDimensions(dims[0], dims[1], 1);
+        func->AllocateScalars(VTK_FLOAT, 4);
+      }
+      this->Property->SetTransferFunction2D(func);
+    }
+    this->MarkModified();
+  }
+}
