@@ -27,7 +27,7 @@
 #include "vtkObject.h"
 #include "vtkRemotingViewsModule.h" //needed for exports
 
-#include <vector>
+#include <vector> // for std::vector
 
 class vtkBoundingBox;
 class vtkCamera;
@@ -49,7 +49,7 @@ public:
 
 protected:
   vtkOrderedCompositingHelper();
-  ~vtkOrderedCompositingHelper();
+  ~vtkOrderedCompositingHelper() override;
 
   std::vector<vtkBoundingBox> Boxes;
 
