@@ -14,7 +14,10 @@
 =========================================================================*/
 #include "vtkPVDiscretizableColorTransferFunction.h"
 
+#include "vtkPVTransferFunction2D.h"
+
 #include "vtkDoubleArray.h"
+#include "vtkImageData.h"
 #include "vtkLookupTable.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
@@ -22,12 +25,14 @@
 #include "vtkVariantArray.h"
 
 vtkStandardNewMacro(vtkPVDiscretizableColorTransferFunction);
+vtkCxxSetObjectMacro(
+  vtkPVDiscretizableColorTransferFunction, TransferFunction2D, vtkPVTransferFunction2D);
 
 //-------------------------------------------------------------------------
 vtkPVDiscretizableColorTransferFunction::vtkPVDiscretizableColorTransferFunction()
 {
-  this->AnnotatedValuesInFullSet = NULL;
-  this->AnnotationsInFullSet = NULL;
+  this->AnnotatedValuesInFullSet = nullptr;
+  this->AnnotationsInFullSet = nullptr;
   this->IndexedColorsInFullSet = vtkDoubleArray::New();
   this->IndexedColorsInFullSet->SetNumberOfComponents(3);
   this->IndexedOpacitiesInFullSet = vtkDoubleArray::New();
@@ -36,6 +41,8 @@ vtkPVDiscretizableColorTransferFunction::vtkPVDiscretizableColorTransferFunction
   this->ActiveAnnotatedValues = vtkVariantArray::New();
 
   this->UseActiveValues = 1;
+
+  this->TransferFunction2D = nullptr;
 }
 
 //-------------------------------------------------------------------------
@@ -65,6 +72,8 @@ vtkPVDiscretizableColorTransferFunction::~vtkPVDiscretizableColorTransferFunctio
   {
     this->ActiveAnnotatedValues->Delete();
   }
+
+  this->SetTransferFunction2D(nullptr);
 }
 
 //-------------------------------------------------------------------------
@@ -85,7 +94,7 @@ void vtkPVDiscretizableColorTransferFunction::SetAnnotationsInFullSet(
   if (this->AnnotatedValuesInFullSet && !values)
   {
     this->AnnotatedValuesInFullSet->Delete();
-    this->AnnotatedValuesInFullSet = 0;
+    this->AnnotatedValuesInFullSet = nullptr;
   }
   else if (values)
   { // Ensure arrays are of the same type before copying.
@@ -94,7 +103,7 @@ void vtkPVDiscretizableColorTransferFunction::SetAnnotationsInFullSet(
       if (this->AnnotatedValuesInFullSet->GetDataType() != values->GetDataType())
       {
         this->AnnotatedValuesInFullSet->Delete();
-        this->AnnotatedValuesInFullSet = 0;
+        this->AnnotatedValuesInFullSet = nullptr;
       }
     }
     if (!this->AnnotatedValuesInFullSet)
@@ -111,7 +120,7 @@ void vtkPVDiscretizableColorTransferFunction::SetAnnotationsInFullSet(
   if (this->AnnotationsInFullSet && !annotations)
   {
     this->AnnotationsInFullSet->Delete();
-    this->AnnotationsInFullSet = 0;
+    this->AnnotationsInFullSet = nullptr;
   }
   else if (!this->AnnotationsInFullSet && annotations)
   {
@@ -175,7 +184,7 @@ vtkIdType vtkPVDiscretizableColorTransferFunction::SetAnnotationInFullSet(
   {
     return this->SetAnnotationInFullSet(x, annotation);
   }
-  else if (value == "")
+  else if (value.empty())
   {
     // NOTE: This prevents the value "" in vtkStringArrays from being annotated.
     // Hopefully, that isn't a desired use case.
@@ -392,6 +401,12 @@ void vtkPVDiscretizableColorTransferFunction::Build()
   this->BuildTime.Modified();
 }
 
+//-------------------------------------------------------------------------
+vtkPVTransferFunction2D* vtkPVDiscretizableColorTransferFunction::GetTransferFunction2D() const
+{
+  return this->TransferFunction2D;
+}
+
 //-------------------------------------------------------------------------
 void vtkPVDiscretizableColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
 {
