@@ -17,6 +17,7 @@
 #define vtkPVPlotMatrixView_h
 
 #include "vtkPVContextView.h"
+#include "vtkParaViewDeprecation.h" // for PARAVIEW_DEPRECATED_IN_5_10_0
 #include "vtkRemotingViewsModule.h" //needed for exports
 
 class vtkScatterPlotMatrix;
@@ -146,6 +147,13 @@ public:
   void SetGutterY(float value);
   //@}
 
+  //@{
+  /**
+   * Set the padding that applied an uniform padding on each charts.
+   */
+  virtual void SetPadding(float padding);
+  //@}
+
   //@{
   /**
    * Set/get the borders of the chart matrix (space in pixels around each chart).
@@ -343,12 +351,21 @@ public:
    * @deprecated in ParaView 5.10.
    * Use Get[...]Color([...], double color[3]) methods instead.
    */
-  VTK_LEGACY(double* GetBackgroundColor(int plotType));
-  VTK_LEGACY(double* GetGridColor(int plotType));
-  VTK_LEGACY(double* GetAxisColor(int plotType));
-  VTK_LEGACY(double* GetAxisLabelColor(int plotType));
-  VTK_LEGACY(double* GetScatterPlotSelectedRowColumnColor());
-  VTK_LEGACY(double* GetScatterPlotSelectedActiveColor());
+  PARAVIEW_DEPRECATED_IN_5_10_0("Use `vtkPVPlotMatrixView::Get(int, double[3])` instead")
+  double* GetBackgroundColor(int plotType);
+  PARAVIEW_DEPRECATED_IN_5_10_0("Use `vtkPVPlotMatrixView::GetGridColor(int, double[3])` instead")
+  double* GetGridColor(int plotType);
+  PARAVIEW_DEPRECATED_IN_5_10_0("Use `vtkPVPlotMatrixView::GetAxisColor(int, double[3])` instead")
+  double* GetAxisColor(int plotType);
+  PARAVIEW_DEPRECATED_IN_5_10_0(
+    "Use `vtkPVPlotMatrixView::GetAxisLabelColor(int, double[3])` instead")
+  double* GetAxisLabelColor(int plotType);
+  PARAVIEW_DEPRECATED_IN_5_10_0(
+    "Use `vtkPVPlotMatrixView::GetScatterPlotSelectedRowColumnColor(double[3])` instead")
+  double* GetScatterPlotSelectedRowColumnColor();
+  PARAVIEW_DEPRECATED_IN_5_10_0(
+    "Use `vtkPVPlotMatrixView::GetScatterPlotSelectedActiveColor(double[3])` instead")
+  double* GetScatterPlotSelectedActiveColor();
   //@}
 
 protected:
