@@ -22,7 +22,7 @@
  * processes. vtkPVRenderView uses the information about what process it has
  * been created on to decide what part of the "rendering" happens on the
  * process.
-*/
+ */
 
 #ifndef vtkPVRenderView_h
 #define vtkPVRenderView_h
@@ -30,6 +30,7 @@
 #include "vtkBoundingBox.h" // needed for iVar
 #include "vtkNew.h"         // needed for iVar
 #include "vtkPVView.h"
+#include "vtkParaViewDeprecation.h"
 #include "vtkRemotingViewsModule.h" //needed for exports
 #include "vtkSmartPointer.h"        // needed for iVar
 #include "vtkWeakPointer.h"         // needed for iVar
@@ -173,6 +174,19 @@ public:
    */
   void ResetCamera();
   void ResetCamera(double bounds[6]);
+  void ResetCameraScreenSpace();
+  void ResetCameraScreenSpace(double bounds[6]);
+  //@}
+
+  //@{
+  /**
+   * Compute and reduce the visible bounds of the provided
+   * representation. Uses LastRepresentationVisibleBounds
+   * to store the result until the next call.
+   * \note CallOnAllProcesses
+   */
+  double* ComputeVisibleBounds(vtkPVDataRepresentation* pvrepr) VTK_SIZEHINT(6);
+  double LastRepresentationVisibleBounds[6];
   //@}
 
   /**
@@ -461,24 +475,6 @@ public:
     vtkInformation* info, vtkPVDataRepresentation* repr);
   //@}
 
-  //@{
-  /**
-   * As of ParaView 5.9, these methods are replaced by
-   * `SetOrderedCompositingConfiguration` which provides a new mechanisms for
-   * indicating to the view how this representation participates in
-   * data-redistribution needed when ordered-compositing is being used.
-   *
-   * @deprecated ParaView 5.9.
-   */
-  VTK_LEGACY(static void MarkAsRedistributable(
-    vtkInformation* info, vtkPVDataRepresentation* repr, bool value = true, int port = 0));
-  VTK_LEGACY(static void SetOrderedCompositingInformation(vtkInformation* info,
-    vtkPVDataRepresentation* repr, vtkExtentTranslator* translator, const int whole_extents[6],
-    const double origin[3], const double spacing[3]));
-  VTK_LEGACY(
-    static void SetOrderedCompositingInformation(vtkInformation* info, const double bounds[6]));
-  //@}
-
   //@{
   /**
    * `OrderedCompositingConfiguration` lets representations indicate to the view
@@ -655,16 +651,41 @@ public:
 
   //*****************************************************************
   // Forward to 3D renderer.
-  vtkSetMacro(UseHiddenLineRemoval, bool) virtual void SetUseDepthPeeling(int val);
+  vtkSetMacro(UseHiddenLineRemoval, bool);
+  virtual void SetUseDepthPeeling(int val);
   virtual void SetUseDepthPeelingForVolumes(bool val);
   virtual void SetMaximumNumberOfPeels(int val);
-  virtual void SetBackground(double r, double g, double b);
-  virtual void SetBackground2(double r, double g, double b);
   virtual void SetBackgroundTexture(vtkTexture* val);
-  virtual void SetGradientBackground(int val);
-  virtual void SetTexturedBackground(int val);
-  virtual void SetSkyboxBackground(int val);
-  virtual void SetUseEnvironmentLighting(bool val);
+
+  //@{
+  /**
+   * When set, background color and mode will be obtained from
+   * vtkPVRenderViewSettings.
+   */
+  vtkSetMacro(UseRenderViewSettingsForBackground, bool);
+  vtkGetMacro(UseRenderViewSettingsForBackground, bool);
+  ///@}
+
+  enum BackgroundMode
+  {
+    DEFAULT,
+    GRADIENT,
+    IMAGE,
+    SKYBOX,
+    STEREO_SKYBOX,
+  };
+
+  ///@{
+  /**
+   * API for background color selection.
+   */
+  vtkSetClampMacro(BackgroundColorMode, int, DEFAULT, STEREO_SKYBOX);
+  vtkSetVector3Macro(Background, double);
+  vtkGetVector3Macro(Background, double);
+  vtkSetVector3Macro(Background2, double);
+  vtkGetVector3Macro(Background2, double);
+  vtkSetMacro(UseEnvironmentLighting, bool);
+  ///@}
 
   //*****************************************************************
   // Entry point for environmental backgrounds
@@ -699,6 +720,8 @@ public:
   virtual void SetCamera2DManipulators(const int manipulators[9]);
   virtual void SetCamera3DManipulators(const int manipulators[9]);
   void SetCameraManipulators(vtkPVInteractorStyle* style, const int manipulators[9]);
+  virtual void SetReverseMouseWheelZoomDirection(bool reverse);
+  virtual void SetMouseWheelZoomsToCursor(bool value);
   virtual void SetCamera2DMouseWheelMotionFactor(double factor);
   virtual void SetCamera3DMouseWheelMotionFactor(double factor);
 
@@ -867,48 +890,22 @@ public:
 
   //@{
   /**
-   * Tells view that it should draw a particular array component
-   * to the screen such that the pixels can be read back and
-   * decoded to obtain the values.
+   * Experimental API to grab re-colorable images. Between
+   * BeginValuePassForRendering and EndValuePassForRendering calls, all renders
+   * will end up using vtkValuePass for rendering instead of the standard
+   * rendering passes that generate results on screen.
+   *
+   * GrabValuePassResult must be called between BeginValuePassForRendering and
+   * EndValuePassForRendering. Returns the vtkFloatArray grabbed by
+   * vtkValuePass.
+   *
+   * This API is not intended for remote-rendering use-cases. Thus only supported in client-only and
+   * pvbatch (or in situ) cases. That's the reason why we are exposing this directly on
+   * the vtkPVRenderView rather accessing it via a proxy.
    */
-  void SetDrawCells(bool choice);
-  void SetArrayNameToDraw(const char* name);
-  void SetArrayNumberToDraw(int fieldAttributeType);
-  void SetArrayComponentToDraw(int comp);
-  void SetScalarRange(double min, double max);
-  void BeginValueCapture();
-  void EndValueCapture();
-  //@}
-
-  //@{
-  /**
-   * Current rendering mode of vtkValuePass (float or invertible RGB).
-   * @deprecation Invertible is deprecated, so this currently does nothing and will be removed.
-   */
-  void SetValueRenderingModeCommand(int mode);
-  int GetValueRenderingModeCommand();
-  //@}
-
-  //@{
-  /**
-   * Access to vtkValuePass::FLOATING_POINT mode rendered image. vtkValuePass's
-   * internal FBO is accessed directly when rendering locally. When rendering in
-   * parallel, IceT composites the intermediate results from vtkValuePass and the
-   * final result is accessed through vtkIceTCompositePass. Float value rendering
-   * is only supported in BATCH mode and in CLIENT mode (local rendering). These methods
-   * do nothing if INVERTIBLE_LUT mode is active.
-   */
-  void CaptureValuesFloat();
-  vtkFloatArray* GetCapturedValuesFloat();
-  //@}
-
-  //@{
-  /**
-   * Tells views that it should draw the lighting contributions to the
-   * framebuffer.
-   */
-  void StartCaptureLuminance();
-  void StopCaptureLuminance();
+  bool BeginValuePassForRendering(int fieldAssociation, const char* arrayName, int component);
+  void EndValuePassForRendering();
+  vtkSmartPointer<vtkFloatArray> GrabValuePassResult();
   //@}
 
   //@{
@@ -951,9 +948,12 @@ public:
   /**
    * Set the path tracers volume anisotropy
    */
+  PARAVIEW_DEPRECATED_IN_5_11_0("Use vtkVolumeProperty::SetScatteringAnisotropy instead")
   void SetVolumeAnisotropy(double);
+  PARAVIEW_DEPRECATED_IN_5_11_0("Use vtkVolumeProperty::GetScatteringAnisotropy instead")
   double GetVolumeAnisotropy();
   //@}
+
   //@{
   /**
    * Set the number of primary rays that OSPRay shoots per pixel.
@@ -1159,9 +1159,10 @@ protected:
   void PostSelect(vtkSelection* sel, const char* array = nullptr);
 
   /**
-   * Update skybox actor
+   * Updates background color. If no renderer is specified, then the default
+   * renderer returned by `GetRenderer` is used.
    */
-  void UpdateSkybox();
+  virtual void UpdateBackground(vtkRenderer* renderer = nullptr);
 
   /**
    * Configure texture based on scalar type
@@ -1182,7 +1183,6 @@ protected:
   vtkSelection* LastSelection;
   vtkSmartPointer<vtkPVGridAxes3DActor> GridAxes3DActor;
   vtkNew<vtkSkybox> Skybox;
-  bool NeedSkybox = false;
 
   int StillRenderImageReductionFactor;
   int InteractiveRenderImageReductionFactor;
@@ -1203,6 +1203,8 @@ protected:
   vtkPVInteractorStyle* TwoDInteractorStyle;
   vtkPVInteractorStyle* ThreeDInteractorStyle;
 
+  bool ReverseMouseWheelZoomDirection = false;
+
   // Active interactor style either [TwoDInteractorStyle, ThreeDInteractorStyle]
   vtkPVInteractorStyle* InteractorStyle;
 
@@ -1291,11 +1293,19 @@ private:
   int ServerStereoType;
   void UpdateStereoProperties();
 
+  int BackgroundColorMode;
+  bool UseEnvironmentLighting;
+  bool UseRenderViewSettingsForBackground;
+  double Background[3];
+  double Background2[3];
+
   vtkSmartPointer<vtkCuller> Culler;
   vtkNew<vtkTimerLog> Timer;
 
   int ForceDataDistributionMode;
   int PreviousDiscreteCameraIndex;
+  vtkSmartPointer<vtkTexture> EnvironmentalBGTexture;
+  bool UseTexturedEnvironmentalBG;
 };
 
 #endif
