@@ -25,7 +25,7 @@
 #include "vtkSMUncheckedPropertyHelper.h"
 
 #include <algorithm>
-#include <assert.h>
+#include <cassert>
 #include <vector>
 
 vtkStandardNewMacro(vtkSMChartSeriesListDomain);
@@ -36,9 +36,7 @@ vtkSMChartSeriesListDomain::vtkSMChartSeriesListDomain()
 }
 
 //----------------------------------------------------------------------------
-vtkSMChartSeriesListDomain::~vtkSMChartSeriesListDomain()
-{
-}
+vtkSMChartSeriesListDomain::~vtkSMChartSeriesListDomain() = default;
 
 //----------------------------------------------------------------------------
 void vtkSMChartSeriesListDomain::Update(vtkSMProperty*)
@@ -63,7 +61,7 @@ void vtkSMChartSeriesListDomain::Update(vtkSMProperty*)
   int fieldAssociation = vtkSMUncheckedPropertyHelper(fieldDataSelection).GetAsInt(0);
   vtkPVDataSetAttributesInformation* dsa = dataInfo->GetAttributeInformation(fieldAssociation);
 
-  for (int cc = 0; dsa != NULL && cc < dsa->GetNumberOfArrays(); cc++)
+  for (int cc = 0; dsa != nullptr && cc < dsa->GetNumberOfArrays(); cc++)
   {
     this->PopulateArrayComponents(dsa->GetArrayInformation(cc), strings);
   }
@@ -85,7 +83,7 @@ void vtkSMChartSeriesListDomain::PopulateArrayComponents(
   {
     int dataType = arrayInfo->GetDataType();
 
-    if (dataType != VTK_STRING && dataType != VTK_UNICODE_STRING && dataType != VTK_VARIANT)
+    if (dataType != VTK_STRING && dataType != VTK_VARIANT)
     {
       if (arrayInfo->GetNumberOfComponents() > 1)
       {
@@ -121,7 +119,7 @@ vtkPVDataInformation* vtkSMChartSeriesListDomain::GetInputInformation()
       return sp->GetDataInformation(helper.GetOutputPort());
     }
   }
-  return NULL;
+  return nullptr;
 }
 
 //----------------------------------------------------------------------------
@@ -163,7 +161,7 @@ int vtkSMChartSeriesListDomain::SetDefaultValues(vtkSMProperty* prop, bool use_u
   const char** strings_to_check = vtkSMChartSeriesListDomain::GetKnownSeriesNames();
 
   const std::vector<std::string> domain_strings = this->GetStrings();
-  for (int cc = 0; strings_to_check[cc] != NULL; cc++)
+  for (int cc = 0; strings_to_check[cc] != nullptr; cc++)
   {
     if (std::find(domain_strings.begin(), domain_strings.end(),
           std::string(strings_to_check[cc])) != domain_strings.end())
