@@ -28,13 +28,14 @@
  * data-representations (i.e. representations showing input data) in the render
  * views. It provides helper functions for controlling transfer functions,
  * scalar coloring, etc.
-*/
+ */
 
 #ifndef vtkSMPVRepresentationProxy_h
 #define vtkSMPVRepresentationProxy_h
 
 #include "vtkRemotingViewsModule.h" //needed for exports
 #include "vtkSMRepresentationProxy.h"
+#include "vtkSmartPointer.h" // For LastLUTProxy
 
 class vtkPVArrayInformation;
 
@@ -52,6 +53,12 @@ public:
    */
   virtual bool GetUsingScalarColoring();
 
+  /**
+   * Returns the lut proxy of this representation in the given view.
+   * This method will return `nullptr` if no lut proxy exists in this view.
+   */
+  vtkSMProxy* GetLUTProxy(vtkSMProxy* view);
+
   //@{
   /**
    * Safely call GetUsingScalarColoring() after casting the proxy to appropriate
@@ -64,10 +71,19 @@ public:
   }
   //@}
 
+  /**
+   * Updates the ranges shown in the scalar bar.
+   * If deleteRange is true, then the range stored for current representation proxy is deleted.
+   * This should be done when the scalar bar gets separated or becomes not visible.
+   * If deleteRange is false, then the range stored for current representation proxy is updated
+   * with the new range value.
+   */
+  bool UpdateScalarBarRange(vtkSMProxy* view, bool deleteRange);
+
   /**
    * Enable/disable scalar coloring using the specified array. This will set up a
    * color and opacity transfer functions using vtkSMTransferFunctionProxy
-   * instance. If arrayname is NULL, then scalar coloring is turned off.
+   * instance. If arrayname is nullptr, then scalar coloring is turned off.
    * \c attribute_type must be one of vtkDataObject::AttributeTypes.
    */
   virtual bool SetScalarColoring(const char* arrayname, int attribute_type);
@@ -75,7 +91,7 @@ public:
   /**
    * Enable/disable scalar coloring using the specified array. This will set up a
    * color and opacity transfer functions using vtkSMTransferFunctionProxy
-   * instance. If arrayname is NULL, then scalar coloring is turned off.
+   * instance. If arrayname is nullptr, then scalar coloring is turned off.
    * \param arrayname the name of the array.
    * \param attribute_type must be one of vtkDataObject::AttributeTypes.
    * \param component enables choosing a component to color with,
@@ -283,7 +299,7 @@ public:
   /**
    * Returns the array information for the data array used for scalar coloring, from input data.
    * If checkRepresentedData is true, it will also check in the represented data. Default is true.
-   * If none is found, returns NULL.
+   * If none is found, returns nullptr.
    */
   virtual vtkPVArrayInformation* GetArrayInformationForColorArray(bool checkRepresentedData = true);
   static vtkPVArrayInformation* GetArrayInformationForColorArray(
@@ -297,7 +313,7 @@ public:
   //@{
   /**
    * Call vtkSMRepresentationProxy::GetProminentValuesInformation() for the
-   * array used for scalar color, if any. Otherwise returns NULL.
+   * array used for scalar color, if any. Otherwise returns nullptr.
    */
   virtual vtkPVProminentValuesInformation* GetProminentValuesInformationForColorArray(
     double uncertaintyAllowed = 1e-6, double fraction = 1e-3, bool force = false);
@@ -307,7 +323,7 @@ public:
     vtkSMPVRepresentationProxy* self = vtkSMPVRepresentationProxy::SafeDownCast(proxy);
     return self
       ? self->GetProminentValuesInformationForColorArray(uncertaintyAllowed, fraction, force)
-      : NULL;
+      : nullptr;
   }
   //@}
 
@@ -347,6 +363,11 @@ public:
   int IsScalarBarStickyVisible(vtkSMProxy* view);
   //@}
 
+  /**
+   * Called after the view updates.
+   */
+  void ViewUpdated(vtkSMProxy* view) override;
+
 protected:
   vtkSMPVRepresentationProxy();
   ~vtkSMPVRepresentationProxy() override;
@@ -391,6 +412,13 @@ protected:
   virtual bool SetScalarColoringInternal(
     const char* arrayname, int attribute_type, bool useComponent, int component);
 
+  /**
+   * Used as a memory of what was the last LUT proxy linked to this representation.
+   * This is used in `UpdateScalarBarRange` to update the scalar bar range when
+   * turning off the coloring for this representation.
+   */
+  vtkSmartPointer<vtkSMProxy> LastLUTProxy;
+
 private:
   vtkSMPVRepresentationProxy(const vtkSMPVRepresentationProxy&) = delete;
   void operator=(const vtkSMPVRepresentationProxy&) = delete;
