@@ -19,7 +19,7 @@
  *
  * vtkSMRenderViewProxy is a 3D view consisting for a render window and two
  * renderers: 1 for 3D geometry and 1 for overlaid 2D geometry.
-*/
+ */
 
 #ifndef vtkSMRenderViewProxy_h
 #define vtkSMRenderViewProxy_h
@@ -33,7 +33,6 @@ class vtkFloatArray;
 class vtkIntArray;
 class vtkRenderer;
 class vtkRenderWindow;
-class vtkRenderWinwInteractor;
 class vtkSMViewProxyInteractorHelper;
 
 class VTKREMOTINGVIEWS_EXPORT vtkSMRenderViewProxy : public vtkSMViewProxy
@@ -85,17 +84,23 @@ public:
    * Convenience method to pick a block in a multi-block data set. Will return
    * the selected representation. Furthermore, if it is a multi-block data set
    * the flat index of the selected block will be returned in flatIndex.
+   *
+   * With introduction of vtkPartitionedDataSet and
+   * vtkPartitionedDataSetCollection, flatIndex is no longer consistent across
+   * ranks and hence this method was changed to return the rank number as well.
    */
-  vtkSMRepresentationProxy* PickBlock(int x, int y, unsigned int& flatIndex);
+  vtkSMRepresentationProxy* PickBlock(int x, int y, unsigned int& flatIndex, int& rank);
 
   /**
    * Given a location is display coordinates (pixels), tries to compute and
-   * return the world location on a surface, if possible. Returns true if the
-   * conversion was successful, else returns false.
-   * If Snap on mesh point is true, it will return a point from the mesh only
+   * return the world location and normal on a surface, if possible. Returns true if the
+   * conversion was successful, else assigns the focal point and plane normal and returns false.
+   * If Snap on mesh point is true, it will return a point and normal from the mesh only.
+   * If point or normal were not available, they will have a vector of
+   * std::numeric_limits<double>::quiet_NaN().
    */
-  bool ConvertDisplayToPointOnSurface(
-    const int display_position[2], double world_position[3], bool snapOnMeshPoint = false);
+  bool ConvertDisplayToPointOnSurface(const int display_position[2], double world_position[3],
+    double world_normal[3], bool snapOnMeshPoint = false);
 
   /**
    * Checks if color depth is sufficient to support selection.
@@ -108,15 +113,16 @@ public:
   /**
    * For backwards compatibility in Python scripts.
    */
-  void ResetCamera();
-  void ResetCamera(double bounds[6]);
-  void ResetCamera(double xmin, double xmax, double ymin, double ymax, double zmin, double zmax);
+  void ResetCamera(bool closest = false);
+  void ResetCamera(double bounds[6], bool closest = false);
+  void ResetCamera(double xmin, double xmax, double ymin, double ymax, double zmin, double zmax,
+    bool closest = false);
   //@}
 
   /**
    * Convenience method for zooming to a representation.
    */
-  virtual void ZoomTo(vtkSMProxy* representation);
+  virtual void ZoomTo(vtkSMProxy* representation, bool closest = false);
 
   //@{
   /**
@@ -145,10 +151,35 @@ public:
    */
   vtkRenderer* GetRenderer();
 
+  enum class CameraAdjustmentType : int
+  {
+    Roll = 0,
+    Elevation,
+    Azimuth,
+    Zoom
+  };
+  //@{
   /**
-   * Returns the client-side camera object.
+   * Returns the client-side active camera object.
+   * Helper methods to adjust its orientation and position.
    */
   vtkCamera* GetActiveCamera();
+  void AdjustActiveCamera(const CameraAdjustmentType&, const double&);
+  void AdjustActiveCamera(const int&, const double&);
+  void AdjustAzimuth(const double& value);
+  void AdjustElevation(const double& value);
+  void AdjustRoll(const double& value);
+  void AdjustZoom(const double& value);
+  void ApplyIsometricView();
+  void ResetActiveCameraToDirection(const double& look_x, const double& look_y,
+    const double& look_z, const double& up_x, const double& up_y, const double& up_z);
+  void ResetActiveCameraToPositiveX();
+  void ResetActiveCameraToNegativeX();
+  void ResetActiveCameraToPositiveY();
+  void ResetActiveCameraToNegativeY();
+  void ResetActiveCameraToPositiveZ();
+  void ResetActiveCameraToNegativeZ();
+  //@}
 
   /**
    * This method calls UpdateInformation on the Camera Proxy
@@ -205,27 +236,6 @@ public:
    */
   vtkFloatArray* CaptureDepthBuffer();
 
-  /**
-   * Access to value-rendered array. Used for deferred color mapping during
-   * in-situ visualization (Cinema).
-   */
-  vtkFloatArray* GetValuesFloat();
-
-  //@{
-
-  /**
-   * Value raster capture controls.
-   */
-  void StartCaptureValues();
-  void StopCaptureValues();
-
-  /**
-   * Access to the current vtkValuePass rendering mode.
-   */
-  int GetValueRenderingMode();
-  void SetValueRenderingMode(int mode);
-  //@}
-
 protected:
   vtkSMRenderViewProxy();
   ~vtkSMRenderViewProxy() override;
@@ -276,7 +286,12 @@ protected:
   bool IsInSelectionMode();
 
   bool IsSelectionCached;
-  void ClearSelectionCache(bool force = false);
+
+  /**
+   * Returns true if the cache clear request was sent to vtkPVRenderView. The
+   * return value is primarily intended for debugging/logging purposes.
+   */
+  bool ClearSelectionCache(bool force = false);
 
   // Internal fields for the observer mechanism that is used to invalidate
   // the cache of selection when the current user became master
