@@ -16,7 +16,6 @@
 
 #include "vtkAppendPolyData.h"
 #include "vtkCellData.h"
-#include "vtkContourValues.h"
 #include "vtkCutter.h"
 #include "vtkDataObject.h"
 #include "vtkDataSet.h"
@@ -32,11 +31,8 @@
 #include "vtkPointLocator.h"
 #include "vtkPointSource.h"
 #include "vtkPolyData.h"
-#include "vtkSMPTools.h"
 #include "vtkUnsignedIntArray.h"
 
-#include <math.h>
-
 vtkStandardNewMacro(vtkThreeSliceFilter);
 
 //----------------------------------------------------------------------------
@@ -58,7 +54,7 @@ vtkThreeSliceFilter::vtkThreeSliceFilter()
     // Bind pipeline
     this->CombinedFilteredInput->AddInputConnection(this->Slices[i]->GetOutputPort());
   }
-  this->Probe = NULL;
+  this->Probe = nullptr;
   this->PointToProbe = vtkPointSource::New();
   this->PointToProbe->SetNumberOfPoints(1);
   this->PointToProbe->SetRadius(0);
@@ -71,24 +67,24 @@ vtkThreeSliceFilter::~vtkThreeSliceFilter()
   for (int i = 0; i < 3; ++i)
   {
     this->Slices[i]->Delete();
-    this->Slices[i] = NULL;
+    this->Slices[i] = nullptr;
     this->Planes[i]->Delete();
-    this->Planes[i] = NULL;
+    this->Planes[i] = nullptr;
   }
 
   this->CombinedFilteredInput->Delete();
-  this->CombinedFilteredInput = NULL;
+  this->CombinedFilteredInput = nullptr;
 
   if (this->PointToProbe)
   {
     this->PointToProbe->Delete();
-    this->PointToProbe = NULL;
+    this->PointToProbe = nullptr;
   }
   if (this->Probe)
   {
     this->Probe->ReleaseDataFlagOn();
     this->Probe->Delete();
-    this->Probe = NULL;
+    this->Probe = nullptr;
   }
 }
 
@@ -223,28 +219,6 @@ int vtkThreeSliceFilter::RequestData(
   return 1;
 }
 
-namespace
-{
-class CutWorker
-{
-public:
-  CutWorker(vtkCutter* slices[3])
-    : Slices(slices)
-  {
-  }
-  void operator()(vtkIdType begin, vtkIdType end)
-  {
-    for (vtkIdType idx = begin; idx < end; ++idx)
-    {
-      Slices[idx]->Update();
-    }
-  }
-
-private:
-  vtkCutter** Slices;
-};
-}
-
 //----------------------------------------------------------------------------
 void vtkThreeSliceFilter::Process(
   vtkDataSet* input, vtkPolyData* outputs[4], unsigned int compositeIndex)
@@ -306,14 +280,12 @@ void vtkThreeSliceFilter::Process(
     }
   }
 
-  // Setup internal pipeline
-  this->Slices[0]->SetInputData(input);
-  this->Slices[1]->SetInputData(input);
-  this->Slices[2]->SetInputData(input);
-
-  // Update components in parallel
-  CutWorker worker(this->Slices);
-  vtkSMPTools::For(0, 3, 1, worker);
+  // Update slices
+  for (int i = 0; i < 3; ++i)
+  {
+    this->Slices[i]->SetInputData(input);
+    this->Slices[i]->Update();
+  }
 
   // Update the internal pipeline
   this->CombinedFilteredInput->Update();
@@ -386,14 +358,14 @@ void vtkThreeSliceFilter::Process(
 //----------------------------------------------------------------------------
 void vtkThreeSliceFilter::EnableProbe(int enable)
 {
-  if (enable != 0 && this->Probe == NULL)
+  if (enable != 0 && this->Probe == nullptr)
   {
     this->Probe = vtkPProbeFilter::New();
   }
-  else if (this->Probe != NULL)
+  else if (this->Probe != nullptr)
   {
     this->Probe->Delete();
-    this->Probe = NULL;
+    this->Probe = nullptr;
   }
 }
 //----------------------------------------------------------------------------
