@@ -30,11 +30,11 @@
 #include "vtkOpenGLState.h"
 #include "vtkPNGWriter.h"
 #include "vtkPVLogger.h"
-#include "vtkPVOptions.h"
 #include "vtkPVProcessWindow.h"
 #include "vtkPVView.h"
 #include "vtkProcessModule.h"
 #include "vtkProp.h"
+#include "vtkRemotingCoreConfiguration.h"
 #include "vtkRendererCollection.h"
 #include "vtkSmartPointer.h"
 #include "vtkTilesHelper.h"
@@ -64,8 +64,8 @@ public:
   }
 
 protected:
-  vtkViewLayoutProp() {}
-  ~vtkViewLayoutProp() override {}
+  vtkViewLayoutProp() = default;
+  ~vtkViewLayoutProp() override = default;
 
   vtkWeakPointer<vtkViewLayout> Layout;
 
@@ -119,21 +119,21 @@ vtkViewLayout::vtkViewLayout()
     auto ren = processWindow->GetRenderers()->GetFirstRenderer();
     ren->AddActor(this->Prop);
 
-    auto options = vtkProcessModule::GetProcessModule()->GetOptions();
-    if (options->GetIsInTileDisplay())
+    auto config = vtkRemotingCoreConfiguration::GetInstance();
+    if (config->GetIsInTileDisplay())
     {
       this->InTileDisplay = true;
-      this->SetTileMullions(options->GetTileMullions());
-      this->SetTileDimensions(options->GetTileDimensions());
+      this->SetTileMullions(config->GetTileMullions());
+      this->SetTileDimensions(config->GetTileDimensions());
       // TODO: skip paste-back on extra ranks if not debugging.
     }
-    else if (options->GetIsInCave())
+    else if (config->GetIsInCave())
     {
       this->InCave = true;
     }
 
     this->DisplayResults =
-      this->InCave || this->InTileDisplay || options->GetForceOnscreenRendering();
+      this->InCave || this->InTileDisplay || config->GetForceOnscreenRendering();
   }
 }
 
@@ -448,7 +448,7 @@ void vtkViewLayout::Paint(vtkViewport* vp)
     {
       auto renWin = vtkOpenGLRenderWindow::SafeDownCast(item.View->GetRenderWindow());
       const int* size = renWin->GetActualSize();
-      if (auto fbo = renWin ? renWin->GetRenderFramebuffer() : nullptr)
+      if (auto fbo = renWin ? renWin->GetDisplayFramebuffer() : nullptr)
       {
         vtkVLogF(PARAVIEW_LOG_RENDERING_VERBOSITY(), "paste back results from `%s`",
           item.View->GetLogName().c_str());
