@@ -37,7 +37,8 @@ protected:
     : ArrayToSortBy(nullptr)
   {
   }
-  ~SortTableFilter() override {}
+  ~SortTableFilter() override = default;
+
 public:
   static SortTableFilter* New();
   int RequestData(
@@ -146,7 +147,7 @@ vtkChartXY* vtkXYChartRepresentation::GetChart()
   }
   else
   {
-    return 0;
+    return nullptr;
   }
 }
 
@@ -183,6 +184,16 @@ void vtkXYChartRepresentation::SetColor(const char* seriesname, double r, double
   this->Modified();
 }
 
+//----------------------------------------------------------------------------
+void vtkXYChartRepresentation::SetOpacity(const char* seriesname, double opacity)
+{
+  if (seriesname)
+  {
+    this->Internals->Opacities[seriesname] = opacity;
+    this->Modified();
+  }
+}
+
 //----------------------------------------------------------------------------
 void vtkXYChartRepresentation::SetUseColorMapping(const char* seriesname, bool useColorMapping)
 {
@@ -269,6 +280,13 @@ void vtkXYChartRepresentation::ClearColors()
   this->Modified();
 }
 
+//----------------------------------------------------------------------------
+void vtkXYChartRepresentation::ClearOpacities()
+{
+  this->Internals->Opacities.clear();
+  this->Modified();
+}
+
 //----------------------------------------------------------------------------
 void vtkXYChartRepresentation::ClearAxisCorners()
 {
@@ -376,6 +394,7 @@ void vtkXYChartRepresentation::PrepareForRendering()
   // Update plots. This will create new vtkPlot if needed.
   this->Internals->UpdatePlots(this, tables);
   this->Internals->UpdatePlotProperties(this);
+
   assert(this->UseIndexForXAxis == true || this->XAxisSeriesName != nullptr);
 }
 
