@@ -168,11 +168,12 @@ QMap<QString, pqEventObserver*> pqTestUtility::eventObservers() const
 }
 
 //-----------------------------------------------------------------------------
-void pqTestUtility::openPlayerDialog()
+pqPlayBackEventsDialog* pqTestUtility::openPlayerDialog()
 {
   pqPlayBackEventsDialog* dialog =
     new pqPlayBackEventsDialog(this->Player, this->Dispatcher, this, QApplication::activeWindow());
   dialog->show();
+  return dialog;
 }
 
 //-----------------------------------------------------------------------------
@@ -247,10 +248,10 @@ bool pqTestUtility::playTests(const QStringList& filenames)
   }
 
   this->PlayingTest = true;
-  emit this->playbackStarted();
+  Q_EMIT this->playbackStarted();
 
   bool success = true;
-  foreach (QString filename, filenames)
+  Q_FOREACH (QString filename, filenames)
   {
     this->Filename = filename;
     if (!this->playingTest())
@@ -258,8 +259,16 @@ bool pqTestUtility::playTests(const QStringList& filenames)
       break;
     }
     QFileInfo info(filename);
-    emit this->playbackStarted(filename);
+
+    if (!info.exists())
+    {
+      qCritical() << filename << " does not exists, aborting";
+      return false;
+    }
+
+    Q_EMIT this->playbackStarted(filename);
     QString suffix = info.suffix();
+
     QMap<QString, pqEventSource*>::iterator iter;
     iter = this->EventSources.find(suffix);
     if (info.isReadable() && iter != this->EventSources.end())
@@ -275,17 +284,17 @@ bool pqTestUtility::playTests(const QStringList& filenames)
         // dispatcher returned failure, don't continue with rest of the tests
         // and flag error.
         success = false;
-        emit this->playbackStopped(info.fileName(), success);
+        Q_EMIT this->playbackStopped(info.fileName(), success);
         break;
       }
-      emit this->playbackStopped(info.fileName(), success);
+      Q_EMIT this->playbackStopped(info.fileName(), success);
       qDebug() << "Test " << info.fileName() << "is finished. Success = " << success;
     }
   }
 
   this->Filename = "";
   this->PlayingTest = false;
-  emit this->playbackStopped();
+  Q_EMIT this->playbackStopped();
 
   return success;
 }
@@ -370,7 +379,7 @@ void pqTestUtility::addObjectStateProperty(QObject* object, const QString& prope
   {
     return;
   }
-  if (property.isEmpty() || !object->property(property.toLatin1()).isValid())
+  if (property.isEmpty() || !object->property(property.toUtf8()).isValid())
   {
     return;
   }
