@@ -1,40 +1,6 @@
-/*****************************************************************************
-*
-* Copyright (c) 2000 - 2018, Lawrence Livermore National Security, LLC
-* Produced at the Lawrence Livermore National Laboratory
-* LLNL-CODE-442911
-* All rights reserved.
-*
-* This file is  part of VisIt. For  details, see https://visit.llnl.gov/.  The
-* full copyright notice is contained in the file COPYRIGHT located at the root
-* of the VisIt distribution or at http://www.llnl.gov/visit/copyright.html.
-*
-* Redistribution  and  use  in  source  and  binary  forms,  with  or  without
-* modification, are permitted provided that the following conditions are met:
-*
-*  - Redistributions of  source code must  retain the above  copyright notice,
-*    this list of conditions and the disclaimer below.
-*  - Redistributions in binary form must reproduce the above copyright notice,
-*    this  list of  conditions  and  the  disclaimer (as noted below)  in  the
-*    documentation and/or other materials provided with the distribution.
-*  - Neither the name of  the LLNS/LLNL nor the names of  its contributors may
-*    be used to endorse or promote products derived from this software without
-*    specific prior written permission.
-*
-* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT  HOLDERS AND CONTRIBUTORS "AS IS"
-* AND ANY EXPRESS OR  IMPLIED WARRANTIES, INCLUDING,  BUT NOT  LIMITED TO, THE
-* IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS FOR A PARTICULAR  PURPOSE
-* ARE  DISCLAIMED. IN  NO EVENT  SHALL LAWRENCE  LIVERMORE NATIONAL  SECURITY,
-* LLC, THE  U.S.  DEPARTMENT OF  ENERGY  OR  CONTRIBUTORS BE  LIABLE  FOR  ANY
-* DIRECT,  INDIRECT,   INCIDENTAL,   SPECIAL,   EXEMPLARY,  OR   CONSEQUENTIAL
-* DAMAGES (INCLUDING, BUT NOT  LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR
-* SERVICES; LOSS OF  USE, DATA, OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER
-* CAUSED  AND  ON  ANY  THEORY  OF  LIABILITY,  WHETHER  IN  CONTRACT,  STRICT
-* LIABILITY, OR TORT  (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY  WAY
-* OUT OF THE  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
-* DAMAGE.
-*
-*****************************************************************************/
+// Copyright (c) Lawrence Livermore National Security, LLC and other VisIt
+// Project developers.  See the top-level LICENSE file for dates and other
+// details.  No copyright assignment is required to contribute to VisIt.
 
 // ************************************************************************* //
 //                                avtDataRequest.h                           //
@@ -56,6 +22,7 @@
 #include <avtGhostData.h>
 
 #include <avtDataSelection.h>
+#include <QueryOverTimeAttributes.h>
 
 class PIPELINE_API avtSILSpecification
 {
@@ -225,6 +192,10 @@ typedef ref_ptr<avtDataRequest> avtDataRequest_p;
 //    Added forceConstructMaterialLabels to allow access to 
 //    material labels without a material variable. 
 //
+//    Alister Maguire, Tue Sep 24 11:15:10 MST 2019
+//    Added retrieveQOTDataset and QOTAtts along with their respective
+//    getters and setters. 
+//
 // ****************************************************************************
 
 class PIPELINE_API avtDataRequest
@@ -247,6 +218,9 @@ class PIPELINE_API avtDataRequest
     const char                  *GetVariable(void) const { return variable; };
     avtSILSpecification         &GetSIL(void)          { return sil; };
     avtSILRestriction_p          GetRestriction(void);
+    const QueryOverTimeAttributes
+                                *GetQOTAtts(void) const;
+    void                         SetQOTAtts(QueryOverTimeAttributes *);
 
     const char                  *GetOriginalVariable(void)
                                                        {return orig_variable;};
@@ -480,6 +454,11 @@ class PIPELINE_API avtDataRequest
     void                         SetNeedPostGhostMaterialInfo(bool b)
                                      { needPostGhostMaterialInfo = b; }
 
+    bool                         RetrieveQOTDataset() const
+                                     { return retrieveQOTDataset; }; 
+    void                         SetRetrieveQOTDataset(bool q)
+                                     { retrieveQOTDataset = q; }; 
+
     void                         SetSelectionName(const std::string &s)
                                      { selectionName = s; }
     const std::string           &GetSelectionName() const
@@ -507,6 +486,7 @@ class PIPELINE_API avtDataRequest
     int                          timestep;
     char                        *variable;
     avtSILSpecification          sil;
+    QueryOverTimeAttributes     *QOTAtts;
     std::vector<CharStrRef>      secondaryVariables;
 
     // original_variable is the name of the variable that the pipeline is
@@ -555,6 +535,7 @@ class PIPELINE_API avtDataRequest
     bool                         passNativeCSG;
     bool                         transformVectorsDuringProject;
     bool                         needPostGhostMaterialInfo;
+    bool                         retrieveQOTDataset;
     std::string                  selectionName;
     MissingDataBehavior_t        missingDataBehavior;
 
