@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    ImageDataConverter.h
+  Module:    ImageDataConverter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -53,9 +53,9 @@ struct ComputeExtents
 
 struct SetGlobalPointIndexStart
 {
-  template <vtkm::IdComponent Dim, typename DynamicCellSetType>
+  template <vtkm::IdComponent Dim>
   void operator()(const vtkm::cont::CellSetStructured<Dim>&, const vtkm::Id3& structuredCoordsDims,
-    const int extent[6], DynamicCellSetType& dcs) const
+    const int extent[6], vtkm::cont::UnknownCellSet& dcs) const
   {
     typename vtkm::cont::CellSetStructured<Dim>::SchedulingRangeType extStart{};
     for (int i = 0, ii = 0; i < 3; ++i)
@@ -65,7 +65,10 @@ struct SetGlobalPointIndexStart
         vtkm::VecTraits<decltype(extStart)>::SetComponent(extStart, ii++, extent[2 * i]);
       }
     }
-    vtkm::cont::Cast<vtkm::cont::CellSetStructured<Dim>>(dcs).SetGlobalPointIndexStart(extStart);
+
+    vtkm::cont::CellSetStructured<Dim> cs;
+    dcs.AsCellSet(cs);
+    cs.SetGlobalPointIndexStart(extStart);
   }
 };
 
@@ -73,6 +76,7 @@ struct SetGlobalPointIndexStart
 
 namespace tovtkm
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 //------------------------------------------------------------------------------
 // convert an image data type
@@ -107,21 +111,23 @@ vtkm::cont::DataSet Convert(vtkImageData* input, FieldsFlag fields)
   return dataset;
 }
 
+VTK_ABI_NAMESPACE_END
 } // tovtkm
 
 namespace fromvtkm
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 bool Convert(
   const vtkm::cont::DataSet& voutput, int extents[6], vtkImageData* output, vtkDataSet* input)
 {
-  vtkm::cont::CoordinateSystem cs = voutput.GetCoordinateSystem();
+  vtkm::cont::CoordinateSystem const& cs = voutput.GetCoordinateSystem();
   if (!cs.GetData().IsType<vtkm::cont::ArrayHandleUniformPointCoordinates>())
   {
     return false;
   }
 
-  auto points = cs.GetData().Cast<vtkm::cont::ArrayHandleUniformPointCoordinates>();
+  auto points = cs.GetData().AsArrayHandle<vtkm::cont::ArrayHandleUniformPointCoordinates>();
   auto portal = points.ReadPortal();
 
   auto origin = portal.GetOrigin();
@@ -150,13 +156,13 @@ bool Convert(
 
 bool Convert(const vtkm::cont::DataSet& voutput, vtkImageData* output, vtkDataSet* input)
 {
-  vtkm::cont::CoordinateSystem cs = voutput.GetCoordinateSystem();
+  vtkm::cont::CoordinateSystem const& cs = voutput.GetCoordinateSystem();
   if (!cs.GetData().IsType<vtkm::cont::ArrayHandleUniformPointCoordinates>())
   {
     return false;
   }
 
-  auto points = cs.GetData().Cast<vtkm::cont::ArrayHandleUniformPointCoordinates>();
+  auto points = cs.GetData().AsArrayHandle<vtkm::cont::ArrayHandleUniformPointCoordinates>();
   auto portal = points.ReadPortal();
 
   auto dim = portal.GetDimensions();
@@ -169,4 +175,5 @@ bool Convert(const vtkm::cont::DataSet& voutput, vtkImageData* output, vtkDataSe
   return Convert(voutput, extents, output, input);
 }
 
+VTK_ABI_NAMESPACE_END
 } // fromvtkm
