@@ -20,12 +20,15 @@
 #include "vtkType.h"             // For vtkMTimeType
 #include "vtkmConfigDataModel.h" //required for general vtkm setup
 
-#include "vtkm/cont/ImplicitFunctionHandle.h"
+#include "vtkm/ImplicitFunction.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImplicitFunction;
+VTK_ABI_NAMESPACE_END
 
 namespace tovtkm
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 class VTKACCELERATORSVTKMDATAMODEL_EXPORT ImplicitFunctionConverter
 {
@@ -33,14 +36,15 @@ public:
   ImplicitFunctionConverter();
 
   void Set(vtkImplicitFunction*);
-  const vtkm::cont::ImplicitFunctionHandle& Get() const;
+  const vtkm::ImplicitFunctionGeneral& Get();
 
 private:
   vtkImplicitFunction* InFunction;
-  vtkm::cont::ImplicitFunctionHandle OutFunction;
+  vtkm::ImplicitFunctionGeneral OutFunction;
   mutable vtkMTimeType MTime;
 };
 
+VTK_ABI_NAMESPACE_END
 }
 
 #endif // vtkmlib_ImplicitFunctionConverter_h
