@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkChartHistogram2D.h"
 #include "vtkColorTransferFunction.h"
 #include "vtkContextMouseEvent.h"
@@ -69,7 +66,7 @@ int TestHistogram2D(int, char*[])
 
   vtkPlotLine* plot = vtkPlotLine::SafeDownCast(chart->AddPlot(vtkChart::LINE));
   plot->SetInputData(table, 0, 1);
-  plot->SetColor(1.0, 0.0, 0.0);
+  plot->SetColorF(1.0, 0.0, 0.0);
   plot->SetWidth(5);
 
   vtkContextMouseEvent mouseEvent;
