@@ -27,6 +27,7 @@
 #include "vtkChart.h"
 #include "vtkChartsCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdTypeArray;
 class vtkPlotBox;
 class vtkStdString;
@@ -56,13 +57,13 @@ public:
    */
   bool Paint(vtkContext2D* painter) override;
 
-  //@{
+  ///@{
   /**
    * Set the visibility of the specified column.
    */
   void SetColumnVisibility(const vtkStdString& name, bool visible);
   void SetColumnVisibility(vtkIdType column, bool visible);
-  //@}
+  ///@}
 
   /**
    * Set the visibility of all columns (true will make them all visible, false
@@ -70,25 +71,25 @@ public:
    */
   void SetColumnVisibilityAll(bool visible);
 
-  //@{
+  ///@{
   /**
    * Get the visibility of the specified column.
    */
   bool GetColumnVisibility(const vtkStdString& name);
   bool GetColumnVisibility(vtkIdType column);
-  //@}
+  ///@}
 
   /**
    * Get the input table column id of a column by its name.
    */
   vtkIdType GetColumnId(const vtkStdString& name);
 
-  //@{
+  ///@{
   /**
    * Get a list of the columns, and the order in which they are displayed.
    */
   vtkGetObjectMacro(VisibleColumns, vtkStringArray);
-  //@}
+  ///@}
 
   // Index of the selected column in the visible columns list.
   vtkGetMacro(SelectedColumn, int);
@@ -161,17 +162,35 @@ public:
   virtual void SetTooltipInfo(const vtkContextMouseEvent&, const vtkVector2d&, vtkIdType, vtkPlot*,
     vtkIdType segmentIndex = -1);
 
+  /**
+   * Calls superclass implementation and sets GeometryValid to False, causing
+   * the chart's geometry to be updated on the next Paint call.
+   */
+  virtual void SetSize(const vtkRectf& rect) override;
+
+  /**
+   * Calls superclass implementation and sets GeometryValid to False, causing
+   * the chart's geometry to be updated on the next Paint call.
+   */
+  virtual void SetGeometry(int arg1, int arg2) override;
+
+  /**
+   * Calls superclass implementation and sets GeometryValid to False, causing
+   * the chart's geometry to be updated on the next Paint call.
+   */
+  virtual void SetLayoutStrategy(int strategy) override;
+
 protected:
   vtkChartBox();
   ~vtkChartBox() override;
 
-  //@{
+  ///@{
   /**
    * Private storage object - where we hide all of our STL objects...
    */
   class Private;
   Private* Storage;
-  //@}
+  ///@}
 
   bool GeometryValid;
 
@@ -185,13 +204,13 @@ protected:
    */
   vtkStringArray* VisibleColumns;
 
-  //@{
+  ///@{
   /**
    * Index of the selected column in the visible columns list.
    */
   int SelectedColumn;
   float SelectedColumnDelta;
-  //@}
+  ///@}
 
   /**
    * The point cache is marked dirty until it has been initialized.
@@ -223,7 +242,7 @@ private:
   void operator=(const vtkChartBox&) = delete;
 };
 
-//@{
+///@{
 /**
  * Small struct used by InvokeEvent to send some information about the point
  * that was clicked on. This is an experimental part of the API, subject to
@@ -236,6 +255,7 @@ struct vtkChartBoxData
   vtkVector2i ScreenPosition;
   int Index;
 };
-//@}
+///@}
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkChartBox_h
