@@ -24,6 +24,7 @@
 #include "vtkContextMouseEvent.h"
 #include "vtkContextScene.h"
 #include "vtkDataArray.h"
+#include "vtkDataSetAttributes.h"
 #include "vtkIdTypeArray.h"
 #include "vtkObjectFactory.h"
 #include "vtkPen.h"
@@ -37,19 +38,15 @@
 #include "vtkTransform2D.h"
 
 #include <algorithm>
+#include <array>
 #include <vector>
 
 // Minimal storage class for STL containers etc.
-class vtkChartParallelCoordinates::Private
+VTK_ABI_NAMESPACE_BEGIN
+struct vtkChartParallelCoordinates::Private final
 {
-public:
-  Private()
-  {
-    this->Plot = vtkSmartPointer<vtkPlotParallelCoordinates>::New();
-    this->Transform = vtkSmartPointer<vtkTransform2D>::New();
-    this->CurrentAxis = -1;
-    this->AxisResize = -1;
-  }
+  Private() { this->Plot = vtkSmartPointer<vtkPlotParallelCoordinates>::New(); }
+
   ~Private()
   {
     for (std::vector<vtkAxis*>::iterator it = this->Axes.begin(); it != this->Axes.end(); ++it)
@@ -57,13 +54,22 @@ public:
       (*it)->Delete();
     }
   }
+
   vtkSmartPointer<vtkPlotParallelCoordinates> Plot;
-  vtkSmartPointer<vtkTransform2D> Transform;
+  vtkNew<vtkTransform2D> Transform;
   std::vector<vtkAxis*> Axes;
-  std::vector<vtkVector<float, 2>> AxesSelections;
-  int CurrentAxis;
-  int AxisResize;
-  bool InteractiveSelection;
+
+  /**
+   * Store for each axe, an sorted array like { minRange1, maxRange1, minRange2, maxRange2, ...} to
+   * simplify the treatment of selection for addition, subtraction, toggle
+   */
+  std::vector<std::vector<float>> AxesSelections;
+  std::array<float, 2> CurrentSelection = { { -1, -1 } };
+
+  int CurrentAxis = -1;
+  int AxisResize = -1;
+
+  bool InteractiveSelection = false;
 };
 
 //------------------------------------------------------------------------------
@@ -128,19 +134,17 @@ void vtkChartParallelCoordinates::Update()
       this->AddItem(axis);
       this->Storage->Axes.push_back(axis);
     }
-    this->Storage->AxesSelections.resize(this->Storage->Axes.size(), vtkVector2f(0, 0));
+
+    this->Storage->AxesSelections.resize(this->Storage->Axes.size());
   }
 
+  vtkDataSetAttributes* rowData = table->GetRowData();
+
   // Now set up their ranges and locations
   for (int i = 0; i < this->VisibleColumns->GetNumberOfTuples(); ++i)
   {
     double range[2];
-    vtkDataArray* array =
-      vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(this->VisibleColumns->GetValue(i)));
-    if (array)
-    {
-      array->GetRange(range);
-    }
+    rowData->GetRange(this->VisibleColumns->GetValue(i).c_str(), range);
     vtkAxis* axis = this->Storage->Axes[i];
     if (axis->GetBehavior() == 0)
     {
@@ -216,27 +220,47 @@ bool vtkChartParallelCoordinates::Paint(vtkContext2D* painter)
       axis->GetPoint1()[0] - 10, this->Point1[1], 20, this->Point2[1] - this->Point1[1]);
   }
 
-  // Now draw our active selections
-  for (size_t i = 0; i < this->Storage->AxesSelections.size(); ++i)
+  // Draw the active selection
+  std::array<float, 2> range = this->Storage->CurrentSelection;
+  if (range[0] != range[1])
   {
-    vtkVector<float, 2>& range = this->Storage->AxesSelections[i];
-    if (range[0] != range[1])
-    {
-      painter->GetBrush()->SetColor(200, 20, 20, 220);
-      float x = this->Storage->Axes[i]->GetPoint1()[0] - 5;
-      float y = range[0];
-      y *= this->Storage->Transform->GetMatrix()->GetElement(1, 1);
-      y += this->Storage->Transform->GetMatrix()->GetElement(1, 2);
-      float height = range[1] - range[0];
-      height *= this->Storage->Transform->GetMatrix()->GetElement(1, 1);
+    this->PaintRect(painter, this->Storage->CurrentAxis, range[0], range[1]);
+  }
 
-      painter->DrawRect(x, y, 10, height);
+  // Draw all stored range
+  for (size_t axis = 0; axis < this->Storage->AxesSelections.size(); ++axis)
+  {
+    size_t size = this->Storage->AxesSelections[axis].size();
+    size = size - size % 2;
+    for (size_t j = 0; j < size; j += 2)
+    {
+      float min = this->Storage->AxesSelections[axis][j];
+      float max = this->Storage->AxesSelections[axis][j + 1];
+      if (min != max)
+      {
+        this->PaintRect(painter, static_cast<int>(axis), min, max);
+      }
     }
   }
 
   return true;
 }
 
+//------------------------------------------------------------------------------
+bool vtkChartParallelCoordinates::PaintRect(vtkContext2D* painter, int axis, float min, float max)
+{
+  painter->GetBrush()->SetColor(200, 20, 20, 220);
+  float x = this->Storage->Axes[axis]->GetPoint1()[0] - 5;
+  float y = min;
+  y *= this->Storage->Transform->GetMatrix()->GetElement(1, 1);
+  y += this->Storage->Transform->GetMatrix()->GetElement(1, 2);
+  float height = max - min;
+  height *= this->Storage->Transform->GetMatrix()->GetElement(1, 1);
+
+  painter->DrawRect(x, y, 10, height);
+  return true;
+}
+
 //------------------------------------------------------------------------------
 void vtkChartParallelCoordinates::SetColumnVisibility(const vtkStdString& name, bool visible)
 {
@@ -461,7 +485,7 @@ bool vtkChartParallelCoordinates::MouseMoveEvent(const vtkContextMouseEvent& mou
     // If an axis is selected, then lets try to narrow down a selection...
     if (this->Storage->CurrentAxis >= 0)
     {
-      vtkVector<float, 2>& range = this->Storage->AxesSelections[this->Storage->CurrentAxis];
+      std::array<float, 2>& range = this->Storage->CurrentSelection;
 
       // Normalize the coordinates
       float current = mouse.GetScenePos().GetY();
@@ -521,11 +545,6 @@ bool vtkChartParallelCoordinates::MouseMoveEvent(const vtkContextMouseEvent& mou
       float scale =
         (axis->GetPoint2()[1] - axis->GetPoint1()[1]) / (axis->GetMaximum() - axis->GetMinimum());
       axis->SetMinimum(axis->GetMinimum() - deltaY / scale);
-      // If there is an active selection on the axis, remove it
-      if (this->ResetAxeSelection(this->Storage->CurrentAxis))
-      {
-        this->ResetSelection();
-      }
 
       // Now update everything that needs to be
       axis->Update();
@@ -539,11 +558,6 @@ bool vtkChartParallelCoordinates::MouseMoveEvent(const vtkContextMouseEvent& mou
       float scale =
         (axis->GetPoint2()[1] - axis->GetPoint1()[1]) / (axis->GetMaximum() - axis->GetMinimum());
       axis->SetMaximum(axis->GetMaximum() - deltaY / scale);
-      // If there is an active selection on the axis, remove it
-      if (this->ResetAxeSelection(this->Storage->CurrentAxis))
-      {
-        this->ResetSelection();
-      }
 
       axis->Update();
       axis->RecalculateTickSpacing();
@@ -577,8 +591,6 @@ bool vtkChartParallelCoordinates::MouseButtonPressEvent(const vtkContextMouseEve
           axis->GetPoint1()[0] + 10 > mouse.GetScenePos()[0])
         {
           this->Storage->CurrentAxis = static_cast<int>(i);
-          this->ResetAxeSelection(this->Storage->CurrentAxis);
-          this->ResetSelection();
           // This is a manual interactive selection
           this->Storage->InteractiveSelection = true;
 
@@ -586,7 +598,7 @@ bool vtkChartParallelCoordinates::MouseButtonPressEvent(const vtkContextMouseEve
           float low = mouse.GetScenePos()[1];
           low -= this->Storage->Transform->GetMatrix()->GetElement(1, 2);
           low /= this->Storage->Transform->GetMatrix()->GetElement(1, 1);
-          vtkVector<float, 2>& range = this->Storage->AxesSelections[this->Storage->CurrentAxis];
+          std::array<float, 2>& range = this->Storage->CurrentSelection;
           range[0] = range[1] = low;
 
           this->Scene->SetDirty(true);
@@ -643,7 +655,7 @@ bool vtkChartParallelCoordinates::MouseButtonReleaseEvent(const vtkContextMouseE
   {
     if (this->Storage->CurrentAxis >= 0)
     {
-      vtkVector<float, 2>& range = this->Storage->AxesSelections[this->Storage->CurrentAxis];
+      std::array<float, 2>& range = this->Storage->CurrentSelection;
 
       float final = mouse.GetScenePos()[1];
       final -= this->Storage->Transform->GetMatrix()->GetElement(1, 2);
@@ -663,22 +675,11 @@ bool vtkChartParallelCoordinates::MouseButtonReleaseEvent(const vtkContextMouseE
         range[1] = final;
       }
 
-      if (range[0] == range[1])
-      {
-        this->ResetSelection();
-      }
-      else
-      {
-        // Add a new selection
-        if (range[0] < range[1])
-        {
-          this->Storage->Plot->SetSelectionRange(this->Storage->CurrentAxis, range[0], range[1]);
-        }
-        else
-        {
-          this->Storage->Plot->SetSelectionRange(this->Storage->CurrentAxis, range[1], range[0]);
-        }
-      }
+      // Update all range stored based on the new selection
+      UpdateCurrentAxisSelection(this->Storage->CurrentAxis);
+      this->Storage->CurrentSelection[0] = 0;
+      this->Storage->CurrentSelection[1] = 0;
+
       // This is a manual interactive selection
       this->Storage->InteractiveSelection = true;
 
@@ -719,38 +720,27 @@ bool vtkChartParallelCoordinates::MouseWheelEvent(const vtkContextMouseEvent&, i
 void vtkChartParallelCoordinates::ResetSelection()
 {
   // This function takes care of resetting the selection of the chart
-  // Reset the axes.
   this->Storage->Plot->ResetSelectionRange();
 
-  // Now set the remaining selections that were kept
-  for (size_t i = 0; i < this->Storage->AxesSelections.size(); ++i)
+  for (size_t axe = 0; axe < this->Storage->AxesSelections.size(); axe++)
   {
-    vtkVector<float, 2>& range = this->Storage->AxesSelections[i];
-    if (range[0] != range[1])
+    if (!this->Storage->AxesSelections[axe].empty())
     {
-      // Process the selected range and display this
-      if (range[0] < range[1])
-      {
-        this->Storage->Plot->SetSelectionRange(static_cast<int>(i), range[0], range[1]);
-      }
-      else
-      {
-        this->Storage->Plot->SetSelectionRange(static_cast<int>(i), range[1], range[0]);
-      }
+      this->Storage->Plot->SetSelectionRange(
+        static_cast<int>(axe), this->Storage->AxesSelections[axe]);
     }
   }
 }
 
 //------------------------------------------------------------------------------
-bool vtkChartParallelCoordinates::ResetAxeSelection(int axe)
+void vtkChartParallelCoordinates::ResetAxeSelection(int axe)
 {
-  vtkVector<float, 2>& range = this->Storage->AxesSelections[axe];
-  if (range[0] != range[1])
+  for (size_t i = 0; i < this->Storage->AxesSelections[axe].size(); i += 2)
   {
-    range[0] = range[1] = 0.0f;
-    return true;
+    float& min = this->Storage->AxesSelections[axe][i];
+    float& max = this->Storage->AxesSelections[axe][i + 1];
+    min = max = 0.0f;
   }
-  return false;
 }
 
 //------------------------------------------------------------------------------
@@ -779,13 +769,152 @@ void vtkChartParallelCoordinates::SwapAxes(int a1, int a2)
   this->Storage->Axes[a1] = this->Storage->Axes[a2];
   this->Storage->Axes[a2] = axisTmp;
 
-  vtkVector<float, 2> selTmp = this->Storage->AxesSelections[a1];
+  std::vector<float> selTmp = this->Storage->AxesSelections[a1];
   this->Storage->AxesSelections[a1] = this->Storage->AxesSelections[a2];
   this->Storage->AxesSelections[a2] = selTmp;
 
-  vtkStdString colTmp = this->VisibleColumns->GetValue(a1);
+  std::string colTmp = this->VisibleColumns->GetValue(a1);
   this->VisibleColumns->SetValue(a1, this->VisibleColumns->GetValue(a2));
   this->VisibleColumns->SetValue(a2, colTmp);
 
   this->Storage->Plot->Update();
 }
+
+//------------------------------------------------------------------------------
+void vtkChartParallelCoordinates::UpdateCurrentAxisSelection(int axisId)
+{
+  // min/max in the selection can be not ordered
+  std::array<float, 2> currentSelection = this->Storage->CurrentSelection;
+  float minCurrentSelection = std::min(currentSelection[0], currentSelection[1]);
+  float maxCurrentSelection = std::max(currentSelection[0], currentSelection[1]);
+
+  bool isANewRange = true;
+  bool startAMerge = false;
+
+  // Invalid range will be set to -1
+  size_t size = this->Storage->AxesSelections[axisId].size();
+  size =
+    this->Storage->AxesSelections[axisId].size() - this->Storage->AxesSelections[axisId].size() % 2;
+  for (size_t i = 0; i < size; i += 2)
+  {
+    if (this->GetSelectionMode() == vtkContextScene::SELECTION_TOGGLE)
+    {
+      break;
+    }
+
+    float& minRange = this->Storage->AxesSelections[axisId][i];
+    float& maxRange = this->Storage->AxesSelections[axisId][i + 1];
+
+    if (this->GetSelectionMode() == vtkContextScene::SELECTION_ADDITION)
+    {
+      // Delete range inside the currentSeleciton
+      if (minCurrentSelection < minRange && maxCurrentSelection > maxRange)
+      {
+        minRange = -1;
+        if (startAMerge && i >= this->Storage->AxesSelections[axisId].size())
+        {
+          maxRange = maxCurrentSelection;
+        }
+        else
+        {
+          maxRange = -1;
+          continue;
+        }
+      }
+
+      // Increase the range in min
+      if (minCurrentSelection < minRange && maxCurrentSelection > minRange &&
+        maxCurrentSelection < maxRange)
+      {
+        if (startAMerge)
+        {
+          minRange = -1;
+        }
+        else
+        {
+          minRange = minCurrentSelection;
+          isANewRange = false;
+          break;
+        }
+      }
+
+      // Merge range by addition
+      if (minCurrentSelection > minRange && minCurrentSelection < maxRange)
+      {
+        if (maxCurrentSelection > maxRange)
+        {
+          bool isLastRange = (i + 2) >= this->Storage->AxesSelections[axisId].size();
+          if (isLastRange)
+          {
+            maxRange = maxCurrentSelection;
+            isANewRange = false;
+            break;
+          }
+          else
+          {
+            if (maxCurrentSelection < this->Storage->AxesSelections[axisId][i + 2])
+            {
+              maxRange = maxCurrentSelection;
+            }
+            else
+            {
+              maxRange = -1;
+              startAMerge = true;
+            }
+          }
+          isANewRange = false;
+        }
+      }
+    }
+
+    if (this->GetSelectionMode() == vtkContextScene::SELECTION_SUBTRACTION)
+    {
+      isANewRange = false;
+
+      // Delete a range
+      if (minCurrentSelection <= minRange && maxCurrentSelection >= maxRange)
+      {
+        minRange = -1;
+        maxRange = -1;
+      }
+
+      // Shrink a range
+      if (minCurrentSelection < minRange &&
+        (maxCurrentSelection > minRange && maxCurrentSelection <= maxRange))
+      {
+        minRange = maxCurrentSelection;
+      }
+      if (maxCurrentSelection > maxRange &&
+        (minCurrentSelection < maxRange && minCurrentSelection >= minRange))
+      {
+        maxRange = minCurrentSelection;
+      }
+
+      // Split a range in 2 part
+      if (minCurrentSelection > minRange && maxCurrentSelection < maxRange)
+      {
+        isANewRange = true;
+        break;
+      }
+    }
+  }
+
+  // Remove invalidated ranges
+  this->Storage->AxesSelections[axisId].erase(
+    std::remove(this->Storage->AxesSelections[axisId].begin(),
+      this->Storage->AxesSelections[axisId].end(), -1),
+    this->Storage->AxesSelections[axisId].end());
+
+  if (isANewRange)
+  {
+    this->Storage->AxesSelections[axisId].push_back(minCurrentSelection);
+    this->Storage->AxesSelections[axisId].push_back(maxCurrentSelection);
+  }
+
+  std::sort(
+    this->Storage->AxesSelections[axisId].begin(), this->Storage->AxesSelections[axisId].end());
+
+  // To support multiple selection, we need to recalculate all the selection
+  this->ResetSelection();
+}
+VTK_ABI_NAMESPACE_END
