@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkChartXY.h"
 
 #include "vtkAnnotationLink.h"
@@ -25,6 +22,7 @@
 #include "vtkChartLegend.h"
 #include "vtkColorSeries.h"
 #include "vtkCommand.h"
+#include "vtkCompositeDataIterator.h"
 #include "vtkContext2D.h"
 #include "vtkContextClip.h"
 #include "vtkContextKeyEvent.h"
@@ -37,6 +35,7 @@
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkMath.h"
+#include "vtkMultiBlockDataSet.h"
 #include "vtkObjectFactory.h"
 #include "vtkPen.h"
 #include "vtkPlotArea.h"
@@ -51,7 +50,6 @@
 #include "vtkSelection.h"
 #include "vtkSelectionNode.h"
 #include "vtkSmartPointer.h"
-#include "vtkStdString.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
 #include "vtkTextProperty.h"
@@ -63,9 +61,11 @@
 // My STL containers
 #include <algorithm>
 #include <unordered_map>
+#include <utility>
 #include <vector>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 class vtkChartXYPrivate
 {
 public:
@@ -139,6 +139,11 @@ public:
   vtkTimeStamp TransformCalculatedTime;
   std::unordered_map<vtkIdType, vtkPlot*> PlotCache;
   bool PlotCacheUpdated = false;
+
+  // Associate a flat composite index to a list of related plot
+  std::unordered_map<unsigned int, std::vector<vtkPlot*>> MapCompositeIndexToPlots;
+  // Reversed association
+  std::unordered_map<vtkPlot*, unsigned int> PlotCompositeIndexes;
 };
 
 //------------------------------------------------------------------------------
@@ -176,7 +181,7 @@ vtkChartXY::vtkChartXY()
   {
     this->ChartPrivate->axes.push_back(vtkAxis::New());
     // By default just show the left and bottom axes
-    this->ChartPrivate->axes.back()->SetVisible(i < 2 ? true : false);
+    this->ChartPrivate->axes.back()->SetVisible(i < 2);
     this->AttachAxisRangeListener(this->ChartPrivate->axes.back());
     this->AddItem(this->ChartPrivate->axes.back());
   }
@@ -215,6 +220,10 @@ vtkChartXY::vtkChartXY()
   this->ForceAxesToBounds = false;
   this->IgnoreNanInBounds = false;
   this->ZoomWithMouseWheel = true;
+  for (int i = 0; i < 4; ++i)
+  {
+    this->AxisZoom[i] = true;
+  }
   this->AdjustLowerBoundForLogPlot = false;
 
   this->DragPoint = false;
@@ -257,13 +266,36 @@ void vtkChartXY::Update()
     // Two major selection methods - row based or plot based.
     if (this->SelectionMethod == vtkChart::SELECTION_ROWS)
     {
-      vtkSelectionNode* node = selection->GetNumberOfNodes() > 0 ? selection->GetNode(0) : nullptr;
-      vtkIdTypeArray* idArray =
-        node ? vtkArrayDownCast<vtkIdTypeArray>(node->GetSelectionList()) : nullptr;
-      for (vtkPlot* plot : this->ChartPrivate->plots)
+      // Clear former selections before assigning anything
+      this->ReleasePlotSelections();
+
+      for (unsigned int i = 0; i < selection->GetNumberOfNodes(); ++i)
       {
-        // Use the first selection node for all plots to select the rows.
-        plot->SetSelection(idArray);
+        vtkSelectionNode* node = selection->GetNode(i);
+        vtkIdTypeArray* idArray = vtkArrayDownCast<vtkIdTypeArray>(node->GetSelectionList());
+        if (node->GetProperties()->Has(vtkSelectionNode::COMPOSITE_INDEX()))
+        {
+          const int compositeIndex =
+            node->GetProperties()->Get(vtkSelectionNode::COMPOSITE_INDEX());
+
+          const auto findIndex = this->ChartPrivate->MapCompositeIndexToPlots.find(compositeIndex);
+          if (findIndex != this->ChartPrivate->MapCompositeIndexToPlots.end())
+          {
+            for (vtkPlot* plot : findIndex->second)
+            {
+              plot->SetSelection(idArray);
+            }
+          }
+        }
+        else
+        {
+          // Use the first selection node for all plots to select the rows if no composite index
+          for (vtkPlot* plot : this->ChartPrivate->plots)
+          {
+            plot->SetSelection(idArray);
+          }
+          break;
+        }
       }
     }
     else if (this->SelectionMethod == vtkChart::SELECTION_PLOTS)
@@ -422,22 +454,27 @@ bool vtkChartXY::Paint(vtkContext2D* painter)
 
   // Now that plot transforms, including whether to use log scaling and the
   // shift-scale factors, have been updated, we give the vtkPlot instances an
-  // opportunity to update caches.
+  // opportunity to update their internal caches.
   for (size_t i = 0; i < this->ChartPrivate->plots.size(); ++i)
   {
-    this->ChartPrivate->plots[i]->UpdateCache();
+    this->ChartPrivate->plots[i]->Update();
   }
 
   // Update the clipping if necessary
-  this->ChartPrivate->Clip->SetClip(this->Point1[0], this->Point1[1],
-    this->Point2[0] - this->Point1[0], this->Point2[1] - this->Point1[1]);
+  // An extra padding of 1 pixel is taken into account such that lines near
+  // the edge of the chart's patch are correctly shown.
+  const double pad = 1;
+  this->ChartPrivate->Clip->SetClip(this->Point1[0] - pad, this->Point1[1] - pad,
+    this->Point2[0] - this->Point1[0] + 2 * pad, this->Point2[1] - this->Point1[1] + 2 * pad);
 
   // draw background
   if (this->BackgroundBrush)
   {
     painter->GetPen()->SetLineType(vtkPen::NO_PEN);
     painter->ApplyBrush(this->BackgroundBrush);
-    painter->DrawRect(this->Point1[0], this->Point1[1], this->Geometry[0], this->Geometry[1]);
+    // Take borders into account:
+    painter->DrawRect(this->Point1[0] - this->Borders[0], this->Point1[1] - this->Borders[1],
+      this->Geometry[0], this->Geometry[1]);
   }
 
   // Use the scene to render most of the chart.
@@ -483,22 +520,19 @@ bool vtkChartXY::Paint(vtkContext2D* painter)
     }
   }
 
-  if (this->Title)
+  int offset = 0; // title margin.
+  vtkAxis* topAxis = this->ChartPrivate->axes[vtkAxis::TOP];
+  if (topAxis->GetVisible())
   {
-    int offset = 0; // title margin.
-    vtkAxis* topAxis = this->ChartPrivate->axes[vtkAxis::TOP];
-    if (topAxis->GetVisible())
-    {
-      vtkRectf bounds = topAxis->GetBoundingRect(painter);
-      offset += static_cast<int>(bounds.GetHeight());
-    }
-    vtkPoints2D* rect = vtkPoints2D::New();
-    rect->InsertNextPoint(this->Point1[0], this->Point2[1] + offset);
-    rect->InsertNextPoint(this->Point2[0] - this->Point1[0], 10);
-    painter->ApplyTextProp(this->TitleProperties);
-    painter->DrawStringRect(rect, this->Title);
-    rect->Delete();
+    vtkRectf bounds = topAxis->GetBoundingRect(painter);
+    offset += static_cast<int>(bounds.GetHeight());
   }
+  vtkPoints2D* rect = vtkPoints2D::New();
+  rect->InsertNextPoint(this->Point1[0], this->Point2[1] + offset);
+  rect->InsertNextPoint(this->Point2[0] - this->Point1[0], 10);
+  painter->ApplyTextProp(this->TitleProperties);
+  painter->DrawStringRect(rect, this->Title);
+  rect->Delete();
 
   return true;
 }
@@ -705,7 +739,7 @@ void vtkChartXY::RecalculatePlotBounds()
   double bounds[4] = { 0.0, 0.0, 0.0, 0.0 };
   for (it = this->ChartPrivate->plots.begin(); it != this->ChartPrivate->plots.end(); ++it)
   {
-    if ((*it)->GetVisible() == false)
+    if (!(*it)->GetVisible())
     {
       continue;
     }
@@ -967,7 +1001,7 @@ bool vtkChartXY::UpdateLayout(vtkContext2D* painter)
         }
       }
       border += this->GetLegendBorder(painter, i);
-      if (i == vtkAxis::TOP && this->Title)
+      if (i == vtkAxis::TOP)
       {
         painter->ApplyTextProp(this->TitleProperties);
         float bounds[4];
@@ -1206,7 +1240,7 @@ void vtkChartXY::SetLegendPosition(const vtkRectf& rect)
 }
 
 //------------------------------------------------------------------------------
-vtkPlot* vtkChartXY::AddPlot(int type)
+vtkPlot* vtkChartXY::AddPlot(int type, unsigned int blockIndex)
 {
   // Use a variable to return the object created (or nullptr), this is necessary
   // as the HP compiler is broken (thinks this function does not return) and
@@ -1276,14 +1310,20 @@ vtkPlot* vtkChartXY::AddPlot(int type)
   }
   if (plot)
   {
-    this->AddPlot(plot);
+    this->AddPlot(plot, blockIndex);
     plot->Delete();
   }
   return plot;
 }
 
 //------------------------------------------------------------------------------
-vtkIdType vtkChartXY::AddPlot(vtkPlot* plot)
+vtkPlot* vtkChartXY::AddPlot(int type)
+{
+  return this->AddPlot(type, 0);
+}
+
+//------------------------------------------------------------------------------
+vtkIdType vtkChartXY::AddPlot(vtkPlot* plot, unsigned int blockIndex)
 {
   if (plot == nullptr)
   {
@@ -1307,16 +1347,35 @@ vtkIdType vtkChartXY::AddPlot(vtkPlot* plot)
   {
     this->Scene->SetDirty(true);
   }
+
+  this->ChartPrivate->MapCompositeIndexToPlots[blockIndex].emplace_back(plot);
+  this->ChartPrivate->PlotCompositeIndexes[plot] = blockIndex;
+
   return plotIndex;
 }
 
+//------------------------------------------------------------------------------
+vtkIdType vtkChartXY::AddPlot(vtkPlot* plot)
+{
+  return this->AddPlot(plot, 0);
+}
+
 //------------------------------------------------------------------------------
 bool vtkChartXY::RemovePlot(vtkIdType index)
 {
   if (index < static_cast<vtkIdType>(this->ChartPrivate->plots.size()))
   {
     this->RemovePlotFromCorners(this->ChartPrivate->plots[index]);
-    this->ChartPrivate->plots[index]->Delete();
+
+    // Remove plot from our block search structures
+    vtkPlot* plot = this->ChartPrivate->plots[index];
+    const auto& flatIndex = this->ChartPrivate->PlotCompositeIndexes.find(plot);
+    auto& vecPlots = this->ChartPrivate->MapCompositeIndexToPlots[flatIndex->second];
+    this->ChartPrivate->PlotCompositeIndexes.erase(flatIndex);
+    vecPlots.erase(std::find(vecPlots.begin(), vecPlots.end(), plot));
+
+    // Delete plot
+    plot->Delete();
     this->ChartPrivate->plots.erase(this->ChartPrivate->plots.begin() + index);
 
     // Ensure that the bounds are recalculated
@@ -1500,11 +1559,19 @@ void vtkChartXY::SetAxis(int axisIndex, vtkAxis* axis)
 {
   if ((axisIndex < 4) && (axisIndex >= 0))
   {
+    // Retrieve plot corners for all plots.
+    std::vector<int> corners;
+    corners.reserve(this->GetNumberOfPlots());
+    std::transform(this->ChartPrivate->plots.begin(), this->ChartPrivate->plots.end(),
+      std::back_inserter(corners),
+      [this](vtkPlot* plot) -> int { return this->GetPlotCorner(plot); });
+
     vtkAxis* old_axis = this->ChartPrivate->axes[axisIndex];
     this->ChartPrivate->axes[axisIndex] = axis;
     this->ChartPrivate->axes[axisIndex]->SetVisible(old_axis->GetVisible());
 
     // remove the old axis
+    old_axis->RemoveObservers(vtkChartXY::UpdateRange);
     this->RemoveItem(old_axis);
 
     this->AttachAxisRangeListener(this->ChartPrivate->axes[axisIndex]);
@@ -1529,6 +1596,12 @@ void vtkChartXY::SetAxis(int axisIndex, vtkAxis* axis)
         grid2->SetYAxis(this->ChartPrivate->axes[vtkAxis::RIGHT]);
         break;
     }
+
+    // Reset plot corner for all plots (which will update the plot's reference to the new axis)
+    for (int i = 0; i < this->GetNumberOfPlots(); i++)
+    {
+      this->SetPlotCorner(this->ChartPrivate->plots[i], corners[i]);
+    }
   }
 }
 
@@ -1588,6 +1661,25 @@ void vtkChartXY::RemovePlotSelections()
   this->InvokeEvent(vtkCommand::SelectionChangedEvent);
 }
 
+//------------------------------------------------------------------------------
+void vtkChartXY::SetAxisZoom(int index, bool v)
+{
+  if ((index >= 0) && (index < 4))
+  {
+    this->AxisZoom[index] = v;
+  }
+}
+
+//------------------------------------------------------------------------------
+bool vtkChartXY::GetAxisZoom(int index)
+{
+  if ((index >= 0) && (index < 4))
+  {
+    return this->AxisZoom[index];
+  }
+  return false;
+}
+
 //------------------------------------------------------------------------------
 bool vtkChartXY::Hit(const vtkContextMouseEvent& mouse)
 {
@@ -1596,15 +1688,8 @@ bool vtkChartXY::Hit(const vtkContextMouseEvent& mouse)
     return false;
   }
   vtkVector2i pos(mouse.GetScreenPos());
-  if (pos[0] > this->Point1[0] && pos[0] < this->Point2[0] && pos[1] > this->Point1[1] &&
-    pos[1] < this->Point2[1])
-  {
-    return true;
-  }
-  else
-  {
-    return false;
-  }
+  return pos[0] > this->Point1[0] && pos[0] < this->Point2[0] && pos[1] > this->Point1[1] &&
+    pos[1] < this->Point2[1];
 }
 
 //------------------------------------------------------------------------------
@@ -1892,9 +1977,10 @@ bool vtkChartXY::LocatePointInPlots(const vtkContextMouseEvent& mouse, int invok
           int seriesIndex = LocatePointInPlot(position, tolerance, plotPos, plot, segmentIndex);
           if (seriesIndex >= 0)
           {
-            // We found a point, set up the tooltip and return
-            vtkRectd ss(plot->GetShiftScale());
-            vtkVector2d plotPosd(plotPos[0] / ss[2] - ss[0], plotPos[1] / ss[3] - ss[1]);
+            // We found a point, set up the tooltip and return. Note: we do not
+            // need to apply the shift nor scale from the plot because they
+            // have been applied in LocatePointInPlot() already.
+            vtkVector2d plotPosd(plotPos[0], plotPos[1]);
             this->SetTooltipInfo(mouse, plotPosd, seriesIndex, plot, segmentIndex);
             if (invokeEvent >= 0)
             {
@@ -1938,7 +2024,7 @@ void vtkChartXY::SetTooltipInfo(const vtkContextMouseEvent& mouse, const vtkVect
   }
 
   // Have the plot generate its tooltip label
-  vtkStdString tooltipLabel = plot->GetTooltipLabel(plotPos, seriesIndex, segmentIndex);
+  std::string tooltipLabel = plot->GetTooltipLabel(plotPos, seriesIndex, segmentIndex);
 
   // Set the tooltip
   this->Tooltip->SetText(tooltipLabel);
@@ -2109,10 +2195,10 @@ bool vtkChartXY::MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse)
     // supported - row-based selections add all rows from all plots and set that
     // as the selection, plot-based selections create a selection node for each
     // plot.
-    vtkNew<vtkIdTypeArray> oldSelection;
-    vtkNew<vtkIdTypeArray> accumulateSelection;
     if (this->SelectionMethod == vtkChart::SELECTION_ROWS)
     {
+      MapIndexToIds oldSelection;
+      MapIndexToIds accumulateSelection;
       // There is only one global selection, we build up a union of all rows
       // selected in all charts and set that on all plots.
       for (size_t i = 0; i < this->ChartPrivate->PlotCorners.size(); ++i)
@@ -2132,11 +2218,31 @@ bool vtkChartXY::MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse)
             vtkPlot* plot = vtkPlot::SafeDownCast(this->ChartPrivate->PlotCorners[i]->GetItem(j));
             if (plot && plot->GetVisible() && plot->GetSelectable())
             {
-              // There is only really one old selection in this mode.
-              if (i == 0 && j == 0)
+              const auto findPlot = this->ChartPrivate->PlotCompositeIndexes.find(plot);
+              // Skipping unrelated plot
+              if (findPlot == this->ChartPrivate->PlotCompositeIndexes.end())
               {
-                oldSelection->DeepCopy(plot->GetSelection());
+                continue;
               }
+              const unsigned int flatIndex = findPlot->second;
+
+              // Build old selection (there is only really one old selection in this mode)
+              if (i == 0)
+              {
+                const auto findOld = oldSelection.find(flatIndex);
+                if (findOld == oldSelection.end())
+                {
+                  auto array = vtkSmartPointer<vtkIdTypeArray>::New();
+                  array->DeepCopy(plot->GetSelection());
+                  oldSelection.insert({ flatIndex, array });
+                }
+                else
+                {
+                  vtkChartXY::BuildSelection(nullptr, vtkContextScene::SELECTION_ADDITION,
+                    findOld->second, plot->GetSelection(), nullptr);
+                }
+              }
+
               // Populate the selection using the appropriate shape.
               if (polygonMode)
               {
@@ -2147,19 +2253,29 @@ bool vtkChartXY::MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse)
                 plot->SelectPoints(min, max);
               }
 
-              // Accumulate the selection in each plot.
+              // Accumulate the selection in each plot and block.
+              auto findSel = accumulateSelection.find(flatIndex);
+              if (findSel == accumulateSelection.end())
+              {
+                findSel =
+                  accumulateSelection.insert({ flatIndex, vtkSmartPointer<vtkIdTypeArray>::New() })
+                    .first;
+              }
               vtkChartXY::BuildSelection(nullptr, vtkContextScene::SELECTION_ADDITION,
-                accumulateSelection, plot->GetSelection(), nullptr);
+                findSel->second.GetPointer(), plot->GetSelection(), nullptr);
             }
           }
         }
       }
+
       // Now add the accumulated selection to the old selection.
-      vtkChartXY::BuildSelection(
-        this->AnnotationLink, selectionMode, accumulateSelection, oldSelection, nullptr);
+      vtkChartXY::BuildSelection(selectionMode, accumulateSelection, oldSelection);
+      vtkChartXY::MakeSelection(this->AnnotationLink, accumulateSelection);
     }
     else if (this->SelectionMethod == vtkChart::SELECTION_PLOTS)
     {
+      vtkNew<vtkIdTypeArray> oldSelection;
+      vtkNew<vtkIdTypeArray> accumulateSelection;
       // We are performing plot based selections.
       for (size_t i = 0; i < this->ChartPrivate->PlotCorners.size(); ++i)
       {
@@ -2198,6 +2314,8 @@ bool vtkChartXY::MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse)
     }
     else if (this->SelectionMethod == vtkChart::SELECTION_COLUMNS)
     {
+      vtkNew<vtkIdTypeArray> oldSelection;
+      vtkNew<vtkIdTypeArray> accumulateSelection;
       if (this->AnnotationLink)
       {
         this->AnnotationLink->Update();
@@ -2243,8 +2361,7 @@ bool vtkChartXY::MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse)
                 int idx = 1; // y
                 vtkAbstractArray* column =
                   plot->GetData()->GetInputAbstractArrayToProcess(idx, plot->GetInput());
-                int columnID = -1;
-                plot->GetInput()->GetRowData()->GetAbstractArray(column->GetName(), columnID);
+                int columnID = plot->GetInput()->GetColumnIndex(column->GetName());
                 if (plotSelection->GetNumberOfTuples() != column->GetNumberOfTuples())
                 {
                   plotSelection->SetNumberOfTuples(0);
@@ -2267,6 +2384,7 @@ bool vtkChartXY::MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse)
       vtkChartXY::BuildSelection(
         this->AnnotationLink, selectionMode, accumulateSelection, oldSelection, nullptr);
     }
+
     this->InvokeEvent(vtkCommand::SelectionChangedEvent);
     this->MouseBox.SetWidth(0.0);
     this->MouseBox.SetHeight(0.0);
@@ -2367,6 +2485,11 @@ bool vtkChartXY::MouseWheelEvent(const vtkContextMouseEvent&, int delta)
   // Get the bounds of each plot.
   for (int i = 0; i < 4; ++i)
   {
+    if (!this->AxisZoom[i])
+    {
+      continue;
+    }
+
     vtkAxis* axis = this->ChartPrivate->axes[i];
     double min = axis->GetMinimum();
     double max = axis->GetMaximum();
@@ -2410,6 +2533,11 @@ bool vtkChartXY::KeyPressEvent(const vtkContextKeyEvent& key)
   return true;
 }
 
+const std::vector<vtkContextTransform*>& vtkChartXY::GetTransforms() const
+{
+  return this->ChartPrivate->PlotCorners;
+}
+
 //------------------------------------------------------------------------------
 bool vtkChartXY::RemovePlotFromCorners(vtkPlot* plot)
 {
@@ -2521,6 +2649,46 @@ void vtkChartXY::MakeSelection(vtkAnnotationLink* link, vtkIdTypeArray* selectio
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkChartXY::MakeSelection(vtkAnnotationLink* link, const MapIndexToIds& inSelection)
+{
+  if (!link)
+  {
+    return;
+  }
+
+  vtkNew<vtkSelection> selection;
+
+  // If only one key and this key is 0, we consider input is not a composite dataset and we
+  // handle the selection without COMPOSITE_INDEX
+  if (inSelection.size() == 1 && inSelection.count(0) > 0)
+  {
+    vtkNew<vtkSelectionNode> node;
+    selection->AddNode(node);
+    node->SetContentType(vtkSelectionNode::INDICES);
+    node->SetFieldType(vtkSelectionNode::POINT);
+    node->SetSelectionList(inSelection.at(0));
+  }
+  else
+  {
+    for (const auto& pair : inSelection)
+    {
+      if (pair.second->GetNumberOfValues() > 0)
+      {
+        vtkNew<vtkSelectionNode> node;
+        node->SetContentType(vtkSelectionNode::INDICES);
+        node->SetFieldType(vtkSelectionNode::POINT);
+        node->GetProperties()->Set(vtkSelectionNode::COMPOSITE_INDEX(), pair.first);
+        node->SetSelectionList(pair.second);
+
+        selection->AddNode(node);
+      }
+    }
+  }
+
+  link->SetCurrentSelection(selection);
+}
+
 //------------------------------------------------------------------------------
 void vtkChartXY::MinusSelection(vtkIdTypeArray* selection, vtkIdTypeArray* oldSelection)
 {
@@ -2659,6 +2827,72 @@ void vtkChartXY::BuildSelection(vtkAnnotationLink* link, int selectionMode,
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkChartXY::BuildSelection(
+  int selectionMode, MapIndexToIds& selection, const MapIndexToIds& oldSelection)
+{
+  // Some set of keys useful for processing our selections
+  // Having a map of indices here is kind of overkill since we don't really need the values
+  // but it is necessary for doing the intersection of keys in a cross-plateform way
+  MapIndexToIds intersection;
+  MapIndexToIds uniqueOldSelection;
+  MapIndexToIds uniqueSelection;
+  using MapPair = std::pair<unsigned int, vtkSmartPointer<vtkIdTypeArray>>;
+  const auto compKey = [](const MapPair& p1, const MapPair& p2) { return p1.first < p2.first; };
+  std::set_intersection(selection.begin(), selection.end(), oldSelection.begin(),
+    oldSelection.end(), std::inserter(intersection, intersection.begin()), compKey);
+  std::set_difference(oldSelection.begin(), oldSelection.end(), selection.begin(), selection.end(),
+    std::inserter(uniqueOldSelection, uniqueOldSelection.begin()), compKey);
+
+  switch (selectionMode)
+  {
+    case vtkContextScene::SELECTION_ADDITION:
+      for (const auto& pair : intersection)
+      {
+        AddSelection(selection.at(pair.first), oldSelection.at(pair.first));
+      }
+      for (const auto& pair : uniqueOldSelection)
+      {
+        selection.insert(pair);
+      }
+      break;
+
+    case vtkContextScene::SELECTION_SUBTRACTION:
+      for (const auto& pair : intersection)
+      {
+        MinusSelection(selection.at(pair.first), oldSelection.at(pair.first));
+      }
+      for (const auto& pair : uniqueOldSelection)
+      {
+        selection.insert(pair);
+      }
+      // Remove selection not affecting old selected blocks because we're substracting
+      std::set_difference(selection.begin(), selection.end(), oldSelection.begin(),
+        oldSelection.end(), std::inserter(uniqueSelection, uniqueSelection.begin()), compKey);
+      for (const auto& pair : uniqueSelection)
+      {
+        selection.erase(pair.first);
+      }
+      break;
+
+    case vtkContextScene::SELECTION_TOGGLE:
+      for (const auto& pair : intersection)
+      {
+        ToggleSelection(selection.at(pair.first), oldSelection.at(pair.first));
+      }
+      for (const auto& pair : uniqueOldSelection)
+      {
+        selection.insert(pair);
+      }
+      break;
+
+    case vtkContextScene::SELECTION_DEFAULT:
+    default:
+      // Nothing necessary - overwrite the old selection.
+      break;
+  }
+}
+
 //------------------------------------------------------------------------------
 int vtkChartXY::GetMouseSelectionMode(const vtkContextMouseEvent& mouse, int selectionMode)
 {
@@ -2678,3 +2912,4 @@ int vtkChartXY::GetMouseSelectionMode(const vtkContextMouseEvent& mouse, int sel
   }
   return selectionMode;
 }
+VTK_ABI_NAMESPACE_END
