@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkChartXYZ.h
+  Module:    vtkChartXYZ.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -45,6 +45,7 @@
 #include <list>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkChartXYZ);
 
 //------------------------------------------------------------------------------
@@ -772,7 +773,7 @@ void vtkChartXYZ::NewDetermineWhichAxesToLabel()
       gradient = dy / dx;
     }
 
-    axisData.push_back(std::make_tuple(axisState, std::abs(gradient), gradient, axis));
+    axisData.emplace_back(axisState, std::abs(gradient), gradient, axis);
   }
 
   // sort the list of axes by state (low enum value to high) and, for standard axes by gradient
@@ -1140,12 +1141,7 @@ void vtkChartXYZ::LegacyDetermineWhichAxesToLabel()
 //------------------------------------------------------------------------------
 bool vtkChartXYZ::Hit(const vtkContextMouseEvent& vtkNotUsed(mouse))
 {
-  if (!this->Interactive || !this->Visible || this->AutoRotate)
-  {
-    return false;
-  }
-
-  return true;
+  return this->Interactive && this->Visible && !this->AutoRotate;
 }
 
 //------------------------------------------------------------------------------
@@ -1906,7 +1902,7 @@ bool vtkChartXYZ::RemovePlot(vtkPlot3D* plot)
   {
     if (this->Plots[i] == plot)
     {
-      this->Plots[i] = 0;
+      this->Plots[i] = nullptr;
       this->FreePlaces.push_back(i);
       ret = true;
     }
@@ -1979,3 +1975,4 @@ void vtkChartXYZ::SetClippingPlanesEnabled(bool v)
     this->Scene->SetDirty(true);
   }
 }
+VTK_ABI_NAMESPACE_END
