@@ -29,6 +29,7 @@
 #include "vtkTransform2D.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkColorLegend);
 
 //------------------------------------------------------------------------------
@@ -37,6 +38,7 @@ vtkColorLegend::vtkColorLegend()
   this->Interpolate = true;
   this->Axis = vtkSmartPointer<vtkAxis>::New();
   this->Axis->SetPosition(vtkAxis::RIGHT);
+  this->Axis->SetRangeLabelsVisible(true);
   this->AddItem(this->Axis);
   this->SetInline(false);
   this->SetHorizontalAlignment(vtkChartLegend::RIGHT);
@@ -105,6 +107,8 @@ void vtkColorLegend::Update()
   if (bounds[0] != axisBounds[0] || bounds[1] != axisBounds[1])
   {
     this->Axis->SetUnscaledRange(bounds[0], bounds[1]);
+    this->Axis->SetUnscaledMinimumLimit(bounds[0]);
+    this->Axis->SetUnscaledMaximumLimit(bounds[1]);
   }
 
   this->Axis->Update();
@@ -272,10 +276,6 @@ void vtkColorLegend::ComputeTexture()
     return;
   }
 
-  // Set the axis up
-  this->Axis->SetUnscaledRange(bounds[0], bounds[1]);
-  // this->Axis->AutoScale();
-
   // Could depend on the screen resolution
   const int dimension = 256;
   double* values = new double[dimension];
@@ -288,14 +288,14 @@ void vtkColorLegend::ComputeTexture()
   {
     this->ImageData->SetExtent(0, dimension - 1, 0, 0, 0, 0);
   }
-  this->ImageData->AllocateScalars(VTK_UNSIGNED_CHAR, 3);
+  this->ImageData->AllocateScalars(VTK_UNSIGNED_CHAR, 4);
 
   for (int i = 0; i < dimension; ++i)
   {
     values[i] = bounds[0] + i * (bounds[1] - bounds[0]) / (dimension - 1);
   }
   unsigned char* ptr = reinterpret_cast<unsigned char*>(this->ImageData->GetScalarPointer());
-  this->TransferFunction->MapScalarsThroughTable2(values, ptr, VTK_DOUBLE, dimension, 1, 3);
+  this->TransferFunction->MapScalarsThroughTable2(values, ptr, VTK_DOUBLE, dimension, 1, 4);
   delete[] values;
 }
 
@@ -368,3 +368,4 @@ bool vtkColorLegend::MouseMoveEvent(const vtkContextMouseEvent& mouse)
   this->UpdateAxisPosition();
   return retval;
 }
+VTK_ABI_NAMESPACE_END
