@@ -28,12 +28,15 @@
 #ifndef vtkControlPointsItem_h
 #define vtkControlPointsItem_h
 
+#include "vtkPlot.h"
+
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkCommand.h"          // For vtkCommand enum
-#include "vtkPlot.h"
-#include "vtkSmartPointer.h" // for SmartPointer
-#include "vtkVector.h"       // For vtkVector2f
+#include "vtkSmartPointer.h"     // For SmartPointer
+#include "vtkVector.h"           // For vtkVector2f
+#include <string>                // Used by GetControlPointLabel
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCallbackCommand;
 class vtkContext2D;
 class vtkControlPointsAddPointItem;
@@ -65,7 +68,7 @@ public:
    */
   void GetBounds(double bounds[4]) override;
 
-  //@{
+  ///@{
   /**
    * Set custom bounds, except if bounds are invalid, bounds will be
    * automatically computed based on the range of the control points
@@ -73,9 +76,9 @@ public:
    */
   vtkSetVector4Macro(UserBounds, double);
   vtkGetVector4Macro(UserBounds, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Controls the valid range for the values.
    * An invalid value (0, -1, 0., -1, 0, -1.) indicates that the valid
@@ -83,18 +86,18 @@ public:
    */
   vtkSetVector4Macro(ValidBounds, double);
   vtkGetVector4Macro(ValidBounds, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/set the radius for screen points.
    * Default is 6.f
    */
   vtkGetMacro(ScreenPointRadius, float);
   vtkSetMacro(ScreenPointRadius, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the flag to draw points.
    * Default is true.
@@ -102,7 +105,7 @@ public:
   vtkGetMacro(DrawPoints, bool);
   vtkSetMacro(DrawPoints, bool);
   vtkBooleanMacro(DrawPoints, bool);
-  //@}
+  ///@}
 
   /**
    * Paint the points with a fixed size (cosmetic) which doesn't depend
@@ -193,7 +196,7 @@ public:
    */
   void GetControlPointsIds(vtkIdTypeArray* ids, bool excludeFirstAndLast = false) const;
 
-  //@{
+  ///@{
   /**
    * Controls whether or not control points are drawn (true) or clicked and
    * moved (false).
@@ -201,9 +204,9 @@ public:
    */
   vtkSetMacro(StrokeMode, bool);
   vtkGetMacro(StrokeMode, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If DrawPoints is false, SwitchPoints controls the behavior when a control
    * point is dragged past another point. The crossed point becomes current
@@ -212,9 +215,9 @@ public:
    */
   vtkSetMacro(SwitchPointsMode, bool);
   vtkGetMacro(SwitchPointsMode, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If EndPointsMovable is false, the two end points will not
    * be moved. True by default.
@@ -224,33 +227,33 @@ public:
   vtkSetMacro(EndPointsYMovable, bool);
   vtkGetMacro(EndPointsYMovable, bool);
   virtual bool GetEndPointsMovable();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If EndPointsRemovable is false, the two end points will not
    * be removed. True by default.
    */
   vtkSetMacro(EndPointsRemovable, bool);
   vtkGetMacro(EndPointsRemovable, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When set to true, labels are shown on the current control point and the end
    * points. Default is false.
    */
   vtkSetMacro(ShowLabels, bool);
   vtkGetMacro(ShowLabels, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the label format. Default is "%.4f, %.4f".
    */
   vtkSetStringMacro(LabelFormat);
   vtkGetStringMacro(LabelFormat);
-  //@}
+  ///@}
 
   /**
    * Add a point to the function. Returns the index of the point (0 based),
@@ -340,22 +343,22 @@ public:
    */
   void SetCurrentPoint(vtkIdType index);
 
-  //@{
+  ///@{
   /**
    * Gets the selected point pen and brush.
    */
   vtkGetObjectMacro(SelectedPointPen, vtkPen);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Depending on the control points item, the brush might not be taken into
    * account.
    */
   vtkGetObjectMacro(SelectedPointBrush, vtkBrush);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When enabled, a dedicated item is used to determine if a point should
    * be added when clicking anywhere.
@@ -365,7 +368,7 @@ public:
   vtkGetMacro(UseAddPointItem, bool);
   vtkSetMacro(UseAddPointItem, bool);
   vtkBooleanMacro(UseAddPointItem, bool);
-  //@}
+  ///@}
 
   /**
    * Item dedicated to add point, to be added below all other items.
@@ -379,7 +382,7 @@ public:
    */
   void ResetBounds();
 
-  //@{
+  ///@{
   /**
    * Mouse and key events.
    */
@@ -389,7 +392,7 @@ public:
   bool MouseMoveEvent(const vtkContextMouseEvent& mouse) override;
   bool KeyPressEvent(const vtkContextKeyEvent& key) override;
   bool KeyReleaseEvent(const vtkContextKeyEvent& key) override;
-  //@}
+  ///@}
 
 protected:
   vtkControlPointsItem();
@@ -409,14 +412,14 @@ protected:
   static void CallComputePoints(
     vtkObject* sender, unsigned long event, void* receiver, void* params);
 
-  //@{
+  ///@{
   /**
    * Must be reimplemented by subclasses to calculate the points to draw.
    * It's subclass responsibility to call ComputePoints() via the callback
    */
   virtual void ComputePoints();
   virtual vtkMTimeType GetControlPointsMTime() = 0;
-  //@}
+  ///@}
 
   /**
    * Returns true if the supplied x, y are within the bounds or on a control point.
@@ -425,16 +428,16 @@ protected:
    */
   bool Hit(const vtkContextMouseEvent& mouse) override;
 
-  //@{
+  ///@{
   /**
    * Clamp the given 2D pos into the bounds of the function.
    * Return true if the pos has been clamped, false otherwise.
    */
   bool ClampValidDataPos(double pos[2]);
   bool ClampValidScreenPos(double pos[2]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Internal function that paints a collection of points and optionally
    * excludes some.
@@ -442,7 +445,7 @@ protected:
   void DrawUnselectedPoints(vtkContext2D* painter);
   void DrawSelectedPoints(vtkContext2D* painter);
   virtual void DrawPoint(vtkContext2D* painter, vtkIdType index);
-  //@}
+  ///@}
 
   void SetCurrentPointPos(const vtkVector2f& newPos);
   vtkIdType SetPointPos(vtkIdType point, const vtkVector2f& newPos);
@@ -458,7 +461,7 @@ protected:
   /**
    * Generate label for a control point.
    */
-  virtual vtkStdString GetControlPointLabel(vtkIdType index);
+  virtual std::string GetControlPointLabel(vtkIdType index);
 
   void AddPointId(vtkIdType addedPointId);
 
@@ -493,7 +496,7 @@ protected:
   double UserBounds[4] = { 0., -1., 0., -1. };
   double ValidBounds[4] = { 0., -1., 0., -1. };
 
-  vtkNew<vtkTransform2D> Transform;
+  vtkNew<vtkTransform2D> ControlPointsTransform;
   float ScreenPointRadius = 6.f;
 
   bool DrawPoints = true;
@@ -523,4 +526,5 @@ private:
   bool UseAddPointItem = false;
   vtkNew<vtkControlPointsAddPointItem> AddPointItem;
 };
+VTK_ABI_NAMESPACE_END
 #endif
