@@ -13,14 +13,13 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkPlot.h"
 
 #include "vtkAxis.h"
 #include "vtkBrush.h"
 #include "vtkContextMapper2D.h"
+#include "vtkContextMouseEvent.h"
+#include "vtkContextTransform.h"
 #include "vtkDataObject.h"
 #include "vtkIdTypeArray.h"
 #include "vtkNew.h"
@@ -28,8 +27,10 @@
 #include "vtkPen.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
+#include "vtkTransform2D.h"
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkPlot, XAxis, vtkAxis);
 vtkCxxSetObjectMacro(vtkPlot, YAxis, vtkAxis);
 
@@ -75,6 +76,44 @@ vtkPlot::~vtkPlot()
   this->SetYAxis(nullptr);
 }
 
+//------------------------------------------------------------------------------
+void vtkPlot::Update()
+{
+  if (!this->Visible)
+  {
+    return;
+  }
+  // Check if we have an input
+  if (!this->Data->GetInput())
+  {
+    vtkDebugMacro(<< "Update event called with no input table data set.");
+    return;
+  }
+
+  bool data_updated = false;
+  if (this->Data->GetMTime() > this->BuildTime ||
+    this->Data->GetInput()->GetMTime() > this->BuildTime)
+  {
+    this->Data->Update();
+    data_updated = true;
+  }
+
+  if (data_updated || this->CacheRequiresUpdate())
+  {
+    vtkDebugMacro(<< "Updating internal cached values.");
+    this->UpdateCache();
+    this->BuildTime.Modified();
+  }
+}
+
+//------------------------------------------------------------------------------
+bool vtkPlot::CacheRequiresUpdate()
+{
+  return (this->MTime > this->BuildTime) ||
+    (this->XAxis && this->XAxis->GetMTime() > this->BuildTime) ||
+    (this->YAxis && this->YAxis->GetMTime() > this->BuildTime);
+}
+
 //------------------------------------------------------------------------------
 bool vtkPlot::PaintLegend(vtkContext2D*, const vtkRectf&, int)
 {
@@ -82,54 +121,18 @@ bool vtkPlot::PaintLegend(vtkContext2D*, const vtkRectf&, int)
 }
 
 //------------------------------------------------------------------------------
-vtkIdType vtkPlot::GetNearestPoint(
-  const vtkVector2f& point, const vtkVector2f& tolerance, vtkVector2f* location)
+vtkIdType vtkPlot::GetNearestPoint(const vtkVector2f& vtkNotUsed(point),
+  const vtkVector2f& vtkNotUsed(tolerance), vtkVector2f* vtkNotUsed(location),
+  vtkIdType* vtkNotUsed(segmentId))
 {
-  // When using legacy code, we need to make sure old override are still called
-  // and old call are still working. This is the more generic way to achieve that
-  // The flag is here to ensure that the two implementation
-  // do not call each other in an infinite loop.
-  if (!this->LegacyRecursionFlag)
-  {
-    vtkIdType segmentId;
-    this->LegacyRecursionFlag = true;
-    vtkIdType ret = this->GetNearestPoint(point, tolerance, location, &segmentId);
-    this->LegacyRecursionFlag = false;
-    return ret;
-  }
-  else
-  {
-    return -1;
-  }
-}
-
-//------------------------------------------------------------------------------
-vtkIdType vtkPlot::GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tolerance,
-  vtkVector2f* location, vtkIdType* vtkNotUsed(segmentId))
-{
-  if (!this->LegacyRecursionFlag)
-  {
-    this->LegacyRecursionFlag = true;
-    int ret = this->GetNearestPoint(point, tolerance, location);
-    this->LegacyRecursionFlag = false;
-    if (ret != -1)
-    {
-      VTK_LEGACY_REPLACED_BODY(vtkPlot::GetNearestPoint(const vtkVector2f& point,
-                                 const vtkVector2f& tol, vtkVector2f* location),
-        "VTK 9.0",
-        vtkPlot::GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tol,
-          vtkVector2f* location, vtkIdType* segmentId));
-    }
-    return ret;
-  }
   return -1;
 }
 
 //------------------------------------------------------------------------------
 vtkStdString vtkPlot::GetTooltipLabel(const vtkVector2d& plotPos, vtkIdType seriesIndex, vtkIdType)
 {
-  vtkStdString tooltipLabel;
-  vtkStdString& format =
+  std::string tooltipLabel;
+  std::string& format =
     this->TooltipLabelFormat.empty() ? this->TooltipDefaultLabelFormat : this->TooltipLabelFormat;
   // Parse TooltipLabelFormat and build tooltipLabel
   bool escapeNext = false;
@@ -235,25 +238,27 @@ void vtkPlot::SetColor(unsigned char r, unsigned char g, unsigned char b, unsign
 }
 
 //------------------------------------------------------------------------------
-void vtkPlot::SetColor(double r, double g, double b)
+void vtkPlot::SetColorF(double r, double g, double b, double a)
+{
+  this->Pen->SetColorF(r, g, b, a);
+}
+
+//------------------------------------------------------------------------------
+void vtkPlot::SetColorF(double r, double g, double b)
 {
   this->Pen->SetColorF(r, g, b);
 }
 
 //------------------------------------------------------------------------------
-void vtkPlot::GetColor(double rgb[3])
+void vtkPlot::GetColor(unsigned char rgb[3])
 {
-  this->Pen->GetColorF(rgb);
+  this->Pen->GetColor(rgb);
 }
 
 //------------------------------------------------------------------------------
-void vtkPlot::GetColor(unsigned char rgb[3])
+void vtkPlot::GetColorF(double rgb[3])
 {
-  double rgbF[3];
-  this->GetColor(rgbF);
-  rgb[0] = static_cast<unsigned char>(255. * rgbF[0] + 0.5);
-  rgb[1] = static_cast<unsigned char>(255. * rgbF[1] + 0.5);
-  rgb[2] = static_cast<unsigned char>(255. * rgbF[2] + 0.5);
+  this->Pen->GetColorF(rgb);
 }
 
 //------------------------------------------------------------------------------
@@ -483,7 +488,7 @@ vtkStdString vtkPlot::GetLabel(vtkIdType index)
   }
   else
   {
-    return vtkStdString();
+    return {};
   }
 }
 //------------------------------------------------------------------------------
@@ -497,8 +502,8 @@ void vtkPlot::SetInputData(vtkTable* table)
 void vtkPlot::SetInputData(
   vtkTable* table, const vtkStdString& xColumn, const vtkStdString& yColumn)
 {
-  vtkDebugMacro(<< "Setting input, X column = \"" << xColumn.c_str() << "\", "
-                << "Y column = \"" << yColumn.c_str() << "\"");
+  vtkDebugMacro(<< "Setting input, X column = \"" << xColumn << "\", "
+                << "Y column = \"" << yColumn << "\"");
 
   this->Data->SetInputData(table);
   this->Data->SetInputArrayToProcess(
@@ -514,12 +519,24 @@ void vtkPlot::SetInputData(vtkTable* table, vtkIdType xColumn, vtkIdType yColumn
   this->SetInputData(table, table->GetColumnName(xColumn), table->GetColumnName(yColumn));
 }
 
+//------------------------------------------------------------------------------
+void vtkPlot::SetInputConnection(vtkAlgorithmOutput* input)
+{
+  this->Data->SetInputConnection(0, input);
+}
+
 //------------------------------------------------------------------------------
 vtkTable* vtkPlot::GetInput()
 {
   return this->Data->GetInput();
 }
 
+//------------------------------------------------------------------------------
+vtkAlgorithmOutput* vtkPlot::GetInputConnection()
+{
+  return this->Data->GetInputConnection(0, 0);
+}
+
 //------------------------------------------------------------------------------
 void vtkPlot::SetInputArray(int index, const vtkStdString& name)
 {
@@ -674,3 +691,28 @@ bool vtkPlot::ClampPos(double pos[2])
   this->GetBounds(bounds);
   return vtkPlot::ClampPos(pos, bounds);
 }
+
+//------------------------------------------------------------------------------
+bool vtkPlot::Hit(const vtkContextMouseEvent& mouse)
+{
+  if (!this->Interactive || !this->Visible)
+  {
+    return false;
+  }
+  double screenBounds[4];
+  this->GetBounds(screenBounds);
+  vtkContextTransform* transform = vtkContextTransform::SafeDownCast(this->Parent);
+  vtkVector2f tol;
+  constexpr int picking_zone_size = 5;
+  if (transform != nullptr)
+  {
+    tol.SetX(std::fabs(
+      picking_zone_size * (1.0 / transform->GetTransform()->GetMatrix()->GetElement(0, 0))));
+    tol.SetY(std::fabs(
+      picking_zone_size * (1.0 / transform->GetTransform()->GetMatrix()->GetElement(1, 1))));
+  }
+  vtkVector2f loc;
+  vtkIdType segmentId;
+  return this->GetNearestPoint(mouse.GetPos(), tol, &loc, &segmentId) >= 0;
+}
+VTK_ABI_NAMESPACE_END
