@@ -30,11 +30,12 @@
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkContextItem.h"
 #include "vtkContextPolygon.h" // For vtkContextPolygon
-#include "vtkDeprecation.h"    // For VTK_DEPRECATED_IN_9_0_0
+#include "vtkDeprecation.h"    // For VTK_DEPRECATED_IN_9_3_0
 #include "vtkRect.h"           // For vtkRectd ivar
 #include "vtkSmartPointer.h"   // Needed to hold SP ivars
 #include "vtkStdString.h"      // Needed to hold TooltipLabelFormat ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkVariant;
 class vtkTable;
 class vtkIdTypeArray;
@@ -43,6 +44,7 @@ class vtkPen;
 class vtkBrush;
 class vtkAxis;
 class vtkStringArray;
+class vtkAlgorithmOutput;
 
 class VTKCHARTSCORE_EXPORT vtkPlot : public vtkContextItem
 {
@@ -50,7 +52,14 @@ public:
   vtkTypeMacro(vtkPlot, vtkContextItem);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  /**
+   * Perform any updates to the item that may be necessary before rendering.
+   * The scene should take care of calling this on all items before their
+   * Paint function is invoked.
+   */
+  void Update() override;
+
+  ///@{
   /**
    * Set whether the plot renders an entry in the legend. Default is true.
    * vtkPlot::PaintLegend will get called to render the legend marker on when
@@ -59,7 +68,7 @@ public:
   vtkSetMacro(LegendVisibility, bool);
   vtkGetMacro(LegendVisibility, bool);
   vtkBooleanMacro(LegendVisibility, bool);
-  //@}
+  ///@}
 
   /**
    * Paint legend event for the plot, called whenever the legend needs the
@@ -70,7 +79,7 @@ public:
    */
   virtual bool PaintLegend(vtkContext2D* painter, const vtkRectf& rect, int legendIndex);
 
-  //@{
+  ///@{
   /**
    * Sets/gets a printf-style string to build custom tooltip labels from.
    * An empty string generates the default tooltip labels.
@@ -85,23 +94,23 @@ public:
    */
   virtual void SetTooltipLabelFormat(const vtkStdString& label);
   virtual vtkStdString GetTooltipLabelFormat();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets/gets the tooltip notation style.
    */
   virtual void SetTooltipNotation(int notation);
   virtual int GetTooltipNotation();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets/gets the tooltip precision.
    */
   virtual void SetTooltipPrecision(int precision);
   virtual int GetTooltipPrecision();
-  //@}
+  ///@}
 
   /**
    * Generate and return the tooltip label string for this plot
@@ -118,17 +127,6 @@ public:
   virtual vtkIdType GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tolerance,
     vtkVector2f* location, vtkIdType* segmentId);
 
-  /**
-   * Function to query a plot for the nearest point to the specified coordinate.
-   * Returns the index of the data series with which the point is associated, or
-   * -1 if no point was found.
-   * Deprecated method, uses GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tolerance,
-   * vtkVector2f* location, vtkIdType* segmentId); instead.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Use the vtkPlot::GetNearestPoint() overload with a segmentId argument")
-  virtual vtkIdType GetNearestPoint(
-    const vtkVector2f& point, const vtkVector2f& tolerance, vtkVector2f* location);
-
   /**
    * Select all points in the specified rectangle.
    */
@@ -139,15 +137,40 @@ public:
    */
   virtual bool SelectPointsInPolygon(const vtkContextPolygon& polygon);
 
-  //@{
   /**
-   * Set the plot color
+   * Set the plot color with integer values (comprised between 0 and 255)
    */
   virtual void SetColor(unsigned char r, unsigned char g, unsigned char b, unsigned char a);
-  virtual void SetColor(double r, double g, double b);
-  virtual void GetColor(double rgb[3]);
+
+  ///@{
+  /**
+   * Set the plot color with floating values (comprised between 0.0 and 1.0)
+   */
+  virtual void SetColorF(double r, double g, double b, double a);
+  virtual void SetColorF(double r, double g, double b);
+
+  // If removed, please remplace it with the following function:
+  // SetColor(unsigned char r, unsigned char g, unsigned char b)
+  // here and in the inheriting classes overriding it
+  VTK_DEPRECATED_IN_9_3_0("Please use unambiguous SetColorF method instead.")
+  virtual void SetColor(double r, double g, double b) { this->SetColorF(r, g, b); };
+  ///@}
+
+  /**
+   * Get the plot color as integer rgb values (comprised between 0 and 255)
+   */
   void GetColor(unsigned char rgb[3]);
-  //@}
+
+  ///@{
+  /**
+   * Get the plot color as floating rgb values (comprised between 0.0 and 1.0)
+   */
+  virtual void GetColorF(double rgb[3]);
+
+  // If removed, please make GetColor(unsigned char rgb[3]) virtual
+  VTK_DEPRECATED_IN_9_3_0("Please use unambiguous GetColorF method instead.")
+  virtual void GetColor(double rgb[3]) { this->GetColorF(rgb); };
+  ///@
 
   /**
    * Set the width of the line.
@@ -159,39 +182,39 @@ public:
    */
   virtual float GetWidth();
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkPen object that controls how this plot draws (out)lines.
    */
   void SetPen(vtkPen* pen);
   vtkPen* GetPen();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkBrush object that controls how this plot fills shapes.
    */
   void SetBrush(vtkBrush* brush);
   vtkBrush* GetBrush();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkBrush object that controls how this plot fills selected
    * shapes.
    */
   void SetSelectionPen(vtkPen* pen);
   vtkPen* GetSelectionPen();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkBrush object that controls how this plot fills selected
    * shapes.
    */
   void SetSelectionBrush(vtkBrush* brush);
   vtkBrush* GetSelectionBrush();
-  //@}
+  ///@}
 
   /**
    * Set the label of this plot.
@@ -242,23 +265,23 @@ public:
    */
   vtkContextMapper2D* GetData();
 
-  //@{
+  ///@{
   /**
    * Use the Y array index for the X value. If true any X column setting will be
    * ignored, and the X values will simply be the index of the Y column.
    */
   vtkGetMacro(UseIndexForXSeries, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Use the Y array index for the X value. If true any X column setting will be
    * ignored, and the X values will simply be the index of the Y column.
    */
   vtkSetMacro(UseIndexForXSeries, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This is a convenience function to set the input table and the x, y column
    * for the plot.
@@ -267,13 +290,25 @@ public:
   virtual void SetInputData(
     vtkTable* table, const vtkStdString& xColumn, const vtkStdString& yColumn);
   void SetInputData(vtkTable* table, vtkIdType xColumn, vtkIdType yColumn);
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * This is a convenience function to set the input connection for the plot.
+   */
+  virtual void SetInputConnection(vtkAlgorithmOutput* input);
+  ///@}
 
   /**
    * Get the input table used by the plot.
    */
   virtual vtkTable* GetInput();
 
+  /**
+   * Get the input connection used by the plot.
+   */
+  vtkAlgorithmOutput* GetInputConnection();
+
   /**
    * Convenience function to set the input arrays. For most plots index 0
    * is the x axis, and index 1 is the y axis. The name is the name of the
@@ -281,7 +316,7 @@ public:
    */
   virtual void SetInputArray(int index, const vtkStdString& name);
 
-  //@{
+  ///@{
   /**
    * Set whether the plot can be selected. True by default.
    * If not, then SetSelection(), SelectPoints() or SelectPointsInPolygon()
@@ -291,9 +326,9 @@ public:
   vtkSetMacro(Selectable, bool);
   vtkGetMacro(Selectable, bool);
   vtkBooleanMacro(Selectable, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets the list of points that must be selected.
    * If Selectable is false, then this method does nothing.
@@ -301,25 +336,25 @@ public:
    */
   virtual void SetSelection(vtkIdTypeArray* id);
   vtkGetObjectMacro(Selection, vtkIdTypeArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/set the X axis associated with this plot.
    */
   vtkGetObjectMacro(XAxis, vtkAxis);
   virtual void SetXAxis(vtkAxis* axis);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/set the Y axis associated with this plot.
    */
   vtkGetObjectMacro(YAxis, vtkAxis);
   virtual void SetYAxis(vtkAxis* axis);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/set the origin shift and scaling factor used by the plot, this is
    * normally 0.0 offset and 1.0 scaling, but can be used to render data outside
@@ -328,7 +363,7 @@ public:
    */
   void SetShiftScale(const vtkRectd& shiftScale);
   vtkRectd GetShiftScale();
-  //@}
+  ///@}
 
   /**
    * Get the bounds for this plot as (Xmin, Xmax, Ymin, Ymax).
@@ -368,31 +403,36 @@ public:
     return this->GetBounds(bounds);
   }
 
-  /**
-   * Subclasses that build data caches to speed up painting should override this
-   * method to update such caches. This is called on each Paint, hence
-   * subclasses must add checks to avoid rebuilding of cache, unless necessary.
-   * Default implementation is empty.
-   */
-  virtual void UpdateCache() {}
-
-  //@{
+  ///@{
   /**
    * A General setter/getter that should be overridden. It can silently drop
    * options, case is important
    */
   virtual void SetProperty(const vtkStdString& property, const vtkVariant& var);
   virtual vtkVariant GetProperty(const vtkStdString& property);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Clamp the given 2D pos into the provided bounds
    * Return true if the pos has been clamped, false otherwise.
    */
   static bool ClampPos(double pos[2], double bounds[4]);
   virtual bool ClampPos(double pos[2]);
-  //@}
+  ///@}
+
+  /**
+   * Returns true if the supplied x, y coordinate is inside the item.
+   */
+  bool Hit(const vtkContextMouseEvent& mouse) override;
+
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  virtual bool UpdateCache() { return true; }
 
 protected:
   vtkPlot();
@@ -403,7 +443,7 @@ protected:
    */
   vtkStdString GetNumber(double position, vtkAxis* axis);
 
-  //@{
+  ///@{
   /**
    * Transform the mouse event in the control-points space. This is needed when
    * using logScale or shiftscale.
@@ -414,7 +454,17 @@ protected:
     const double inX, const double inY, double& outX, double& outY);
   virtual void TransformDataToScreen(
     const double inX, const double inY, double& outX, double& outY);
-  //@}
+  ///@}
+
+  /**
+   * Test if the internal cache requires an update.
+   */
+  virtual bool CacheRequiresUpdate();
+
+  /**
+   * The point cache is marked dirty until it has been initialized.
+   */
+  vtkTimeStamp BuildTime;
 
   /**
    * This object stores the vtkPen that controls how the plot is drawn.
@@ -507,16 +557,10 @@ protected:
 
   bool LegendVisibility;
 
-  /**
-   * Flag used by GetNearestPoint legacy implementation
-   * to avoid infinite call
-   */
-  // VTK_DEPRECATED_IN_9_0_0("used to track deprecation integration logic")
-  bool LegacyRecursionFlag = false;
-
 private:
   vtkPlot(const vtkPlot&) = delete;
   void operator=(const vtkPlot&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPlot_h
