@@ -22,18 +22,19 @@
  *
  * @sa
  * vtkPlot3DPoints vtkPlot3DLine vtkPlot3DBar vtkChart vtkChartXY
-*/
+ */
 
 #ifndef vtkPlot3D_h
 #define vtkPlot3D_h
 
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkContextItem.h"
-#include "vtkNew.h"              // Needed to hold vtkNew ivars
-#include "vtkSmartPointer.h"     // Needed to hold SP ivars
-#include "vtkVector.h"           // For Points ivar
-#include <vector>                // For ivars
+#include "vtkNew.h"          // Needed to hold vtkNew ivars
+#include "vtkSmartPointer.h" // Needed to hold SP ivars
+#include "vtkVector.h"       // For Points ivar
+#include <vector>            // For ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkChartXYZ;
 class vtkDataArray;
 class vtkIdTypeArray;
@@ -45,59 +46,56 @@ class VTKCHARTSCORE_EXPORT vtkPlot3D : public vtkContextItem
 {
 public:
   vtkTypeMacro(vtkPlot3D, vtkContextItem);
-  void PrintSelf(ostream &os, vtkIndent indent) override;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkPen object that controls how this plot draws (out)lines.
    */
-  void SetPen(vtkPen *pen);
+  void SetPen(vtkPen* pen);
   vtkPen* GetPen();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkPen object that controls how this plot draws (out)lines.
    */
-  void SetSelectionPen(vtkPen *pen);
+  void SetSelectionPen(vtkPen* pen);
   vtkPen* GetSelectionPen();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the input to the plot.
    */
-  virtual void SetInputData(vtkTable *input);
-  virtual void SetInputData(vtkTable *input, const vtkStdString &xName,
-                            const vtkStdString &yName,
-                            const vtkStdString &zName);
-  virtual void SetInputData(vtkTable *input, const vtkStdString &xName,
-                            const vtkStdString &yName,
-                            const vtkStdString &zName,
-                            const vtkStdString &colorName);
-  virtual void SetInputData(vtkTable *input, vtkIdType xColumn,
-                            vtkIdType yColumn, vtkIdType zColumn);
-  //@}
+  virtual void SetInputData(vtkTable* input);
+  virtual void SetInputData(vtkTable* input, const vtkStdString& xName, const vtkStdString& yName,
+    const vtkStdString& zName);
+  virtual void SetInputData(vtkTable* input, const vtkStdString& xName, const vtkStdString& yName,
+    const vtkStdString& zName, const vtkStdString& colorName);
+  virtual void SetInputData(
+    vtkTable* input, vtkIdType xColumn, vtkIdType yColumn, vtkIdType zColumn);
+  ///@}
 
   /**
    * Set the color of each point in the plot.  The input is a single component
    * scalar array.  The values of this array will be passed through a lookup
    * table to generate the color for each data point in the plot.
    */
-  virtual void SetColors(vtkDataArray *colorArr);
+  virtual void SetColors(vtkDataArray* colorArr);
 
   /**
    * Get all the data points within this plot.
    */
   std::vector<vtkVector3f> GetPoints();
 
-  //@{
+  ///@{
   /**
    * Get/set the chart for this plot.
    */
   vtkGetObjectMacro(Chart, vtkChartXYZ);
   virtual void SetChart(vtkChartXYZ* chart);
-  //@}
+  ///@}
 
   /**
    * Get the label for the X axis.
@@ -119,13 +117,13 @@ public:
    */
   std::vector<vtkVector3f> GetDataBounds() { return this->DataBounds; }
 
-  //@{
+  ///@{
   /**
    * Set/get the selection array for the plot.
    */
-  virtual void SetSelection(vtkIdTypeArray *id);
+  virtual void SetSelection(vtkIdTypeArray* id);
   virtual vtkIdTypeArray* GetSelection();
-  //@}
+  ///@}
 
 protected:
   vtkPlot3D();
@@ -198,9 +196,9 @@ protected:
   vtkSmartPointer<vtkIdTypeArray> Selection;
 
 private:
-  vtkPlot3D(const vtkPlot3D &) = delete;
-  void operator=(const vtkPlot3D &) = delete;
-
+  vtkPlot3D(const vtkPlot3D&) = delete;
+  void operator=(const vtkPlot3D&) = delete;
 };
 
-#endif //vtkPlot3D_h
+VTK_ABI_NAMESPACE_END
+#endif // vtkPlot3D_h
