@@ -28,7 +28,7 @@
  *
  * @sa
  * vtkHighestDensityRegionsStatistics
-*/
+ */
 
 #ifndef vtkPlotBag_h
 #define vtkPlotBag_h
@@ -36,30 +36,24 @@
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkPlotPoints.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPen;
 
 class VTKCHARTSCORE_EXPORT vtkPlotBag : public vtkPlotPoints
 {
 public:
   vtkTypeMacro(vtkPlotBag, vtkPlotPoints);
-  void PrintSelf(ostream &os, vtkIndent indent) override;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Creates a new Bag Plot object.
    */
-  static vtkPlotBag *New();
-
-  /**
-   * Perform any updates to the item that may be necessary before rendering.
-   * The scene should take care of calling this on all items before their
-   * Paint function is invoked.
-   */
-  void Update() override;
+  static vtkPlotBag* New();
 
   /**
    * Paint event for the XY plot, called whenever the chart needs to be drawn.
    */
-  bool Paint(vtkContext2D *painter) override;
+  bool Paint(vtkContext2D* painter) override;
 
   /**
    * Paint legend event for the XY plot, called whenever the legend needs the
@@ -67,24 +61,22 @@ public:
    * corner of the rect (elements 0 and 1) and with width x height (elements 2
    * and 3). The plot can choose how to fill the space supplied.
    */
-  bool PaintLegend(vtkContext2D *painter, const vtkRectf& rect,
-                           int legendIndex) override;
+  bool PaintLegend(vtkContext2D* painter, const vtkRectf& rect, int legendIndex) override;
 
   /**
    * Get the plot labels. If this array has a length greater than 1 the index
    * refers to the stacked objects in the plot. See vtkPlotBar for example.
    */
-  vtkStringArray *GetLabels() override;
+  vtkStringArray* GetLabels() override;
 
   /**
    * Generate and return the tooltip label string for this plot
    * The segmentIndex parameter is ignored, except for vtkPlotBar
    */
-  vtkStdString GetTooltipLabel(const vtkVector2d &plotPos,
-                                       vtkIdType seriesIndex,
-                                       vtkIdType segmentIndex) override;
+  vtkStdString GetTooltipLabel(
+    const vtkVector2d& plotPos, vtkIdType seriesIndex, vtkIdType segmentIndex) override;
 
-  //@{
+  ///@{
   /**
    * Set the input, we are expecting a vtkTable with three columns. The first
    * column and the second represent the x,y position . The five others
@@ -92,34 +84,32 @@ public:
    * Inherited method will call the last SetInputData method with default
    * parameters.
    */
-  void SetInputData(vtkTable *table) override;
-  void SetInputData(vtkTable *table, const vtkStdString &yColumn,
-                            const vtkStdString &densityColumn) override;
-  virtual void SetInputData(vtkTable *table, const vtkStdString &xColumn,
-                            const vtkStdString &yColumn,
-                            const vtkStdString &densityColumn);
-  //@}
+  void SetInputData(vtkTable* table) override;
+  void SetInputData(
+    vtkTable* table, const vtkStdString& yColumn, const vtkStdString& densityColumn) override;
+  virtual void SetInputData(vtkTable* table, const vtkStdString& xColumn,
+    const vtkStdString& yColumn, const vtkStdString& densityColumn);
+  ///@}
 
-  virtual void SetInputData(vtkTable *table, vtkIdType xColumn,
-                            vtkIdType yColumn,
-                            vtkIdType densityColumn);
+  virtual void SetInputData(
+    vtkTable* table, vtkIdType xColumn, vtkIdType yColumn, vtkIdType densityColumn);
 
-  //@{
+  ///@{
   /**
    * Set/get the visibility of the bags.
    * True by default.
    */
   vtkSetMacro(BagVisible, bool);
   vtkGetMacro(BagVisible, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the vtkPen object that controls how this plot draws boundary lines.
    */
   void SetLinePen(vtkPen* pen);
   vtkGetObjectMacro(LinePen, vtkPen);
-  //@}
+  ///@}
 
   /**
    * Set/get the vtkPen object that controls how this plot draws points.
@@ -129,20 +119,27 @@ public:
   void SetPointPen(vtkPen* pen) { this->SetPen(pen); }
   vtkPen* GetPointPen() { return this->GetPen(); }
 
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  bool UpdateCache() override;
+
 protected:
   vtkPlotBag();
   ~vtkPlotBag() override;
 
-  void UpdateTableCache(vtkDataArray*);
-
   bool BagVisible;
   vtkPoints2D* MedianPoints;
   vtkPoints2D* Q3Points;
   vtkPen* LinePen;
 
 private:
-  vtkPlotBag(const vtkPlotBag &) = delete;
-  void operator=(const vtkPlotBag &) = delete;
+  vtkPlotBag(const vtkPlotBag&) = delete;
+  void operator=(const vtkPlotBag&) = delete;
 };
 
-#endif //vtkPlotBag_h
+VTK_ABI_NAMESPACE_END
+#endif // vtkPlotBag_h
