@@ -21,6 +21,7 @@
 #include "vtkContext2D.h"
 #include "vtkContextDevice2D.h"
 #include "vtkContextMapper2D.h"
+#include "vtkDataSetAttributes.h"
 #include "vtkExecutive.h"
 #include "vtkFloatArray.h"
 #include "vtkIdTypeArray.h"
@@ -43,6 +44,7 @@
 #include <vector>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
@@ -523,7 +525,7 @@ public:
   std::vector<vtkSmartPointer<vtkPlotBarSegment>> Segments;
   vtkPlotBar* Bar;
   std::map<int, std::string> AdditionalSeries;
-  vtkStdString GroupName;
+  std::string GroupName;
 };
 
 //------------------------------------------------------------------------------
@@ -533,12 +535,11 @@ vtkStandardNewMacro(vtkPlotBar);
 vtkPlotBar::vtkPlotBar()
 {
   this->Private = new vtkPlotBarPrivate(this);
+  // Points is not a vtkSmartPointer, so set it explicitly to nullptr
   this->Points = nullptr;
-  this->AutoLabels = nullptr;
   this->Width = 1.0;
   this->Pen->SetWidth(1.0);
   this->Offset = 1.0;
-  this->ColorSeries = nullptr;
   this->Orientation = vtkPlotBar::VERTICAL;
   this->ScalarVisibility = false;
   this->EnableOpacityMapping = true;
@@ -610,9 +611,14 @@ void vtkPlotBar::GetBounds(double bounds[4], bool unscaled)
 
   // Get the x and y arrays (index 0 and 1 respectively)
   vtkTable* table = this->Data->GetInput();
+  if (!table)
+  {
+    return;
+  }
   vtkDataArray* x =
     this->UseIndexForXSeries ? nullptr : this->Data->GetInputArrayToProcess(0, table);
   vtkDataArray* y = this->Data->GetInputArrayToProcess(1, table);
+  vtkDataSetAttributes* rowData = table->GetRowData();
   if (!y)
   {
     return;
@@ -625,7 +631,7 @@ void vtkPlotBar::GetBounds(double bounds[4], bool unscaled)
   }
   else if (x)
   {
-    x->GetRange(&bounds[seriesLow]);
+    rowData->GetRange(x->GetName(), &bounds[seriesLow]);
     // We surround our point by Width/2 on either side
     bounds[seriesLow] -= this->Width / 2.0 + this->Offset;
     bounds[seriesHigh] += this->Width / 2.0 - this->Offset;
@@ -635,7 +641,7 @@ void vtkPlotBar::GetBounds(double bounds[4], bool unscaled)
     return;
   }
 
-  y->GetRange(&bounds[valuesLow]);
+  rowData->GetRange(y->GetName(), &bounds[valuesLow]);
 
   double yRange[2];
   std::map<int, std::string>::iterator it;
@@ -643,7 +649,7 @@ void vtkPlotBar::GetBounds(double bounds[4], bool unscaled)
        ++it)
   {
     y = vtkArrayDownCast<vtkDataArray>(table->GetColumnByName((*it).second.c_str()));
-    y->GetRange(yRange);
+    rowData->GetRange(y->GetName(), yRange);
     bounds[valuesHigh] += yRange[1];
   }
 
@@ -707,15 +713,21 @@ void vtkPlotBar::SetColor(unsigned char r, unsigned char g, unsigned char b, uns
 }
 
 //------------------------------------------------------------------------------
-void vtkPlotBar::SetColor(double r, double g, double b)
+void vtkPlotBar::SetColorF(double r, double g, double b, double a)
+{
+  this->Brush->SetColorF(r, g, b, a);
+}
+
+//------------------------------------------------------------------------------
+void vtkPlotBar::SetColorF(double r, double g, double b)
 {
   this->Brush->SetColorF(r, g, b);
 }
 
 //------------------------------------------------------------------------------
-void vtkPlotBar::GetColor(double rgb[3])
+void vtkPlotBar::GetColorF(double rgb[3])
 {
-  double rgba[4];
+  double rgba[4] = { 0.0, 0.0, 0.0, 0.0 };
   this->Brush->GetColorF(rgba);
   rgb[0] = rgba[0];
   rgb[1] = rgba[1];
@@ -823,7 +835,8 @@ bool vtkPlotBar::UpdateCache()
   // Additions for color mapping
   if (this->ScalarVisibility && !this->ColorArrayName.empty())
   {
-    vtkDataArray* c = vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(this->ColorArrayName));
+    vtkDataArray* c =
+      vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(this->ColorArrayName.c_str()));
     // TODO: Should add support for categorical coloring & try enum lookup
     if (c)
     {
@@ -935,7 +948,8 @@ void vtkPlotBar::CreateDefaultLookupTable()
   // rainbow - blue to red
   lut->SetHueRange(0.6667, 0.0);
   lut->Build();
-  double bounds[4];
+  // set reasonable defaults in case no data has been set
+  double bounds[4] = { 0.0, 1.0, 0.0, 1.0 };
   this->GetBounds(bounds);
   lut->SetRange(bounds[0], bounds[1]);
   this->LookupTable = lut;
@@ -1021,8 +1035,8 @@ bool vtkPlotBar::SelectPoints(const vtkVector2f& min, const vtkVector2f& max)
 vtkStdString vtkPlotBar::GetTooltipLabel(
   const vtkVector2d& plotPos, vtkIdType seriesIndex, vtkIdType segmentIndex)
 {
-  vtkStdString baseLabel = Superclass::GetTooltipLabel(plotPos, seriesIndex, segmentIndex);
-  vtkStdString tooltipLabel;
+  std::string baseLabel = Superclass::GetTooltipLabel(plotPos, seriesIndex, segmentIndex);
+  std::string tooltipLabel;
   bool escapeNext = false;
   for (size_t i = 0; i < baseLabel.length(); ++i)
   {
@@ -1088,6 +1102,7 @@ void vtkPlotBar::GetDataBounds(double bounds[2])
   vtkDataArray* x = this->Data->GetInputArrayToProcess(0, table);
   if (x)
   {
-    x->GetRange(bounds);
+    table->GetRowData()->GetRange(x->GetName(), bounds);
   }
 }
+VTK_ABI_NAMESPACE_END
