@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkPlotBox.h"
 
 #include "vtkAbstractArray.h"
@@ -45,6 +42,7 @@
 #include <algorithm>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPlotBox::Private : public std::vector<std::vector<double>>
 {
 public:
@@ -84,24 +82,6 @@ vtkPlotBox::~vtkPlotBox()
   this->TitleProperties->Delete();
 }
 
-//------------------------------------------------------------------------------
-void vtkPlotBox::Update()
-{
-  if (!this->Visible)
-  {
-    return;
-  }
-  // Check if we have an input
-  vtkTable* table = this->Data->GetInput();
-  if (!table)
-  {
-    vtkDebugMacro(<< "Update event called with no input table set.");
-    return;
-  }
-
-  this->UpdateTableCache(table);
-}
-
 //------------------------------------------------------------------------------
 bool vtkPlotBox::Paint(vtkContext2D* painter)
 {
@@ -126,9 +106,8 @@ bool vtkPlotBox::Paint(vtkContext2D* painter)
   int nbCols = static_cast<int>(this->Storage->size());
   for (int i = 0; i < nbCols; i++)
   {
-    vtkStdString colName = parent->GetVisibleColumns()->GetValue(i);
-    int index;
-    this->GetInput()->GetRowData()->GetAbstractArray(colName.c_str(), index);
+    std::string colName = parent->GetVisibleColumns()->GetValue(i);
+    int index = this->GetInput()->GetColumnIndex(colName.c_str());
     double rgb[4];
     this->LookupTable->GetIndexedColor(index, rgb);
     unsigned char crgba[4] = { static_cast<unsigned char>(rgb[0] * 255.),
@@ -166,7 +145,7 @@ void vtkPlotBox::DrawBoxPlot(int i, unsigned char* rgba, double x, vtkContext2D*
   double hBoxW = this->BoxWidth * 0.25;
 
   // Fetch the quartiles and median
-  double* q = &colQuartiles[0];
+  double* q = colQuartiles.data();
 
   // Draw the box
   painter->DrawQuad(xpos, q[1], xneg, q[1], xneg, q[3], xpos, q[3]);
@@ -219,7 +198,7 @@ bool vtkPlotBox::PaintLegend(vtkContext2D* painter, const vtkRectf& rec, int)
   int nbCols = static_cast<int>(this->Storage->size());
   for (int i = 0; i < nbCols; i++)
   {
-    vtkStdString colName = parent->GetVisibleColumns()->GetValue(i);
+    std::string colName = parent->GetVisibleColumns()->GetValue(i);
     if (this->GetLabels() && this->GetLabels()->GetNumberOfValues() > i)
     {
       colName = this->GetLabels()->GetValue(parent->GetColumnId(colName));
@@ -278,22 +257,6 @@ bool inRange(const vtkVector2f& point, const vtkVector2f& tol, const vtkVector2f
 vtkIdType vtkPlotBox::GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tol,
   vtkVector2f* location, vtkIdType* vtkNotUsed(segmentId))
 {
-  if (!this->LegacyRecursionFlag)
-  {
-    this->LegacyRecursionFlag = true;
-    vtkIdType ret = this->GetNearestPoint(point, tol, location);
-    this->LegacyRecursionFlag = false;
-    if (ret != -1)
-    {
-      VTK_LEGACY_REPLACED_BODY(vtkPlotBox::GetNearestPoint(const vtkVector2f& point,
-                                 const vtkVector2f& tol, vtkVector2f* location),
-        "VTK 9.0",
-        vtkPlotBox::GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tol,
-          vtkVector2f* location, vtkIdType* segmentId));
-      return ret;
-    }
-  }
-
   vtkChartBox* parent = vtkChartBox::SafeDownCast(this->Parent);
 
   int nbCols = static_cast<int>(this->Storage->size());
@@ -320,12 +283,17 @@ vtkIdType vtkPlotBox::GetNearestPoint(const vtkVector2f& point, const vtkVector2
   return -1;
 }
 //------------------------------------------------------------------------------
-bool vtkPlotBox::UpdateTableCache(vtkTable* table)
+bool vtkPlotBox::UpdateCache()
 {
+  if (!this->Superclass::UpdateCache())
+  {
+    return false;
+  }
+
   // Each boxplot is a column in our storage array,
   // they are scaled from 0.0 to 1.0
   vtkChartBox* parent = vtkChartBox::SafeDownCast(this->Parent);
-
+  vtkTable* table = this->Data->GetInput();
   if (!parent || !table || table->GetNumberOfColumns() == 0)
   {
     return false;
@@ -341,7 +309,7 @@ bool vtkPlotBox::UpdateTableCache(vtkTable* table)
     std::vector<double>& col = this->Storage->at(i);
     col.resize(rows);
     vtkSmartPointer<vtkDataArray> data =
-      vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(cols->GetValue(i)));
+      vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(cols->GetValue(i).c_str()));
     if (!data)
     {
       continue;
@@ -399,8 +367,7 @@ void vtkPlotBox::SetColumnColor(const vtkStdString& colName, double* rgb)
   {
     this->CreateDefaultLookupTable();
   }
-  int index;
-  this->GetInput()->GetRowData()->GetAbstractArray(colName.c_str(), index);
+  int index = this->GetInput()->GetColumnIndex(colName.c_str());
   vtkLookupTable* lut = vtkLookupTable::SafeDownCast(this->LookupTable);
   if (index >= 0 && lut)
   {
@@ -435,3 +402,4 @@ void vtkPlotBox::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
