@@ -30,7 +30,7 @@
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkContextItem.h"
 
-class vtkStdString;
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContext2D;
 class vtkPoints2D;
 class vtkAxis;
@@ -65,18 +65,19 @@ protected:
   vtkPlotGrid();
   ~vtkPlotGrid() override;
 
-  //@{
+  ///@{
   /**
    * The vtkAxis objects are used to figure out where the grid lines should be
    * drawn.
    */
   vtkAxis* XAxis;
   vtkAxis* YAxis;
-  //@}
+  ///@}
 
 private:
   vtkPlotGrid(const vtkPlotGrid&) = delete;
   void operator=(const vtkPlotGrid&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPlotGrid_h
