@@ -19,16 +19,17 @@
  *
  *
  *
-*/
+ */
 
 #ifndef vtkPlotHistogram2D_h
 #define vtkPlotHistogram2D_h
 
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkPlot.h"
-#include "vtkSmartPointer.h"  // Needed for SP ivars
-#include "vtkRect.h"          // Needed for vtkRectf
+#include "vtkRect.h"         // Needed for vtkRectf
+#include "vtkSmartPointer.h" // Needed for SP ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 class vtkScalarsToColors;
 
@@ -36,12 +37,12 @@ class VTKCHARTSCORE_EXPORT vtkPlotHistogram2D : public vtkPlot
 {
 public:
   vtkTypeMacro(vtkPlotHistogram2D, vtkPlot);
-  void PrintSelf(ostream &os, vtkIndent indent) override;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Creates a new object.
    */
-  static vtkPlotHistogram2D *New();
+  static vtkPlotHistogram2D* New();
 
   /**
    * Perform any updates to the item that may be necessary before rendering.
@@ -53,32 +54,32 @@ public:
   /**
    * Paint event for the item, called whenever it needs to be drawn.
    */
-  bool Paint(vtkContext2D *painter) override;
+  bool Paint(vtkContext2D* painter) override;
 
   /**
    * Set the input, we are expecting a vtkImageData with just one component,
    * this would normally be a float or a double. It will be passed to the other
    * functions as a double to generate a color.
    */
-  virtual void SetInputData(vtkImageData *data, vtkIdType z = 0);
-  void SetInputData(vtkTable*) override { }
-  void SetInputData(vtkTable*, const vtkStdString&, const vtkStdString&) override { }
+  virtual void SetInputData(vtkImageData* data, vtkIdType z = 0);
+  void SetInputData(vtkTable*) override {}
+  void SetInputData(vtkTable*, const vtkStdString&, const vtkStdString&) override {}
 
   /**
    * Get the input table used by the plot.
    */
-  vtkImageData * GetInputImageData();
+  vtkImageData* GetInputImageData();
 
   /**
    * Set the color transfer function that will be used to generate the 2D
    * histogram.
    */
-  void SetTransferFunction(vtkScalarsToColors *transfer);
+  void SetTransferFunction(vtkScalarsToColors* transfer);
 
   /**
    * Get the color transfer function that is used to generate the histogram.
    */
-  vtkScalarsToColors * GetTransferFunction();
+  vtkScalarsToColors* GetTransferFunction();
 
   void GetBounds(double bounds[4]) override;
 
@@ -103,9 +104,8 @@ public:
    * Any other characters or unrecognized format tags are printed in the
    * tooltip label verbatim.
    */
-  vtkStdString GetTooltipLabel(const vtkVector2d &plotPos,
-                                       vtkIdType seriesIndex,
-                                       vtkIdType segmentIndex) override;
+  vtkStdString GetTooltipLabel(
+    const vtkVector2d& plotPos, vtkIdType seriesIndex, vtkIdType segmentIndex) override;
 
   /**
    * Function to query a plot for the nearest point to the specified coordinate.
@@ -115,37 +115,31 @@ public:
    * The referent of "location" is set to the x and y integer indices of the
    * histogram cell.
    */
-  vtkIdType GetNearestPoint(const vtkVector2f& point,
-                                    const vtkVector2f& tolerance,
-                                    vtkVector2f* location,
-#ifndef VTK_LEGACY_REMOVE
-                                    vtkIdType* segmentId) override;
-#else
-                                    vtkIdType* segmentId = nullptr) override;
-#endif // VTK_LEGACY_REMOVE
-
-#ifndef VTK_LEGACY_REMOVE
+  vtkIdType GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tolerance,
+    vtkVector2f* location, vtkIdType* segmentId) override;
   using vtkPlot::GetNearestPoint;
-#endif // VTK_LEGACY_REMOVE
+
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  bool UpdateCache() override;
 
 protected:
   vtkPlotHistogram2D();
   ~vtkPlotHistogram2D() override;
 
-  /**
-   * Where all the magic happens...
-   */
-  void GenerateHistogram();
-
   vtkSmartPointer<vtkImageData> Input;
   vtkSmartPointer<vtkImageData> Output;
   vtkSmartPointer<vtkScalarsToColors> TransferFunction;
   vtkRectf Position;
 
 private:
-  vtkPlotHistogram2D(const vtkPlotHistogram2D &) = delete;
-  void operator=(const vtkPlotHistogram2D &) = delete;
-
+  vtkPlotHistogram2D(const vtkPlotHistogram2D&) = delete;
+  void operator=(const vtkPlotHistogram2D&) = delete;
 };
 
-#endif //vtkPlotHistogram2D_h
+VTK_ABI_NAMESPACE_END
+#endif // vtkPlotHistogram2D_h
