@@ -16,28 +16,29 @@
 #include "vtkPlotLine.h"
 
 #include "vtkContext2D.h"
-#include "vtkPen.h"
-#include "vtkRect.h"
-#include "vtkPoints2D.h"
 #include "vtkIdTypeArray.h"
+#include "vtkPen.h"
+#include "vtkPoints2D.h"
+#include "vtkRect.h"
 
 #include "vtkObjectFactory.h"
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPlotLine);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPlotLine::vtkPlotLine()
 {
   this->MarkerStyle = vtkPlotPoints::NONE;
   this->PolyLine = true;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPlotLine::~vtkPlotLine() = default;
 
-//-----------------------------------------------------------------------------
-bool vtkPlotLine::Paint(vtkContext2D *painter)
+//------------------------------------------------------------------------------
+bool vtkPlotLine::Paint(vtkContext2D* painter)
 {
   // This is where everything should be drawn, or dispatched to other methods.
   vtkDebugMacro(<< "Paint event called in vtkPlotLine.");
@@ -53,7 +54,7 @@ bool vtkPlotLine::Paint(vtkContext2D *painter)
   if (this->BadPoints && this->BadPoints->GetNumberOfTuples() > 0)
   {
     // draw lines skipping bad points
-    float *points = static_cast<float *>(this->Points->GetVoidPointer(0));
+    float* points = static_cast<float*>(this->Points->GetVoidPointer(0));
     const int pointSize = 2;
     vtkIdType lastGood = 0;
     vtkIdType bpIdx = 0;
@@ -63,8 +64,8 @@ bool vtkPlotLine::Paint(vtkContext2D *painter)
 
     while (lastGood < nPoints)
     {
-      vtkIdType id = bpIdx < nBadPoints ?
-        this->BadPoints->GetValue(bpIdx) : this->Points->GetNumberOfPoints();
+      vtkIdType id =
+        bpIdx < nBadPoints ? this->BadPoints->GetValue(bpIdx) : this->Points->GetNumberOfPoints();
 
       // With non polyline, we discard a line if any of its points are bad
       if (!this->PolyLine && id % 2 == 1)
@@ -106,18 +107,18 @@ bool vtkPlotLine::Paint(vtkContext2D *painter)
   return this->vtkPlotPoints::Paint(painter);
 }
 
-//-----------------------------------------------------------------------------
-bool vtkPlotLine::PaintLegend(vtkContext2D *painter, const vtkRectf& rect, int)
+//------------------------------------------------------------------------------
+bool vtkPlotLine::PaintLegend(vtkContext2D* painter, const vtkRectf& rect, int)
 {
   painter->ApplyPen(this->Pen);
-  painter->DrawLine(rect[0], rect[1]+0.5*rect[3],
-                    rect[0]+rect[2], rect[1]+0.5*rect[3]);
+  painter->DrawLine(rect[0], rect[1] + 0.5 * rect[3], rect[0] + rect[2], rect[1] + 0.5 * rect[3]);
   this->Superclass::PaintLegend(painter, rect, 0);
   return true;
 }
 
-//-----------------------------------------------------------------------------
-void vtkPlotLine::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkPlotLine::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
