@@ -27,6 +27,7 @@
 #include "vtkPlot.h"
 #include "vtkSmartPointer.h" // To hold ColorSeries etc.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContext2D;
 class vtkColorSeries;
 class vtkPoints2D;
@@ -66,13 +67,13 @@ public:
    */
   void SetDimensions(const int arg[4]);
 
-  //@{
+  ///@{
   /**
    * Get the dimensions of the pie, elements 0 and 1 are the x and y coordinate
    * of the bottom corner. Elements 2 and 3 are the width and height.
    */
   vtkGetVector4Macro(Dimensions, int);
-  //@}
+  ///@}
 
   /**
    * Set the color series to use for the Pie.
@@ -93,15 +94,18 @@ public:
     vtkVector2f* location, vtkIdType* segmentId) override;
   using vtkPlot::GetNearestPoint;
 
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  bool UpdateCache() override;
+
 protected:
   vtkPlotPie();
   ~vtkPlotPie() override;
 
-  /**
-   * Update the table cache.
-   */
-  bool UpdateTableCache(vtkTable* table);
-
   int Dimensions[4];
 
   /**
@@ -114,11 +118,6 @@ protected:
    */
   vtkPoints2D* Points;
 
-  /**
-   * The point cache is marked dirty until it has been initialized.
-   */
-  vtkTimeStamp BuildTime;
-
 private:
   vtkPlotPie(const vtkPlotPie&) = delete;
   void operator=(const vtkPlotPie&) = delete;
@@ -126,4 +125,5 @@ private:
   vtkPlotPiePrivate* Private;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPlotPie_h
