@@ -38,6 +38,7 @@
 #include <vector>
 
 // PIMPL for STL vector...
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkIndexedVector2f
 {
   size_t index;
@@ -645,10 +646,10 @@ bool vtkPlotPoints::UpdateCache()
   this->CalculateLogSeries();
 
   if (table && !this->ValidPointMaskName.empty() &&
-    table->GetColumnByName(this->ValidPointMaskName))
+    table->GetColumnByName(this->ValidPointMaskName.c_str()))
   {
     this->ValidPointMask =
-      vtkArrayDownCast<vtkCharArray>(table->GetColumnByName(this->ValidPointMaskName));
+      vtkArrayDownCast<vtkCharArray>(table->GetColumnByName(this->ValidPointMaskName.c_str()));
   }
   else
   {
@@ -663,7 +664,8 @@ bool vtkPlotPoints::UpdateCache()
   // Additions for color mapping
   if (this->ScalarVisibility && !this->ColorArrayName.empty())
   {
-    vtkDataArray* c = vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(this->ColorArrayName));
+    vtkDataArray* c =
+      vtkArrayDownCast<vtkDataArray>(table->GetColumnByName(this->ColorArrayName.c_str()));
     // TODO: Should add support for categorical coloring & try enum lookup
     if (c)
     {
@@ -965,3 +967,4 @@ void vtkPlotPoints::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
