@@ -37,12 +37,12 @@
 #include "vtkScalarsToColors.h"    // For VTK_COLOR_MODE_DEFAULT and _MAP_SCALARS
 #include "vtkStdString.h"          // For color array name
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCharArray;
 class vtkContext2D;
 class vtkTable;
 class vtkPoints2D;
 class vtkFloatArray;
-class vtkStdString;
 class vtkImageData;
 class vtkScalarsToColors;
 class vtkUnsignedCharArray;
@@ -58,13 +58,6 @@ public:
    */
   static vtkPlotPoints* New();
 
-  /**
-   * Perform any updates to the item that may be necessary before rendering.
-   * The scene should take care of calling this on all items before their
-   * Paint function is invoked.
-   */
-  void Update() override;
-
   /**
    * Paint event for the XY plot, called whenever the chart needs to be drawn
    */
@@ -88,13 +81,13 @@ public:
    */
   void GetUnscaledInputBounds(double bounds[4]) override;
 
-  //@{
+  ///@{
   /**
    * Specify a lookup table for the mapper to use.
    */
   void SetLookupTable(vtkScalarsToColors* lut);
   vtkScalarsToColors* GetLookupTable();
-  //@}
+  ///@}
 
   /**
    * Create default lookup table. Generally used to create one when none
@@ -102,16 +95,16 @@ public:
    */
   virtual void CreateDefaultLookupTable();
 
-  //@{
+  ///@{
   /**
    * Turn on/off flag to control whether scalar data is used to color objects.
    */
   vtkSetMacro(ScalarVisibility, vtkTypeBool);
   vtkGetMacro(ScalarVisibility, vtkTypeBool);
   vtkBooleanMacro(ScalarVisibility, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When ScalarMode is set to UsePointFieldData or UseCellFieldData,
    * you can specify which array to use for coloring using these methods.
@@ -119,7 +112,7 @@ public:
    */
   void SelectColorArray(vtkIdType arrayNum);
   void SelectColorArray(const vtkStdString& arrayName);
-  //@}
+  ///@}
 
   /**
    * Get the array name to color by.
@@ -158,31 +151,39 @@ public:
     DIAMOND = VTK_MARKER_DIAMOND
   };
 
-  //@{
+  ///@{
   /**
    * Get/set the marker style that should be used. The default is none, the enum
    * in this class is used as a parameter.
    */
   vtkGetMacro(MarkerStyle, int);
   vtkSetMacro(MarkerStyle, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/set the marker size that should be used. The default is negative, and
    * in that case it is 2.3 times the pen width, if less than 8 will be used.
    */
   vtkGetMacro(MarkerSize, float);
   vtkSetMacro(MarkerSize, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/set the valid point mask array name.
    */
   vtkGetMacro(ValidPointMaskName, vtkStdString);
   vtkSetMacro(ValidPointMaskName, vtkStdString);
-  //@}
+  ///@}
+
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  bool UpdateCache() override;
 
 protected:
   vtkPlotPoints();
@@ -194,9 +195,9 @@ protected:
   bool GetDataArrays(vtkTable* table, vtkDataArray* array[2]);
 
   /**
-   * Update the table cache.
+   * Test if the internal cache requires an update.
    */
-  bool UpdateTableCache(vtkTable* table);
+  virtual bool CacheRequiresUpdate() override;
 
   /**
    * Calculate the unscaled input bounds from the input arrays.
@@ -205,7 +206,7 @@ protected:
 
   /**
    * Handle calculating the log of the x or y series if necessary. Should be
-   * called by UpdateTableCache once the data has been updated in Points.
+   * called by UpdateCache once the data has been updated in Points.
    */
   void CalculateLogSeries();
 
@@ -226,21 +227,21 @@ protected:
    */
   void CreateSortedPoints();
 
-  //@{
+  ///@{
   /**
    * Store a well packed set of XY coordinates for this data series.
    */
   vtkPoints2D* Points;
   vtkNew<vtkFloatArray> SelectedPoints;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sorted points, used when searching for the nearest point.
    */
   class VectorPIMPL;
   VectorPIMPL* Sorted;
-  //@}
+  ///@}
 
   /**
    * An array containing the indices of all the "bad points", meaning any x, y
@@ -259,22 +260,17 @@ protected:
    */
   vtkStdString ValidPointMaskName;
 
-  /**
-   * The point cache is marked dirty until it has been initialized.
-   */
-  vtkTimeStamp BuildTime;
-
-  //@{
+  ///@{
   /**
    * The marker style that should be used
    */
   int MarkerStyle;
   float MarkerSize;
-  //@}
+  ///@}
 
   bool LogX, LogY;
 
-  //@{
+  ///@{
   /**
    * Lookup Table for coloring points by scalar value
    */
@@ -282,7 +278,7 @@ protected:
   vtkUnsignedCharArray* Colors;
   vtkTypeBool ScalarVisibility;
   vtkStdString ColorArrayName;
-  //@}
+  ///@}
 
   /**
    * Cached bounds on the plot input axes
@@ -294,4 +290,5 @@ private:
   void operator=(const vtkPlotPoints&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPlotPoints_h
