@@ -28,9 +28,9 @@
 #include "vtkTransform2D.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRangeHandlesItem);
-vtkSetObjectImplementationMacro(
-  vtkRangeHandlesItem, ColorTransferFunction, vtkColorTransferFunction);
+vtkCxxSetObjectMacro(vtkRangeHandlesItem, ColorTransferFunction, vtkColorTransferFunction);
 
 //------------------------------------------------------------------------------
 vtkRangeHandlesItem::vtkRangeHandlesItem()
@@ -40,6 +40,7 @@ vtkRangeHandlesItem::vtkRangeHandlesItem()
   this->RangeLabelBrush->SetColor(255, 255, 255, 200);
   this->ExtentToAxisRangeOff();
   this->SetHandleOrientation(vtkPlotRangeHandlesItem::Orientation::VERTICAL);
+  this->LockTooltipToMouseOff();
 }
 
 //------------------------------------------------------------------------------
@@ -159,3 +160,4 @@ void vtkRangeHandlesItem::SetActiveHandlePosition(double position)
     this->TransformScreenToData(position, 1, this->ActiveHandleRangeValue, unused);
   }
 }
+VTK_ABI_NAMESPACE_END
