@@ -39,6 +39,7 @@
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkPlotRangeHandlesItem.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkColorTransferFunction;
 
 class VTKCHARTSCORE_EXPORT vtkRangeHandlesItem : public vtkPlotRangeHandlesItem
@@ -65,13 +66,13 @@ public:
    */
   void GetHandlesRange(double range[2]) override;
 
-  //@{
+  ///@{
   /**
    * Get/set the color transfer function to interact with.
    */
   void SetColorTransferFunction(vtkColorTransferFunction* ctf);
   vtkGetObjectMacro(ColorTransferFunction, vtkColorTransferFunction);
-  //@}
+  ///@}
 
   /**
    * Compute the handles draw range by using the handle width and the transfer
@@ -79,7 +80,7 @@ public:
    */
   void ComputeHandlesDrawRange() override;
 
-  //@{
+  ///@{
   /**
    * Overridden to force using desynchronized vertical handles.
    * Desynchronized handles means that handles are always moved independently,
@@ -97,14 +98,14 @@ public:
   {
     this->Superclass::SetHandleOrientation(Orientation::VERTICAL);
   }
-  //@}
+  ///@}
 
 protected:
   vtkRangeHandlesItem();
   ~vtkRangeHandlesItem() override;
 
   /**
-   * Overridden to clamp the handle position in the color tranfer function
+   * Overridden to clamp the handle position in the color transfer function
    * range.
    */
   void SetActiveHandlePosition(double position) override;
@@ -116,4 +117,5 @@ private:
   vtkColorTransferFunction* ColorTransferFunction = nullptr;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkRangeHandlesItem_h
