@@ -13,12 +13,14 @@
 
 =========================================================================*/
 
+#include "vtkScalarsToColorsItem.h"
 #include "vtkAxis.h"
 #include "vtkBrush.h"
 #include "vtkCallbackCommand.h"
 #include "vtkContext2D.h"
 #include "vtkContextDevice2D.h"
 #include "vtkContextScene.h"
+#include "vtkDataSetAttributes.h"
 #include "vtkDoubleArray.h"
 #include "vtkFloatArray.h"
 #include "vtkImageData.h"
@@ -27,17 +29,17 @@
 #include "vtkPen.h"
 #include "vtkPlotBar.h"
 #include "vtkPoints2D.h"
-#include "vtkScalarsToColorsItem.h"
 #include "vtkSmartPointer.h"
 #include "vtkTable.h"
 #include "vtkTransform2D.h"
 
 #include <cassert>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkScalarsToColorsItem, HistogramTable, vtkTable);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScalarsToColorsItem::vtkScalarsToColorsItem()
 {
   this->PolyLinePen->SetWidth(2.);
@@ -48,8 +50,7 @@ vtkScalarsToColorsItem::vtkScalarsToColorsItem()
   this->Shape->SetNumberOfPoints(0);
 
   this->Callback->SetClientData(this);
-  this->Callback->SetCallback(
-    vtkScalarsToColorsItem::OnScalarsToColorsModified);
+  this->Callback->SetCallback(vtkScalarsToColorsItem::OnScalarsToColorsModified);
 
   this->MaskAboveCurve = false;
 
@@ -65,7 +66,7 @@ vtkScalarsToColorsItem::vtkScalarsToColorsItem()
   this->AddItem(this->PlotBar);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScalarsToColorsItem::~vtkScalarsToColorsItem()
 {
   if (this->HistogramTable)
@@ -80,18 +81,17 @@ vtkScalarsToColorsItem::~vtkScalarsToColorsItem()
   }
 }
 
-//-----------------------------------------------------------------------------
-void vtkScalarsToColorsItem::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkScalarsToColorsItem::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Interpolate: " << this->Interpolate << endl;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsItem::GetBounds(double bounds[4])
 {
-  if (this->UserBounds[1] > this->UserBounds[0] &&
-      this->UserBounds[3] > this->UserBounds[2])
+  if (this->UserBounds[1] > this->UserBounds[0] && this->UserBounds[3] > this->UserBounds[2])
   {
     bounds[0] = this->UserBounds[0];
     bounds[1] = this->UserBounds[1];
@@ -102,7 +102,7 @@ void vtkScalarsToColorsItem::GetBounds(double bounds[4])
   this->ComputeBounds(bounds);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsItem::ComputeBounds(double bounds[4])
 {
   bounds[0] = 0.;
@@ -111,12 +111,11 @@ void vtkScalarsToColorsItem::ComputeBounds(double bounds[4])
   bounds[3] = 1.;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkScalarsToColorsItem::Paint(vtkContext2D* painter)
 {
   this->TextureWidth = this->GetScene()->GetViewWidth();
-  if (this->Texture == nullptr ||
-      this->Texture->GetMTime() < this->GetMTime())
+  if (this->Texture == nullptr || this->Texture->GetMTime() < this->GetMTime())
   {
     this->ComputeTexture();
   }
@@ -140,23 +139,20 @@ bool vtkScalarsToColorsItem::Paint(vtkContext2D* painter)
     painter->GetBrush()->SetColorF(1., 1., 1., 1.);
     painter->GetBrush()->SetTexture(this->Texture);
     painter->GetBrush()->SetTextureProperties(
-      (this->Interpolate ? vtkBrush::Nearest : vtkBrush::Linear) |
-      vtkBrush::Stretch);
+      (this->Interpolate ? vtkBrush::Nearest : vtkBrush::Linear) | vtkBrush::Stretch);
     if (!this->MaskAboveCurve || size < 2)
     {
       double dbounds[4];
       this->GetBounds(dbounds);
-      painter->DrawQuad(dbounds[0], dbounds[2],
-                        dbounds[0], dbounds[3],
-                        dbounds[1], dbounds[3],
-                        dbounds[1], dbounds[2]);
+      painter->DrawQuad(dbounds[0], dbounds[2], dbounds[0], dbounds[3], dbounds[1], dbounds[3],
+        dbounds[1], dbounds[2]);
     }
     else
     {
       const vtkRectd& ss = this->ShiftScale;
 
       vtkNew<vtkPoints2D> trapezoids;
-      trapezoids->SetNumberOfPoints(2*size);
+      trapezoids->SetNumberOfPoints(2 * size);
       double point[2];
       vtkIdType j = -1;
       for (vtkIdType i = 0; i < size; ++i)
@@ -173,8 +169,7 @@ bool vtkScalarsToColorsItem::Paint(vtkContext2D* painter)
     }
   }
 
-  if (this->PolyLinePen->GetLineType() != vtkPen::NO_PEN
-    && size >= 2)
+  if (this->PolyLinePen->GetLineType() != vtkPen::NO_PEN && size >= 2)
   {
     const vtkRectd& ss = this->ShiftScale;
 
@@ -196,48 +191,42 @@ bool vtkScalarsToColorsItem::Paint(vtkContext2D* painter)
   return true;
 }
 
-//-----------------------------------------------------------------------------
-void vtkScalarsToColorsItem::OnScalarsToColorsModified(vtkObject* caller,
-                                                       unsigned long eid,
-                                                       void *clientdata,
-                                                       void* calldata)
+//------------------------------------------------------------------------------
+void vtkScalarsToColorsItem::OnScalarsToColorsModified(
+  vtkObject* caller, unsigned long eid, void* clientdata, void* calldata)
 {
-  vtkScalarsToColorsItem* self =
-    reinterpret_cast<vtkScalarsToColorsItem*>(clientdata);
+  vtkScalarsToColorsItem* self = reinterpret_cast<vtkScalarsToColorsItem*>(clientdata);
   self->ScalarsToColorsModified(caller, eid, calldata);
 }
 
-//-----------------------------------------------------------------------------
-void vtkScalarsToColorsItem::ScalarsToColorsModified(vtkObject* vtkNotUsed(object),
-                                                     unsigned long vtkNotUsed(eid),
-                                                     void* vtkNotUsed(calldata))
+//------------------------------------------------------------------------------
+void vtkScalarsToColorsItem::ScalarsToColorsModified(
+  vtkObject* vtkNotUsed(object), unsigned long vtkNotUsed(eid), void* vtkNotUsed(calldata))
 {
   this->Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkScalarsToColorsItem::ConfigurePlotBar()
 {
-  bool visible = this->HistogramTable && this->HistogramTable->GetNumberOfColumns() >= 2
-    && this->GetXAxis() && this->GetYAxis();
+  bool visible = this->HistogramTable && this->HistogramTable->GetNumberOfColumns() >= 2 &&
+    this->GetXAxis() && this->GetYAxis();
   if (visible)
   {
     // Configure the plot bar
-    this->PlotBar->SetInputData(this->HistogramTable,
-      this->HistogramTable->GetColumnName(0), this->HistogramTable->GetColumnName(1));
+    this->PlotBar->SetInputData(this->HistogramTable, this->HistogramTable->GetColumnName(0),
+      this->HistogramTable->GetColumnName(1));
     this->PlotBar->SelectColorArray(this->HistogramTable->GetColumnName(0));
     this->PlotBar->SetXAxis(this->GetXAxis());
     this->PlotBar->SetYAxis(this->GetYAxis());
 
     // Configure the plot bar Y Axis
-    vtkDoubleArray* valueArray = vtkDoubleArray::SafeDownCast(this->HistogramTable->GetColumn(1));
-    if (!valueArray)
+    double valueRange[2];
+    if (!this->HistogramTable->GetRowData()->GetRange(1, valueRange))
     {
       vtkErrorMacro("HistogramTable is not containing expected data");
       return false;
     }
-    double valueRange[2];
-    valueArray->GetRange(valueRange);
     double val = 1 / valueRange[1];
     vtkRectd shiftScale = this->ShiftScale;
     shiftScale.SetHeight(shiftScale.GetHeight() * val);
@@ -249,7 +238,7 @@ bool vtkScalarsToColorsItem::ConfigurePlotBar()
     {
       // It is necessary to extract the actual range of computation of the histogram
       // as it can be different to the range of the scalar to colors item.
-      int nBin =  this->HistogramTable->GetNumberOfRows();
+      int nBin = this->HistogramTable->GetNumberOfRows();
       double range = binExtent->GetValue(nBin - 1) - binExtent->GetValue(0);
       double delta = range / (nBin - 1);
       this->PlotBar->SetWidth((range + delta) / nBin);
@@ -264,11 +253,9 @@ bool vtkScalarsToColorsItem::ConfigurePlotBar()
   return visible;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColorsItem::GetNearestPoint(const vtkVector2f& point,
-                                      const vtkVector2f& tolerance,
-                                      vtkVector2f* location,
-                                      vtkIdType* segmentIndex)
+  const vtkVector2f& tolerance, vtkVector2f* location, vtkIdType* segmentIndex)
 {
   if (this->PlotBar->GetVisible())
   {
@@ -277,10 +264,9 @@ vtkIdType vtkScalarsToColorsItem::GetNearestPoint(const vtkVector2f& point,
   return -1;
 }
 
-//-----------------------------------------------------------------------------
-vtkStdString vtkScalarsToColorsItem::GetTooltipLabel(const vtkVector2d &plotPos,
-                                         vtkIdType seriesIndex,
-                                         vtkIdType segmentIndex)
+//------------------------------------------------------------------------------
+vtkStdString vtkScalarsToColorsItem::GetTooltipLabel(
+  const vtkVector2d& plotPos, vtkIdType seriesIndex, vtkIdType segmentIndex)
 {
   if (this->PlotBar->GetVisible())
   {
@@ -288,3 +274,4 @@ vtkStdString vtkScalarsToColorsItem::GetTooltipLabel(const vtkVector2d &plotPos,
   }
   return "";
 }
+VTK_ABI_NAMESPACE_END
