@@ -53,6 +53,7 @@
 #include "vtkObject.h"
 #include "vtkStdString.h" // Needed for arguments
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLookupTable;
 
 class VTKCOMMONCOLOR_EXPORT vtkColorSeries : public vtkObject
@@ -212,7 +213,7 @@ public:
     CATEGORICAL
   };
 
-  //@{
+  ///@{
   /**
    * Set the color scheme that should be used.
    * The variant of this function that takes an integer should pass a
@@ -222,7 +223,7 @@ public:
    */
   virtual void SetColorScheme(int scheme);
   virtual int SetColorSchemeByName(const vtkStdString& schemeName);
-  //@}
+  ///@}
 
   /**
    * Return the number of schemes currently defined.
@@ -330,13 +331,13 @@ protected:
    */
   virtual void CopyOnWrite();
 
-  //@{
+  ///@{
   /**
    * Private data pointer of the class, stores the color list.
    */
   class Private;
   Private* Storage;
-  //@}
+  ///@}
 
   /**
    * The color scheme being used.
@@ -351,4 +352,5 @@ private:
   void operator=(const vtkColorSeries&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkColorSeries_h
