@@ -26,6 +26,7 @@
 #include <sstream>  // STL Header for parsing character arrays
 #include <vector>   // STL Header for returning/storing color values
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkNamedColorsDataStore
 {
 public:
@@ -33,20 +34,19 @@ public:
 
   virtual ~vtkNamedColorsDataStore() = default;
 
-public:
   //-----------------------------------------------------------------------------
   // Return a pointer to the internal color map.
   // Use with caution.
   // Likely uses could be for searching for colors that have the same
   // value but different names e.g. aqua and cyan.
-  std::map<vtkStdString, vtkColor4ub>* GetColorMap() { return &this->colorMap; }
+  std::map<std::string, vtkColor4ub>* GetColorMap() { return &this->colorMap; }
 
   //-----------------------------------------------------------------------------
   // Get the color by name.
   // The name is treated as being case-insensitive.
   // The color is returned as vtkColor4ub class.
   // Black is returned if the color is not found.
-  void GetColor(const vtkStdString& name, vtkColor4ub& color)
+  void GetColor(const std::string& name, vtkColor4ub& color)
   {
     for (int i = 0; i < 3; ++i)
     {
@@ -55,8 +55,8 @@ public:
     color[3] = 255;
     if (!name.empty())
     {
-      vtkStdString s = this->ToLowercase(name);
-      std::map<vtkStdString, vtkColor4ub>::iterator p = this->colorMap.find(s);
+      std::string s = this->ToLowercase(name);
+      std::map<std::string, vtkColor4ub>::iterator p = this->colorMap.find(s);
       if (p != this->colorMap.end())
       {
         color = p->second;
@@ -69,7 +69,7 @@ public:
   // The name is treated as being case-insensitive.
   // The color is returned as vtkColor4ub class.
   // Black is returned if the color is not found.
-  void GetColor(const vtkStdString& name, vtkColor4d& color)
+  void GetColor(const std::string& name, vtkColor4d& color)
   {
     vtkColor4ub c;
     this->GetColor(name, c);
@@ -84,7 +84,7 @@ public:
   // The name is treated as being case-insensitive.
   // The color is returned as vtkColor3ub class.
   // Black is returned if the color is not found.
-  void GetColor(const vtkStdString& name, vtkColor3ub& color)
+  void GetColor(const std::string& name, vtkColor3ub& color)
   {
     vtkColor4ub c;
     this->GetColor(name, c);
@@ -99,7 +99,7 @@ public:
   // The name is treated as being case-insensitive.
   // The color is returned as vtkColor3d class.
   // Black is returned if the color is not found.
-  void GetColor(const vtkStdString& name, vtkColor3d& color)
+  void GetColor(const std::string& name, vtkColor3d& color)
   {
     vtkColor4d c;
     this->GetColor(name, c);
@@ -114,11 +114,11 @@ public:
   // The name is treated as being case-insensitive.
   // The color is a vtkColor4ub class.
   // No color is set if the name is empty or the color vector is not of size 4.
-  void SetColor(const vtkStdString& name, const vtkColor4ub& color)
+  void SetColor(const std::string& name, const vtkColor4ub& color)
   {
     if (!name.empty() && color.GetSize() == 4)
     {
-      vtkStdString s = this->ToLowercase(name);
+      std::string s = this->ToLowercase(name);
       this->colorMap[s] = color;
     }
   }
@@ -128,11 +128,11 @@ public:
   // The name is treated as being case-insensitive.
   // The color is a vtkColor4d class.
   // No color is set if the name is empty or the color vector is not of size 4.
-  void SetColor(const vtkStdString& name, const vtkColor4d& color)
+  void SetColor(const std::string& name, const vtkColor4d& color)
   {
     if (!name.empty() && color.GetSize() == 4)
     {
-      vtkStdString s = this->ToLowercase(name);
+      std::string s = this->ToLowercase(name);
       unsigned char r, g, b, a;
       r = static_cast<unsigned char>(color.GetRed() * 255.0);
       g = static_cast<unsigned char>(color.GetGreen() * 255.0);
@@ -147,7 +147,7 @@ public:
   // The name is treated as being case-insensitive.
   // The color is a vtkColor3ub class.
   // No color is set if the name is empty or the color vector is not of size 4.
-  void SetColor(const vtkStdString& name, const vtkColor3ub& color)
+  void SetColor(const std::string& name, const vtkColor3ub& color)
   {
     vtkColor4ub c;
     for (int i = 0; i < 3; ++i)
@@ -163,7 +163,7 @@ public:
   // The name is treated as being case-insensitive.
   // The color is a vtkColor3d class.
   // No color is set if the name is empty or the color vector is not of size 4.
-  void SetColor(const vtkStdString& name, const vtkColor3d& color)
+  void SetColor(const std::string& name, const vtkColor3d& color)
   {
     vtkColor4d c;
     for (int i = 0; i < 3; ++i)
@@ -177,12 +177,12 @@ public:
   //-----------------------------------------------------------------------------
   // Remove the color by name.
   // The name is treated as being case-insensitive.
-  void RemoveColor(const vtkStdString& name)
+  void RemoveColor(const std::string& name)
   {
     if (!name.empty())
     {
-      vtkStdString s = this->ToLowercase(name);
-      std::map<vtkStdString, vtkColor4ub>::iterator p = this->colorMap.find(s);
+      std::string s = this->ToLowercase(name);
+      std::map<std::string, vtkColor4ub>::iterator p = this->colorMap.find(s);
       if (p != this->colorMap.end())
       {
         this->colorMap.erase(p);
@@ -192,18 +192,18 @@ public:
 
   //-----------------------------------------------------------------------------
   // Return true if the color exists.
-  bool ColorExists(const vtkStdString& name)
+  bool ColorExists(const std::string& name)
   {
-    vtkStdString s = this->ToLowercase(name);
+    std::string s = this->ToLowercase(name);
     return this->colorMap.find(s) != this->colorMap.end();
   }
 
   //-----------------------------------------------------------------------------
   // Return a vector of color names.
-  std::vector<vtkStdString> GetColorNames()
+  std::vector<std::string> GetColorNames()
   {
-    std::vector<vtkStdString> colorNames;
-    for (std::map<vtkStdString, vtkColor4ub>::const_iterator p = this->GetColorMap()->begin();
+    std::vector<std::string> colorNames;
+    for (std::map<std::string, vtkColor4ub>::const_iterator p = this->GetColorMap()->begin();
          p != this->GetColorMap()->end(); ++p)
     {
       colorNames.push_back(p->first);
@@ -215,16 +215,16 @@ public:
   // Return a vector where each element of the vector is a vector of
   // synonyms such as cyan/aqua and magenta/fuchsia
   // Warning this could take a long time for very large color maps.
-  std::vector<std::vector<vtkStdString>> GetSynonyms()
+  std::vector<std::vector<std::string>> GetSynonyms()
   {
-    std::vector<vtkStdString> cn = this->GetColorNames();
-    std::map<vtkStdString, std::vector<vtkStdString>> synonyms;
-    for (std::vector<vtkStdString>::const_iterator p = cn.begin(); p != cn.end(); ++p)
+    std::vector<std::string> cn = this->GetColorNames();
+    std::map<std::string, std::vector<std::string>> synonyms;
+    for (std::vector<std::string>::const_iterator p = cn.begin(); p != cn.end(); ++p)
     {
       vtkColor4ub vu;
       this->GetColor(*p, vu);
-      std::vector<vtkStdString> duplicates;
-      for (std::map<vtkStdString, vtkColor4ub>::const_iterator q = this->GetColorMap()->begin();
+      std::vector<std::string> duplicates;
+      for (std::map<std::string, vtkColor4ub>::const_iterator q = this->GetColorMap()->begin();
            q != this->GetColorMap()->end(); ++q)
       {
         if (*p != q->first && vu.Compare(q->second, 1))
@@ -235,8 +235,8 @@ public:
       if (!duplicates.empty())
       {
         bool alreadyInMap = false;
-        for (std::vector<vtkStdString>::const_iterator r = duplicates.begin();
-             r != duplicates.end(); ++r)
+        for (std::vector<std::string>::const_iterator r = duplicates.begin(); r != duplicates.end();
+             ++r)
         {
           if (synonyms.find(*r) != synonyms.end())
           {
@@ -250,13 +250,13 @@ public:
         }
       }
     }
-    std::vector<std::vector<vtkStdString>> retVec;
-    for (std::map<vtkStdString, std::vector<vtkStdString>>::const_iterator p = synonyms.begin();
+    std::vector<std::vector<std::string>> retVec;
+    for (std::map<std::string, std::vector<std::string>>::const_iterator p = synonyms.begin();
          p != synonyms.end(); ++p)
     {
-      std::vector<vtkStdString> vstr;
+      std::vector<std::string> vstr;
       vstr.push_back(p->first);
-      for (std::vector<vtkStdString>::const_iterator q = p->second.begin(); q != p->second.end();
+      for (std::vector<std::string>::const_iterator q = p->second.begin(); q != p->second.end();
            ++q)
       {
         vstr.push_back(*q);
@@ -266,7 +266,6 @@ public:
     return retVec;
   }
 
-public:
   //-----------------------------------------------------------------------------
   // Initialise the color map by loading the colors from a list.
   void Init()
@@ -649,10 +648,10 @@ public:
     for (size_t i = 0; i < colorTableSz; ++i)
     {
       std::vector<unsigned char> color;
-      vtkStdString s = colorTable[i];
+      std::string s = colorTable[i];
       size_t idx = s.find(',');
-      vtkStdString name = s.substr(0, idx);
-      vtkStdString t = this->ToLowercase(name);
+      std::string name = s.substr(0, idx);
+      std::string t = this->ToLowercase(name);
       name = t;
       size_t start = idx + 1;
       idx = s.find(',', start);
@@ -674,17 +673,17 @@ public:
   }
 
 private:
-  //-----------------------------------------------------------------------------
+  //----------------------------------------------------------------------------
+
   // Convert a string to lowercase.
-  vtkStdString ToLowercase(const vtkStdString& str)
+  std::string ToLowercase(std::string s)
   {
-    vtkStdString s;
-    std::transform(str.begin(), str.end(), std::back_inserter(s), (int (*)(int))std::tolower);
+    std::transform(s.begin(), s.end(), s.begin(), [](unsigned char c) { return std::tolower(c); });
     return s;
   }
 
   // The names and color values.
-  std::map<vtkStdString, vtkColor4ub> colorMap;
+  std::map<std::string, vtkColor4ub> colorMap;
 };
 
 //------------------------------------------------------------------------------
@@ -699,24 +698,22 @@ public:
     this->NamedColors = namedColors;
   }
 
-  bool Parse(const vtkStdString& colorString);
+  bool Parse(const std::string& colorString);
 
   const vtkColor4ub& GetColor() const { return this->Color; }
 
 private:
-  void RGBAFuncStringToRGBA(vtkStdString color, vtkStdString::size_type pos, unsigned int argCount);
+  void RGBAFuncStringToRGBA(std::string color, std::string::size_type pos, unsigned int argCount);
 
-  void HexStringToRGBA(vtkStdString color);
+  void HexStringToRGBA(std::string color);
 
   // Convert a string to lowercase.
-  vtkStdString ToLowercase(const vtkStdString& str)
+  std::string ToLowercase(std::string s)
   {
-    vtkStdString s;
-    std::transform(str.begin(), str.end(), std::back_inserter(s), (int (*)(int))std::tolower);
+    std::transform(s.begin(), s.end(), s.begin(), [](unsigned char c) { return std::tolower(c); });
     return s;
   }
 
-private:
   vtkColor4ub Color;
   bool StateGood;
   vtkNamedColors* NamedColors;
@@ -732,20 +729,20 @@ private:
 // - a CSS3 color name, e.g. "steelblue"
 // If the passed string defines a color using one of the above formats returns
 // true else returns false.
-bool vtkColorStringParser::Parse(const vtkStdString& colorString)
+bool vtkColorStringParser::Parse(const std::string& colorString)
 {
-  vtkStdString color = this->ToLowercase(colorString);
+  std::string color = this->ToLowercase(colorString);
 
   // Skip heading spaces.
-  vtkStdString::size_type pos = color.find_first_not_of(" \t");
-  this->StateGood = (pos != vtkStdString::npos);
+  std::string::size_type pos = color.find_first_not_of(" \t");
+  this->StateGood = (pos != std::string::npos);
 
   if (this->StateGood)
   {
     if (color[pos] == '#')
     {
       // Trim trailing spaces.
-      vtkStdString::size_type last = color.find_last_not_of(" \t");
+      std::string::size_type last = color.find_last_not_of(" \t");
       this->HexStringToRGBA(color.substr(pos + 1, last - pos));
     }
     else if (color.compare(pos, 4, "rgba") == 0)
@@ -812,18 +809,18 @@ double clipPercentage(double value)
 // Parse a string of type "#RRGGBB".
 // Heading and trailing spaces must be already trimmed.
 // If the parsed string is not valid set `StateGood` to false.
-void vtkColorStringParser::HexStringToRGBA(vtkStdString color)
+void vtkColorStringParser::HexStringToRGBA(std::string color)
 {
   // Check if it is valid hexadecimal representation.
-  vtkStdString::size_type pos = color.find_first_not_of("0123456789abcdefABCDEF");
-  this->StateGood = (pos == vtkStdString::npos);
+  std::string::size_type pos = color.find_first_not_of("0123456789abcdefABCDEF");
+  this->StateGood = (pos == std::string::npos);
 
   if (this->StateGood)
   {
     if (color.size() == 3) // #RGB -> #RRGGBB
     {
       color.resize(6);
-      vtkStdString::size_type i = 3, j = 6;
+      std::string::size_type i = 3, j = 6;
       do
       {
         color[--j] = color[--i];
@@ -859,18 +856,18 @@ void vtkColorStringParser::HexStringToRGBA(vtkStdString color)
 // a is a floating number in 0.0..1.0.
 // If the parsed string is not valid set `StateGood` to false.
 void vtkColorStringParser::RGBAFuncStringToRGBA(
-  vtkStdString color, vtkStdString::size_type pos, unsigned int argCount)
+  std::string color, std::string::size_type pos, unsigned int argCount)
 {
   // Parse '('.
   pos = color.find_first_not_of(" \t", pos);
-  this->StateGood = (pos != vtkStdString::npos && color[pos] == '(');
+  this->StateGood = (pos != std::string::npos && color[pos] == '(');
 
   // Check if percentage values are used.
-  bool usePercentage = (color.find_first_of("%", pos + 1) != vtkStdString::npos);
+  bool usePercentage = (color.find_first_of('%', pos + 1) != std::string::npos);
 
   // Count and replace delimiters.
   unsigned int delimiterCount = 0;
-  for (vtkStdString::size_type i = pos + 1; (delimiterCount < argCount) && (i < color.size()); ++i)
+  for (std::string::size_type i = pos + 1; (delimiterCount < argCount) && (i < color.size()); ++i)
   {
     if (color[i] == ',')
     {
@@ -921,14 +918,14 @@ void vtkColorStringParser::RGBAFuncStringToRGBA(
   {
     pos = end - color.c_str();
     pos = color.find_first_not_of(" \t", pos);
-    this->StateGood = (pos != vtkStdString::npos && color[pos] == ')');
+    this->StateGood = (pos != std::string::npos && color[pos] == ')');
   }
 
   // Left characters must be only trailing spaces or the string is not valid.
   if (this->StateGood)
   {
     pos = color.find_first_not_of(" \t", pos + 1);
-    this->StateGood = (pos == vtkStdString::npos);
+    this->StateGood = (pos == std::string::npos);
   }
 }
 
@@ -954,7 +951,7 @@ vtkNamedColors::~vtkNamedColors()
 void vtkNamedColors::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  for (std::map<vtkStdString, vtkColor4ub>::const_iterator p = this->Colors->GetColorMap()->begin();
+  for (std::map<std::string, vtkColor4ub>::const_iterator p = this->Colors->GetColorMap()->begin();
        p != this->Colors->GetColorMap()->end(); ++p)
   {
     os << indent << ": " << p->first << "(";
@@ -973,13 +970,13 @@ void vtkNamedColors::PrintSelf(ostream& os, vtkIndent indent)
 //------------------------------------------------------------------------------
 vtkStdString vtkNamedColors::GetColorNames()
 {
-  std::vector<vtkStdString> cnv = this->Colors->GetColorNames();
-  vtkStdString colorNames;
+  std::vector<std::string> cnv = this->Colors->GetColorNames();
+  std::string colorNames;
   // Get the last element in the vector.
-  std::vector<vtkStdString>::iterator lastItr = cnv.end();
+  std::vector<std::string>::iterator lastItr = cnv.end();
   --lastItr;
   // Now just iterate through the map getting the color names.
-  for (std::vector<vtkStdString>::const_iterator p = cnv.begin(); p != cnv.end(); ++p)
+  for (std::vector<std::string>::const_iterator p = cnv.begin(); p != cnv.end(); ++p)
   {
     colorNames += *p;
     if (p != lastItr)
@@ -993,9 +990,9 @@ vtkStdString vtkNamedColors::GetColorNames()
 //------------------------------------------------------------------------------
 void vtkNamedColors::GetColorNames(vtkStringArray* colorNames)
 {
-  std::vector<vtkStdString> cnv = this->Colors->GetColorNames();
+  std::vector<std::string> cnv = this->Colors->GetColorNames();
   // Now just iterate through the map getting the color names.
-  for (std::vector<vtkStdString>::const_iterator p = cnv.begin(); p != cnv.end(); ++p)
+  for (std::vector<std::string>::const_iterator p = cnv.begin(); p != cnv.end(); ++p)
   {
     colorNames->InsertNextValue(*p);
   }
@@ -1004,16 +1001,16 @@ void vtkNamedColors::GetColorNames(vtkStringArray* colorNames)
 //------------------------------------------------------------------------------
 vtkStdString vtkNamedColors::GetSynonyms()
 {
-  vtkStdString synonyms;
-  std::vector<std::vector<vtkStdString>> syn = this->Colors->GetSynonyms();
-  std::vector<std::vector<vtkStdString>>::const_iterator synLast = syn.end();
+  std::string synonyms;
+  std::vector<std::vector<std::string>> syn = this->Colors->GetSynonyms();
+  std::vector<std::vector<std::string>>::const_iterator synLast = syn.end();
   --synLast;
-  for (std::vector<std::vector<vtkStdString>>::const_iterator p = syn.begin(); p != syn.end(); ++p)
+  for (std::vector<std::vector<std::string>>::const_iterator p = syn.begin(); p != syn.end(); ++p)
   {
     // Get the last element in the vector.
-    std::vector<vtkStdString>::const_iterator strLast = p->end();
+    std::vector<std::string>::const_iterator strLast = p->end();
     --strLast;
-    for (std::vector<vtkStdString>::const_iterator q = p->begin(); q != p->end(); ++q)
+    for (std::vector<std::string>::const_iterator q = p->begin(); q != p->end(); ++q)
     {
       synonyms += *q;
       if (q != strLast)
@@ -1305,3 +1302,4 @@ vtkStdString vtkNamedColors::RGBAToHTMLColor(const vtkColor4ub& rgba)
      << (int)(rgba.GetBlue()) << "," << (rgba.GetAlpha() / 255.0) << ")";
   return ss.str();
 }
+VTK_ABI_NAMESPACE_END
