@@ -16,6 +16,7 @@
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkParametricBohemianDome);
 //----------------------------------------------------------------------------//
 vtkParametricBohemianDome::vtkParametricBohemianDome()
@@ -87,3 +88,4 @@ void vtkParametricBohemianDome::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
