@@ -16,6 +16,9 @@
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 
+#include <cmath>
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkParametricDini);
 
 //------------------------------------------------------------------------------
@@ -58,7 +61,16 @@ void vtkParametricDini::Evaluate(double uvw[3], double Pt[3], double Duvw[9])
   // The point
   Pt[0] = this->A * cu * sv;
   Pt[1] = this->A * su * sv;
-  Pt[2] = this->A * (cos(v) + log(tan((v / 2)))) + this->B * u;
+  double tolerance = 0.0001;
+  if (std::abs(v) > tolerance)
+  {
+    Pt[2] = this->A * (cos(v) + log(tan((v / 2)))) + this->B * u;
+  }
+  else
+  {
+    // avoid log(0)=-inf result for v=0
+    Pt[2] = this->A * (cos(v) + log(tan((tolerance / 2)))) + this->B * u;
+  }
 
   // The derivatives are:
   Du[0] = -Pt[1];
@@ -91,3 +103,4 @@ void vtkParametricDini::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "A: " << this->A << "\n";
   os << indent << "B: " << this->B << "\n";
 }
+VTK_ABI_NAMESPACE_END
