@@ -38,6 +38,7 @@
 #include "vtkCommonComputationalGeometryModule.h" // For export macro
 #include "vtkParametricFunction.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDoubleArray;
 class vtkMinimalStandardRandomSequence;
 
@@ -71,43 +72,43 @@ public:
    */
   static vtkParametricRandomHills* New();
 
-  //@{
+  ///@{
   /**
    * Set/Get the number of hills.
    * Default is 30.
    */
   vtkSetMacro(NumberOfHills, int);
   vtkGetMacro(NumberOfHills, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the hill variance in the x-direction.
    * Default is 2.5.
    */
   vtkSetMacro(HillXVariance, double);
   vtkGetMacro(HillXVariance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the hill variance in the y-direction.
    * Default is 2.5.
    */
   vtkSetMacro(HillYVariance, double);
   vtkGetMacro(HillYVariance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the hill amplitude (height).
    * Default is 2.
    */
   vtkSetMacro(HillAmplitude, double);
   vtkGetMacro(HillAmplitude, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the Seed for the random number generator,
    * a value of 1 will initialize the random number generator,
@@ -116,9 +117,9 @@ public:
    */
   vtkSetMacro(RandomSeed, int);
   vtkGetMacro(RandomSeed, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the random generation flag.
    * A value of 0 will disable the generation of random hills on the surface
@@ -135,34 +136,34 @@ public:
   vtkSetClampMacro(AllowRandomGeneration, vtkTypeBool, 0, 1);
   vtkGetMacro(AllowRandomGeneration, vtkTypeBool);
   vtkBooleanMacro(AllowRandomGeneration, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the scaling factor for the variance in the x-direction.
    * Default is 1/3.
    */
   vtkSetMacro(XVarianceScaleFactor, double);
   vtkGetMacro(XVarianceScaleFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the scaling factor for the variance in the y-direction.
    * Default is 1/3.
    */
   vtkSetMacro(YVarianceScaleFactor, double);
   vtkGetMacro(YVarianceScaleFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the scaling factor for the amplitude.
    * Default is 1/3.
    */
   vtkSetMacro(AmplitudeScaleFactor, double);
   vtkGetMacro(AmplitudeScaleFactor, double);
-  //@}
+  ///@}
 
   /**
    * Construct a terrain consisting of hills on a surface.
@@ -227,7 +228,7 @@ private:
   /**
    * Return a random number between 0 and 1.
    */
-  double Rand(void);
+  double Rand();
 
   /**
    * A random sequence generator.
@@ -240,7 +241,7 @@ private:
    * the u, v coordinates of each hill, their variances in the u, v directions
    * and their amplitudes.
    */
-  void MakeTheHillData(void);
+  void MakeTheHillData();
 
   /**
    * True if any parameters have changed.
@@ -252,12 +253,13 @@ private:
    */
   void CopyParameters();
 
-  //@{
+  ///@{
   /**
    * Centers (x,y), variances (x,y) and amplitudes of the hills.
    */
   vtkDoubleArray* hillData;
+  ///@}
 };
-//@}
 
+VTK_ABI_NAMESPACE_END
 #endif
