@@ -47,18 +47,24 @@ std::size_t NumErrors = 0;
 
 // Various properties required by random access iterators:
 #define CHECK_ITER_TYPE(type)                                                                      \
-  static_assert(std::is_default_constructible<Iter>::value,                                        \
-    "Iterator types must be default constructable at " LOCATION());                                \
-  static_assert(std::is_copy_constructible<Iter>::value,                                           \
-    "Iterator types must be copy constructible at " LOCATION());                                   \
-  static_assert(std::is_copy_assignable<Iter>::value,                                              \
-    "Iterator types must be copy assignable at " LOCATION());                                      \
-  static_assert(                                                                                   \
-    std::is_destructible<Iter>::value, "Iterator types must be destructible at " LOCATION());
+  do                                                                                               \
+  {                                                                                                \
+    static_assert(std::is_default_constructible<Iter>::value,                                      \
+      "Iterator types must be default constructable at " LOCATION());                              \
+    static_assert(std::is_copy_constructible<Iter>::value,                                         \
+      "Iterator types must be copy constructible at " LOCATION());                                 \
+    static_assert(std::is_copy_assignable<Iter>::value,                                            \
+      "Iterator types must be copy assignable at " LOCATION());                                    \
+    static_assert(                                                                                 \
+      std::is_destructible<Iter>::value, "Iterator types must be destructible at " LOCATION());    \
+  } while (false)
 
 #define LOG_ERROR(message)                                                                         \
-  ++NumErrors;                                                                                     \
-  std::cerr << NumErrors << ": " << message << "\n"
+  do                                                                                               \
+  {                                                                                                \
+    ++NumErrors;                                                                                   \
+    std::cerr << NumErrors << ": " << message << "\n";                                             \
+  } while (false)
 
 #define CHECK_TRUE(expr)                                                                           \
   do                                                                                               \
@@ -769,7 +775,9 @@ struct UnitTestValueIteratorAPI
     CHECK_TRUE(iter == iter1);
 
     {
-      std::swap(iter1, iter2);
+      // ADL swap:
+      using std::swap;
+      swap(iter1, iter2);
     }
 
     CHECK_FALSE(iter1 < iter2);
@@ -778,7 +786,9 @@ struct UnitTestValueIteratorAPI
     CHECK_TRUE(iter == iter2);
 
     {
-      std::swap(iter1, iter2);
+      // ADL swap:
+      using std::swap;
+      swap(iter1, iter2);
     }
 
     CHECK_TRUE(iter1 < iter2);
@@ -973,6 +983,7 @@ struct UnitTestValueReferenceAPI
 
     APIType val2 = val1 + 1;
 
+    // ADL swap:
     using std::swap;
     swap(ref1, val2);
 
@@ -1657,6 +1668,7 @@ struct UnitTestEdgeCases
       auto it2 = start2;
       for (auto it1 = start1; it1 < end1; ++it1)
       {
+        // ADL swap:
         using std::swap;
         swap(*it1, *it2++);
       }
