@@ -25,14 +25,14 @@ class vtkHandler : public vtkObject
 public:
   static std::map<int, int> EventCounts;
   static int VoidEventCounts;
-public:
+
   static vtkHandler* New();
   vtkTypeMacro(vtkHandler, vtkObject);
 
-  void VoidCallback() { this->VoidEventCounts++; }
+  void VoidCallback() { vtkHandler::VoidEventCounts++; }
   void CallbackWithArguments(vtkObject*, unsigned long event, void*)
   {
-    this->EventCounts[event]++;
+    vtkHandler::EventCounts[event]++;
   }
 };
 vtkStandardNewMacro(vtkHandler);
@@ -45,17 +45,28 @@ class OtherHandler
 public:
   static std::map<int, int> EventCounts;
   static int VoidEventCounts;
-public:
-  void VoidCallback() { this->VoidEventCounts++; }
+
+  void VoidCallback() { OtherHandler::VoidEventCounts++; }
   void CallbackWithArguments(vtkObject*, unsigned long event, void*)
   {
-    this->EventCounts[event]++;
+    OtherHandler::EventCounts[event]++;
   }
 };
 
 int OtherHandler::VoidEventCounts = 0;
 std::map<int, int> OtherHandler::EventCounts;
 
+class NestedHandler1
+{
+public:
+  void CallbackWithArguments(vtkObject* self, unsigned long, void*) { self->InvokeEvent(1001); }
+};
+class NestedHandler2
+{
+public:
+  void CallbackWithArguments(vtkObject* self, unsigned long, void*) { self->RemoveAllObservers(); }
+};
+
 int TestObservers(int, char*[])
 {
   unsigned long event0 = 0;
@@ -64,15 +75,22 @@ int TestObservers(int, char*[])
 
   vtkObject* volcano = vtkObject::New();
 
-  // First the base test, with a vtkObject pointer
+  // Test nested callbacks invalidating iteration of observers
+  // This will seg fault if the iterators are not handled properly
+  NestedHandler1* handlerNested1 = new NestedHandler1();
+  event0 = volcano->AddObserver(1000, handlerNested1, &NestedHandler1::CallbackWithArguments);
+  NestedHandler2* handlerNested2 = new NestedHandler2();
+  event1 = volcano->AddObserver(1001, handlerNested2, &NestedHandler2::CallbackWithArguments);
+  volcano->InvokeEvent(1000);
+  delete handlerNested1;
+  delete handlerNested2;
+
+  // Handle the base test, with a vtkObject pointer
   vtkHandler* handler = vtkHandler::New();
 
-  event0 = volcano->AddObserver(
-    1000, handler, &vtkHandler::VoidCallback);
-  event1 = volcano->AddObserver(
-    1001, handler, &vtkHandler::CallbackWithArguments);
-  event2 = volcano->AddObserver(
-    1002, handler, &vtkHandler::CallbackWithArguments);
+  event0 = volcano->AddObserver(1000, handler, &vtkHandler::VoidCallback);
+  event1 = volcano->AddObserver(1001, handler, &vtkHandler::CallbackWithArguments);
+  event2 = volcano->AddObserver(1002, handler, &vtkHandler::CallbackWithArguments);
 
   volcano->InvokeEvent(1000);
   volcano->InvokeEvent(1001);
@@ -100,10 +118,8 @@ int TestObservers(int, char*[])
   // remove the final observer
   volcano->RemoveObserver(event0);
 
-  if (vtkHandler::VoidEventCounts == 2 &&
-    vtkHandler::EventCounts[1000] == 0 &&
-    vtkHandler::EventCounts[1001] == 2 &&
-    vtkHandler::EventCounts[1002] == 1)
+  if (vtkHandler::VoidEventCounts == 2 && vtkHandler::EventCounts[1000] == 0 &&
+    vtkHandler::EventCounts[1001] == 2 && vtkHandler::EventCounts[1002] == 1)
   {
     cout << "All vtkObject callback counts as expected." << endl;
   }
@@ -122,12 +138,9 @@ int TestObservers(int, char*[])
   {
     vtkSmartPointer<vtkHandler> handler2 = vtkSmartPointer<vtkHandler>::New();
 
-    event0 = volcano->AddObserver(
-      1003, handler2, &vtkHandler::VoidCallback);
-    event1 = volcano->AddObserver(
-      1004, handler2, &vtkHandler::CallbackWithArguments);
-    event2 = volcano->AddObserver(
-      1005, handler2, &vtkHandler::CallbackWithArguments);
+    event0 = volcano->AddObserver(1003, handler2, &vtkHandler::VoidCallback);
+    event1 = volcano->AddObserver(1004, handler2, &vtkHandler::CallbackWithArguments);
+    event2 = volcano->AddObserver(1005, handler2, &vtkHandler::CallbackWithArguments);
 
     volcano->InvokeEvent(1003);
     volcano->InvokeEvent(1004);
@@ -157,10 +170,8 @@ int TestObservers(int, char*[])
   // remove the final observer
   volcano->RemoveObserver(event0);
 
-  if (vtkHandler::VoidEventCounts == 2 &&
-    vtkHandler::EventCounts[1003] == 0 &&
-    vtkHandler::EventCounts[1004] == 2 &&
-    vtkHandler::EventCounts[1005] == 1)
+  if (vtkHandler::VoidEventCounts == 2 && vtkHandler::EventCounts[1003] == 0 &&
+    vtkHandler::EventCounts[1004] == 2 && vtkHandler::EventCounts[1005] == 1)
   {
     cout << "All smart pointer callback counts as expected." << endl;
   }
@@ -175,14 +186,11 @@ int TestObservers(int, char*[])
   // Test yet again, this time with a non-VTK object
   // (this _can_ leave dangling pointers!!!)
 
-  OtherHandler *handler3 = new OtherHandler();
+  OtherHandler* handler3 = new OtherHandler();
 
-  event0 = volcano->AddObserver(
-    1006, handler3, &OtherHandler::VoidCallback);
-  event1 = volcano->AddObserver(
-    1007, handler3, &OtherHandler::CallbackWithArguments);
-  event2 = volcano->AddObserver(
-    1008, handler3, &OtherHandler::CallbackWithArguments);
+  event0 = volcano->AddObserver(1006, handler3, &OtherHandler::VoidCallback);
+  event1 = volcano->AddObserver(1007, handler3, &OtherHandler::CallbackWithArguments);
+  event2 = volcano->AddObserver(1008, handler3, &OtherHandler::CallbackWithArguments);
 
   volcano->InvokeEvent(1006);
   volcano->InvokeEvent(1007);
@@ -205,10 +213,8 @@ int TestObservers(int, char*[])
   // delete the observed object
   volcano->Delete();
 
-  if (OtherHandler::VoidEventCounts == 2 &&
-    OtherHandler::EventCounts[1006] == 0 &&
-    OtherHandler::EventCounts[1007] == 2 &&
-    OtherHandler::EventCounts[1008] == 1)
+  if (OtherHandler::VoidEventCounts == 2 && OtherHandler::EventCounts[1006] == 0 &&
+    OtherHandler::EventCounts[1007] == 2 && OtherHandler::EventCounts[1008] == 1)
   {
     cout << "All non-VTK observer callback counts as expected." << endl;
     return 0;
