@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkTestNewVar.cxx
+  Module:    vtkTestNewVar.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -23,7 +23,9 @@
 #include "vtkNew.h"
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPoints2D;
+VTK_ABI_NAMESPACE_END
 
 class vtkTestNewVar : public vtkObject
 {
