@@ -99,6 +99,8 @@ compare(randomVec[dsa.VTKCompositeDataArray([(slice(None, None, None), slice(0,2
 compare(algs.cos(randomVec) - numpy.cos(npa), 1E-7)
 assert algs.cos(randomVec).DataSet is randomVec.DataSet
 
+assert algs.in1d(elev, [0,1]) == [item in [0, 1] for item in elev]
+
 # Various numerical ops implemented in VTK
 g = algs.gradient(elev)
 assert algs.all(g[0] == (1, 0, 0))
@@ -118,8 +120,8 @@ assert algs.all(algs.eigenvalue(g) == [2, 1, 1])
 
 assert algs.all(randomVec[:,0] == randomVec[:,0])
 
-int_array1 = numpy.array([1, 0, 1], dtype=numpy.int)
-int_array2 = numpy.array([0, 1, 0], dtype=numpy.int)
+int_array1 = numpy.array([1, 0, 1], dtype=int)
+int_array2 = numpy.array([0, 1, 0], dtype=int)
 assert algs.all(algs.bitwise_or(int_array1, int_array2) == 1)
 assert algs.all(algs.bitwise_or(int_array1, dsa.NoneArray) == int_array1)
 assert algs.all(algs.bitwise_or(dsa.NoneArray, int_array1) == int_array1)
@@ -272,3 +274,10 @@ original_arrays = pdw.PointData.GetNumberOfArrays()
 pdw.PointData.append(12, "twelve")
 pdw.PointData.append(12.12, "twelve-point-twelve")
 assert pdw.PointData.GetNumberOfArrays() == (2 + original_arrays)
+
+# create a table
+table = dsa.WrapDataObject(vtk.vtkTable())
+table.RowData.append(numpy.ones(5), "ones")
+table.RowData.append(2*numpy.ones(5), "twos")
+assert table.GetNumberOfRows() == 5
+assert table.GetNumberOfColumns() == 2
