@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_1_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkAbstractArray.h"
 
 #include "vtkBitArray.h"
@@ -49,8 +46,6 @@
 #include "vtkTypeUInt32Array.h"
 #include "vtkTypeUInt64Array.h"
 #include "vtkTypeUInt8Array.h"
-#include "vtkUnicodeString.h" // for vtkSuperExtraExtendedTemplateMacro
-#include "vtkUnicodeStringArray.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
@@ -63,17 +58,21 @@
 #include <iterator>
 #include <set>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkInformationKeyMacro(vtkAbstractArray, GUI_HIDE, Integer);
 vtkInformationKeyMacro(vtkAbstractArray, PER_COMPONENT, InformationVector);
 vtkInformationKeyMacro(vtkAbstractArray, PER_FINITE_COMPONENT, InformationVector);
 vtkInformationKeyMacro(vtkAbstractArray, DISCRETE_VALUES, VariantVector);
 vtkInformationKeyRestrictedMacro(
   vtkAbstractArray, DISCRETE_VALUE_SAMPLE_PARAMETERS, DoubleVector, 2);
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
-typedef std::vector<vtkStdString*> vtkInternalComponentNameBase;
+typedef std::vector<std::string*> vtkInternalComponentNameBase;
 }
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray::vtkInternalComponentNames : public vtkInternalComponentNameBase
 {
 };
@@ -128,7 +127,7 @@ void vtkAbstractArray::SetComponentName(vtkIdType component, const char* name)
   if (index == this->ComponentNames->size())
   {
     // the array isn't large enough, so we will resize
-    this->ComponentNames->push_back(new vtkStdString(name));
+    this->ComponentNames->push_back(new std::string(name));
     return;
   }
   else if (index > this->ComponentNames->size())
@@ -137,10 +136,10 @@ void vtkAbstractArray::SetComponentName(vtkIdType component, const char* name)
   }
 
   // replace an existing element
-  vtkStdString* compName = this->ComponentNames->at(index);
+  std::string* compName = this->ComponentNames->at(index);
   if (!compName)
   {
-    compName = new vtkStdString(name);
+    compName = new std::string(name);
     this->ComponentNames->at(index) = compName;
   }
   else
@@ -159,7 +158,7 @@ const char* vtkAbstractArray::GetComponentName(vtkIdType component) const
     return nullptr;
   }
 
-  vtkStdString* compName = this->ComponentNames->at(index);
+  std::string* compName = this->ComponentNames->at(index);
   return (compName) ? compName->c_str() : nullptr;
 }
 
@@ -368,7 +367,6 @@ int vtkAbstractArray::GetDataTypeSize(int type)
 
     case VTK_BIT:
     case VTK_STRING:
-    case VTK_UNICODE_STRING:
       return 0;
 
     default:
@@ -469,9 +467,6 @@ vtkAbstractArray* vtkAbstractArray::CreateArray(int dataType)
     case VTK_STRING:
       return vtkStringArray::New();
 
-    case VTK_UNICODE_STRING:
-      return vtkUnicodeStringArray::New();
-
     case VTK_VARIANT:
       return vtkVariantArray::New();
 
@@ -555,6 +550,8 @@ const char* vtkAbstractArray::GetArrayTypeAsString() const
       return "MappedDataArray";
     case ScaleSoADataArrayTemplate:
       return "ScaleSoADataArrayTemplate";
+    case ImplicitArray:
+      return "ImplicitArray";
   }
   return "Unknown";
 }
@@ -632,6 +629,7 @@ void vtkAbstractArray::GetProminentComponentValues(
     }
   }
 }
+VTK_ABI_NAMESPACE_END
 
 //------------------------------------------------------------------------------
 namespace
@@ -767,6 +765,7 @@ void SampleProminentValues(std::vector<std::vector<vtkVariant>>& uniques, vtkIdT
 }
 } // End anonymous namespace.
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimumProminence)
 {
@@ -781,12 +780,13 @@ void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimum
   //
   // N is chosen to satisfy the requested uncertainty and prominence criteria
   // specified.
-#define VTK_CACHE_LINE_SIZE 64
-#define VTK_SAMPLE_FACTOR 5
+  constexpr int cacheLineSize = 64;
+  constexpr int sampleFactor = 5;
+
   // I. Determine the granularity at which the array should be sampled.
   int numberOfComponentsWithProminentValues = 0;
   int nc = this->NumberOfComponents;
-  int blockSize = VTK_CACHE_LINE_SIZE / (this->GetDataTypeSize() * nc);
+  int blockSize = cacheLineSize / (this->GetDataTypeSize() * nc);
   if (!blockSize)
   {
     blockSize = 4;
@@ -803,7 +803,7 @@ void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimum
     }
     if (!vtkMath::IsInf(logfac))
     {
-      numberOfSampleTuples = static_cast<vtkIdType>(VTK_SAMPLE_FACTOR * logfac);
+      numberOfSampleTuples = static_cast<vtkIdType>(sampleFactor * logfac);
     }
   }
   /*
@@ -824,9 +824,8 @@ void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimum
   std::vector<std::vector<vtkVariant>> uniques(nc > 1 ? nc + 1 : nc);
   switch (this->GetDataType())
   {
-    vtkSuperExtraExtendedTemplateMacro(
-      SampleProminentValues(uniques, this->MaxId, nc, nt, blockSize, numberOfBlocks,
-        static_cast<VTK_TT*>(this->GetVoidPointer(0)), this->MaxDiscreteValues));
+    vtkExtraExtendedTemplateMacro(SampleProminentValues(uniques, this->MaxId, nc, nt, blockSize,
+      numberOfBlocks, static_cast<VTK_TT*>(this->GetVoidPointer(0)), this->MaxDiscreteValues));
     default:
       vtkErrorMacro("Array type " << this->GetClassName() << " not supported.");
       break;
@@ -849,7 +848,7 @@ void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimum
         iv = this->GetInformation()->Get(PER_COMPONENT());
       }
       iv->GetInformationObject(c)->Set(
-        DISCRETE_VALUES(), &uniques[c][0], static_cast<int>(uniques[c].size()));
+        DISCRETE_VALUES(), uniques[c].data(), static_cast<int>(uniques[c].size()));
     }
     else
     {
@@ -864,7 +863,7 @@ void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimum
   {
     ++numberOfComponentsWithProminentValues;
     this->GetInformation()->Set(
-      DISCRETE_VALUES(), &uniques[nc][0], static_cast<int>(uniques[nc].size()));
+      DISCRETE_VALUES(), uniques[nc].data(), static_cast<int>(uniques[nc].size()));
   }
   else
   { // Remove the key
@@ -878,3 +877,4 @@ void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimum
   params[1] = minimumProminence;
   this->GetInformation()->Set(DISCRETE_VALUE_SAMPLE_PARAMETERS(), params, 2);
 }
+VTK_ABI_NAMESPACE_END
