@@ -32,6 +32,7 @@
 
 //------------------------------------------------------------------------------
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkArray::vtkArray() = default;
 
 //------------------------------------------------------------------------------
@@ -96,8 +97,6 @@ vtkArray* vtkArray::CreateArray(int StorageType, int ValueType)
           return vtkDenseArray<vtkIdType>::New();
         case VTK_STRING:
           return vtkDenseArray<vtkStdString>::New();
-        case VTK_UNICODE_STRING:
-          return vtkDenseArray<vtkUnicodeString>::New();
         case VTK_VARIANT:
           return vtkDenseArray<vtkVariant>::New();
       }
@@ -140,8 +139,6 @@ vtkArray* vtkArray::CreateArray(int StorageType, int ValueType)
           return vtkSparseArray<vtkIdType>::New();
         case VTK_STRING:
           return vtkSparseArray<vtkStdString>::New();
-        case VTK_UNICODE_STRING:
-          return vtkSparseArray<vtkUnicodeString>::New();
         case VTK_VARIANT:
           return vtkSparseArray<vtkVariant>::New();
       }
@@ -210,7 +207,7 @@ vtkTypeUInt64 vtkArray::GetSize()
 void vtkArray::SetName(const vtkStdString& raw_name)
 {
   // Don't allow newlines in array names ...
-  vtkStdString name(raw_name);
+  std::string name(raw_name);
   name.erase(std::remove(name.begin(), name.end(), '\r'), name.end());
   name.erase(std::remove(name.begin(), name.end(), '\n'), name.end());
 
@@ -232,7 +229,7 @@ void vtkArray::SetDimensionLabel(DimensionT i, const vtkStdString& raw_label)
   }
 
   // Don't allow newlines in dimension labels ...
-  vtkStdString label(raw_label);
+  std::string label(raw_label);
   label.erase(std::remove(label.begin(), label.end(), '\r'), label.end());
   label.erase(std::remove(label.begin(), label.end(), '\n'), label.end());
 
@@ -250,3 +247,4 @@ vtkStdString vtkArray::GetDimensionLabel(DimensionT i)
 
   return this->InternalGetDimensionLabel(i);
 }
+VTK_ABI_NAMESPACE_END
