@@ -16,8 +16,8 @@
 
 #include "vtkArrayIteratorTemplate.txx"
 
-vtkInstantiateTemplateMacro(
-  template class VTKCOMMONCORE_EXPORT vtkArrayIteratorTemplate)
+VTK_ABI_NAMESPACE_BEGIN
+vtkInstantiateTemplateMacro(template class VTKCOMMONCORE_EXPORT vtkArrayIteratorTemplate);
 template class VTKCOMMONCORE_EXPORT vtkArrayIteratorTemplate<vtkStdString>;
-template class VTKCOMMONCORE_EXPORT vtkArrayIteratorTemplate<vtkUnicodeString>;
 template class VTKCOMMONCORE_EXPORT vtkArrayIteratorTemplate<vtkVariant>;
+VTK_ABI_NAMESPACE_END
