@@ -18,13 +18,11 @@
 #include "vtkIdList.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
-// This is used to initialize the last byte of the array when allocating memory
-// to prevent the presence of uninitialized bits that are out of range for the
-// array.
-static constexpr unsigned char InitializationMaskForUnusedBitsOfLastByte[8] = { 0xff, 0x80, 0xc0,
-  0xe0, 0xf0, 0xf8, 0xfc, 0xfe };
+constexpr unsigned char InitializationMaskForUnusedBitsOfLastByte[8] = { 0x80, 0xc0, 0xe0, 0xf0,
+  0xf8, 0xfc, 0xfe, 0xff };
 } // anonymous namespace
 
 //------------------------------------------------------------------------------
@@ -79,6 +77,14 @@ vtkBitArray::~vtkBitArray()
   delete this->Lookup;
 }
 
+void vtkBitArray::InitializeUnusedBitsInLastByte()
+{
+  if (this->MaxId > -1)
+  {
+    this->Array[this->MaxId / 8] &= InitializationMaskForUnusedBitsOfLastByte[this->MaxId % 8];
+  }
+}
+
 //------------------------------------------------------------------------------
 unsigned char* vtkBitArray::WritePointer(vtkIdType id, vtkIdType number)
 {
@@ -90,6 +96,7 @@ unsigned char* vtkBitArray::WritePointer(vtkIdType id, vtkIdType number)
   if ((--newSize) > this->MaxId)
   {
     this->MaxId = newSize;
+    this->InitializeUnusedBitsInLastByte();
   }
   this->DataChanged();
   return this->Array + id / 8;
@@ -104,7 +111,6 @@ unsigned char* vtkBitArray::WritePointer(vtkIdType id, vtkIdType number)
 // from the supplied array.
 void vtkBitArray::SetArray(unsigned char* array, vtkIdType size, int save, int deleteMethod)
 {
-
   if ((this->Array) && (this->DeleteFunction))
   {
     vtkDebugMacro(<< "Deleting the array...");
@@ -120,6 +126,7 @@ void vtkBitArray::SetArray(unsigned char* array, vtkIdType size, int save, int d
   this->Array = array;
   this->Size = size;
   this->MaxId = size - 1;
+  this->InitializeUnusedBitsInLastByte();
 
   if (save != 0)
   {
@@ -171,8 +178,6 @@ vtkTypeBool vtkBitArray::Allocate(vtkIdType sz, vtkIdType vtkNotUsed(ext))
     this->Size = (sz > 0 ? sz : 1);
     if ((this->Array = new unsigned char[(this->Size + 7) / 8]) == nullptr)
     {
-      this->Array[(this->Size + 7) / 8 - 1] &=
-        InitializationMaskForUnusedBitsOfLastByte[this->Size % 8];
       return 0;
     }
     this->DeleteFunction = ::operator delete[];
@@ -301,14 +306,13 @@ unsigned char* vtkBitArray::ResizeAndExtend(vtkIdType sz)
     }
   }
 
-  newArray[(newSize + 7) / 8 - 1] &= InitializationMaskForUnusedBitsOfLastByte[newSize % 8];
-
+  this->Array = newArray;
   if (newSize < this->Size)
   {
     this->MaxId = newSize - 1;
+    this->InitializeUnusedBitsInLastByte();
   }
   this->Size = newSize;
-  this->Array = newArray;
   this->DeleteFunction = ::operator delete[];
   this->DataChanged();
 
@@ -349,14 +353,13 @@ vtkTypeBool vtkBitArray::Resize(vtkIdType sz)
     }
   }
 
-  newArray[(newSize + 7) / 8 - 1] &= InitializationMaskForUnusedBitsOfLastByte[newSize % 8];
-
+  this->Array = newArray;
   if (newSize < this->Size)
   {
     this->MaxId = newSize - 1;
+    this->InitializeUnusedBitsInLastByte();
   }
   this->Size = newSize;
-  this->Array = newArray;
   this->DeleteFunction = ::operator delete[];
   this->DataChanged();
 
@@ -370,6 +373,17 @@ void vtkBitArray::SetNumberOfTuples(vtkIdType number)
   this->SetNumberOfValues(number * this->NumberOfComponents);
 }
 
+//------------------------------------------------------------------------------
+bool vtkBitArray::SetNumberOfValues(vtkIdType number)
+{
+  if (!this->Superclass::SetNumberOfValues(number))
+  {
+    return false;
+  }
+  this->InitializeUnusedBitsInLastByte();
+  return true;
+}
+
 //------------------------------------------------------------------------------
 // Description:
 // Set the tuple at the ith location using the jth tuple in the source array.
@@ -409,10 +423,50 @@ void vtkBitArray::InsertTuple(vtkIdType i, vtkIdType j, vtkAbstractArray* source
 
   vtkIdType loci = i * this->NumberOfComponents;
   vtkIdType locj = j * ba->GetNumberOfComponents();
+  vtkIdType previousMaxId = this->MaxId;
   for (vtkIdType cur = 0; cur < this->NumberOfComponents; cur++)
   {
     this->InsertValue(loci + cur, ba->GetValue(locj + cur));
   }
+  if (previousMaxId / 8 != this->MaxId / 8)
+  {
+    this->InitializeUnusedBitsInLastByte();
+  }
+  this->DataChanged();
+}
+
+//------------------------------------------------------------------------------
+void vtkBitArray::InsertTuplesStartingAt(
+  vtkIdType dstStart, vtkIdList* srcIds, vtkAbstractArray* source)
+{
+  vtkBitArray* ba = vtkArrayDownCast<vtkBitArray>(source);
+  if (!ba)
+  {
+    vtkWarningMacro("Input and output arrays types do not match.");
+    return;
+  }
+
+  if (ba->NumberOfComponents != this->NumberOfComponents)
+  {
+    vtkWarningMacro("Number of components do not match.");
+    return;
+  }
+
+  vtkIdType previousMaxId = this->MaxId;
+  for (vtkIdType idIndex = 0; idIndex < srcIds->GetNumberOfIds(); ++idIndex)
+  {
+    vtkIdType numComp = this->NumberOfComponents;
+    vtkIdType srcLoc = srcIds->GetId(idIndex) * this->NumberOfComponents;
+    vtkIdType dstLoc = (dstStart + idIndex) * this->NumberOfComponents;
+    while (numComp-- > 0)
+    {
+      this->InsertValue(dstLoc++, ba->GetValue(srcLoc++));
+    }
+  }
+  if (previousMaxId / 8 != this->MaxId / 8)
+  {
+    this->InitializeUnusedBitsInLastByte();
+  }
   this->DataChanged();
 }
 
@@ -439,6 +493,7 @@ void vtkBitArray::InsertTuples(vtkIdList* dstIds, vtkIdList* srcIds, vtkAbstract
     return;
   }
 
+  vtkIdType previousMaxId = this->MaxId;
   for (vtkIdType idIndex = 0; idIndex < numIds; ++idIndex)
   {
     vtkIdType numComp = this->NumberOfComponents;
@@ -449,6 +504,10 @@ void vtkBitArray::InsertTuples(vtkIdList* dstIds, vtkIdList* srcIds, vtkAbstract
       this->InsertValue(dstLoc++, ba->GetValue(srcLoc++));
     }
   }
+  if (previousMaxId / 8 != this->MaxId / 8)
+  {
+    this->InitializeUnusedBitsInLastByte();
+  }
   this->DataChanged();
 }
 
@@ -477,6 +536,7 @@ void vtkBitArray::InsertTuples(
     return;
   }
 
+  vtkIdType previousMaxId = this->MaxId;
   for (vtkIdType i = 0; i < n; ++i)
   {
     vtkIdType numComp = this->NumberOfComponents;
@@ -487,7 +547,10 @@ void vtkBitArray::InsertTuples(
       this->InsertValue(dstLoc++, sa->GetValue(srcLoc++));
     }
   }
-
+  if (previousMaxId / 8 != this->MaxId / 8)
+  {
+    this->InitializeUnusedBitsInLastByte();
+  }
   this->DataChanged();
 }
 
@@ -774,3 +837,4 @@ void vtkBitArray::ClearLookup()
   delete this->Lookup;
   this->Lookup = nullptr;
 }
+VTK_ABI_NAMESPACE_END
