@@ -19,8 +19,15 @@
 #include <cstdint>
 #include <memory.h>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkByteSwap);
 
+//------------------------------------------------------------------------------
+void vtkByteSwap::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 vtkByteSwap::vtkByteSwap() = default;
 
@@ -355,3 +362,4 @@ void vtkByteSwap::SwapVoidRange(void* buffer, size_t numWords, size_t wordSize)
     buf += half;
   }
 }
+VTK_ABI_NAMESPACE_END
