@@ -16,6 +16,7 @@
 #include "vtkCallbackCommand.h"
 
 //----------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkCallbackCommand::vtkCallbackCommand()
 {
   this->ClientData = nullptr;
@@ -34,8 +35,7 @@ vtkCallbackCommand::~vtkCallbackCommand()
 }
 
 //----------------------------------------------------------------
-void vtkCallbackCommand::Execute(vtkObject *caller, unsigned long event,
-                                 void *callData)
+void vtkCallbackCommand::Execute(vtkObject* caller, unsigned long event, void* callData)
 {
   if (this->Callback)
   {
@@ -46,4 +46,4 @@ void vtkCallbackCommand::Execute(vtkObject *caller, unsigned long event,
     }
   }
 }
-
+VTK_ABI_NAMESPACE_END
