@@ -16,12 +16,10 @@
 #ifndef vtkCollectionRange_h
 #define vtkCollectionRange_h
 
-#ifndef __VTK_WRAP__
-
 #include "vtkCollection.h"
 #include "vtkMeta.h"
-#include "vtkSmartPointer.h"
 #include "vtkRange.h"
+#include "vtkSmartPointer.h"
 
 #include <cassert>
 
@@ -29,18 +27,22 @@ namespace vtk
 {
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 
-template <typename CollectionType> struct CollectionRange;
-template <typename CollectionType> struct CollectionIterator;
+template <typename CollectionType>
+struct CollectionRange;
+template <typename CollectionType>
+struct CollectionIterator;
 
 //------------------------------------------------------------------------------
 // Detect vtkCollection types
 template <typename T>
-struct IsCollection : std::is_base_of<vtkCollection, T> {};
+struct IsCollection : std::is_base_of<vtkCollection, T>
+{
+};
 
 template <typename CollectionType, typename T = CollectionType>
-using EnableIfIsCollection =
-typename std::enable_if<IsCollection<CollectionType>::value, T>::type;
+using EnableIfIsCollection = typename std::enable_if<IsCollection<CollectionType>::value, T>::type;
 
 //------------------------------------------------------------------------------
 // Detect the type of items held by the collection by checking the return type
@@ -48,10 +50,9 @@ typename std::enable_if<IsCollection<CollectionType>::value, T>::type;
 template <typename CollectionType>
 struct GetCollectionItemType
 {
-  static_assert(IsCollection<CollectionType>::value,
-                "Invalid vtkCollection subclass.");
-private:
+  static_assert(IsCollection<CollectionType>::value, "Invalid vtkCollection subclass.");
 
+private:
   // The GetType methods are only used in a decltype context and are left
   // unimplemented as we only care about their signatures. They are used to
   // determine the type of object held by the collection.
@@ -70,13 +71,11 @@ private:
 
   // not implemented
   template <typename T>
-  static auto GetType(...)
-  -> decltype(std::declval<T>().GetNextItemAsObject());
+  static auto GetType(...) -> decltype(std::declval<T>().GetNextItemAsObject());
 
   // not implemented
   template <typename T>
-  static auto GetType(int)
-  -> decltype(std::declval<T>().GetNextItem());
+  static auto GetType(int) -> decltype(std::declval<T>().GetNextItem());
 
   using PointerType = decltype(GetType<CollectionType>(0));
 
@@ -99,31 +98,24 @@ public:
 // There are no const_reference, etc, since VTK is not const correct and marking
 // vtkObjects consts makes them unusable.
 template <typename CollectionType>
-struct CollectionIterator :
-    public std::iterator<std::forward_iterator_tag,
-                         typename GetCollectionItemType<CollectionType>::Type*,
-                         int,
-                         typename GetCollectionItemType<CollectionType>::Type*,
-                         typename GetCollectionItemType<CollectionType>::Type*>
+struct CollectionIterator
 {
-  static_assert(IsCollection<CollectionType>::value,
-                "Invalid vtkCollection subclass.");
+  static_assert(IsCollection<CollectionType>::value, "Invalid vtkCollection subclass.");
+
 private:
   using ItemType = typename GetCollectionItemType<CollectionType>::Type;
-  using Superclass = std::iterator<std::forward_iterator_tag,
-                                   ItemType*,
-                                   int,
-                                   ItemType*,
-                                   ItemType*>;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::forward_iterator_tag;
+  using value_type = typename GetCollectionItemType<CollectionType>::Type*;
+  using difference_type = int;
+  using pointer = typename GetCollectionItemType<CollectionType>::Type*;
+  using reference = typename GetCollectionItemType<CollectionType>::Type*;
 
-  CollectionIterator() noexcept : Element(nullptr) {}
+  CollectionIterator() noexcept
+    : Element(nullptr)
+  {
+  }
 
   CollectionIterator(const CollectionIterator& o) noexcept = default;
   CollectionIterator& operator=(const CollectionIterator& o) noexcept = default;
@@ -138,32 +130,24 @@ public:
   {
     auto elem = this->Element;
     this->Increment();
-    return CollectionIterator{elem};
+    return CollectionIterator{ elem };
   }
 
-  reference operator*() const noexcept
-  {
-    return this->GetItem();
-  }
+  reference operator*() const noexcept { return this->GetItem(); }
 
-  pointer operator->() const noexcept
-  {
-    return this->GetItem();
-  }
+  pointer operator->() const noexcept { return this->GetItem(); }
 
-  friend bool operator==(const CollectionIterator& lhs,
-                         const CollectionIterator& rhs) noexcept
+  friend bool operator==(const CollectionIterator& lhs, const CollectionIterator& rhs) noexcept
   {
     return lhs.Element == rhs.Element;
   }
 
-  friend bool operator!=(const CollectionIterator& lhs,
-                         const CollectionIterator& rhs) noexcept
+  friend bool operator!=(const CollectionIterator& lhs, const CollectionIterator& rhs) noexcept
   {
     return lhs.Element != rhs.Element;
   }
 
-  friend void swap(CollectionIterator& lhs, CollectionIterator &rhs) noexcept
+  friend void swap(CollectionIterator& lhs, CollectionIterator& rhs) noexcept
   {
     using std::swap;
     swap(lhs.Element, rhs.Element);
@@ -172,7 +156,7 @@ public:
   friend struct CollectionRange<CollectionType>;
 
 protected:
-  CollectionIterator(vtkCollectionElement *element) noexcept
+  CollectionIterator(vtkCollectionElement* element) noexcept
     : Element(element)
   {
   }
@@ -183,12 +167,9 @@ private:
     this->Element = this->Element->Next;
   }
 
-  ItemType* GetItem() const noexcept
-  {
-    return static_cast<ItemType*>(this->Element->Item);
-  }
+  ItemType* GetItem() const noexcept { return static_cast<ItemType*>(this->Element->Item); }
 
-  vtkCollectionElement *Element;
+  vtkCollectionElement* Element;
 };
 
 //------------------------------------------------------------------------------
@@ -198,8 +179,7 @@ private:
 template <typename CollectionType>
 struct CollectionRange
 {
-  static_assert(IsCollection<CollectionType>::value,
-                "Invalid vtkCollection subclass.");
+  static_assert(IsCollection<CollectionType>::value, "Invalid vtkCollection subclass.");
 
   using ItemType = typename GetCollectionItemType<CollectionType>::Type;
 
@@ -212,7 +192,7 @@ struct CollectionRange
   using const_reference = ItemType*;
   using value_type = ItemType*;
 
-  CollectionRange(CollectionType *coll) noexcept
+  CollectionRange(CollectionType* coll) noexcept
     : Collection(coll)
   {
     assert(this->Collection);
@@ -220,23 +200,17 @@ struct CollectionRange
 
   CollectionType* GetCollection() const noexcept { return this->Collection; }
 
-  size_type size() const noexcept
-  {
-    return this->Collection->GetNumberOfItems();
-  }
+  size_type size() const noexcept { return this->Collection->GetNumberOfItems(); }
 
   iterator begin() const
   {
     vtkCollectionSimpleIterator cookie;
     this->Collection->InitTraversal(cookie);
     // The cookie is a linked list node pointer, vtkCollectionElement:
-    return iterator{static_cast<vtkCollectionElement*>(cookie)};
+    return iterator{ static_cast<vtkCollectionElement*>(cookie) };
   }
 
-  iterator end() const
-  {
-    return iterator{nullptr};
-  }
+  iterator end() const { return iterator{ nullptr }; }
 
   // Note: These return mutable objects because const vtkObject are unusable.
   const_iterator cbegin() const
@@ -244,24 +218,20 @@ struct CollectionRange
     vtkCollectionSimpleIterator cookie;
     this->Collection->InitTraversal(cookie);
     // The cookie is a linked list node pointer, vtkCollectionElement:
-    return const_iterator{static_cast<vtkCollectionElement*>(cookie)};
+    return const_iterator{ static_cast<vtkCollectionElement*>(cookie) };
   }
 
   // Note: These return mutable objects because const vtkObjects are unusable.
-  const_iterator cend() const
-  {
-    return const_iterator{nullptr};
-  }
+  const_iterator cend() const { return const_iterator{ nullptr }; }
 
 private:
   vtkSmartPointer<CollectionType> Collection;
 };
 
+VTK_ABI_NAMESPACE_END
 }
 } // end namespace vtk::detail
 
-#endif // __VTK_WRAP__
-
 #endif // vtkCollectionRange_h
 
 // VTK-HeaderTest-Exclude: vtkCollectionRange.h
