@@ -379,7 +379,8 @@
     _vtk_add_event(Clip3DEvent)                                                                    \
     _vtk_add_event(PositionProp3DEvent)                                                            \
     _vtk_add_event(Pick3DEvent)                                                                    \
-    _vtk_add_event(Select3DEvent)
+    _vtk_add_event(Select3DEvent)                                                                  \
+    _vtk_add_event(Elevation3DEvent)
 // clang-format on
 
 #define vtkEventDeclarationMacro(_enum_name)                                                       \
@@ -390,6 +391,7 @@
   }
 
 // The superclass that all commands should be subclasses of
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONCORE_EXPORT vtkCommand : public vtkObjectBase
 {
 public:
@@ -480,6 +482,7 @@ private:
   const char* GetDebugClassName() const final;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* vtkCommand_h */
 
 // VTK-HeaderTest-Exclude: vtkCommand.h
