@@ -102,15 +102,7 @@ struct DeepCopyWorker
   void operator()(
     vtkSOADataArrayTemplate<ValueType>* src, vtkSOADataArrayTemplate<ValueType>* dst) const
   {
-    vtkIdType numTuples = src->GetNumberOfTuples();
-    for (int comp = 0; comp < src->GetNumberOfComponents(); ++comp)
-    {
-      ValueType* srcBegin = src->GetComponentArrayPointer(comp);
-      ValueType* srcEnd = srcBegin + numTuples;
-      ValueType* dstBegin = dst->GetComponentArrayPointer(comp);
-
-      std::copy(srcBegin, srcEnd, dstBegin);
-    }
+    dst->CopyData(src);
   }
 
 #ifdef VTK_USE_SCALED_SOA_ARRAYS
@@ -131,6 +123,7 @@ struct DeepCopyWorker
     dst->SetScale(src->GetScale());
   }
 #endif
+
 // Undo warning suppression.
 #if defined(__clang__) && defined(__has_warning)
 #if __has_warning("-Wunused-template")
@@ -442,6 +435,8 @@ bool hasValidKey(InfoType info, KeyType key, ComponentKeyType ckey, double range
 
 } // end anon namespace
 
+VTK_ABI_NAMESPACE_BEGIN
+
 vtkInformationKeyRestrictedMacro(vtkDataArray, COMPONENT_RANGE, DoubleVector, 2);
 vtkInformationKeyRestrictedMacro(vtkDataArray, L2_NORM_RANGE, DoubleVector, 2);
 vtkInformationKeyRestrictedMacro(vtkDataArray, L2_NORM_FINITE_RANGE, DoubleVector, 2);
@@ -547,13 +542,6 @@ void vtkDataArray::SetTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx, vtkAbs
     return;
   }
 
-  if (!vtkDataTypesCompare(source->GetDataType(), this->GetDataType()))
-  {
-    vtkErrorMacro("Type mismatch: Source: " << source->GetDataTypeAsString()
-                                            << " Dest: " << this->GetDataTypeAsString());
-    return;
-  }
-
   if (source->GetNumberOfComponents() != this->GetNumberOfComponents())
   {
     vtkErrorMacro("Number of components do not match: Source: "
@@ -562,7 +550,7 @@ void vtkDataArray::SetTuple(vtkIdType dstTupleIdx, vtkIdType srcTupleIdx, vtkAbs
   }
 
   SetTupleArrayWorker worker(srcTupleIdx, dstTupleIdx);
-  if (!vtkArrayDispatch::Dispatch2SameValueType::Execute(srcDA, this, worker))
+  if (!vtkArrayDispatch::Dispatch2::Execute(srcDA, this, worker))
   {
     worker(srcDA, this);
   }
@@ -668,7 +656,7 @@ void vtkDataArray::InsertTuples(vtkIdList* dstIds, vtkIdList* srcIds, vtkAbstrac
   this->MaxId = std::max(this->MaxId, newSize - 1);
 
   SetTuplesIdListWorker worker(srcIds, dstIds);
-  if (!vtkArrayDispatch::Dispatch2SameValueType::Execute(srcDA, this, worker))
+  if (!vtkArrayDispatch::Dispatch2::Execute(srcDA, this, worker))
   {
     worker(srcDA, this);
   }
@@ -770,7 +758,7 @@ void vtkDataArray::InsertTuples(
   this->MaxId = std::max(this->MaxId, newSize - 1);
 
   SetTuplesRangeWorker worker(srcStart, dstStart, n);
-  if (!vtkArrayDispatch::Dispatch2SameValueType::Execute(srcDA, this, worker))
+  if (!vtkArrayDispatch::Dispatch2::Execute(srcDA, this, worker))
   {
     worker(srcDA, this);
   }
@@ -1495,6 +1483,7 @@ void vtkDataArray::Fill(double value)
     this->FillComponent(i, value);
   }
 }
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
@@ -1527,6 +1516,7 @@ struct CopyComponentWorker
 };
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 void vtkDataArray::CopyComponent(int dstComponent, vtkDataArray* src, int srcComponent)
 {
@@ -1598,6 +1588,13 @@ int vtkDataArray::CopyInformation(vtkInformation* infoFrom, int deep)
 
 //------------------------------------------------------------------------------
 void vtkDataArray::ComputeFiniteRange(double range[2], int comp)
+{
+  this->ComputeFiniteRange(range, comp, nullptr);
+}
+
+//------------------------------------------------------------------------------
+void vtkDataArray::ComputeFiniteRange(
+  double range[2], int comp, const unsigned char* ghosts, unsigned char ghostsToSkip)
 {
   // this method needs a large refactoring to be way easier to read
 
@@ -1618,11 +1615,15 @@ void vtkDataArray::ComputeFiniteRange(double range[2], int comp)
   vtkInformationDoubleVectorKey* rkey;
   if (comp < 0)
   {
+    if (ghosts)
+    {
+      this->ComputeFiniteVectorRange(range, ghosts, ghostsToSkip);
+      return;
+    }
     rkey = L2_NORM_FINITE_RANGE();
     // hasValidKey will update range to the cached value if it exists.
     if (!hasValidKey(info, rkey, range))
     {
-
       this->ComputeFiniteVectorRange(range);
       info->Set(rkey, range, 2);
     }
@@ -1630,6 +1631,11 @@ void vtkDataArray::ComputeFiniteRange(double range[2], int comp)
   }
   else
   {
+    if (ghosts)
+    {
+      this->ComputeFiniteScalarRange(range, ghosts, ghostsToSkip);
+      return;
+    }
     rkey = COMPONENT_RANGE();
 
     // hasValidKey will update range to the cached value if it exists.
@@ -1661,6 +1667,13 @@ void vtkDataArray::ComputeFiniteRange(double range[2], int comp)
 
 //------------------------------------------------------------------------------
 void vtkDataArray::ComputeRange(double range[2], int comp)
+{
+  this->ComputeRange(range, comp, nullptr);
+}
+
+//------------------------------------------------------------------------------
+void vtkDataArray::ComputeRange(
+  double range[2], int comp, const unsigned char* ghosts, unsigned char ghostsToSkip)
 {
   // this method needs a large refactoring to be way easier to read
 
@@ -1681,6 +1694,11 @@ void vtkDataArray::ComputeRange(double range[2], int comp)
   vtkInformationDoubleVectorKey* rkey;
   if (comp < 0)
   {
+    if (ghosts)
+    {
+      this->ComputeVectorRange(range, ghosts, ghostsToSkip);
+      return;
+    }
     rkey = L2_NORM_RANGE();
     // hasValidKey will update range to the cached value if it exists.
     if (!hasValidKey(info, rkey, range))
@@ -1692,6 +1710,11 @@ void vtkDataArray::ComputeRange(double range[2], int comp)
   }
   else
   {
+    if (ghosts)
+    {
+      this->ComputeScalarRange(range, ghosts, ghostsToSkip);
+      return;
+    }
     rkey = COMPONENT_RANGE();
 
     // hasValidKey will update range to the cached value if it exists.
@@ -1734,6 +1757,7 @@ void vtkDataArray::Modified()
   }
   this->Superclass::Modified();
 }
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
@@ -1743,18 +1767,23 @@ struct ScalarRangeDispatchWrapper
 {
   bool Success;
   double* Range;
+  const unsigned char* GhostArray;
+  unsigned char GhostTypesToSkip;
 
-  ScalarRangeDispatchWrapper(double* range)
+  ScalarRangeDispatchWrapper(
+    double* range, const unsigned char* ghostArray, unsigned char ghostTypesToSkip)
     : Success(false)
     , Range(range)
+    , GhostArray(ghostArray)
+    , GhostTypesToSkip(ghostTypesToSkip)
   {
   }
 
   template <typename ArrayT>
   void operator()(ArrayT* array)
   {
-    this->Success = vtkDataArrayPrivate::DoComputeScalarRange(
-      array, this->Range, vtkDataArrayPrivate::AllValues());
+    this->Success = vtkDataArrayPrivate::DoComputeScalarRange(array, this->Range,
+      vtkDataArrayPrivate::AllValues(), this->GhostArray, this->GhostTypesToSkip);
   }
 };
 
@@ -1762,18 +1791,23 @@ struct VectorRangeDispatchWrapper
 {
   bool Success;
   double* Range;
+  const unsigned char* GhostArray;
+  unsigned char GhostTypesToSkip;
 
-  VectorRangeDispatchWrapper(double* range)
+  VectorRangeDispatchWrapper(
+    double* range, const unsigned char* ghostArray, unsigned char ghostTypesToSkip)
     : Success(false)
     , Range(range)
+    , GhostArray(ghostArray)
+    , GhostTypesToSkip(ghostTypesToSkip)
   {
   }
 
   template <typename ArrayT>
   void operator()(ArrayT* array)
   {
-    this->Success = vtkDataArrayPrivate::DoComputeVectorRange(
-      array, this->Range, vtkDataArrayPrivate::AllValues());
+    this->Success = vtkDataArrayPrivate::DoComputeVectorRange(array, this->Range,
+      vtkDataArrayPrivate::AllValues(), this->GhostArray, this->GhostTypesToSkip);
   }
 };
 
@@ -1782,18 +1816,23 @@ struct FiniteScalarRangeDispatchWrapper
 {
   bool Success;
   double* Range;
+  const unsigned char* GhostArray;
+  unsigned char GhostTypesToSkip;
 
-  FiniteScalarRangeDispatchWrapper(double* range)
+  FiniteScalarRangeDispatchWrapper(
+    double* range, const unsigned char* ghostArray, unsigned char ghostTypesToSkip)
     : Success(false)
     , Range(range)
+    , GhostArray(ghostArray)
+    , GhostTypesToSkip(ghostTypesToSkip)
   {
   }
 
   template <typename ArrayT>
   void operator()(ArrayT* array)
   {
-    this->Success = vtkDataArrayPrivate::DoComputeScalarRange(
-      array, this->Range, vtkDataArrayPrivate::FiniteValues());
+    this->Success = vtkDataArrayPrivate::DoComputeScalarRange(array, this->Range,
+      vtkDataArrayPrivate::FiniteValues(), this->GhostArray, this->GhostTypesToSkip);
   }
 };
 
@@ -1801,27 +1840,40 @@ struct FiniteVectorRangeDispatchWrapper
 {
   bool Success;
   double* Range;
+  const unsigned char* GhostArray;
+  unsigned char GhostTypesToSkip;
 
-  FiniteVectorRangeDispatchWrapper(double* range)
+  FiniteVectorRangeDispatchWrapper(
+    double* range, const unsigned char* ghostArray, unsigned char ghostTypesToSkip)
     : Success(false)
     , Range(range)
+    , GhostArray(ghostArray)
+    , GhostTypesToSkip(ghostTypesToSkip)
   {
   }
 
   template <typename ArrayT>
   void operator()(ArrayT* array)
   {
-    this->Success = vtkDataArrayPrivate::DoComputeVectorRange(
-      array, this->Range, vtkDataArrayPrivate::FiniteValues());
+    this->Success = vtkDataArrayPrivate::DoComputeVectorRange(array, this->Range,
+      vtkDataArrayPrivate::FiniteValues(), this->GhostArray, this->GhostTypesToSkip);
   }
 };
 
 } // end anon namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 bool vtkDataArray::ComputeScalarRange(double* ranges)
 {
-  ScalarRangeDispatchWrapper worker(ranges);
+  return this->ComputeScalarRange(ranges, nullptr);
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataArray::ComputeScalarRange(
+  double* ranges, const unsigned char* ghosts, unsigned char ghostsToSkip)
+{
+  ScalarRangeDispatchWrapper worker(ranges, ghosts, ghostsToSkip);
   if (!vtkArrayDispatch::Dispatch::Execute(this, worker))
   {
     worker(this);
@@ -1830,9 +1882,16 @@ bool vtkDataArray::ComputeScalarRange(double* ranges)
 }
 
 //------------------------------------------------------------------------------
-bool vtkDataArray::ComputeVectorRange(double range[2])
+bool vtkDataArray::ComputeVectorRange(double* ranges)
 {
-  VectorRangeDispatchWrapper worker(range);
+  return this->ComputeVectorRange(ranges, nullptr);
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataArray::ComputeVectorRange(
+  double range[2], const unsigned char* ghosts, unsigned char ghostsToSkip)
+{
+  VectorRangeDispatchWrapper worker(range, ghosts, ghostsToSkip);
   if (!vtkArrayDispatch::Dispatch::Execute(this, worker))
   {
     worker(this);
@@ -1843,7 +1902,14 @@ bool vtkDataArray::ComputeVectorRange(double range[2])
 //------------------------------------------------------------------------------
 bool vtkDataArray::ComputeFiniteScalarRange(double* ranges)
 {
-  FiniteScalarRangeDispatchWrapper worker(ranges);
+  return this->ComputeFiniteScalarRange(ranges, nullptr);
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataArray::ComputeFiniteScalarRange(
+  double* ranges, const unsigned char* ghosts, unsigned char ghostsToSkip)
+{
+  FiniteScalarRangeDispatchWrapper worker(ranges, ghosts, ghostsToSkip);
   if (!vtkArrayDispatch::Dispatch::Execute(this, worker))
   {
     worker(this);
@@ -1854,7 +1920,14 @@ bool vtkDataArray::ComputeFiniteScalarRange(double* ranges)
 //------------------------------------------------------------------------------
 bool vtkDataArray::ComputeFiniteVectorRange(double range[2])
 {
-  FiniteVectorRangeDispatchWrapper worker(range);
+  return this->ComputeFiniteVectorRange(range, nullptr);
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataArray::ComputeFiniteVectorRange(
+  double range[2], const unsigned char* ghosts, unsigned char ghostsToSkip)
+{
+  FiniteVectorRangeDispatchWrapper worker(range, ghosts, ghostsToSkip);
   if (!vtkArrayDispatch::Dispatch::Execute(this, worker))
   {
     worker(this);
@@ -2004,3 +2077,4 @@ void vtkDataArray::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "LookupTable: (none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
