@@ -100,9 +100,8 @@
 #ifndef vtkDataArrayAccessor_h
 #define vtkDataArrayAccessor_h
 
-#ifndef __VTK_WRAP__
-
 // Generic form for all (non-bit) vtkDataArray subclasses.
+VTK_ABI_NAMESPACE_BEGIN
 template <typename ArrayT>
 struct vtkDataArrayAccessor
 {
@@ -201,7 +200,6 @@ struct vtkDataArrayAccessor<vtkDataArray>
   }
 };
 
-#endif
-
+VTK_ABI_NAMESPACE_END
 #endif // vtkDataArrayAccessor_h
 // VTK-HeaderTest-Exclude: vtkDataArrayAccessor.h
