@@ -29,15 +29,13 @@
 #include <iterator>
 #include <type_traits>
 
-#ifndef __VTK_WRAP__
-
 VTK_ITER_OPTIMIZE_START
 
 namespace vtk
 {
-
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 // Forward decs for friends/args
 template <typename ArrayType, ComponentIdType>
@@ -72,6 +70,8 @@ private:
   using APIType = GetAPIType<ArrayType>;
 
 public:
+  using value_type = APIType;
+
   VTK_ITER_INLINE
   ConstComponentReference() noexcept
     : Array{ nullptr }
@@ -163,6 +163,8 @@ private:
   using APIType = GetAPIType<ArrayType>;
 
 public:
+  using value_type = APIType;
+
   VTK_ITER_INLINE
   ComponentReference() noexcept
     : Array{ nullptr }
@@ -373,24 +375,19 @@ protected:
 // Const component iterator
 template <typename ArrayType, ComponentIdType TupleSize>
 struct ConstComponentIterator
-  : public std::iterator<std::random_access_iterator_tag, GetAPIType<ArrayType>, ComponentIdType,
-      // expected types don't have members, no op->().
-      void, ConstComponentReference<ArrayType, TupleSize>>
 {
 private:
   static_assert(IsValidTupleSize<TupleSize>::value, "Invalid tuple size.");
   static_assert(IsVtkDataArray<ArrayType>::value, "Invalid array type.");
 
   using NumCompsType = GenericTupleSize<TupleSize>;
-  using Superclass = std::iterator<std::random_access_iterator_tag, GetAPIType<ArrayType>,
-    ComponentIdType, void, ConstComponentReference<ArrayType, TupleSize>>;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = GetAPIType<ArrayType>;
+  using difference_type = ComponentIdType;
+  using pointer = void;
+  using reference = ConstComponentReference<ArrayType, TupleSize>;
 
   VTK_ITER_INLINE
   ConstComponentIterator() noexcept
@@ -562,8 +559,6 @@ private:
 // Component iterator
 template <typename ArrayType, ComponentIdType TupleSize>
 struct ComponentIterator
-  : public std::iterator<std::random_access_iterator_tag, GetAPIType<ArrayType>, ComponentIdType,
-      ComponentReference<ArrayType, TupleSize>, ComponentReference<ArrayType, TupleSize>>
 {
 private:
   static_assert(IsValidTupleSize<TupleSize>::value, "Invalid tuple size.");
@@ -571,15 +566,13 @@ private:
 
   using NumCompsType = GenericTupleSize<TupleSize>;
   using APIType = GetAPIType<ArrayType>;
-  using Superclass = std::iterator<std::random_access_iterator_tag, APIType, ComponentIdType,
-    ComponentReference<ArrayType, TupleSize>, ComponentReference<ArrayType, TupleSize>>;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = APIType;
+  using difference_type = ComponentIdType;
+  using pointer = ComponentReference<ArrayType, TupleSize>;
+  using reference = ComponentReference<ArrayType, TupleSize>;
 
   VTK_ITER_INLINE
   ComponentIterator() noexcept = default;
@@ -1273,25 +1266,19 @@ protected:
 // Const tuple iterator
 template <typename ArrayType, ComponentIdType TupleSize>
 struct ConstTupleIterator
-  : public std::iterator<std::random_access_iterator_tag, ConstTupleReference<ArrayType, TupleSize>,
-      TupleIdType, ConstTupleReference<ArrayType, TupleSize>,
-      ConstTupleReference<ArrayType, TupleSize>>
 {
 private:
   static_assert(IsValidTupleSize<TupleSize>::value, "Invalid tuple size.");
   static_assert(IsVtkDataArray<ArrayType>::value, "Invalid array type.");
 
   using NumCompsType = GenericTupleSize<TupleSize>;
-  using Superclass = std::iterator<std::random_access_iterator_tag,
-    ConstTupleReference<ArrayType, TupleSize>, TupleIdType,
-    ConstTupleReference<ArrayType, TupleSize>, ConstTupleReference<ArrayType, TupleSize>>;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = ConstTupleReference<ArrayType, TupleSize>;
+  using difference_type = TupleIdType;
+  using pointer = ConstTupleReference<ArrayType, TupleSize>;
+  using reference = ConstTupleReference<ArrayType, TupleSize>;
 
   VTK_ITER_INLINE
   ConstTupleIterator() noexcept = default;
@@ -1463,24 +1450,19 @@ private:
 // Tuple iterator
 template <typename ArrayType, ComponentIdType TupleSize>
 struct TupleIterator
-  : public std::iterator<std::random_access_iterator_tag, TupleReference<ArrayType, TupleSize>,
-      TupleIdType, TupleReference<ArrayType, TupleSize>, TupleReference<ArrayType, TupleSize>>
 {
 private:
   static_assert(IsValidTupleSize<TupleSize>::value, "Invalid tuple size.");
   static_assert(IsVtkDataArray<ArrayType>::value, "Invalid array type.");
 
   using NumCompsType = GenericTupleSize<TupleSize>;
-  using Superclass =
-    std::iterator<std::random_access_iterator_tag, TupleReference<ArrayType, TupleSize>,
-      TupleIdType, TupleReference<ArrayType, TupleSize>, TupleReference<ArrayType, TupleSize>>;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = TupleReference<ArrayType, TupleSize>;
+  using difference_type = TupleIdType;
+  using pointer = TupleReference<ArrayType, TupleSize>;
+  using reference = TupleReference<ArrayType, TupleSize>;
 
   VTK_ITER_INLINE
   TupleIterator() noexcept = default;
@@ -1761,12 +1743,12 @@ private:
 template <typename ArrayType, ComponentIdType TupleSize>
 TupleRange<ArrayType, TupleSize> DeclareTupleRangeSpecialization(vtkDataArray*);
 
+VTK_ABI_NAMESPACE_END
 } // end namespace detail
 } // end namespace vtk
 
 VTK_ITER_OPTIMIZE_END
 
 #endif // __VTK_WRAP__
-#endif // vtkDataArrayTupleRange_Generic_h
 
 // VTK-HeaderTest-Exclude: vtkDataArrayTupleRange_Generic.h
