@@ -19,6 +19,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkWindows.h"
 
+#include <vtksys/Encoding.hxx>
 #include <vtksys/SystemInformation.hxx>
 #include <vtksys/SystemTools.hxx>
 
@@ -29,6 +30,7 @@
 #include <unordered_map>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 static const char* vtkDebugLeaksIgnoreClasses[] = { nullptr };
 
 //------------------------------------------------------------------------------
@@ -49,6 +51,12 @@ static int vtkDebugLeaksIgnoreClassesCheck(const char* s)
 
 vtkStandardNewMacro(vtkDebugLeaks);
 
+//------------------------------------------------------------------------------
+void vtkDebugLeaks::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 class vtkDebugLeaksHashTable
 {
@@ -188,10 +196,10 @@ void vtkDebugLeaksTraceManager::PrintObjects(std::ostream& vtkNotUsed(os)) {}
 #ifdef VTK_DEBUG_LEAKS
 void vtkDebugLeaks::ConstructClass(vtkObjectBase* object)
 {
-  vtkDebugLeaks::CriticalSection->lock();
-  vtkDebugLeaks::MemoryTable->IncrementCount(object->GetClassName());
+  const std::lock_guard<std::mutex> lock(*vtkDebugLeaks::CriticalSection);
+  (void)lock; // To avoid compiler warning on unused variables.
+  vtkDebugLeaks::MemoryTable->IncrementCount(object->GetDebugClassName());
   vtkDebugLeaks::TraceManager->RegisterObject(object);
-  vtkDebugLeaks::CriticalSection->unlock();
 }
 #else
 void vtkDebugLeaks::ConstructClass(vtkObjectBase* vtkNotUsed(object)) {}
@@ -201,9 +209,9 @@ void vtkDebugLeaks::ConstructClass(vtkObjectBase* vtkNotUsed(object)) {}
 #ifdef VTK_DEBUG_LEAKS
 void vtkDebugLeaks::ConstructClass(const char* className)
 {
-  vtkDebugLeaks::CriticalSection->lock();
+  const std::lock_guard<std::mutex> lock(*vtkDebugLeaks::CriticalSection);
+  (void)lock; // To avoid compiler warning on unused variables.
   vtkDebugLeaks::MemoryTable->IncrementCount(className);
-  vtkDebugLeaks::CriticalSection->unlock();
 }
 #else
 void vtkDebugLeaks::ConstructClass(const char* vtkNotUsed(className)) {}
@@ -213,22 +221,30 @@ void vtkDebugLeaks::ConstructClass(const char* vtkNotUsed(className)) {}
 #ifdef VTK_DEBUG_LEAKS
 void vtkDebugLeaks::DestructClass(vtkObjectBase* object)
 {
-  vtkDebugLeaks::CriticalSection->lock();
-
-  // Ensure the trace manager has not yet been deleted.
-  if (vtkDebugLeaks::TraceManager)
+  bool need_warning = false;
   {
-    vtkDebugLeaks::TraceManager->UnRegisterObject(object);
+    const std::lock_guard<std::mutex> lock(*vtkDebugLeaks::CriticalSection);
+    (void)lock; // To avoid compiler warning on unused variables.
+
+    // Ensure the trace manager has not yet been deleted.
+    if (vtkDebugLeaks::TraceManager)
+    {
+      vtkDebugLeaks::TraceManager->UnRegisterObject(object);
+    }
+
+    // Due to globals being deleted, this table may already have
+    // been deleted.
+    // The warning must be deferred until after the critical section because
+    // creating a new instance of `vtkOutputWindow` ends up deadlocking when it
+    // calls `vtkDebugLeaks::ConstructClass`.
+    need_warning = (vtkDebugLeaks::MemoryTable &&
+      !vtkDebugLeaks::MemoryTable->DecrementCount(object->GetDebugClassName()));
   }
 
-  // Due to globals being deleted, this table may already have
-  // been deleted.
-  if (vtkDebugLeaks::MemoryTable &&
-    !vtkDebugLeaks::MemoryTable->DecrementCount(object->GetClassName()))
+  if (need_warning)
   {
     vtkGenericWarningMacro("Deleting unknown object: " << object->GetClassName());
   }
-  vtkDebugLeaks::CriticalSection->unlock();
 }
 #else
 void vtkDebugLeaks::DestructClass(vtkObjectBase* vtkNotUsed(object)) {}
@@ -238,15 +254,24 @@ void vtkDebugLeaks::DestructClass(vtkObjectBase* vtkNotUsed(object)) {}
 #ifdef VTK_DEBUG_LEAKS
 void vtkDebugLeaks::DestructClass(const char* className)
 {
-  vtkDebugLeaks::CriticalSection->lock();
+  bool need_warning = false;
+  {
+    const std::lock_guard<std::mutex> lock(*vtkDebugLeaks::CriticalSection);
+    (void)lock; // To avoid compiler warning on unused variables.
 
-  // Due to globals being deleted, this table may already have
-  // been deleted.
-  if (vtkDebugLeaks::MemoryTable && !vtkDebugLeaks::MemoryTable->DecrementCount(className))
+    // Due to globals being deleted, this table may already have
+    // been deleted.
+    // The warning must be deferred until after the critical section because
+    // creating a new instance of `vtkOutputWindow` ends up deadlocking when it
+    // calls `vtkDebugLeaks::ConstructClass`.
+    need_warning =
+      vtkDebugLeaks::MemoryTable && !vtkDebugLeaks::MemoryTable->DecrementCount(className);
+  }
+
+  if (need_warning)
   {
     vtkGenericWarningMacro("Deleting unknown object: " << className);
   }
-  vtkDebugLeaks::CriticalSection->unlock();
 }
 #else
 void vtkDebugLeaks::DestructClass(const char* vtkNotUsed(className)) {}
@@ -344,15 +369,8 @@ int vtkDebugLeaks::PrintCurrentLeaks()
 #ifdef _WIN32
 int vtkDebugLeaks::DisplayMessageBox(const char* msg)
 {
-#ifdef UNICODE
-  wchar_t* wmsg = new wchar_t[mbstowcs(nullptr, msg, 32000) + 1];
-  mbstowcs(wmsg, msg, 32000);
-  int result = (MessageBox(nullptr, wmsg, L"Error", MB_ICONERROR | MB_OKCANCEL) == IDCANCEL);
-  delete[] wmsg;
-#else
-  int result = (MessageBox(nullptr, msg, "Error", MB_ICONERROR | MB_OKCANCEL) == IDCANCEL);
-#endif
-  return result;
+  std::wstring wmsg = vtksys::Encoding::ToWide(msg);
+  return MessageBoxW(nullptr, wmsg.c_str(), L"Error", MB_ICONERROR | MB_OKCANCEL) == IDCANCEL;
 }
 #else
 int vtkDebugLeaks::DisplayMessageBox(const char*)
@@ -439,3 +457,4 @@ int vtkDebugLeaks::ExitError;
 
 // Purposely not initialized.  ClassInitialize will handle it.
 vtkDebugLeaksObserver* vtkDebugLeaks::Observer;
+VTK_ABI_NAMESPACE_END
