@@ -17,19 +17,18 @@
 #include "vtkObject.h"
 
 //----------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkEventForwarderCommand::vtkEventForwarderCommand()
 {
   this->Target = nullptr;
 }
 
 //----------------------------------------------------------------
-void vtkEventForwarderCommand::Execute(vtkObject *,
-                                       unsigned long event,
-                                       void *call_data)
+void vtkEventForwarderCommand::Execute(vtkObject*, unsigned long event, void* call_data)
 {
   if (this->Target)
   {
     this->Target->InvokeEvent(event, call_data);
   }
 }
-
+VTK_ABI_NAMESPACE_END
