@@ -21,17 +21,20 @@ VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATE(float);
 
 #include "vtkObjectFactory.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFloatArray);
+vtkStandardExtendedNewMacro(vtkFloatArray);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkFloatArray::vtkFloatArray() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkFloatArray::~vtkFloatArray() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFloatArray::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->RealSuperclass::PrintSelf(os,indent);
+  this->RealSuperclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
