@@ -36,6 +36,7 @@
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGarbageCollector);
 
 #if VTK_GARBAGE_COLLECTOR_HASH
@@ -81,7 +82,8 @@ vtkGarbageCollector::vtkGarbageCollector() = default;
 //------------------------------------------------------------------------------
 vtkGarbageCollector::~vtkGarbageCollector()
 {
-  this->SetReferenceCount(0);
+  // Avoid warnings from `vtkObject` destructor about a non-zero reference count.
+  this->ClearReferenceCounts();
 }
 
 //------------------------------------------------------------------------------
@@ -241,7 +243,6 @@ public:
       , VisitOrder(0)
       , Count(0)
       , GarbageCount(0)
-      , References()
     {
     }
     ~Entry() { assert(this->GarbageCount == 0); }
@@ -618,7 +619,7 @@ void vtkGarbageCollectorImpl::Report(vtkObjectBase* obj, void* ptr, const char*
       std::ostringstream msg;
       msg << "Report: " << current->GetClassName() << "(" << current << ") " << (desc ? desc : "")
           << " -> " << obj->GetClassName() << "(" << obj << ")";
-      vtkDebugMacro(<< msg.str().c_str());
+      vtkDebugMacro(<< msg.str());
     }
 
     // Forward call to the internal implementation.
@@ -718,7 +719,7 @@ void vtkGarbageCollectorImpl::PrintComponent(ComponentType* c)
       msg << "\n  " << obj->GetClassName() << "(" << obj << ")"
           << " with " << count << " external " << ((count == 1) ? "reference" : "references");
     }
-    vtkDebugMacro(<< msg.str().c_str());
+    vtkDebugMacro(<< msg.str());
   }
 }
 #else
@@ -1065,3 +1066,4 @@ void vtkGarbageCollectorReport(
 {
   ptr.Report(collector, desc);
 }
+VTK_ABI_NAMESPACE_END
