@@ -75,6 +75,7 @@
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 template <class DerivedT, class ValueTypeT>
 class vtkGenericDataArray : public vtkDataArray
 {
@@ -225,7 +226,16 @@ public:
   /**
    * Get the range of array values for the given component in the
    * native data type.
+   *
+   * The optional `ghosts` array is used to skip values when computing the range.
+   * Values whose associated ghost matches types from `ghostsToSkip` are skipped.
+   * See `vtkDataSetAttributes` for a definition of ghosts.
+   *
+   * @sa
+   * vtkDataSetAttributes
    */
+  void GetValueRange(
+    ValueType range[2], int comp, const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
   void GetValueRange(ValueType range[2], int comp);
   ValueType* GetValueRange(int comp) VTK_SIZEHINT(2);
   ///@}
@@ -242,6 +252,8 @@ public:
    * only consider finite values.
    * @{
    */
+  void GetFiniteValueRange(
+    ValueType range[2], int comp, const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
   void GetFiniteValueRange(ValueType range[2], int comp);
   ValueType* GetFiniteValueRange(int comp) VTK_SIZEHINT(2);
   ValueType* GetFiniteValueRange() VTK_SIZEHINT(2) { return this->GetFiniteValueRange(0); }
@@ -360,7 +372,8 @@ protected:
    * to the range argument.
    * THIS METHOD IS NOT THREAD SAFE.
    */
-  void ComputeValueRange(ValueType range[2], int comp);
+  void ComputeValueRange(
+    ValueType range[2], int comp, const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
 
   /**
    * Compute the range for a specific component. If comp is set -1
@@ -369,7 +382,8 @@ protected:
    * to the range argument.
    * THIS METHOD IS NOT THREAD SAFE.
    */
-  void ComputeFiniteValueRange(ValueType range[2], int comp);
+  void ComputeFiniteValueRange(
+    ValueType range[2], int comp, const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
 
   /**
    * Computes the range for each component of an array, the length
@@ -377,13 +391,15 @@ protected:
    * Returns true if the range was computed. Will return false
    * if you try to compute the range of an array of length zero.
    */
-  bool ComputeScalarValueRange(ValueType* ranges);
+  bool ComputeScalarValueRange(
+    ValueType* ranges, const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
 
   /**
    * Returns true if the range was computed. Will return false
    * if you try to compute the range of an array of length zero.
    */
-  bool ComputeVectorValueRange(ValueType range[2]);
+  bool ComputeVectorValueRange(
+    ValueType range[2], const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
 
   /**
    * Computes the range for each component of an array, the length
@@ -391,13 +407,15 @@ protected:
    * Returns true if the range was computed. Will return false
    * if you try to compute the range of an array of length zero.
    */
-  bool ComputeFiniteScalarValueRange(ValueType* ranges);
+  bool ComputeFiniteScalarValueRange(
+    ValueType* ranges, const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
 
   /**
    * Returns true if the range was computed. Will return false
    * if you try to compute the range of an array of length zero.
    */
-  bool ComputeFiniteVectorValueRange(ValueType range[2]);
+  bool ComputeFiniteVectorValueRange(
+    ValueType range[2], const unsigned char* ghosts, unsigned char ghostsToSkip = 0xff);
 
   std::vector<double> LegacyTuple;
   std::vector<ValueType> LegacyValueRange;
@@ -409,16 +427,21 @@ private:
   vtkGenericDataArray(const vtkGenericDataArray&) = delete;
   void operator=(const vtkGenericDataArray&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 
 // these predeclarations are needed before the .txx include for MinGW
 namespace vtkDataArrayPrivate
 {
+VTK_ABI_NAMESPACE_BEGIN
 template <typename A, typename R, typename T>
-bool DoComputeScalarRange(A*, R*, T);
+bool DoComputeScalarRange(A*, R*, T, const unsigned char* ghosts, unsigned char ghostsToSkip);
 template <typename A, typename R>
-bool DoComputeVectorRange(A*, R[2], AllValues);
+bool DoComputeVectorRange(
+  A*, R[2], AllValues, const unsigned char* ghosts, unsigned char ghostsToSkip);
 template <typename A, typename R>
-bool DoComputeVectorRange(A*, R[2], FiniteValues);
+bool DoComputeVectorRange(
+  A*, R[2], FiniteValues, const unsigned char* ghosts, unsigned char ghostsToSkip);
+VTK_ABI_NAMESPACE_END
 } // namespace vtkDataArrayPrivate
 
 #include "vtkGenericDataArray.txx"
@@ -456,6 +479,7 @@ public:
 #ifdef VTK_GDA_VALUERANGE_INSTANTIATING
 
 // Forward declare necessary stuffs:
+VTK_ABI_NAMESPACE_BEGIN
 template <typename ValueType>
 class vtkAOSDataArrayTemplate;
 template <typename ValueType>
@@ -465,16 +489,17 @@ class vtkSOADataArrayTemplate;
 template <typename ValueType>
 class vtkScaledSOADataArrayTemplate;
 #endif
+VTK_ABI_NAMESPACE_END
 
 #define VTK_INSTANTIATE_VALUERANGE_ARRAYTYPE(ArrayType, ValueType)                                 \
   template VTKCOMMONCORE_EXPORT bool DoComputeScalarRange(                                         \
-    ArrayType*, ValueType*, vtkDataArrayPrivate::AllValues);                                       \
-  template VTKCOMMONCORE_EXPORT bool DoComputeScalarRange(                                         \
-    ArrayType*, ValueType*, vtkDataArrayPrivate::FiniteValues);                                    \
-  template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(                                         \
-    ArrayType*, ValueType[2], vtkDataArrayPrivate::AllValues);                                     \
-  template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(                                         \
-    ArrayType*, ValueType[2], vtkDataArrayPrivate::FiniteValues);
+    ArrayType*, ValueType*, vtkDataArrayPrivate::AllValues, const unsigned char*, unsigned char);  \
+  template VTKCOMMONCORE_EXPORT bool DoComputeScalarRange(ArrayType*, ValueType*,                  \
+    vtkDataArrayPrivate::FiniteValues, const unsigned char*, unsigned char);                       \
+  template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(ArrayType*, ValueType[2],                \
+    vtkDataArrayPrivate::AllValues, const unsigned char*, unsigned char);                          \
+  template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(ArrayType*, ValueType[2],                \
+    vtkDataArrayPrivate::FiniteValues, const unsigned char*, unsigned char);
 
 #ifdef VTK_USE_SCALED_SOA_ARRAYS
 
@@ -502,6 +527,7 @@ class vtkScaledSOADataArrayTemplate;
 #pragma warning(disable : 4910) // extern and dllexport incompatible
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 // Forward declare necessary stuffs:
 template <typename ValueType>
 class vtkAOSDataArrayTemplate;
@@ -513,25 +539,31 @@ template <typename ValueType>
 class vtkScaledSOADataArrayTemplate;
 #endif
 
+VTK_ABI_NAMESPACE_END
+
 namespace vtkDataArrayPrivate
 {
+VTK_ABI_NAMESPACE_BEGIN
 template <typename A, typename R, typename T>
-bool DoComputeScalarRange(A*, R*, T);
+bool DoComputeScalarRange(A*, R*, T, const unsigned char* ghosts, unsigned char ghostsToSkip);
 template <typename A, typename R>
-bool DoComputeVectorRange(A*, R[2], AllValues);
+bool DoComputeVectorRange(
+  A*, R[2], AllValues, const unsigned char* ghosts, unsigned char ghostsToSkip);
 template <typename A, typename R>
-bool DoComputeVectorRange(A*, R[2], FiniteValues);
+bool DoComputeVectorRange(
+  A*, R[2], FiniteValues, const unsigned char* ghosts, unsigned char ghostsToSkip);
+VTK_ABI_NAMESPACE_END
 } // namespace vtkDataArrayPrivate
 
 #define VTK_DECLARE_VALUERANGE_ARRAYTYPE(ArrayType, ValueType)                                     \
   extern template VTKCOMMONCORE_EXPORT bool DoComputeScalarRange(                                  \
-    ArrayType*, ValueType*, vtkDataArrayPrivate::AllValues);                                       \
-  extern template VTKCOMMONCORE_EXPORT bool DoComputeScalarRange(                                  \
-    ArrayType*, ValueType*, vtkDataArrayPrivate::FiniteValues);                                    \
-  extern template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(                                  \
-    ArrayType*, ValueType[2], vtkDataArrayPrivate::AllValues);                                     \
-  extern template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(                                  \
-    ArrayType*, ValueType[2], vtkDataArrayPrivate::FiniteValues);
+    ArrayType*, ValueType*, vtkDataArrayPrivate::AllValues, const unsigned char*, unsigned char);  \
+  extern template VTKCOMMONCORE_EXPORT bool DoComputeScalarRange(ArrayType*, ValueType*,           \
+    vtkDataArrayPrivate::FiniteValues, const unsigned char*, unsigned char);                       \
+  extern template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(ArrayType*, ValueType[2],         \
+    vtkDataArrayPrivate::AllValues, const unsigned char*, unsigned char);                          \
+  extern template VTKCOMMONCORE_EXPORT bool DoComputeVectorRange(ArrayType*, ValueType[2],         \
+    vtkDataArrayPrivate::FiniteValues, const unsigned char*, unsigned char);
 
 #ifdef VTK_USE_SCALED_SOA_ARRAYS
 
@@ -550,6 +582,7 @@ bool DoComputeVectorRange(A*, R[2], FiniteValues);
 
 namespace vtkDataArrayPrivate
 {
+VTK_ABI_NAMESPACE_BEGIN
 // These are instantiated in vtkGenericDataArrayValueRange${i}.cxx
 VTK_DECLARE_VALUERANGE_VALUETYPE(long)
 VTK_DECLARE_VALUERANGE_VALUETYPE(unsigned long)
@@ -606,6 +639,7 @@ VTK_DECLARE_VALUERANGE_ARRAYTYPE(vtkScaledSOADataArrayTemplate<long long>, doubl
 VTK_DECLARE_VALUERANGE_ARRAYTYPE(vtkScaledSOADataArrayTemplate<unsigned long long>, double)
 #endif // VTK_USE_SCALED_SOA_ARRAYS
 
+VTK_ABI_NAMESPACE_END
 } // namespace vtkDataArrayPrivate
 
 #undef VTK_DECLARE_VALUERANGE_ARRAYTYPE
