@@ -16,6 +16,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkSMPTools.h" //for parallel sort
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkIdList);
 
 //------------------------------------------------------------------------------
@@ -24,12 +25,16 @@ vtkIdList::vtkIdList()
   this->NumberOfIds = 0;
   this->Size = 0;
   this->Ids = nullptr;
+  this->ManageMemory = true;
 }
 
 //------------------------------------------------------------------------------
 vtkIdList::~vtkIdList()
 {
-  delete[] this->Ids;
+  if (this->ManageMemory)
+  {
+    delete[] this->Ids;
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -44,7 +49,11 @@ vtkIdType* vtkIdList::Release()
 //------------------------------------------------------------------------------
 void vtkIdList::Initialize()
 {
-  delete[] this->Ids;
+  if (this->ManageMemory)
+  {
+    delete[] this->Ids;
+  }
+  this->ManageMemory = true;
   this->Ids = nullptr;
   this->NumberOfIds = 0;
   this->Size = 0;
@@ -103,9 +112,26 @@ vtkIdType* vtkIdList::WritePointer(const vtkIdType i, const vtkIdType number)
 }
 
 //------------------------------------------------------------------------------
-void vtkIdList::SetArray(vtkIdType* array, vtkIdType size)
+void vtkIdList::SetArray(vtkIdType* array, vtkIdType size, bool save)
 {
-  delete[] this->Ids;
+  if (this->ManageMemory)
+  {
+    delete[] this->Ids;
+  }
+  if (!array)
+  {
+    if (size)
+    {
+      vtkWarningMacro(<< "Passed a nullptr with a non-zero size... Setting size to 0.");
+      size = 0;
+    }
+    if (!save)
+    {
+      vtkWarningMacro(<< "Passed a nullptr while setting save to false... Setting save to true.");
+      save = true;
+    }
+  }
+  this->ManageMemory = save;
   this->Ids = array;
   this->NumberOfIds = size;
   this->Size = size;
@@ -187,8 +213,12 @@ vtkIdType* vtkIdList::Resize(const vtkIdType sz)
   {
     memcpy(newIds, this->Ids,
       static_cast<size_t>(sz < this->Size ? sz : this->Size) * sizeof(vtkIdType));
-    delete[] this->Ids;
+    if (this->ManageMemory)
+    {
+      delete[] this->Ids;
+    }
   }
+  this->ManageMemory = true;
 
   this->Size = newSize;
   this->Ids = newIds;
@@ -255,6 +285,16 @@ void vtkIdList::Sort()
   vtkSMPTools::Sort(this->Ids, this->Ids + this->NumberOfIds);
 }
 
+//------------------------------------------------------------------------------
+void vtkIdList::Fill(vtkIdType value)
+{
+  if (this->Ids == nullptr || this->NumberOfIds < 1)
+  {
+    return;
+  }
+  vtkSMPTools::Fill(this->Ids, this->Ids + this->NumberOfIds, value);
+}
+
 //------------------------------------------------------------------------------
 void vtkIdList::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -262,3 +302,4 @@ void vtkIdList::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Number of Ids: " << this->NumberOfIds << "\n";
 }
+VTK_ABI_NAMESPACE_END
