@@ -19,6 +19,7 @@
 #include <vector>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkInformationDoubleVectorKey ::vtkInformationDoubleVectorKey(
   const char* name, const char* location, int length)
   : vtkInformationKey(name, location)
@@ -91,7 +92,7 @@ double* vtkInformationDoubleVectorKey::Get(vtkInformation* info)
 {
   vtkInformationDoubleVectorValue* v =
     static_cast<vtkInformationDoubleVectorValue*>(this->GetAsObjectBase(info));
-  return (v && !v->Value.empty()) ? (&v->Value[0]) : nullptr;
+  return (v && !v->Value.empty()) ? v->Value.data() : nullptr;
 }
 
 //------------------------------------------------------------------------------
@@ -151,3 +152,4 @@ void vtkInformationDoubleVectorKey::Print(ostream& os, vtkInformation* info)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
