@@ -28,6 +28,7 @@
 
 #include "vtkCommonInformationKeyManager.h" // Manage instances of this type.
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONCORE_EXPORT vtkInformationDoubleVectorKey : public vtkInformationKey
 {
 public:
@@ -42,13 +43,13 @@ public:
    * name, a location and a required length. This method is provided for
    * wrappers. Use the constructor directly from C++ instead.
    */
-  static vtkInformationDoubleVectorKey* MakeKey(
+  static VTK_NEWINSTANCE vtkInformationDoubleVectorKey* MakeKey(
     const char* name, const char* location, int length = -1)
   {
     return new vtkInformationDoubleVectorKey(name, location, length);
   }
 
-  //@{
+  ///@{
   /**
    * Get/Set the value associated with this key in the given
    * information object.
@@ -59,7 +60,7 @@ public:
   double Get(vtkInformation* info, int idx);
   void Get(vtkInformation* info, double* value);
   int Length(vtkInformation* info);
-  //@}
+  ///@}
 
   /**
    * Copy the entry associated with this key from one information
@@ -82,4 +83,5 @@ private:
   void operator=(const vtkInformationDoubleVectorKey&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
