@@ -18,6 +18,7 @@
 #include "vtkDebugLeaks.h"
 #include "vtkInformation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkInformationKeyToInformationFriendship
 {
 public:
@@ -57,7 +58,8 @@ vtkInformationKey::vtkInformationKey(const char* name, const char* location)
 //------------------------------------------------------------------------------
 vtkInformationKey::~vtkInformationKey()
 {
-  this->SetReferenceCount(0);
+  // Avoid warnings from `vtkObjectBase` destructor.
+  this->ClearReferenceCounts();
   this->SetName(nullptr);
   this->SetLocation(nullptr);
 }
@@ -146,3 +148,4 @@ void vtkInformationKey::ReportAsObjectBase(vtkInformation* info, vtkGarbageColle
 
 //------------------------------------------------------------------------------
 void vtkInformationKey::ConstructClass(const char*) {}
+VTK_ABI_NAMESPACE_END
