@@ -29,6 +29,7 @@
 #include <vector>
 
 //=============================================================================
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLogger::LogScopeRAII::LSInternals
 {
 public:
@@ -70,9 +71,11 @@ vtkLogger::LogScopeRAII::~LogScopeRAII()
   delete this->Internals;
 }
 //=============================================================================
+VTK_ABI_NAMESPACE_END
 
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 #if VTK_MODULE_ENABLE_VTK_loguru
 using scope_pair = std::pair<std::string, std::shared_ptr<loguru::LogScopeRAII>>;
 static std::mutex g_mutex;
@@ -106,12 +109,16 @@ static void pop_scope(const char* id)
     LOG_F(ERROR, "Mismatched scope! expected (%s), got (%s)", vector.back().first.c_str(), id);
   }
 }
+VTK_THREAD_LOCAL char ThreadName[128] = {};
 #endif
+
+VTK_ABI_NAMESPACE_END
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 //=============================================================================
+bool vtkLogger::EnableUnsafeSignalHandler = true;
 vtkLogger::Verbosity vtkLogger::InternalVerbosityLevel = vtkLogger::VERBOSITY_1;
-std::string vtkLogger::ThreadName;
 
 //------------------------------------------------------------------------------
 vtkLogger::vtkLogger() = default;
@@ -136,15 +143,16 @@ void vtkLogger::Init(int& argc, char* argv[], const char* verbosity_flag /*= "-v
   const auto current_stderr_verbosity = loguru::g_stderr_verbosity;
   if (loguru::g_internal_verbosity > loguru::g_stderr_verbosity)
   {
-    // this avoid printing the preamble-header on stderr except for cases
+    // this avoids printing the preamble-header on stderr except for cases
     // where the stderr log is guaranteed to have some log text generated.
     loguru::g_stderr_verbosity = loguru::Verbosity_WARNING;
   }
   loguru::Options options;
   options.verbosity_flag = verbosity_flag;
-  if (!vtkLogger::ThreadName.empty())
+  options.unsafe_signal_handler = vtkLogger::EnableUnsafeSignalHandler;
+  if (strlen(detail::ThreadName) > 0)
   {
-    options.main_thread_name = vtkLogger::ThreadName.c_str();
+    options.main_thread_name = detail::ThreadName;
   }
   loguru::init(argc, argv, options);
   loguru::g_stderr_verbosity = current_stderr_verbosity;
@@ -216,7 +224,7 @@ void vtkLogger::SetThreadName(const std::string& name)
   loguru::set_thread_name(name.c_str());
   // Save threadname so if this is called before `Init`, we can pass the thread
   // name to loguru::init().
-  vtkLogger::ThreadName = name;
+  strncpy(detail::ThreadName, name.c_str(), sizeof(detail::ThreadName) - 1);
 #else
   (void)name;
 #endif
@@ -416,30 +424,31 @@ vtkLogger::Verbosity vtkLogger::ConvertToVerbosity(const char* text)
     {
       return vtkLogger::ConvertToVerbosity(ivalue);
     }
-    if (std::string("OFF").compare(text) == 0)
+    if (!strcmp(text, "OFF"))
     {
       return vtkLogger::VERBOSITY_OFF;
     }
-    else if (std::string("ERROR").compare(text) == 0)
+    else if (!strcmp(text, "ERROR"))
     {
       return vtkLogger::VERBOSITY_ERROR;
     }
-    else if (std::string("WARNING").compare(text) == 0)
+    else if (!strcmp(text, "WARNING"))
     {
       return vtkLogger::VERBOSITY_WARNING;
     }
-    else if (std::string("INFO").compare(text) == 0)
+    else if (!strcmp(text, "INFO"))
     {
       return vtkLogger::VERBOSITY_INFO;
     }
-    else if (std::string("TRACE").compare(text) == 0)
+    else if (!strcmp(text, "TRACE"))
     {
       return vtkLogger::VERBOSITY_TRACE;
     }
-    else if (std::string("MAX").compare(text) == 0)
+    else if (!strcmp(text, "MAX"))
     {
       return vtkLogger::VERBOSITY_MAX;
     }
   }
   return vtkLogger::VERBOSITY_INVALID;
 }
+VTK_ABI_NAMESPACE_END
