@@ -49,6 +49,10 @@
  * that, use `vtkLogger::SetThreadName`. Calling `vtkLogger::Init` will set the name
  * for the main thread.
  *
+ * To prevent the logging framework from intercepting signals from your application,
+ * you can set the static variable `vtkLogger::EnableUnsafeSignalHandler` to `false`
+ * prior to calling `vtkLogger::Init(argc, argv)` or `vtkLogger::Init()`.
+ *
  * @section Logging Logging
  *
  * vtkLogger provides several macros (again, based on `loguru`) that can be
@@ -65,6 +69,11 @@
  *
  * @code{.cpp}
  *
+ *  // Optional, leaving this as the default value `true` will let the logging
+ *  // framework log signals such as segmentation faults.
+ *
+ *  vtkLogger::EnableUnsafeSignalHandler = false;
+ *
  *  // Optional, but useful to time-stamp the start of the log.
  *  // Will also detect verbosity level on the command line as -v.
  *
@@ -165,6 +174,7 @@
 #define VTK_FORMAT_STRING_TYPE const char*
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONCORE_EXPORT vtkLogger : public vtkObjectBase
 {
 public:
@@ -236,6 +246,11 @@ public:
    * You can also use something else instead of '-v' flag by the via
    * `verbosity_flag` argument. You can also set to nullptr to skip parsing
    * verbosity level from the command line arguments.
+   *
+   * For applications that do not want loguru to handle any signals, i.e.,
+   * print a stack trace when a signal is intercepted, the
+   * `vtkLogger::EnableUnsafeSignalHandler` static member variable
+   * should be set to `false`.
    * @{
    */
   static void Init(int& argc, char* argv[], const char* verbosity_flag = "-v");
@@ -281,13 +296,13 @@ public:
    */
   static void EndLogToFile(const char* path);
 
-  //@{
+  ///@{
   /**
    * Get/Set the name to identify the current thread in the log output.
    */
   static void SetThreadName(const std::string& name);
   static std::string GetThreadName();
-  //@}
+  ///@}
 
   /**
    * Returns a printable string for a vtkObjectBase instance.
@@ -311,14 +326,14 @@ public:
     const char* message;     // User message goes here.
   };
 
-  //@{
+  ///@{
   /**
    * Callback handle types.
    */
   using LogHandlerCallbackT = void (*)(void* user_data, const Message& message);
   using CloseHandlerCallbackT = void (*)(void* user_data);
   using FlushHandlerCallbackT = void (*)(void* user_data);
-  //@}
+  ///@}
 
   /**
    * Add a callback to call on each log message with a  verbosity less or equal
@@ -367,20 +382,21 @@ public:
    */
   static Verbosity ConvertToVerbosity(const char* text);
 
-  //@{
+  ///@{
   /**
    * @internal
    *
    * Not intended for public use, please use the logging macros instead.
    */
-  static void Log(Verbosity verbosity, const char* fname, unsigned int lineno, const char* txt);
+  static void Log(
+    Verbosity verbosity, VTK_FILEPATH const char* fname, unsigned int lineno, const char* txt);
   static void StartScope(
-    Verbosity verbosity, const char* id, const char* fname, unsigned int lineno);
+    Verbosity verbosity, const char* id, VTK_FILEPATH const char* fname, unsigned int lineno);
   static void EndScope(const char* id);
 #if !defined(__WRAP__)
-  static void LogF(Verbosity verbosity, const char* fname, unsigned int lineno,
+  static void LogF(Verbosity verbosity, VTK_FILEPATH const char* fname, unsigned int lineno,
     VTK_FORMAT_STRING_TYPE format, ...) VTK_PRINTF_LIKE(4, 5);
-  static void StartScopeF(Verbosity verbosity, const char* id, const char* fname,
+  static void StartScopeF(Verbosity verbosity, const char* id, VTK_FILEPATH const char* fname,
     unsigned int lineno, VTK_FORMAT_STRING_TYPE format, ...) VTK_PRINTF_LIKE(5, 6);
 
   class VTKCOMMONCORE_EXPORT LogScopeRAII
@@ -408,7 +424,15 @@ public:
     LSInternals* Internals;
   };
 #endif
-  //@}
+  ///@}
+
+  /**
+   * Flag to enable/disable the logging frameworks printing of a stack trace
+   * when catching signals, which could lead to crashes and deadlocks in
+   * certain circumstances.
+   */
+  static bool EnableUnsafeSignalHandler;
+
 protected:
   vtkLogger();
   ~vtkLogger() override;
@@ -417,10 +441,9 @@ private:
   vtkLogger(const vtkLogger&) = delete;
   void operator=(const vtkLogger&) = delete;
   static vtkLogger::Verbosity InternalVerbosityLevel;
-  static std::string ThreadName;
 };
 
-//@{
+///@{
 /**
  * Add to log given the verbosity level.
  * The text will be logged when the log verbosity is set to the specified level
@@ -451,9 +474,9 @@ private:
     vtkmsg.rdbuf()->freeze(0);                                                                     \
   }
 #define vtkLog(verbosity_name, x) vtkVLog(vtkLogger::VERBOSITY_##verbosity_name, x)
-//@}
+///@}
 
-//@{
+///@{
 /**
  * Add to log only when the `cond` passes.
  *
@@ -485,7 +508,7 @@ private:
     vtkmsg.rdbuf()->freeze(0);                                                                     \
   }
 #define vtkLogIf(verbosity_name, cond, x) vtkVLogIf(vtkLogger::VERBOSITY_##verbosity_name, cond, x)
-//@}
+///@}
 
 #define VTKLOG_CONCAT_IMPL(s1, s2) s1##s2
 #define VTKLOG_CONCAT(s1, s2) VTKLOG_CONCAT_IMPL(s1, s2)
@@ -502,7 +525,7 @@ private:
 #define vtkLogScopeFunction(verbosity_name) vtkLogScopeF(verbosity_name, "%s", __func__)
 #define vtkVLogScopeFunction(level) vtkVLogScopeF(level, "%s", __func__)
 
-//@{
+///@{
 /**
  * Explicitly mark start and end of log scope. This is useful in cases where the
  * start and end of the scope does not happen within the same C++ scope.
@@ -517,7 +540,7 @@ private:
 #define vtkVLogStartScope(level, id) vtkLogger::StartScope(level, id, __FILE__, __LINE__)
 #define vtkVLogStartScopeF(level, id, ...)                                                         \
   vtkLogger::StartScopeF(level, id, __FILE__, __LINE__, __VA_ARGS__)
-//@}
+///@}
 
 /**
  * Convenience macro to generate an identifier string for any vtkObjectBase subclass.
@@ -526,4 +549,5 @@ private:
  */
 #define vtkLogIdentifier(vtkobject) vtkLogger::GetIdentifier(vtkobject).c_str()
 
+VTK_ABI_NAMESPACE_END
 #endif
