@@ -37,6 +37,7 @@
 
 #include "vtkTypedDataArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 template <class Scalar>
 class vtkMappedDataArray : public vtkTypedDataArray<Scalar>
 {
@@ -93,16 +94,16 @@ public:
    */
   void DataChanged() override;
 
-  //@{
+  ///@{
   /**
    * These methods don't make sense for mapped data array. Prints an error and
    * returns.
    */
   void SetVoidArray(void*, vtkIdType, int) override;
   void SetVoidArray(void*, vtkIdType, int, int) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Not implemented. Print error and return nullptr.
    */
@@ -111,7 +112,7 @@ public:
     vtkErrorMacro(<< "WriteVoidPointer: Method not implemented.");
     return nullptr;
   }
-  //@}
+  ///@}
 
   /**
    * Invalidate the internal temporary array and call superclass method.
@@ -131,18 +132,19 @@ private:
   vtkMappedDataArray(const vtkMappedDataArray&) = delete;
   void operator=(const vtkMappedDataArray&) = delete;
 
-  //@{
+  ///@{
   /**
    * GetVoidPointer.
    */
   ValueType* TemporaryScalarPointer;
   size_t TemporaryScalarPointerSize;
-  //@}
+  ///@}
 };
 
 // Declare vtkArrayDownCast implementations for mapped containers:
 vtkArrayDownCast_TemplateFastCastMacro(vtkMappedDataArray);
 
+VTK_ABI_NAMESPACE_END
 #include "vtkMappedDataArray.txx"
 
 // Adds an implementation of NewInstanceInternal() that returns an AoS
