@@ -36,6 +36,7 @@
 #include <limits>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMath);
 
 class vtkMathInternal : public vtkObjectBase
@@ -367,7 +368,7 @@ vtkTypeBool vtkMath::SolveLinearSystemGEPP2x2(
     // None of the matrix coefficients are exactly zero.
     // Use GEPP to form upper triangular matrix, i.e. so that a10 == 0.
     // Select pivot by looking at largest absolute value in a00, a10
-    if (fabs(a00) < fabs(a10))
+    if (std::abs(a00) < std::abs(a10))
     {
       // swap rows so largest coefficient in first column is in the first row
       std::swap(a00, a10);
@@ -383,7 +384,7 @@ vtkTypeBool vtkMath::SolveLinearSystemGEPP2x2(
   // Need to check for singularity by looking at a11.
   // Note the choice of eps is reasonable but somewhat arbitrary.
   static const double eps = 256 * std::numeric_limits<double>::epsilon();
-  if (fabs(a11) < eps)
+  if (std::abs(a11) < eps)
   {
     // matrix is singular within small numerical tolerance
     return 0;
@@ -418,7 +419,12 @@ vtkTypeBool vtkMath::SolveLinearSystemGEPP2x2(
   return 1;
 }
 
-#define VTK_SMALL_NUMBER 1.0e-12
+namespace
+{
+constexpr double VTK_SMALL_NUMBER = 1.0e-12;
+constexpr int VTK_MAX_SCRATCH_ARRAY_SIZE = 10;
+constexpr int VTK_MAX_ROTATIONS = 20;
+}
 
 //------------------------------------------------------------------------------
 // Solve linear equations Ax = b using Crout's method. Input is square matrix A
@@ -450,8 +456,8 @@ vtkTypeBool vtkMath::SolveLinearSystem(double** A, double* x, int size)
 
   // Check on allocation of working vectors
   //
-  int *index, scratch[10];
-  index = (size < 10 ? scratch : new int[size]);
+  int *index, scratch[VTK_MAX_SCRATCH_ARRAY_SIZE];
+  index = (size <= VTK_MAX_SCRATCH_ARRAY_SIZE ? scratch : new int[size]);
 
   //
   // Factor and solve matrix
@@ -462,7 +468,7 @@ vtkTypeBool vtkMath::SolveLinearSystem(double** A, double* x, int size)
   }
   vtkMath::LUSolveLinearSystem(A, index, x, size);
 
-  if (size >= 10)
+  if (size > VTK_MAX_SCRATCH_ARRAY_SIZE)
   {
     delete[] index;
   }
@@ -475,25 +481,14 @@ vtkTypeBool vtkMath::SolveLinearSystem(double** A, double* x, int size)
 // if inverse not computed.
 vtkTypeBool vtkMath::InvertMatrix(double** A, double** AI, int size)
 {
-  int *index, iScratch[10];
-  double *column, dScratch[10];
-
-  // Check on allocation of working vectors
-  //
-  if (size <= 10)
-  {
-    index = iScratch;
-    column = dScratch;
-  }
-  else
-  {
-    index = new int[size];
-    column = new double[size];
-  }
+  int iScratch[VTK_MAX_SCRATCH_ARRAY_SIZE];
+  int* index = (size <= VTK_MAX_SCRATCH_ARRAY_SIZE ? iScratch : new int[size]);
+  double dScratch[VTK_MAX_SCRATCH_ARRAY_SIZE];
+  double* column = (size <= VTK_MAX_SCRATCH_ARRAY_SIZE ? dScratch : new double[size]);
 
   vtkTypeBool retVal = vtkMath::InvertMatrix(A, AI, size, index, column);
 
-  if (size > 10)
+  if (size > VTK_MAX_SCRATCH_ARRAY_SIZE)
   {
     delete[] index;
     delete[] column;
@@ -502,7 +497,6 @@ vtkTypeBool vtkMath::InvertMatrix(double** A, double** AI, int size)
   return retVal;
 }
 
-#define VTK_MAX_WARNS 3
 //------------------------------------------------------------------------------
 // Factor linear equations Ax = b using LU decomposition A = LU where L is
 // lower triangular matrix and U is upper triangular matrix. Input is
@@ -511,16 +505,13 @@ vtkTypeBool vtkMath::InvertMatrix(double** A, double** AI, int size)
 // found, method returns 0.
 vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size)
 {
-  double scratch[10];
-  double* scale = (size < 10 ? scratch : new double[size]);
+  double scratch[VTK_MAX_SCRATCH_ARRAY_SIZE];
+  double* scale = (size <= VTK_MAX_SCRATCH_ARRAY_SIZE ? scratch : new double[size]);
 
   int i, j, k;
   int maxI = 0;
   double largest, temp1, temp2, sum;
 
-  // Manage number of output warnings
-  static int numWarns = 0;
-
   //
   // Loop over rows to get implicit scaling information
   //
@@ -528,15 +519,19 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size)
   {
     for (largest = 0.0, j = 0; j < size; ++j)
     {
-      if ((temp2 = fabs(A[i][j])) > largest)
+      if ((temp2 = std::abs(A[i][j])) > largest)
       {
         largest = temp2;
       }
     }
 
-    if (largest == 0.0 && numWarns++ < VTK_MAX_WARNS)
+    if (largest == 0.0)
     {
       vtkGenericWarningMacro(<< "Unable to factor linear system");
+      if (size > VTK_MAX_SCRATCH_ARRAY_SIZE)
+      {
+        delete[] scale;
+      }
       return 0;
     }
     scale[i] = 1.0 / largest;
@@ -567,7 +562,7 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size)
       }
       A[i][j] = sum;
 
-      if ((temp1 = scale[i] * fabs(sum)) >= largest)
+      if ((temp1 = scale[i] * std::abs(sum)) >= largest)
       {
         largest = temp1;
         maxI = i;
@@ -591,9 +586,13 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size)
     //
     index[j] = maxI;
 
-    if (fabs(A[j][j]) <= VTK_SMALL_NUMBER && numWarns++ < VTK_MAX_WARNS)
+    if (std::abs(A[j][j]) <= VTK_SMALL_NUMBER)
     {
       vtkGenericWarningMacro(<< "Unable to factor linear system");
+      if (size > VTK_MAX_SCRATCH_ARRAY_SIZE)
+      {
+        delete[] scale;
+      }
       return 0;
     }
 
@@ -607,7 +606,7 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size)
     }
   }
 
-  if (size >= 10)
+  if (size > VTK_MAX_SCRATCH_ARRAY_SIZE)
   {
     delete[] scale;
   }
@@ -664,20 +663,12 @@ void vtkMath::LUSolveLinearSystem(double** A, int* index, double* x, int size)
   }
 }
 
-#undef VTK_SMALL_NUMBER
-
 #define VTK_ROTATE(a, i, j, k, l)                                                                  \
   g = a[i][j];                                                                                     \
   h = a[k][l];                                                                                     \
   a[i][j] = g - s * (h + g * tau);                                                                 \
   a[k][l] = h + s * (g - h * tau)
 
-#define VTK_MAX_ROTATIONS 20
-
-//#undef VTK_MAX_ROTATIONS
-
-//#define VTK_MAX_ROTATIONS 50
-
 // Jacobi iteration for the solution of eigenvectors/eigenvalues of a nxn
 // real symmetric matrix. Square nxn matrix a; size of matrix in n;
 // output eigenvalues in w; and output eigenvectors in v. Resulting
@@ -689,16 +680,9 @@ vtkTypeBool vtkJacobiN(T** a, int n, T* w, T** v)
 {
   int i, j, k, iq, ip, numPos;
   T tresh, theta, tau, t, sm, s, h, g, c, tmp;
-  T bspace[4], zspace[4];
-  T* b = bspace;
-  T* z = zspace;
-
-  // only allocate memory if the matrix is large
-  if (n > 4)
-  {
-    b = new T[n];
-    z = new T[n];
-  }
+  T bspace[VTK_MAX_SCRATCH_ARRAY_SIZE], zspace[VTK_MAX_SCRATCH_ARRAY_SIZE];
+  T* b = (n <= VTK_MAX_SCRATCH_ARRAY_SIZE) ? bspace : new T[n];
+  T* z = (n <= VTK_MAX_SCRATCH_ARRAY_SIZE) ? zspace : new T[n];
 
   // initialize
   for (ip = 0; ip < n; ip++)
@@ -723,7 +707,7 @@ vtkTypeBool vtkJacobiN(T** a, int n, T* w, T** v)
     {
       for (iq = ip + 1; iq < n; iq++)
       {
-        sm += fabs(a[ip][iq]);
+        sm += std::abs(a[ip][iq]);
       }
     }
     if (sm == 0.0)
@@ -744,24 +728,25 @@ vtkTypeBool vtkJacobiN(T** a, int n, T* w, T** v)
     {
       for (iq = ip + 1; iq < n; iq++)
       {
-        g = 100.0 * fabs(a[ip][iq]);
+        g = 100.0 * std::abs(a[ip][iq]);
 
         // after 4 sweeps
-        if (i > 3 && (fabs(w[ip]) + g) == fabs(w[ip]) && (fabs(w[iq]) + g) == fabs(w[iq]))
+        if (i > 3 && (std::abs(w[ip]) + g) == std::abs(w[ip]) &&
+          (std::abs(w[iq]) + g) == std::abs(w[iq]))
         {
           a[ip][iq] = 0.0;
         }
-        else if (fabs(a[ip][iq]) > tresh)
+        else if (std::abs(a[ip][iq]) > tresh)
         {
           h = w[iq] - w[ip];
-          if ((fabs(h) + g) == fabs(h))
+          if ((std::abs(h) + g) == std::abs(h))
           {
             t = (a[ip][iq]) / h;
           }
           else
           {
             theta = 0.5 * h / (a[ip][iq]);
-            t = 1.0 / (fabs(theta) + std::sqrt(1.0 + theta * theta));
+            t = 1.0 / (std::abs(theta) + std::sqrt(1.0 + theta * theta));
             if (theta < 0.0)
             {
               t = -t;
@@ -812,6 +797,11 @@ vtkTypeBool vtkJacobiN(T** a, int n, T* w, T** v)
   if (i >= VTK_MAX_ROTATIONS)
   {
     vtkGenericWarningMacro("vtkMath::Jacobi: Error extracting eigenfunctions");
+    if (n > VTK_MAX_SCRATCH_ARRAY_SIZE)
+    {
+      delete[] b;
+      delete[] z;
+    }
     return 0;
   }
 
@@ -863,7 +853,7 @@ vtkTypeBool vtkJacobiN(T** a, int n, T* w, T** v)
     }
   }
 
-  if (n > 4)
+  if (n > VTK_MAX_SCRATCH_ARRAY_SIZE)
   {
     delete[] b;
     delete[] z;
@@ -920,9 +910,9 @@ double vtkMath::EstimateMatrixCondition(const double* const* A, int size)
   {
     for (j = i; j < size; ++j)
     {
-      if (fabs(A[i][j]) > max)
+      if (std::abs(A[i][j]) > max)
       {
-        max = fabs(A[i][j]);
+        max = std::abs(A[i][j]);
       }
     }
   }
@@ -930,9 +920,9 @@ double vtkMath::EstimateMatrixCondition(const double* const* A, int size)
   // find the minimum diagonal value
   for (i = 0; i < size; ++i)
   {
-    if (fabs(A[i][i]) < min)
+    if (std::abs(A[i][i]) < min)
     {
-      min = fabs(A[i][i]);
+      min = std::abs(A[i][i]);
     }
   }
 
@@ -1033,8 +1023,6 @@ vtkTypeBool vtkMath::SolveHomogeneousLeastSquares(
   return 1;
 }
 
-static const double VTK_SMALL_NUMBER = 1.0e-12;
-
 //------------------------------------------------------------------------------
 // Solves for the least squares best fit matrix for the equation X'M' = Y'.
 // Uses pseudoinverse to get the ordinary least squares.
@@ -1087,7 +1075,7 @@ vtkTypeBool vtkMath::SolveLeastSquares(int numberOfSamples, double** xt, int xOr
     {
       for (j = 0; j < yOrder; ++j)
       {
-        if (fabs(yt[i][j]) > VTK_SMALL_NUMBER)
+        if (std::abs(yt[i][j]) > VTK_SMALL_NUMBER)
         {
           allHomogeneous = false;
           homogenFlags[j] = 0;
@@ -1264,7 +1252,7 @@ vtkTypeBool vtkMath::SolveLeastSquares(int numberOfSamples, double** xt, int xOr
 // if inverse not computed.
 // -----------------------
 // For thread safe behavior, temporary arrays tmp1SIze and tmp2Size
-// of length size must be passsed in.
+// of length size must be passed in.
 vtkTypeBool vtkMath::InvertMatrix(
   double** A, double** AI, int size, int* tmp1Size, double* tmp2Size)
 {
@@ -1313,9 +1301,6 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size, doub
   int maxI = 0;
   double largest, temp1, temp2, sum;
 
-  // Manage number of output warnings
-  static int numWarns = 0;
-
   //
   // Loop over rows to get implicit scaling information
   //
@@ -1323,13 +1308,13 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size, doub
   {
     for (largest = 0.0, j = 0; j < size; ++j)
     {
-      if ((temp2 = fabs(A[i][j])) > largest)
+      if ((temp2 = std::abs(A[i][j])) > largest)
       {
         largest = temp2;
       }
     }
 
-    if (largest == 0.0 && numWarns++ < VTK_MAX_WARNS)
+    if (largest == 0.0)
     {
       vtkGenericWarningMacro(<< "Unable to factor linear system");
       return 0;
@@ -1362,7 +1347,7 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size, doub
       }
       A[i][j] = sum;
 
-      if ((temp1 = tmpSize[i] * fabs(sum)) >= largest)
+      if ((temp1 = tmpSize[i] * std::abs(sum)) >= largest)
       {
         largest = temp1;
         maxI = i;
@@ -1375,9 +1360,7 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size, doub
     {
       for (k = 0; k < size; ++k)
       {
-        temp1 = A[maxI][k];
-        A[maxI][k] = A[j][k];
-        A[j][k] = temp1;
+        std::swap(A[maxI][k], A[j][k]);
       }
       tmpSize[maxI] = tmpSize[j];
     }
@@ -1386,7 +1369,7 @@ vtkTypeBool vtkMath::LUFactorLinearSystem(double** A, int* index, int size, doub
     //
     index[j] = maxI;
 
-    if (fabs(A[j][j]) <= VTK_SMALL_NUMBER && numWarns++ < VTK_MAX_WARNS)
+    if (std::abs(A[j][j]) <= VTK_SMALL_NUMBER)
     {
       vtkGenericWarningMacro(<< "Unable to factor linear system");
       return 0;
@@ -1418,9 +1401,7 @@ inline void vtkSwapVectors3(T v1[3], T v2[3])
 {
   for (int i = 0; i < 3; ++i)
   {
-    T tmp = v1[i];
-    v1[i] = v2[i];
-    v2[i] = tmp;
+    std::swap(v1[i], v2[i]);
   }
 }
 
@@ -1437,12 +1418,12 @@ inline void vtkLUFactor3x3(T A[3][3], int index[3])
 
   for (i = 0; i < 3; ++i)
   {
-    largest = fabs(A[i][0]);
-    if ((tmp = fabs(A[i][1])) > largest)
+    largest = std::abs(A[i][0]);
+    if ((tmp = std::abs(A[i][1])) > largest)
     {
       largest = tmp;
     }
-    if ((tmp = fabs(A[i][2])) > largest)
+    if ((tmp = std::abs(A[i][2])) > largest)
     {
       largest = tmp;
     }
@@ -1452,14 +1433,14 @@ inline void vtkLUFactor3x3(T A[3][3], int index[3])
   // Loop over all columns using Crout's method
 
   // first column
-  largest = scale[0] * fabs(A[0][0]);
+  largest = scale[0] * std::abs(A[0][0]);
   maxI = 0;
-  if ((tmp = scale[1] * fabs(A[1][0])) >= largest)
+  if ((tmp = scale[1] * std::abs(A[1][0])) >= largest)
   {
     largest = tmp;
     maxI = 1;
   }
-  if ((tmp = scale[2] * fabs(A[2][0])) >= largest)
+  if ((tmp = scale[2] * std::abs(A[2][0])) >= largest)
   {
     maxI = 2;
   }
@@ -1476,9 +1457,9 @@ inline void vtkLUFactor3x3(T A[3][3], int index[3])
   // second column
   A[1][1] -= A[1][0] * A[0][1];
   A[2][1] -= A[2][0] * A[0][1];
-  largest = scale[1] * fabs(A[1][1]);
+  largest = scale[1] * std::abs(A[1][1]);
   maxI = 1;
-  if ((tmp = scale[2] * fabs(A[2][1])) >= largest)
+  if ((tmp = scale[2] * std::abs(A[2][1])) >= largest)
   {
     maxI = 2;
     vtkSwapVectors3(A[2], A[1]);
@@ -1951,9 +1932,9 @@ inline void vtkOrthogonalize3x3(const T1 A[3][3], T2 B[3][3])
   // Loop over rows to get implicit scaling information
   for (i = 0; i < 3; ++i)
   {
-    T2 x1 = fabs(B[i][0]);
-    T2 x2 = fabs(B[i][1]);
-    T2 x3 = fabs(B[i][2]);
+    T2 x1 = std::abs(B[i][0]);
+    T2 x2 = std::abs(B[i][1]);
+    T2 x3 = std::abs(B[i][2]);
     largest = (x2 > x1 ? x2 : x1);
     largest = (x3 > largest ? x3 : largest);
     scale[i] = 1;
@@ -1964,9 +1945,9 @@ inline void vtkOrthogonalize3x3(const T1 A[3][3], T2 B[3][3])
   }
 
   // first column
-  T2 x1 = fabs(B[0][0]) * scale[0];
-  T2 x2 = fabs(B[1][0]) * scale[1];
-  T2 x3 = fabs(B[2][0]) * scale[2];
+  T2 x1 = std::abs(B[0][0]) * scale[0];
+  T2 x2 = std::abs(B[1][0]) * scale[1];
+  T2 x3 = std::abs(B[2][0]) * scale[2];
   index[0] = 0;
   largest = x1;
   if (x2 >= largest)
@@ -1985,8 +1966,8 @@ inline void vtkOrthogonalize3x3(const T1 A[3][3], T2 B[3][3])
   }
 
   // second column
-  T2 y2 = fabs(B[1][1]) * scale[1];
-  T2 y3 = fabs(B[2][1]) * scale[2];
+  T2 y2 = std::abs(B[1][1]) * scale[1];
+  T2 y3 = std::abs(B[2][1]) * scale[2];
   index[1] = 1;
   largest = y2;
   if (y3 >= largest)
@@ -2120,9 +2101,8 @@ bool vtkMath::ProjectVector(const double a[3], const double b[3], double project
 
   for (int i = 0; i < 3; ++i)
   {
-    projection[i] = b[i];
+    projection[i] = b[i] * scale;
   }
-  vtkMath::MultiplyScalar(projection, scale);
 
   return true;
 }
@@ -2216,11 +2196,11 @@ inline void vtkDiagonalize3x3(const T1 A[3][3], T2 w[3], T2 V[3][3])
     if (w[(i + 1) % 3] == w[(i + 2) % 3]) // two eigenvalues are the same
     {
       // find maximum element of the independent eigenvector
-      maxVal = fabs(V[i][0]);
+      maxVal = std::abs(V[i][0]);
       maxI = 0;
       for (j = 1; j < 3; ++j)
       {
-        if (maxVal < (tmp = fabs(V[i][j])))
+        if (maxVal < (tmp = std::abs(V[i][j])))
         {
           maxVal = tmp;
           maxI = j;
@@ -2265,11 +2245,11 @@ inline void vtkDiagonalize3x3(const T1 A[3][3], T2 w[3], T2 V[3][3])
 
   // find the vector with the largest x element, make that vector
   // the first vector
-  maxVal = fabs(V[0][0]);
+  maxVal = std::abs(V[0][0]);
   maxI = 0;
   for (i = 1; i < 3; ++i)
   {
-    if (maxVal < (tmp = fabs(V[i][0])))
+    if (maxVal < (tmp = std::abs(V[i][0])))
     {
       maxVal = tmp;
       maxI = i;
@@ -2284,7 +2264,7 @@ inline void vtkDiagonalize3x3(const T1 A[3][3], T2 w[3], T2 V[3][3])
     vtkSwapVectors3(V[maxI], V[0]);
   }
   // do the same for the y element
-  if (fabs(V[1][1]) < fabs(V[2][1]))
+  if (std::abs(V[1][1]) < std::abs(V[2][1]))
   {
     tmp = w[2];
     w[2] = w[1];
@@ -2413,7 +2393,7 @@ inline void vtkSingularValueDecomposition3x3(const T1 A[3][3], T2 U[3][3], T2 w[
   {
     for (j = 0; j < 3; ++j)
     {
-      if ((tmp = fabs(B[i][j] - M[i][j])) > maxerr)
+      if ((tmp = std::abs(B[i][j] - M[i][j])) > maxerr)
       {
         maxerr = tmp;
       }
@@ -2960,10 +2940,11 @@ vtkTypeBool vtkMath::BoundsIsWithinOtherBounds(
   }
   for (int i = 0; i < 6; i += 2)
   {
-
     if (bounds1[i] + delta[i / 2] < bounds2[i] || bounds1[i] - delta[i / 2] > bounds2[i + 1] ||
       bounds1[i + 1] + delta[i / 2] < bounds2[i] || bounds1[i + 1] - delta[i / 2] > bounds2[i + 1])
+    {
       return 0;
+    }
   }
   return 1;
 }
@@ -2976,14 +2957,9 @@ vtkTypeBool vtkMath::PointIsWithinBounds(
   {
     return 0;
   }
-  for (int i = 0; i < 3; ++i)
-  {
-    if (point[i] + delta[i] < bounds[2 * i] || point[i] - delta[i] > bounds[2 * i + 1])
-    {
-      return 0;
-    }
-  }
-  return 1;
+  return /*i = 0*/ point[0] + delta[0] >= bounds[0] && point[0] - delta[0] <= bounds[1] &&
+    /*i = 1*/ point[1] + delta[1] >= bounds[2] && point[1] - delta[1] <= bounds[3] &&
+    /*i = 2*/ point[2] + delta[2] >= bounds[4] && point[2] - delta[2] <= bounds[5];
 }
 
 //------------------------------------------------------------------------------
@@ -3059,6 +3035,16 @@ double vtkMath::AngleBetweenVectors(const double v1[3], const double v2[3])
   return atan2(vtkMath::Norm(cross), vtkMath::Dot(v1, v2));
 }
 
+//------------------------------------------------------------------------------
+double vtkMath::SignedAngleBetweenVectors(
+  const double v1[3], const double v2[3], const double vn[3])
+{
+  double cross[3];
+  vtkMath::Cross(v1, v2, cross);
+  double angle = atan2(vtkMath::Norm(cross), vtkMath::Dot(v1, v2));
+  return vtkMath::Dot(cross, vn) >= 0 ? angle : -angle;
+}
+
 //------------------------------------------------------------------------------
 double vtkMath::GaussianAmplitude(const double variance, const double distanceFromMean)
 {
@@ -3234,3 +3220,4 @@ int vtkMath::QuadraticRoot(double a, double b, double c, double min, double max,
   }
   return 0;
 }
+VTK_ABI_NAMESPACE_END
