@@ -71,19 +71,24 @@
 #endif // DBL_EPSILON
 #endif // VTK_DBL_EPSILON
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataArray;
 class vtkPoints;
 class vtkMathInternal;
 class vtkMinimalStandardRandomSequence;
 class vtkBoxMuellerRandomSequence;
+VTK_ABI_NAMESPACE_END
 
 namespace vtk_detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 // forward declaration
 template <typename OutT>
 void RoundDoubleToIntegralIfNecessary(double val, OutT* ret);
+VTK_ABI_NAMESPACE_END
 } // end namespace vtk_detail
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONCORE_EXPORT vtkMath : public vtkObject
 {
 public:
@@ -94,23 +99,23 @@ public:
   /**
    * A mathematical constant. This version is atan(1.0) * 4.0
    */
-  static double Pi() { return 3.141592653589793; }
+  static constexpr double Pi() { return 3.141592653589793; }
 
-  //@{
+  ///@{
   /**
    * Convert degrees into radians
    */
   static float RadiansFromDegrees(float degrees);
   static double RadiansFromDegrees(double degrees);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert radians into degrees
    */
   static float DegreesFromRadians(float radians);
   static double DegreesFromRadians(double radians);
-  //@}
+  ///@}
 
   /**
    * Rounds a float to the nearest integer.
@@ -310,15 +315,22 @@ public:
   static double Gaussian(double mean, double std);
 
   /**
-   * Assign values to a 3-vector (double version). Result is stored in b according to b = a.
+   * Assign values to a 3-vector (templated version). Result is stored in b according to b = a.
+   * Each parameter must implement operator[].
    */
-  static void Assign(const double a[3], double b[3])
+  template <class VectorT1, class VectorT2>
+  static void Assign(const VectorT1& a, VectorT2&& b)
   {
     b[0] = a[0];
     b[1] = a[1];
     b[2] = a[2];
   }
 
+  /**
+   * Assign values to a 3-vector (double version). Result is stored in b according to b = a.
+   */
+  static void Assign(const double a[3], double b[3]) { vtkMath::Assign<>(a, b); }
+
   /**
    * Addition of two 3-vectors (float version). Result is stored in c according to c = a + b.
    */
@@ -363,6 +375,19 @@ public:
     }
   }
 
+  /**
+   * Subtraction of two 3-vectors (templated version). Result is stored in c according to c = a - b.
+   *
+   * Each parameter needs to implement `operator[]`.
+   */
+  template <class VectorT1, class VectorT2, class VectorT3>
+  static void Subtract(const VectorT1& a, const VectorT2& b, VectorT3&& c)
+  {
+    c[0] = a[0] - b[0];
+    c[1] = a[1] - b[1];
+    c[2] = a[2] - b[2];
+  }
+
   /**
    * Multiplies a 3-vector by a scalar (float version).
    * This modifies the input 3-vector.
@@ -491,13 +516,13 @@ public:
    */
   static void Cross(const double a[3], const double b[3], double c[3]);
 
-  //@{
+  ///@{
   /**
    * Compute the norm of n-vector. x is the vector, n is its length.
    */
   static float Norm(const float* x, int n);
   static double Norm(const double* x, int n);
-  //@}
+  ///@}
 
   /**
    * Compute the norm of 3-vector (float version).
@@ -539,7 +564,7 @@ public:
    */
   static double Normalize(double v[3]);
 
-  //@{
+  ///@{
   /**
    * Given a unit vector v1, find two unit vectors v2 and v3 such that
    * v1 cross v2 = v3 (i.e. the vectors are perpendicular to each other).
@@ -549,9 +574,9 @@ public:
    */
   static void Perpendiculars(const double v1[3], double v2[3], double v3[3], double theta);
   static void Perpendiculars(const float v1[3], float v2[3], float v3[3], double theta);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Compute the projection of vector a on vector b and return it in projection[3].
    * If b is a zero vector, the function returns false and 'projection' is invalid.
@@ -559,9 +584,9 @@ public:
    */
   static bool ProjectVector(const float a[3], const float b[3], float projection[3]);
   static bool ProjectVector(const double a[3], const double b[3], double projection[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Compute the projection of 2D vector a on 2D vector b and returns the result
    * in projection[2].
@@ -570,7 +595,7 @@ public:
    */
   static bool ProjectVector2D(const float a[2], const float b[2], float projection[2]);
   static bool ProjectVector2D(const double a[2], const double b[2], double projection[2]);
-  //@}
+  ///@}
 
   /**
    * Compute distance squared between two points p1 and p2.
@@ -610,6 +635,12 @@ public:
    */
   static double AngleBetweenVectors(const double v1[3], const double v2[3]);
 
+  /**
+   * Compute signed angle in radians between two vectors with regard to a third orthogonal vector
+   */
+  static double SignedAngleBetweenVectors(
+    const double v1[3], const double v2[3], const double vn[3]);
+
   /**
    * Compute the amplitude of a Gaussian function with mean=0 and specified variance.
    * That is, 1./(std::sqrt(2 Pi * variance)) * exp(-distanceFromMean^2/(2.*variance)).
@@ -706,7 +737,7 @@ public:
     return c1[0] * c2[1] - c2[0] * c1[1];
   }
 
-  //@{
+  ///@{
   /**
    * Calculate the determinant of a 2x2 matrix: | a b | | c d |
    */
@@ -715,48 +746,48 @@ public:
   {
     return c1[0] * c2[1] - c2[0] * c1[1];
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * LU Factorization of a 3x3 matrix.
    */
   static void LUFactor3x3(float A[3][3], int index[3]);
   static void LUFactor3x3(double A[3][3], int index[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * LU back substitution for a 3x3 matrix.
    */
   static void LUSolve3x3(const float A[3][3], const int index[3], float x[3]);
   static void LUSolve3x3(const double A[3][3], const int index[3], double x[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Solve Ay = x for y and place the result in y.  The matrix A is
    * destroyed in the process.
    */
   static void LinearSolve3x3(const float A[3][3], const float x[3], float y[3]);
   static void LinearSolve3x3(const double A[3][3], const double x[3], double y[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Multiply a vector by a 3x3 matrix.  The result is placed in out.
    */
   static void Multiply3x3(const float A[3][3], const float v[3], float u[3]);
   static void Multiply3x3(const double A[3][3], const double v[3], double u[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Multiply one 3x3 matrix by another according to C = AB.
    */
   static void Multiply3x3(const float A[3][3], const float B[3][3], float C[3][3]);
   static void Multiply3x3(const double A[3][3], const double B[3][3], double C[3][3]);
-  //@}
+  ///@}
 
   /**
    * Multiply matrices such that M3 = M1 x M2.
@@ -798,7 +829,7 @@ public:
    * of MatrixLayout.
    *
    * Matrix M is assumed to be a 1D array implementing `operator[]`. The matrix
-   * is indexed row by row. If the input array is indexed columns by colums.
+   * is indexed row by row. If the input array is indexed columns by columns.
    * If LayoutT == vtkMatrixUtilities::Layout::Identity (default), then M indexing is untouched.
    * If LayoutT == vtkMatrixUtilities::Layout::Transpose, then M is read column-wise.
    * If LayoutT == vtkMatrixUtilities::Layout::Diag, then M is considered to be composed
@@ -837,7 +868,7 @@ public:
    * of MatrixLayout.
    *
    * Matrix M is assumed to be a 1D array implementing `operator[]`. The matrix
-   * is indexed row by row. If the input array is indexed columns by colums.
+   * is indexed row by row. If the input array is indexed columns by columns.
    * If LayoutT == vtkMatrixUtilities::Layout::Identity (default), then M indexing is untouched.
    * If LayoutT == vtkMatrixUtilities::Layout::Transpose, then M is read column-wise.
    * If LayoutT == vtkMatrixUtilities::Layout::Diag, then M is considered to be composed
@@ -859,7 +890,7 @@ public:
    * of MatrixLayout.
    *
    * Matrix M is assumed to be a 1D array implementing `operator[]`. The matrix
-   * is indexed row by row. If the input array is indexed columns by colums.
+   * is indexed row by row. If the input array is indexed columns by columns.
    * If LayoutT == vtkMatrixUtilities::Layout::Identity (default), then M indexing is untouched.
    * If LayoutT == vtkMatrixUtilities::Layout::Transpose, then M is read column-wise.
    * If LayoutT == vtkMatrixUtilities::Layout::Diag, then M is considered to be composed
@@ -881,7 +912,7 @@ public:
    * of MatrixLayout.
    *
    * Matrix M is assumed to be a 1D array implementing `operator[]`. The matrix
-   * is indexed row by row. If the input array is indexed columns by colums.
+   * is indexed row by row. If the input array is indexed columns by columns.
    * If LayoutT == vtkMatrixUtilities::Layout::Identity (default), then M indexing is untouched.
    * If LayoutT == vtkMatrixUtilities::Layout::Transpose, then M is read column-wise.
    * If LayoutT == vtkMatrixUtilities::Layout::Diag, then M is considered to be composed
@@ -902,7 +933,7 @@ public:
    * `operator[]`.
    *
    * Matrix M is assumed to be a 1D array implementing `operator[]`. The matrix
-   * is indexed row by row. If the input array is indexed columns by colums.
+   * is indexed row by row. If the input array is indexed columns by columns.
    * If LayoutT == vtkMatrixUtilities::Layout::Identity (default), then M indexing is untouched.
    * If LayoutT == vtkMatrixUtilities::Layout::Transpose, then M is read column-wise.
    * If LayoutT == vtkMatrixUtilities::Layout::Diag, then M is considered to be composed
@@ -926,39 +957,39 @@ public:
   static void MultiplyMatrix(const double* const* A, const double* const* B, unsigned int rowA,
     unsigned int colA, unsigned int rowB, unsigned int colB, double** C);
 
-  //@{
+  ///@{
   /**
    * Transpose a 3x3 matrix. The input matrix is A. The output
    * is stored in AT.
    */
   static void Transpose3x3(const float A[3][3], float AT[3][3]);
   static void Transpose3x3(const double A[3][3], double AT[3][3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Invert a 3x3 matrix. The input matrix is A. The output is
    * stored in AI.
    */
   static void Invert3x3(const float A[3][3], float AI[3][3]);
   static void Invert3x3(const double A[3][3], double AI[3][3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set A to the identity matrix.
    */
   static void Identity3x3(float A[3][3]);
   static void Identity3x3(double A[3][3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return the determinant of a 3x3 matrix.
    */
   static double Determinant3x3(const float A[3][3]);
   static double Determinant3x3(const double A[3][3]);
-  //@}
+  ///@}
 
   /**
    * Compute determinant of 3x3 matrix. Three columns of matrix are input.
@@ -979,7 +1010,7 @@ public:
   static double Determinant3x3(double a1, double a2, double a3, double b1, double b2, double b3,
     double c1, double c2, double c3);
 
-  //@{
+  ///@{
   /**
    * Convert a quaternion to a 3x3 rotation matrix.  The quaternion
    * does not have to be normalized beforehand.
@@ -992,16 +1023,16 @@ public:
   template <class QuaternionT, class MatrixT,
     class EnableT = typename std::enable_if<!vtkMatrixUtilities::MatrixIs2DArray<MatrixT>()>::type>
   static void QuaternionToMatrix3x3(const QuaternionT& q, MatrixT&& A);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert a 3x3 matrix into a quaternion.  This will provide the
    * best possible answer even if the matrix is not a pure rotation matrix.
    * The quaternion is in the form [w, x, y, z].
    * The method used is that of B.K.P. Horn.
    * See: https://people.csail.mit.edu/bkph/articles/Quaternions.pdf
-   * @saQuaternionToMatrix3x3() MultiplyQuaternion()
+   * @sa QuaternionToMatrix3x3() MultiplyQuaternion()
    * @sa vtkQuaternion
    */
   static void Matrix3x3ToQuaternion(const float A[3][3], float quat[4]);
@@ -1009,9 +1040,9 @@ public:
   template <class MatrixT, class QuaternionT,
     class EnableT = typename std::enable_if<!vtkMatrixUtilities::MatrixIs2DArray<MatrixT>()>::type>
   static void Matrix3x3ToQuaternion(const MatrixT& A, QuaternionT&& q);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Multiply two quaternions. This is used to concatenate rotations.
    * Quaternions are in the form [w, x, y, z].
@@ -1020,27 +1051,27 @@ public:
    */
   static void MultiplyQuaternion(const float q1[4], const float q2[4], float q[4]);
   static void MultiplyQuaternion(const double q1[4], const double q2[4], double q[4]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * rotate a vector by a normalized quaternion
    * using // https://en.wikipedia.org/wiki/Rodrigues%27_rotation_formula
    */
   static void RotateVectorByNormalizedQuaternion(const float v[3], const float q[4], float r[3]);
   static void RotateVectorByNormalizedQuaternion(const double v[3], const double q[4], double r[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * rotate a vector by WXYZ
    * using // https://en.wikipedia.org/wiki/Rodrigues%27_rotation_formula
    */
   static void RotateVectorByWXYZ(const float v[3], const float q[4], float r[3]);
   static void RotateVectorByWXYZ(const double v[3], const double q[4], double r[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Orthogonalize a 3x3 matrix and put the result in B.  If matrix A
    * has a negative determinant, then B will be a rotation plus a flip
@@ -1048,9 +1079,9 @@ public:
    */
   static void Orthogonalize3x3(const float A[3][3], float B[3][3]);
   static void Orthogonalize3x3(const double A[3][3], double B[3][3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Diagonalize a symmetric 3x3 matrix and return the eigenvalues in
    * w and the eigenvectors in the columns of V.  The matrix V will
@@ -1059,9 +1090,9 @@ public:
    */
   static void Diagonalize3x3(const float A[3][3], float w[3], float V[3][3]);
   static void Diagonalize3x3(const double A[3][3], double w[3], double V[3][3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Perform singular value decomposition on a 3x3 matrix.  This is not
    * done using a conventional SVD algorithm, instead it is done using
@@ -1075,7 +1106,7 @@ public:
     const float A[3][3], float U[3][3], float w[3], float VT[3][3]);
   static void SingularValueDecomposition3x3(
     const double A[3][3], double U[3][3], double w[3], double VT[3][3]);
-  //@}
+  ///@}
 
   /**
    * Solve linear equation Ax = b using Gaussian Elimination with Partial Pivoting
@@ -1164,7 +1195,7 @@ public:
    */
   static double EstimateMatrixCondition(const double* const* A, int size);
 
-  //@{
+  ///@{
   /**
    * Jacobi iteration for the solution of eigenvectors/eigenvalues of a 3x3
    * real symmetric matrix. Square 3x3 matrix a; output eigenvalues in w;
@@ -1175,9 +1206,9 @@ public:
    */
   static vtkTypeBool Jacobi(float** a, float* w, float** v);
   static vtkTypeBool Jacobi(double** a, double* w, double** v);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * JacobiN iteration for the solution of eigenvectors/eigenvalues of a nxn
    * real symmetric matrix. Square nxn matrix a; size of matrix in n; output
@@ -1189,7 +1220,7 @@ public:
    */
   static vtkTypeBool JacobiN(float** a, int n, float* w, float** v);
   static vtkTypeBool JacobiN(double** a, int n, double* w, double** v);
-  //@}
+  ///@}
 
   /**
    * Solves for the least squares best fit matrix for the homogeneous equation X'M' = 0'.
@@ -1224,7 +1255,7 @@ public:
   static vtkTypeBool SolveLeastSquares(int numberOfSamples, double** xt, int xOrder, double** yt,
     int yOrder, double** mt, int checkHomogeneous = 1);
 
-  //@{
+  ///@{
   /**
    * Convert color in RGB format (Red, Green, Blue) to HSV format
    * (Hue, Saturation, Value). The input color is not modified.
@@ -1242,9 +1273,9 @@ public:
     RGBToHSV(rgb[0], rgb[1], rgb[2], hsv, hsv + 1, hsv + 2);
   }
   static void RGBToHSV(double r, double g, double b, double* h, double* s, double* v);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert color in HSV format (Hue, Saturation, Value) to RGB
    * format (Red, Green, Blue). The input color is not modified.
@@ -1262,9 +1293,9 @@ public:
     HSVToRGB(hsv[0], hsv[1], hsv[2], rgb, rgb + 1, rgb + 2);
   }
   static void HSVToRGB(double h, double s, double v, double* r, double* g, double* b);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert color from the CIE-L*ab system to CIE XYZ.
    */
@@ -1273,9 +1304,9 @@ public:
     LabToXYZ(lab[0], lab[1], lab[2], xyz + 0, xyz + 1, xyz + 2);
   }
   static void LabToXYZ(double L, double a, double b, double* x, double* y, double* z);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert Color from the CIE XYZ system to CIE-L*ab.
    */
@@ -1284,9 +1315,9 @@ public:
     XYZToLab(xyz[0], xyz[1], xyz[2], lab + 0, lab + 1, lab + 2);
   }
   static void XYZToLab(double x, double y, double z, double* L, double* a, double* b);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert color from the CIE XYZ system to RGB.
    */
@@ -1295,9 +1326,9 @@ public:
     XYZToRGB(xyz[0], xyz[1], xyz[2], rgb + 0, rgb + 1, rgb + 2);
   }
   static void XYZToRGB(double x, double y, double z, double* r, double* g, double* b);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert color from the RGB system to CIE XYZ.
    */
@@ -1306,9 +1337,9 @@ public:
     RGBToXYZ(rgb[0], rgb[1], rgb[2], xyz + 0, xyz + 1, xyz + 2);
   }
   static void RGBToXYZ(double r, double g, double b, double* x, double* y, double* z);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert color from the RGB system to CIE-L*ab.
    * The input RGB must be values in the range [0, 1].
@@ -1320,9 +1351,9 @@ public:
     RGBToLab(rgb[0], rgb[1], rgb[2], lab + 0, lab + 1, lab + 2);
   }
   static void RGBToLab(double red, double green, double blue, double* L, double* a, double* b);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convert color from the CIE-L*ab system to RGB.
    */
@@ -1331,9 +1362,9 @@ public:
     LabToRGB(lab[0], lab[1], lab[2], rgb + 0, rgb + 1, rgb + 2);
   }
   static void LabToRGB(double L, double a, double b, double* red, double* green, double* blue);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the bounds to an uninitialized state
    */
@@ -1346,9 +1377,9 @@ public:
     bounds[4] = 1.0;
     bounds[5] = -1.0;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Are the bounds initialized?
    */
@@ -1360,7 +1391,7 @@ public:
     }
     return 1;
   }
-  //@}
+  ///@}
 
   /**
    * Clamp some value against a range, return the result.
@@ -1369,7 +1400,7 @@ public:
   template <class T>
   static T ClampValue(const T& value, const T& min, const T& max);
 
-  //@{
+  ///@{
   /**
    * Clamp some values against a range
    * The method without 'clamped_values' will perform in-place clamping.
@@ -1379,7 +1410,7 @@ public:
   static void ClampValues(double* values, int nb_values, const double range[2]);
   static void ClampValues(
     const double* values, int nb_values, const double range[2], double* clamped_values);
-  //@}
+  ///@}
 
   /**
    * Clamp a value against a range and then normalize it between 0 and 1.
@@ -1508,6 +1539,87 @@ public:
    */
   static int QuadraticRoot(double a, double b, double c, double min, double max, double* u);
 
+  /**
+   * Compute the greatest common divisor (GCD) of two positive integers m and n. If the
+   * computed GCD==1, then the two integers are coprime to one another. This is a simple,
+   * recursive implementation.
+   */
+  static vtkIdType ComputeGCD(vtkIdType m, vtkIdType n) { return (n ? ComputeGCD(n, m % n) : m); }
+
+  /**
+   * Support the convolution operations.
+   */
+  enum class ConvolutionMode
+  {
+    FULL,
+    SAME,
+    VALID
+  };
+
+  /**
+   * Compute the convolution of a sampled 1D signal by a given kernel. There are 3 different modes
+   * available:
+   *
+   * The "full" mode (default), returning the convolution at each point of overlap between
+   * the sample and the kernel. The output size is equal to sampleSize + kernelSize + 1.
+   *
+   * The "same" mode, where the convolution is computed only if the center of the kernel
+   * overlaps with the sample. The output size is equal to the sampleSize.
+   *
+   * The "valid" mode, where the convolution is computed only if the kernel overlaps completely
+   * with the sample. The output size is equal to the sampleSize - kernelSize + 1.
+   *
+   * @note By convention, here the kernel refers to the smallest input signal of the two, but it
+   * doesn't matter if it's passed as the first or the second parameter (the convolution is
+   * commutative).
+   *
+   * @note The function does nothing if iteratorBegin >= iteratorEnd (for each couple of iterators)
+   *
+   * @note The output signal is padded with zeros if its size (endOut - beginOut) is bigger than
+   * the number of generated values. If its size is smaller, the result is truncated from the end.
+   */
+  template <class Iter1, class Iter2, class Iter3>
+  static void Convolve1D(Iter1 beginSample, Iter1 endSample, Iter2 beginKernel, Iter2 endKernel,
+    Iter3 beginOut, Iter3 endOut, ConvolutionMode mode = ConvolutionMode::FULL)
+  {
+    int sampleSize = std::distance(beginSample, endSample);
+    int kernelSize = std::distance(beginKernel, endKernel);
+    int outSize = std::distance(beginOut, endOut);
+
+    if (sampleSize <= 0 || kernelSize <= 0 || outSize <= 0)
+    {
+      return;
+    }
+
+    int begin = 0;
+    int end = outSize;
+
+    switch (mode)
+    {
+      case ConvolutionMode::SAME:
+        begin = static_cast<int>(std::ceil((std::min)(sampleSize, kernelSize) / 2.0)) - 1;
+        end = begin + (std::max)(sampleSize, kernelSize);
+        break;
+      case ConvolutionMode::VALID:
+        begin = (std::min)(sampleSize, kernelSize) - 1;
+        end = begin + std::abs(sampleSize - kernelSize) + 1;
+        break;
+      case ConvolutionMode::FULL:
+      default:
+        break;
+    }
+
+    for (int i = begin; i < end; i++)
+    {
+      Iter3 out = beginOut + i - begin;
+      *out = 0;
+      for (int j = (std::max)(i - sampleSize + 1, 0); j <= (std::min)(i, kernelSize - 1); j++)
+      {
+        *out += *(beginSample + (i - j)) * *(beginKernel + j);
+      }
+    }
+  }
+
 protected:
   vtkMath() = default;
   ~vtkMath() override = default;
@@ -1623,7 +1735,7 @@ inline double vtkMath::Normalize(double v[3])
 }
 
 //----------------------------------------------------------------------------
-inline float vtkMath::Normalize2D(float v[3])
+inline float vtkMath::Normalize2D(float v[2])
 {
   float den = vtkMath::Norm2D(v);
   if (den != 0.0)
@@ -1637,7 +1749,7 @@ inline float vtkMath::Normalize2D(float v[3])
 }
 
 //----------------------------------------------------------------------------
-inline double vtkMath::Normalize2D(double v[3])
+inline double vtkMath::Normalize2D(double v[2])
 {
   double den = vtkMath::Norm2D(v);
   if (den != 0.0)
@@ -1825,6 +1937,7 @@ inline void vtkMath::TensorFromSymmetricTensor(T tensor[9])
   tensor[2] = tensor[6]; // XZ
   tensor[1] = tensor[3]; // XY
 }
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
@@ -1868,6 +1981,7 @@ inline void vtkQuaternionToMatrix3x3(const QuaternionT& quat, MatrixT& A)
 }
 } // anonymous namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 inline void vtkMath::QuaternionToMatrix3x3(const float quat[4], float A[3][3])
 {
@@ -1886,6 +2000,7 @@ inline void vtkMath::QuaternionToMatrix3x3(const QuaternionT& q, MatrixT&& A)
 {
   vtkQuaternionToMatrix3x3(q, A);
 }
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
@@ -1942,6 +2057,7 @@ inline void vtkMatrix3x3ToQuaternion(const MatrixT& A, QuaternionT& quat)
 }
 } // anonymous namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 inline void vtkMath::Matrix3x3ToQuaternion(const float A[3][3], float quat[4])
 {
@@ -1960,9 +2076,11 @@ inline void vtkMath::Matrix3x3ToQuaternion(const MatrixT& A, QuaternionT&& q)
 {
   vtkMatrix3x3ToQuaternion(A, q);
 }
+VTK_ABI_NAMESPACE_END
 
 namespace vtk_detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 // Can't specialize templates inside a template class, so we move the impl here.
 template <typename OutT>
 void RoundDoubleToIntegralIfNecessary(double val, OutT* ret)
@@ -1990,13 +2108,14 @@ inline void RoundDoubleToIntegralIfNecessary(double val, float* retVal)
     double min = static_cast<double>(vtkTypeTraits<float>::Min());
     double max = static_cast<double>(vtkTypeTraits<float>::Max());
     val = vtkMath::ClampValue(val, min, max);
-    *retVal = static_cast<float>(val);
   }
-  else
-    *retVal = val;
+
+  *retVal = static_cast<float>(val);
 }
+VTK_ABI_NAMESPACE_END
 } // end namespace vtk_detail
 
+VTK_ABI_NAMESPACE_BEGIN
 //-----------------------------------------------------------------------------
 #if defined(VTK_HAS_ISINF) || defined(VTK_HAS_STD_ISINF)
 #define VTK_MATH_ISINF_IS_INLINE
@@ -2038,4 +2157,5 @@ inline bool vtkMath::IsFinite(double x)
 }
 #endif
 
+VTK_ABI_NAMESPACE_END
 #endif
