@@ -24,6 +24,7 @@
 /* Monte Carlo and Quasi-Monte Carlo Methods 1998,        */
 /* Springer, 2000, pp 56--69.                             */
 
+// NOLINTNEXTLINE(bugprone-suspicious-include)
 #include "vtkMersenneTwister_Private.cxx"
 #include "vtkMultiThreader.h"
 #include "vtkNew.h"
@@ -112,10 +113,10 @@ protected:
   mt_parameter_map Parameters;
 };
 
-static const int NMersenneExponents = 15;
-static const int MersenneExponents[NMersenneExponents] = { 521, 607, 1279, 2203, 2281, 3217, 4253,
-  4423, 9689, 9941, 11213, 19937, 21701, 23209, 44497 };
-static const int* MersenneExponentsEnd = MersenneExponents + NMersenneExponents;
+const int NMersenneExponents = 15;
+const int MersenneExponents[NMersenneExponents] = { 521, 607, 1279, 2203, 2281, 3217, 4253, 4423,
+  9689, 9941, 11213, 19937, 21701, 23209, 44497 };
+const int* MersenneExponentsEnd = MersenneExponents + NMersenneExponents;
 }
 
 #include <algorithm>
@@ -123,6 +124,7 @@ static const int* MersenneExponentsEnd = MersenneExponents + NMersenneExponents;
 #include "vtkMersenneTwister.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMersenneTwisterInternals : public MersenneTwister
 {
 public:
@@ -156,7 +158,7 @@ void vtkMersenneTwister::InitializeSequence(
     periodExp = MersenneExponents[periodExp % 15];
   }
 
-  if (this->Internal->Values.insert(vtkMersenneTwisterInternals::Value(id, 0.)).second == false)
+  if (!this->Internal->Values.insert(vtkMersenneTwisterInternals::Value(id, 0.)).second)
   {
     vtkWarningMacro(<< "Initializing process " << id << " which is already "
                     << "initialized. This may break sequence encapsulation.");
@@ -226,3 +228,4 @@ void vtkMersenneTwister::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
