@@ -16,27 +16,32 @@
 #ifndef vtkMeta_h
 #define vtkMeta_h
 
+#include "vtkABINamespace.h"
+
 #include <type_traits>
 #include <utility>
 
 /**
- * @file vtkMeta
+ * @file vtkMeta.h
  * This file contains a variety of metaprogramming constructs for working
  * with vtk types.
  */
 
 // Forward decs for StripPointers:
+VTK_ABI_NAMESPACE_BEGIN
 template <typename ArrayType>
 class vtkNew;
 template <typename ArrayType>
 class vtkSmartPointer;
 template <typename ArrayType>
 class vtkWeakPointer;
+VTK_ABI_NAMESPACE_END
 
 namespace vtk
 {
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 //------------------------------------------------------------------------------
 // Strip vtkNew, vtkSmartPointer, etc from a type.
@@ -86,6 +91,7 @@ public:
   static constexpr bool value = bool_constant::value;
 };
 
+VTK_ABI_NAMESPACE_END
 }
 } // end namespace vtk::detail
 
