@@ -49,6 +49,7 @@
 
 #include <type_traits> // for is_base_of
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkObjectBase;
 
 template <class T>
@@ -110,9 +111,9 @@ public:
 
     o.Object = nullptr;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Deletes reference to instance of T.
    */
@@ -127,7 +128,7 @@ public:
       obj->Delete();
     }
   }
-  //@}
+  ///@}
 
   /**
    * Enable pointer-like dereference syntax. Returns a pointer to the contained
@@ -135,7 +136,7 @@ public:
    */
   T* operator->() const noexcept { return this->Object; }
 
-  //@{
+  ///@{
   /**
    * Get a raw pointer to the contained object. When using this function be
    * careful that the reference count does not drop to 0 when using the pointer
@@ -145,7 +146,7 @@ public:
   T* GetPointer() const noexcept { return this->Object; }
   T* Get() const noexcept { return this->Object; }
   operator T*() const noexcept { return static_cast<T*>(this->Object); }
-  //@}
+  ///@}
   /**
    * Dereference the pointer and return a reference to the contained object.
    * When using this function be careful that the reference count does not
@@ -154,11 +155,23 @@ public:
    */
   T& operator*() const noexcept { return *static_cast<T*>(this->Object); }
 
+  /**
+   * Move assignment operator.
+   */
+  vtkNew<T>& operator=(vtkNew<T>&& other) noexcept
+  {
+    this->Reset();
+    this->Object = other.Object;
+    other.Object = nullptr;
+    return *this;
+  }
+
 private:
   vtkNew(vtkNew<T> const&) = delete;
   void operator=(vtkNew<T> const&) = delete;
   T* Object;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkNew.h
