@@ -33,9 +33,12 @@
 Do_not_include_vtkOStreamWrapper_directly_vtkSystemIncludes_includes_it;
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIndent;
 class vtkObjectBase;
 class vtkLargeInteger;
+template <typename T>
+class vtkSmartPointer;
 class vtkSmartPointerBase;
 class vtkStdString;
 
@@ -44,14 +47,14 @@ class VTKCOMMONCORE_EXPORT VTK_WRAPEXCLUDE vtkOStreamWrapper
   class std_string;
 
 public:
-  //@{
+  ///@{
   /**
    * Construct class to reference a real ostream.  All methods and
    * operators will be forwarded.
    */
   vtkOStreamWrapper(ostream& os);
   vtkOStreamWrapper(vtkOStreamWrapper& r);
-  //@}
+  ///@}
 
   virtual ~vtkOStreamWrapper();
 
@@ -62,7 +65,7 @@ public:
   {
   };
 
-  //@{
+  ///@{
   /**
    * Forward this output operator to the real ostream.
    */
@@ -87,7 +90,7 @@ public:
   vtkOStreamWrapper& operator<<(float);
   vtkOStreamWrapper& operator<<(double);
   vtkOStreamWrapper& operator<<(bool);
-  //@}
+  ///@}
 
   // Work-around for IBM Visual Age bug in overload resolution.
 #if defined(__IBMCPP__)
@@ -115,6 +118,14 @@ public:
     return *this << reinterpret_cast<std_string const&>(s);
   }
 
+  // Accept vtkSmartPointer for output.
+  template <typename T>
+  vtkOStreamWrapper& operator<<(const vtkSmartPointer<T>& ptr)
+  {
+    this->ostr << (static_cast<T*>(ptr));
+    return *this;
+  }
+
   /**
    * Forward the write method to the real stream.
    */
@@ -142,13 +153,13 @@ public:
    */
   void flush();
 
-  //@{
+  ///@{
   /**
    * Implementation detail to allow macros to provide an endl that may
    * or may not be used.
    */
   static void UseEndl(const EndlType&) {}
-  //@}
+  ///@}
 protected:
   // Reference to the real ostream.
   ostream& ostr;
@@ -158,5 +169,6 @@ private:
   vtkOStreamWrapper& operator<<(std_string const&);
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkOStreamWrapper.h
