@@ -26,6 +26,7 @@
 #include <vector>
 
 // Initialize static member that controls warning display
+VTK_ABI_NAMESPACE_BEGIN
 static int vtkObjectGlobalWarningDisplay = 1;
 
 //------------------------------------------------------------------------------
@@ -141,7 +142,7 @@ public:
   // "iterators" being used need to be invalidated. So we keep a stack (a
   // vector) of indicators if the list has been modified. When something
   // modifies the list the entire vector is marked as true (modified). Each
-  // depth of recusion then resets its entry in LostModified to false as it
+  // depth of recursion then resets its entry in LostModified to false as it
   // resets its iteration.
   std::vector<bool> ListModified;
 
@@ -505,7 +506,7 @@ int vtkSubjectHelper::InvokeEvent(unsigned long event, void* callData, vtkObject
   // also do something that causes another event to be invoked in this object.
   // That means that this method will be called recursively, which is why we use
   // a std::vector to store ListModified where the size of the vector is equal
-  // to the depth of recusion. We always push upon entry to this method and
+  // to the depth of recursion. We always push upon entry to this method and
   // pop before returning.
   this->ListModified.push_back(false);
 
@@ -1008,3 +1009,4 @@ std::string vtkObject::GetObjectDescription() const
   }
   return s.str();
 }
+VTK_ABI_NAMESPACE_END
