@@ -47,6 +47,7 @@
 #include "vtkTimeStamp.h"
 #include "vtkWeakPointerBase.h" // needed for vtkWeakPointer
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSubjectHelper;
 class vtkCommand;
 
@@ -279,7 +280,7 @@ private:
 
   /**
    * Following classes (vtkClassMemberCallbackBase,
-   * vtkClassMemberCallback, and vtkClassMemberHanderPointer)
+   * vtkClassMemberCallback, and vtkClassMemberHandlerPointer)
    * along with vtkObjectCommandInternal are for supporting
    * templated AddObserver() overloads that allow developers
    * to add event callbacks that are class member functions.
@@ -420,5 +421,6 @@ private:
   ///@}
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkObject.h
