@@ -25,7 +25,7 @@
 
 #include <cctype>
 
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryCollection* vtkObjectFactory::RegisteredFactories = nullptr;
 static unsigned int vtkObjectFactoryRegistryCleanupCounter = 0;
 
@@ -45,22 +45,20 @@ vtkObjectFactoryRegistryCleanup::~vtkObjectFactoryRegistryCleanup()
 // Create an instance of a named vtk object using the loaded
 // factories
 
-vtkObject* vtkObjectFactory::CreateInstance(const char* vtkclassname,
-                                            bool)
+vtkObject* vtkObjectFactory::CreateInstance(const char* vtkclassname, bool)
 {
-  if(!vtkObjectFactory::RegisteredFactories)
+  if (!vtkObjectFactory::RegisteredFactories)
   {
     vtkObjectFactory::Init();
   }
 
   vtkObjectFactory* factory;
   vtkCollectionSimpleIterator osit;
-  for(vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
-      (factory = vtkObjectFactory::RegisteredFactories->
-       GetNextObjectFactory(osit));)
+  for (vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
+       (factory = vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
   {
     vtkObject* newobject = factory->CreateObject(vtkclassname);
-    if(newobject)
+    if (newobject)
     {
       return newobject;
     }
@@ -73,7 +71,7 @@ vtkObject* vtkObjectFactory::CreateInstance(const char* vtkclassname,
 void vtkObjectFactory::Init()
 {
   // Don't do anything if we are already initialized
-  if(vtkObjectFactory::RegisteredFactories)
+  if (vtkObjectFactory::RegisteredFactories)
   {
     return;
   }
@@ -83,14 +81,10 @@ void vtkObjectFactory::Init()
   vtkObjectFactory::LoadDynamicFactories();
 }
 
-
 // Register any factories that are always present in VTK like
 // the OpenGL factory, currently this is not done.
 
-void vtkObjectFactory::RegisterDefaults()
-{
-}
-
+void vtkObjectFactory::RegisterDefaults() {}
 
 // Load all libraries in VTK_AUTOLOAD_PATH
 
@@ -108,14 +102,14 @@ void vtkObjectFactory::LoadDynamicFactories()
 #ifndef _WIN32_WCE
   LoadPath = getenv("VTK_AUTOLOAD_PATH");
 #endif
-  if(LoadPath == nullptr || LoadPath[0] == 0)
+  if (LoadPath == nullptr || LoadPath[0] == 0)
   {
     return;
   }
   std::string CurrentPath;
   CurrentPath.reserve(strlen(LoadPath) + 1);
   char* SeparatorPosition = LoadPath; // initialize to env variable
-  while(SeparatorPosition)
+  while (SeparatorPosition)
   {
     CurrentPath.clear();
 
@@ -123,7 +117,7 @@ void vtkObjectFactory::LoadDynamicFactories()
     // find PathSeparator in LoadPath
     SeparatorPosition = strchr(LoadPath, PathSeparator);
     // if not found then use the whole string
-    if(SeparatorPosition == nullptr)
+    if (SeparatorPosition == nullptr)
     {
       PathLength = strlen(LoadPath);
     }
@@ -145,7 +139,7 @@ void vtkObjectFactory::LoadDynamicFactories()
 static char* CreateFullPath(const std::string& path, const char* file)
 {
   size_t lenpath = path.size();
-  char* ret = new char[lenpath + strlen(file)+2];
+  char* ret = new char[lenpath + strlen(file) + 2];
 #ifdef _WIN32
   const char sep = '\\';
 #else
@@ -153,10 +147,10 @@ static char* CreateFullPath(const std::string& path, const char* file)
 #endif
   // make sure the end of path is a separator
   strcpy(ret, path.c_str());
-  if(ret[lenpath-1] != sep)
+  if (ret[lenpath - 1] != sep)
   {
     ret[lenpath] = sep;
-    ret[lenpath+1] = 0;
+    ret[lenpath + 1] = 0;
   }
   strcat(ret, file);
   return ret;
@@ -164,10 +158,9 @@ static char* CreateFullPath(const std::string& path, const char* file)
 
 // A file scope typedef to make the cast code to the load
 // function cleaner to read.
-typedef vtkObjectFactory* (* VTK_LOAD_FUNCTION)();
-typedef const char* (* VTK_VERSION_FUNCTION)();
-typedef const char* (* VTK_COMPILER_FUNCTION)();
-
+typedef vtkObjectFactory* (*VTK_LOAD_FUNCTION)();
+typedef const char* (*VTK_VERSION_FUNCTION)();
+typedef const char* (*VTK_COMPILER_FUNCTION)();
 
 // A file scoped function to determine if a file has
 // the shared library extension in its name, this converts name to lower
@@ -177,80 +170,62 @@ typedef const char* (* VTK_COMPILER_FUNCTION)();
 inline int vtkNameIsSharedLibrary(const char* name)
 {
   int len = static_cast<int>(strlen(name));
-  char* copy = new char[len+1];
+  char* copy = new char[len + 1];
 
-  for(int i = 0; i < len; i++)
+  for (int i = 0; i < len; i++)
   {
     copy[i] = static_cast<char>(tolower(name[i]));
   }
   copy[len] = 0;
   char* ret = strstr(copy, vtkDynamicLoader::LibExtension());
-  delete [] copy;
+  delete[] copy;
   return (ret != nullptr);
 }
 
 void vtkObjectFactory::LoadLibrariesInPath(const std::string& path)
 {
   vtksys::Directory dir;
-  if(!dir.Load(path))
+  if (!dir.Load(path))
   {
     return;
   }
 
   // Attempt to load each file in the directory as a shared library
-  for(unsigned long i = 0; i < dir.GetNumberOfFiles(); i++)
+  for (unsigned long i = 0; i < dir.GetNumberOfFiles(); i++)
   {
     const char* file = dir.GetFile(i);
     // try to make sure the file has at least the extension
     // for a shared library in it.
-    if(vtkNameIsSharedLibrary(file))
+    if (vtkNameIsSharedLibrary(file))
     {
       char* fullpath = CreateFullPath(path, file);
       vtkLibHandle lib = vtkDynamicLoader::OpenLibrary(fullpath);
-      if(lib)
+      if (lib)
       {
-        // Look for the symbol vtkLoad, vtkGetFactoryCompilerUsed,
-        // and vtkGetFactoryVersion in the library
-        VTK_LOAD_FUNCTION loadfunction
-          = (VTK_LOAD_FUNCTION)(
-          vtkDynamicLoader::GetSymbolAddress(lib,
-                                             "vtkLoad"));
-        VTK_COMPILER_FUNCTION compilerFunction
-          = (VTK_COMPILER_FUNCTION)(
-          vtkDynamicLoader::GetSymbolAddress(lib,
-                                             "vtkGetFactoryCompilerUsed"));
-        VTK_VERSION_FUNCTION versionFunction
-          = (VTK_VERSION_FUNCTION)(
-          vtkDynamicLoader::GetSymbolAddress(lib,
-                                             "vtkGetFactoryVersion"));
+        // Look for the symbol vtkLoad and vtkGetFactoryVersion in the library
+        VTK_LOAD_FUNCTION loadfunction =
+          (VTK_LOAD_FUNCTION)(vtkDynamicLoader::GetSymbolAddress(lib, "vtkLoad"));
+        VTK_VERSION_FUNCTION versionFunction =
+          (VTK_VERSION_FUNCTION)(vtkDynamicLoader::GetSymbolAddress(lib, "vtkGetFactoryVersion"));
         // if the symbol is found call it to create the factory
         // from the library
-        if(loadfunction && compilerFunction && versionFunction)
+        if (loadfunction && versionFunction)
         {
-          const char* compiler = (*compilerFunction)();
           const char* version = (*versionFunction)();
-          if(strcmp(compiler, VTK_CXX_COMPILER) ||
-             strcmp(version, vtkVersion::GetVTKSourceVersion()))
+          if (strcmp(version, vtkVersion::GetVTKSourceVersion()) != 0)
           {
-            vtkGenericWarningMacro(
-              << "Incompatible factory rejected:"
-              << "\nRunning VTK compiled with: " <<  VTK_CXX_COMPILER
-              << "\nFactory compiled with: " << compiler
-              << "\nRunning VTK version: " << vtkVersion::GetVTKSourceVersion()
-              << "\nFactory version: " << version
-              << "\nPath to rejected factory: " << fullpath << "\n");
+            vtkGenericWarningMacro(<< "Incompatible factory rejected:"
+                                   << "\nRunning VTK version: " << vtkVersion::GetVTKSourceVersion()
+                                   << "\nFactory version: " << version
+                                   << "\nPath to rejected factory: " << fullpath << "\n");
           }
           else
           {
             vtkObjectFactory* newfactory = (*loadfunction)();
-            newfactory->LibraryVTKVersion =
-              strcpy(new char[strlen(version)+1], version);
-            newfactory->LibraryCompilerUsed =
-              strcpy(new char[strlen(compiler)+1], compiler);
+            newfactory->LibraryVTKVersion = strcpy(new char[strlen(version) + 1], version);
             // initialize class members if load worked
             newfactory->LibraryHandle = static_cast<void*>(lib);
-            newfactory->LibraryPath =
-              strcpy(new char[strlen(fullpath)+1], fullpath);
+            newfactory->LibraryPath = strcpy(new char[strlen(fullpath) + 1], fullpath);
             vtkObjectFactory::RegisterFactory(newfactory);
             newfactory->Delete();
           }
@@ -258,15 +233,17 @@ void vtkObjectFactory::LoadLibrariesInPath(const std::string& path)
         // if only the loadfunction is found, then warn
         else if (loadfunction)
         {
-          vtkGenericWarningMacro("Old Style Factory not loaded.  Shared object has vtkLoad, but is missing vtkGetFactoryCompilerUsed and vtkGetFactoryVersion.  Recompile factory: " << fullpath << ", and use VTK_FACTORY_INTERFACE_IMPLEMENT macro.");
+          vtkGenericWarningMacro(
+            "Old Style Factory not loaded.  Shared object has vtkLoad, but is missing "
+            "vtkGetFactoryVersion.  Recompile factory: "
+            << fullpath << ", and use VTK_FACTORY_INTERFACE_IMPLEMENT macro.");
         }
       }
-      delete [] fullpath;
+      delete[] fullpath;
     }
   }
 }
 
-
 // Recheck the VTK_AUTOLOAD_PATH for new libraries
 
 void vtkObjectFactory::ReHash()
@@ -285,26 +262,23 @@ vtkObjectFactory::vtkObjectFactory()
   this->SizeOverrideArray = 0;
   this->OverrideArrayLength = 0;
   this->LibraryVTKVersion = nullptr;
-  this->LibraryCompilerUsed = nullptr;
 }
 
-
 // Unload the library and free the path string
 vtkObjectFactory::~vtkObjectFactory()
 {
-  delete [] this->LibraryVTKVersion;
-  delete [] this->LibraryCompilerUsed;
-  delete [] this->LibraryPath;
+  delete[] this->LibraryVTKVersion;
+  delete[] this->LibraryPath;
   this->LibraryPath = nullptr;
 
-  for(int i =0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    delete [] this->OverrideClassNames[i];
-    delete [] this->OverrideArray[i].Description;
-    delete [] this->OverrideArray[i].OverrideWithName;
+    delete[] this->OverrideClassNames[i];
+    delete[] this->OverrideArray[i].Description;
+    delete[] this->OverrideArray[i].OverrideWithName;
   }
-  delete [] this->OverrideArray;
-  delete [] this->OverrideClassNames;
+  delete[] this->OverrideArray;
+  delete[] this->OverrideClassNames;
   this->OverrideArray = nullptr;
   this->OverrideClassNames = nullptr;
 }
@@ -312,44 +286,31 @@ vtkObjectFactory::~vtkObjectFactory()
 // Add a factory to the registered list
 void vtkObjectFactory::RegisterFactory(vtkObjectFactory* factory)
 {
-  if(factory->LibraryHandle == nullptr)
+  if (factory->LibraryHandle == nullptr)
   {
     const char* nonDynamicName = "Non-Dynamicly loaded factory";
-    factory->LibraryPath = strcpy(new char[strlen(nonDynamicName)+1],
-                                  nonDynamicName);
-    factory->LibraryCompilerUsed =
-      strcpy(new char[strlen(VTK_CXX_COMPILER)+1], VTK_CXX_COMPILER);
-    factory->LibraryVTKVersion =
-      strcpy(new char[strlen(vtkVersion::GetVTKSourceVersion())+1],
-             vtkVersion::GetVTKSourceVersion());
+    factory->LibraryPath = strcpy(new char[strlen(nonDynamicName) + 1], nonDynamicName);
+    factory->LibraryVTKVersion = strcpy(
+      new char[strlen(vtkVersion::GetVTKSourceVersion()) + 1], vtkVersion::GetVTKSourceVersion());
   }
   else
   {
-    if(strcmp(factory->LibraryCompilerUsed,
-              VTK_CXX_COMPILER) != 0)
+    if (strcmp(factory->LibraryVTKVersion, vtkVersion::GetVTKSourceVersion()) != 0)
     {
       vtkGenericWarningMacro(<< "Possible incompatible factory load:"
-      << "\nRunning vtk compiled with :\n" <<  VTK_CXX_COMPILER
-      << "\nLoaded Factory compiled with:\n" << factory->LibraryCompilerUsed
-      << "\nRejecting factory:\n" << factory->LibraryPath << "\n");
+                             << "\nRunning vtk version :\n"
+                             << vtkVersion::GetVTKSourceVersion() << "\nLoaded Factory version:\n"
+                             << factory->LibraryVTKVersion << "\nRejecting factory:\n"
+                             << factory->LibraryPath << "\n");
       return;
     }
-    if(strcmp(factory->LibraryVTKVersion,
-              vtkVersion::GetVTKSourceVersion()) != 0)
-    {
-        vtkGenericWarningMacro(<< "Possible incompatible factory load:"
-        << "\nRunning vtk version :\n" << vtkVersion::GetVTKSourceVersion()
-        << "\nLoaded Factory version:\n" << factory->LibraryVTKVersion
-        << "\nRejecting factory:\n" << factory->LibraryPath << "\n");
-        return;
-    }
-    if(strcmp(factory->GetVTKSourceVersion(),
-              vtkVersion::GetVTKSourceVersion()) != 0)
+    if (strcmp(factory->GetVTKSourceVersion(), vtkVersion::GetVTKSourceVersion()) != 0)
     {
       vtkGenericWarningMacro(<< "Possible incompatible factory load:"
-      << "\nRunning vtk version :\n" << vtkVersion::GetVTKSourceVersion()
-      << "\nLoaded Factory version:\n" << factory->GetVTKSourceVersion()
-      << "\nRejecting factory:\n" << factory->LibraryPath << "\n");
+                             << "\nRunning vtk version :\n"
+                             << vtkVersion::GetVTKSourceVersion() << "\nLoaded Factory version:\n"
+                             << factory->GetVTKSourceVersion() << "\nRejecting factory:\n"
+                             << factory->LibraryPath << "\n");
       return;
     }
   }
@@ -364,27 +325,21 @@ void vtkObjectFactory::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   if (this->LibraryPath)
   {
-    os << indent
-       << "Factory DLL path: " << this->LibraryPath << "\n";
+    os << indent << "Factory DLL path: " << this->LibraryPath << "\n";
   }
   if (this->LibraryVTKVersion)
   {
     os << indent << "Library version: " << this->LibraryVTKVersion << "\n";
   }
-  if (this->LibraryCompilerUsed)
-  {
-    os << indent << "Compiler used: " << this->LibraryCompilerUsed << "\n";
-  }
   os << indent << "Factory description: " << this->GetDescription() << endl;
   int num = this->GetNumberOfOverrides();
   os << indent << "Factory overrides " << num << " classes:" << endl;
   indent = indent.GetNextIndent();
-  for(int i =0; i < num; i++)
+  for (int i = 0; i < num; i++)
   {
-    os << indent << "Class : " <<  this->GetClassOverrideName(i) << endl;
-    os << indent << "Overridden with: " <<  this->GetClassOverrideWithName(i)
-       << endl;
-    os << indent << "Enable flag: " <<  this->GetEnableFlag(i) << endl;
+    os << indent << "Class : " << this->GetClassOverrideName(i) << endl;
+    os << indent << "Overridden with: " << this->GetClassOverrideWithName(i) << endl;
+    os << indent << "Enable flag: " << this->GetEnableFlag(i) << endl;
     os << endl;
   }
 }
@@ -394,7 +349,7 @@ void vtkObjectFactory::UnRegisterFactory(vtkObjectFactory* factory)
 {
   void* lib = factory->LibraryHandle;
   vtkObjectFactory::RegisteredFactories->RemoveItem(factory);
-  if(lib)
+  if (lib)
   {
     vtkDynamicLoader::CloseLibrary(static_cast<vtkLibHandle>(lib));
   }
@@ -404,20 +359,19 @@ void vtkObjectFactory::UnRegisterFactory(vtkObjectFactory* factory)
 void vtkObjectFactory::UnRegisterAllFactories()
 {
   // do not do anything if this is null
-  if( ! vtkObjectFactory::RegisteredFactories )
+  if (!vtkObjectFactory::RegisteredFactories)
   {
     return;
   }
   int num = vtkObjectFactory::RegisteredFactories->GetNumberOfItems();
   // collect up all the library handles so they can be closed
   // AFTER the factory has been deleted.
-  void** libs = new void*[num+1];
+  void** libs = new void*[num + 1];
   vtkObjectFactory* factory;
   vtkCollectionSimpleIterator osit;
   vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
   int index = 0;
-  while((factory =
-         vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit)))
+  while ((factory = vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit)))
   {
     libs[index++] = factory->LibraryHandle;
   }
@@ -425,32 +379,27 @@ void vtkObjectFactory::UnRegisterAllFactories()
   vtkObjectFactory::RegisteredFactories->Delete();
   vtkObjectFactory::RegisteredFactories = nullptr;
   // now close the libraries
-  for(int i = 0; i < num; i++)
+  for (int i = 0; i < num; i++)
   {
     void* lib = libs[i];
-    if(lib)
+    if (lib)
     {
       vtkDynamicLoader::CloseLibrary(reinterpret_cast<vtkLibHandle>(lib));
     }
   }
-  delete [] libs;
+  delete[] libs;
 }
 
-
 // Register an override function with a factory.
-void vtkObjectFactory::RegisterOverride(const char* classOverride,
-                                        const char* subclass,
-                                        const char* description,
-                                        int enableFlag,
-                                        CreateFunction createFunction)
+void vtkObjectFactory::RegisterOverride(const char* classOverride, const char* subclass,
+  const char* description, int enableFlag, CreateFunction createFunction)
 {
   this->GrowOverrideArray();
   int nextIndex = this->OverrideArrayLength;
   this->OverrideArrayLength++;
-  char* className = strcpy(new char[strlen(classOverride)+1], classOverride);
-  char* desc = strcpy(new char[strlen(description)+1], description);
-  char* ocn =  strcpy(new char[strlen(subclass)+1],
-                      subclass);
+  char* className = strcpy(new char[strlen(classOverride) + 1], classOverride);
+  char* desc = strcpy(new char[strlen(description) + 1], description);
+  char* ocn = strcpy(new char[strlen(subclass) + 1], subclass);
   this->OverrideClassNames[nextIndex] = className;
   this->OverrideArray[nextIndex].Description = desc;
   this->OverrideArray[nextIndex].OverrideWithName = ocn;
@@ -461,10 +410,10 @@ void vtkObjectFactory::RegisterOverride(const char* classOverride,
 // Create an instance of an object
 vtkObject* vtkObjectFactory::CreateObject(const char* vtkclassname)
 {
-  for(int i=0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    if(this->OverrideArray[i].EnabledFlag &&
-       strcmp(this->OverrideClassNames[i], vtkclassname) == 0)
+    if (this->OverrideArray[i].EnabledFlag &&
+      strcmp(this->OverrideClassNames[i], vtkclassname) == 0)
     {
       return (*this->OverrideArray[i].CreateCallback)();
     }
@@ -475,19 +424,19 @@ vtkObject* vtkObjectFactory::CreateObject(const char* vtkclassname)
 // grow the array if the length is greater than the size.
 void vtkObjectFactory::GrowOverrideArray()
 {
-  if(this->OverrideArrayLength+1 > this->SizeOverrideArray)
+  if (this->OverrideArrayLength + 1 > this->SizeOverrideArray)
   {
     int newLength = this->OverrideArrayLength + 50;
     OverrideInformation* newArray = new OverrideInformation[newLength];
     char** newNameArray = new char*[newLength];
-    for(int i =0; i < this->OverrideArrayLength; i++)
+    for (int i = 0; i < this->OverrideArrayLength; i++)
     {
       newNameArray[i] = this->OverrideClassNames[i];
       newArray[i] = this->OverrideArray[i];
     }
-    delete [] this->OverrideClassNames;
+    delete[] this->OverrideClassNames;
     this->OverrideClassNames = newNameArray;
-    delete [] this->OverrideArray;
+    delete[] this->OverrideArray;
     this->OverrideArray = newArray;
   }
 }
@@ -518,22 +467,21 @@ const char* vtkObjectFactory::GetOverrideDescription(int index)
 }
 
 // Set the enable flag for a class / subclassName pair
-void vtkObjectFactory::SetEnableFlag(vtkTypeBool flag,
-                                     const char* className,
-                                     const char* subclassName)
+void vtkObjectFactory::SetEnableFlag(
+  vtkTypeBool flag, const char* className, const char* subclassName)
 {
-  for(int i =0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    if(strcmp(this->OverrideClassNames[i], className) == 0)
+    if (strcmp(this->OverrideClassNames[i], className) == 0)
     {
       // if subclassName is null, then set on className match
-      if(!subclassName)
+      if (!subclassName)
       {
         this->OverrideArray[i].EnabledFlag = flag;
       }
       else
       {
-        if(strcmp(this->OverrideArray[i].OverrideWithName, subclassName) == 0)
+        if (strcmp(this->OverrideArray[i].OverrideWithName, subclassName) == 0)
         {
           this->OverrideArray[i].EnabledFlag = flag;
         }
@@ -543,14 +491,13 @@ void vtkObjectFactory::SetEnableFlag(vtkTypeBool flag,
 }
 
 // Get the enable flag for a className/subclassName pair
-vtkTypeBool vtkObjectFactory::GetEnableFlag(const char* className,
-                                        const char* subclassName)
+vtkTypeBool vtkObjectFactory::GetEnableFlag(const char* className, const char* subclassName)
 {
-  for(int i =0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    if(strcmp(this->OverrideClassNames[i], className) == 0)
+    if (strcmp(this->OverrideClassNames[i], className) == 0)
     {
-      if(strcmp(this->OverrideArray[i].OverrideWithName, subclassName) == 0)
+      if (strcmp(this->OverrideArray[i].OverrideWithName, subclassName) == 0)
       {
         return this->OverrideArray[i].EnabledFlag;
       }
@@ -562,9 +509,9 @@ vtkTypeBool vtkObjectFactory::GetEnableFlag(const char* className,
 // Set the EnabledFlag to 0 for a given classname
 void vtkObjectFactory::Disable(const char* className)
 {
-  for(int i =0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    if(strcmp(this->OverrideClassNames[i], className) == 0)
+    if (strcmp(this->OverrideClassNames[i], className) == 0)
     {
       this->OverrideArray[i].EnabledFlag = 0;
     }
@@ -574,9 +521,9 @@ void vtkObjectFactory::Disable(const char* className)
 // 1,0 is the class overridden by className
 int vtkObjectFactory::HasOverride(const char* className)
 {
-  for(int i =0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    if(strcmp(this->OverrideClassNames[i], className) == 0)
+    if (strcmp(this->OverrideClassNames[i], className) == 0)
     {
       return 1;
     }
@@ -585,14 +532,13 @@ int vtkObjectFactory::HasOverride(const char* className)
 }
 
 // 1,0 is the class overridden by className/subclassName pair
-int vtkObjectFactory::HasOverride(const char* className,
-                                  const char* subclassName)
+int vtkObjectFactory::HasOverride(const char* className, const char* subclassName)
 {
-  for(int i =0; i < this->OverrideArrayLength; i++)
+  for (int i = 0; i < this->OverrideArrayLength; i++)
   {
-    if(strcmp(this->OverrideClassNames[i], className) == 0)
+    if (strcmp(this->OverrideClassNames[i], className) == 0)
     {
-      if(strcmp(this->OverrideArray[i].OverrideWithName, subclassName) == 0)
+      if (strcmp(this->OverrideArray[i].OverrideWithName, subclassName) == 0)
       {
         return 1;
       }
@@ -601,10 +547,9 @@ int vtkObjectFactory::HasOverride(const char* className,
   return 0;
 }
 
-
 vtkObjectFactoryCollection* vtkObjectFactory::GetRegisteredFactories()
 {
-  if(!vtkObjectFactory::RegisteredFactories)
+  if (!vtkObjectFactory::RegisteredFactories)
   {
     vtkObjectFactory::Init();
   }
@@ -612,17 +557,15 @@ vtkObjectFactoryCollection* vtkObjectFactory::GetRegisteredFactories()
   return vtkObjectFactory::RegisteredFactories;
 }
 
-
 // 1,0 is the className overridden by any registered factories
 int vtkObjectFactory::HasOverrideAny(const char* className)
 {
   vtkObjectFactory* factory;
   vtkCollectionSimpleIterator osit;
-  for(vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
-      (factory =
-       vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
+  for (vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
+       (factory = vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
   {
-    if(factory->HasOverride(className))
+    if (factory->HasOverride(className))
     {
       return 1;
     }
@@ -631,29 +574,26 @@ int vtkObjectFactory::HasOverrideAny(const char* className)
 }
 
 // collect up information about current registered factories
-void vtkObjectFactory::GetOverrideInformation(const char* name,
-                                              vtkOverrideInformationCollection*
-                                              ret)
+void vtkObjectFactory::GetOverrideInformation(
+  const char* name, vtkOverrideInformationCollection* ret)
 {
   // create the collection to return
   vtkOverrideInformation* overInfo; // info object pointer
-  vtkObjectFactory* factory; // factory pointer for traversal
+  vtkObjectFactory* factory;        // factory pointer for traversal
   vtkCollectionSimpleIterator osit;
   vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
-  for(;(factory =
-      vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
+  for (; (factory = vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
   {
-    for(int i =0; i < factory->OverrideArrayLength; i++)
+    for (int i = 0; i < factory->OverrideArrayLength; i++)
     {
-      if( strcmp(name, factory->OverrideClassNames[i]) == 0)
+      if (strcmp(name, factory->OverrideClassNames[i]) == 0)
       {
         // Create a new override info class
         overInfo = vtkOverrideInformation::New();
         // Set the class name
         overInfo->SetClassOverrideName(factory->OverrideClassNames[i]);
         // Set the override class name
-        overInfo->SetClassOverrideWithName(
-          factory->OverrideArray[i].OverrideWithName);
+        overInfo->SetClassOverrideWithName(factory->OverrideArray[i].OverrideWithName);
         // Set the Description for the override
         overInfo->SetDescription(factory->OverrideArray[i].Description);
         // Set the factory for the override
@@ -667,55 +607,44 @@ void vtkObjectFactory::GetOverrideInformation(const char* name,
 }
 
 // set enable flag for all registered factories for the given className
-void vtkObjectFactory::SetAllEnableFlags(vtkTypeBool flag,
-                                         const char* className)
+void vtkObjectFactory::SetAllEnableFlags(vtkTypeBool flag, const char* className)
 {
   vtkObjectFactory* factory;
   vtkCollectionSimpleIterator osit;
-  for(vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
-      (factory =
-       vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
+  for (vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
+       (factory = vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
   {
     factory->SetEnableFlag(flag, className, nullptr);
   }
-
 }
 
 // set enable flag for the first factory that that
 // has an override for className/subclassName pair
-void vtkObjectFactory::SetAllEnableFlags(vtkTypeBool flag,
-                                         const char* className,
-                                         const char* subclassName)
+void vtkObjectFactory::SetAllEnableFlags(
+  vtkTypeBool flag, const char* className, const char* subclassName)
 {
   vtkObjectFactory* factory;
   vtkCollectionSimpleIterator osit;
-  for(vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
-      (factory =
-       vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
+  for (vtkObjectFactory::RegisteredFactories->InitTraversal(osit);
+       (factory = vtkObjectFactory::RegisteredFactories->GetNextObjectFactory(osit));)
   {
     factory->SetEnableFlag(flag, className, subclassName);
   }
 }
 
-
-
-
-
-void vtkObjectFactory::CreateAllInstance(const char* vtkclassname,
-                                               vtkCollection* retList)
+void vtkObjectFactory::CreateAllInstance(const char* vtkclassname, vtkCollection* retList)
 {
   vtkObjectFactory* f;
-  vtkObjectFactoryCollection* collection
-    = vtkObjectFactory::GetRegisteredFactories();
+  vtkObjectFactoryCollection* collection = vtkObjectFactory::GetRegisteredFactories();
   vtkCollectionSimpleIterator osit;
-  for(collection->InitTraversal(osit);
-      (f = collection->GetNextObjectFactory(osit)); )
+  for (collection->InitTraversal(osit); (f = collection->GetNextObjectFactory(osit));)
   {
     vtkObject* o = f->CreateObject(vtkclassname);
-    if(o)
+    if (o)
     {
       retList->AddItem(o);
       o->Delete();
     }
   }
 }
+VTK_ABI_NAMESPACE_END
