@@ -17,6 +17,7 @@
 #include "vtkDebugLeaks.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryCollection* vtkObjectFactoryCollection::New()
 {
   // Don't use the object factory macros. Creating an object factory here
@@ -25,3 +26,9 @@ vtkObjectFactoryCollection* vtkObjectFactoryCollection::New()
   ret->InitializeObjectBase();
   return ret;
 }
+
+void vtkObjectFactoryCollection::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+VTK_ABI_NAMESPACE_END
