@@ -31,11 +31,13 @@
 
 #include "vtkObjectFactory.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONCORE_EXPORT vtkObjectFactoryCollection : public vtkCollection
 {
 public:
   vtkTypeMacro(vtkObjectFactoryCollection, vtkCollection);
   static vtkObjectFactoryCollection* New();
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Add an ObjectFactory the bottom of the list.
@@ -73,5 +75,5 @@ private:
   void operator=(const vtkObjectFactoryCollection&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-// VTK-HeaderTest-Exclude: vtkObjectFactoryCollection.h
