@@ -14,13 +14,14 @@
 =========================================================================*/
 #include "vtkOldStyleCallbackCommand.h"
 
-#include "vtkSetGet.h"
 #include "vtkObject.h"
+#include "vtkSetGet.h"
 
-#include <cstring>
 #include <cctype>
+#include <cstring>
 
 //----------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkOldStyleCallbackCommand::vtkOldStyleCallbackCommand()
 {
   this->ClientData = nullptr;
@@ -36,10 +37,11 @@ vtkOldStyleCallbackCommand::~vtkOldStyleCallbackCommand()
   }
 }
 
-void vtkOldStyleCallbackCommand::Execute(vtkObject *,unsigned long, void *)
+void vtkOldStyleCallbackCommand::Execute(vtkObject*, unsigned long, void*)
 {
   if (this->Callback)
   {
     this->Callback(this->ClientData);
   }
 }
+VTK_ABI_NAMESPACE_END
