@@ -27,14 +27,16 @@
 
 #include "vtkCommonCoreModule.h"  // For export macro
 #include "vtkDebugLeaksManager.h" // Must be included before singletons
-#include "vtkDeprecation.h"       // For VTK_DEPRECATED_IN_9_0_0
+#include "vtkDeprecation.h"       // For `VTK_DEPRECATED_IN_9_3_0`
 #include "vtkObject.h"
 
-class VTKCOMMONCORE_EXPORT vtkOutputWindowCleanup
+VTK_ABI_NAMESPACE_BEGIN
+class VTK_DEPRECATED_IN_9_3_0(
+  "`vtkOutputWindowCleanup` is no longer necessary") VTKCOMMONCORE_EXPORT vtkOutputWindowCleanup
 {
 public:
-  vtkOutputWindowCleanup();
-  ~vtkOutputWindowCleanup();
+  vtkOutputWindowCleanup() = default;
+  ~vtkOutputWindowCleanup() = default;
 
 private:
   vtkOutputWindowCleanup(const vtkOutputWindowCleanup& other) = delete;
@@ -54,7 +56,7 @@ public:
 
   /**
    * Creates a new instance of vtkOutputWindow. Note this *will* create a new
-   * instance using the vtkObjectFactor. If you want to access the global
+   * instance using the vtkObjectFactory. If you want to access the global
    * instance, use `GetInstance` instead.
    */
   static vtkOutputWindow* New();
@@ -69,7 +71,7 @@ public:
    */
   static void SetInstance(vtkOutputWindow* instance);
 
-  //@{
+  ///@{
   /**
    * Display the text. Four virtual methods exist, depending on the type of
    * message to display. This allows redirection or reformatting of the
@@ -82,9 +84,9 @@ public:
   virtual void DisplayWarningText(const char*);
   virtual void DisplayGenericWarningText(const char*);
   virtual void DisplayDebugText(const char*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If PromptUser is set to true then each time a line of text
    * is displayed, the user is asked if they want to keep getting
@@ -96,29 +98,9 @@ public:
    */
   vtkBooleanMacro(PromptUser, bool);
   vtkSetMacro(PromptUser, bool);
-  //@}
+  ///@}
 
-  //@{
-  /**
-   * Historically (VTK 8.1 and earlier), when printing messages to terminals,
-   * vtkOutputWindow would always post messages to `cerr`. Setting this to true
-   * restores that incorrect behavior. When false (default),
-   * vtkOutputWindow uses `cerr` for debug, error and warning messages, and
-   * `cout` for text messages.
-   *
-   * @deprecated use `SetDisplayModeToAlwaysStdErr` instead.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOutputWindow::SetDisplayMode")
-  void SetUseStdErrorForAllMessages(bool);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOutputWindow::GetDisplayMode")
-  bool GetUseStdErrorForAllMessages();
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOutputWindow::SetDisplayMode")
-  void UseStdErrorForAllMessagesOn();
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOutputWindow::SetDisplayMode")
-  void UseStdErrorForAllMessagesOff();
-  //@}
-
-  //@{
+  ///@{
   /**
    * Flag indicates how the vtkOutputWindow handles displaying of text to
    * `stderr` / `stdout`. Default is `DEFAULT` except in
@@ -156,7 +138,7 @@ public:
   void SetDisplayModeToNever() { this->SetDisplayMode(vtkOutputWindow::NEVER); }
   void SetDisplayModeToAlways() { this->SetDisplayMode(vtkOutputWindow::ALWAYS); }
   void SetDisplayModeToAlwaysStdErr() { this->SetDisplayMode(vtkOutputWindow::ALWAYS_STDERR); }
-  //@}
+  ///@}
 protected:
   vtkOutputWindow();
   ~vtkOutputWindow() override;
@@ -193,11 +175,10 @@ protected:
   bool PromptUser;
 
 private:
-  static vtkOutputWindow* Instance;
-  MessageTypes CurrentMessageType;
+  std::atomic<MessageTypes> CurrentMessageType;
   int DisplayMode;
-  int InStandardMacros; // used to suppress display to output streams from standard macros when
-                        // logging is enabled.
+  std::atomic<int> InStandardMacros; // used to suppress display to output streams from standard
+                                     // macros when logging is enabled.
 
   friend class vtkOutputWindowPrivateAccessor;
 
@@ -206,7 +187,5 @@ private:
   void operator=(const vtkOutputWindow&) = delete;
 };
 
-// Uses schwartz counter idiom for singleton management
-static vtkOutputWindowCleanup vtkOutputWindowCleanupInstance;
-
+VTK_ABI_NAMESPACE_END
 #endif
