@@ -27,8 +27,10 @@
 #include <algorithm>
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRandomPool);
 vtkCxxSetObjectMacro(vtkRandomPool, Sequence, vtkRandomSequence);
+VTK_ABI_NAMESPACE_END
 
 //------------------------------------------------------------------------------
 // Static methods to populate a data array.
@@ -138,6 +140,8 @@ struct PopulateDAComponentLauncher
 
 } // anonymous namespace
 
+VTK_ABI_NAMESPACE_BEGIN
+
 //------------------------------------------------------------------------------
 vtkRandomPool::vtkRandomPool()
 {
@@ -310,6 +314,7 @@ const double* vtkRandomPool::GeneratePool()
     this->NumberOfComponents = 1;
   }
   this->ChunkSize = (this->ChunkSize < 1000 ? 1000 : this->ChunkSize);
+  delete[] this->Pool;
   this->Pool = new double[this->TotalSize];
 
   // Control the number of threads spawned.
@@ -361,3 +366,4 @@ void vtkRandomPool::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Number Of Components: " << this->NumberOfComponents << "\n";
   os << indent << "Chunk Size: " << this->ChunkSize << "\n";
 }
+VTK_ABI_NAMESPACE_END
