@@ -16,6 +16,7 @@
 #include <cassert>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkRandomSequence::vtkRandomSequence() = default;
 
 //------------------------------------------------------------------------------
@@ -26,3 +27,11 @@ void vtkRandomSequence::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+
+//------------------------------------------------------------------------------
+double vtkRandomSequence::GetNextValue()
+{
+  this->Next();
+  return this->GetValue();
+}
+VTK_ABI_NAMESPACE_END
