@@ -41,6 +41,7 @@
 
 // The export macro below makes no sense, but is necessary for older compilers
 // when we export instantiations of this class from vtkCommonCore.
+VTK_ABI_NAMESPACE_BEGIN
 template <class ValueTypeT>
 class VTKCOMMONCORE_EXPORT vtkScaledSOADataArrayTemplate
   : public vtkGenericDataArray<vtkScaledSOADataArrayTemplate<ValueTypeT>, ValueTypeT>
@@ -63,7 +64,7 @@ public:
 
   static vtkScaledSOADataArrayTemplate* New();
 
-  //@{
+  ///@{
   /**
    * Set/Get the Scale value for the object. The default is 1.
    */
@@ -83,9 +84,9 @@ public:
     }
   }
   ValueType GetScale() const { return this->Scale; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the value at @a valueIdx. @a valueIdx assumes AOS ordering.
    */
@@ -96,9 +97,9 @@ public:
     this->GetTupleIndexFromValueIndex(valueIdx, tupleIdx, comp);
     return this->GetTypedComponent(tupleIdx, comp);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the value at @a valueIdx to @a value. @a valueIdx assumes AOS ordering.
    */
@@ -109,7 +110,7 @@ public:
     this->GetTupleIndexFromValueIndex(valueIdx, tupleIdx, comp);
     this->SetTypedComponent(tupleIdx, comp, value);
   }
-  //@}
+  ///@}
 
   /**
    * Copy the tuple at @a tupleIdx into @a tuple.
@@ -207,7 +208,7 @@ public:
   void ExportToVoidPointer(void* ptr) override;
 
 #ifndef __VTK_WRAP__
-  //@{
+  ///@{
   /**
    * Perform a fast, safe cast from a vtkAbstractArray to a vtkDataArray.
    * This method checks if source->GetArrayType() returns DataArray
@@ -230,7 +231,7 @@ public:
     }
     return nullptr;
   }
-  //@}
+  ///@}
 #endif
 
   int GetArrayType() const override { return vtkAbstractArray::ScaleSoADataArrayTemplate; }
@@ -247,6 +248,11 @@ public:
   {
     this->Superclass::InsertTuples(dstIds, srcIds, source);
   }
+  void InsertTuplesStartingAt(
+    vtkIdType dstStart, vtkIdList* srcIds, vtkAbstractArray* source) override
+  {
+    this->Superclass::InsertTuplesStartingAt(dstStart, srcIds, source);
+  }
 
 protected:
   vtkScaledSOADataArrayTemplate();
@@ -287,6 +293,7 @@ private:
 // Declare vtkArrayDownCast implementations for scale SoA containers:
 vtkArrayDownCast_TemplateFastCastMacro(vtkScaledSOADataArrayTemplate);
 
+VTK_ABI_NAMESPACE_END
 #endif // header guard
 
 // This portion must be OUTSIDE the include blockers. This is used to tell
@@ -295,7 +302,16 @@ vtkArrayDownCast_TemplateFastCastMacro(vtkScaledSOADataArrayTemplate);
 // from instantiating these on their own.
 #ifdef VTK_SCALED_SOA_DATA_ARRAY_TEMPLATE_INSTANTIATING
 #define VTK_SCALED_SOA_DATA_ARRAY_TEMPLATE_INSTANTIATE(T)                                          \
-  template class VTKCOMMONCORE_EXPORT vtkScaledSOADataArrayTemplate<T>
+  namespace vtkDataArrayPrivate                                                                    \
+  {                                                                                                \
+  VTK_ABI_NAMESPACE_BEGIN                                                                          \
+  VTK_INSTANTIATE_VALUERANGE_ARRAYTYPE(vtkScaledSOADataArrayTemplate<T>, double);                  \
+  VTK_ABI_NAMESPACE_END                                                                            \
+  }                                                                                                \
+  VTK_ABI_NAMESPACE_BEGIN                                                                          \
+  template class VTKCOMMONCORE_EXPORT vtkScaledSOADataArrayTemplate<T>;                            \
+  VTK_ABI_NAMESPACE_END
+
 #elif defined(VTK_USE_EXTERN_TEMPLATE)
 #ifndef VTK_SCALED_SOA_DATA_ARRAY_TEMPLATE_EXTERN
 #define VTK_SCALED_SOA_DATA_ARRAY_TEMPLATE_EXTERN
@@ -305,10 +321,12 @@ vtkArrayDownCast_TemplateFastCastMacro(vtkScaledSOADataArrayTemplate);
 // dllexport and is used from another class in vtkCommonCore
 #pragma warning(disable : 4910) // extern and dllexport incompatible
 #endif
+VTK_ABI_NAMESPACE_BEGIN
 vtkExternTemplateMacro(extern template class VTKCOMMONCORE_EXPORT vtkScaledSOADataArrayTemplate);
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
+VTK_ABI_NAMESPACE_END
 #endif // VTK_SCALED_SOA_DATA_ARRAY_TEMPLATE_EXTERN
 
 // The following clause is only for MSVC 2008 and 2010
@@ -336,11 +354,13 @@ vtkExternTemplateMacro(extern template class VTKCOMMONCORE_EXPORT vtkScaledSOADa
 
 // Use an "extern explicit instantiation" to give the class a DLL
 // interface.  This is a compiler-specific extension.
+VTK_ABI_NAMESPACE_BEGIN
 vtkInstantiateTemplateMacro(
   extern template class VTKCOMMONCORE_EXPORT vtkScaledSOADataArrayTemplate);
 
 #pragma warning(pop)
 
+VTK_ABI_NAMESPACE_END
 #endif
 
 // VTK-HeaderTest-Exclude: vtkScaledSOADataArrayTemplate.h
