@@ -15,7 +15,7 @@
 #include "vtkStringOutputWindow.h"
 #include "vtkObjectFactory.h"
 
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStringOutputWindow);
 
 vtkStringOutputWindow::vtkStringOutputWindow()
@@ -34,7 +34,7 @@ void vtkStringOutputWindow::Initialize()
 
 void vtkStringOutputWindow::DisplayText(const char* text)
 {
-  if(!text)
+  if (!text)
   {
     return;
   }
@@ -46,3 +46,4 @@ void vtkStringOutputWindow::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
