@@ -15,8 +15,8 @@
 #ifndef vtkType_h
 #define vtkType_h
 
+#include "vtkABINamespace.h"
 #include "vtkCompiler.h" // for VTK_USE_EXTERN_TEMPLATE
-#include "vtkLegacy.h"   // For VTK_LEGACY_REMOVE
 #include "vtkOptions.h"  // for VTK_USE_64BIT_IDS and VTK_USE_64BIT_TIMESTAMPS
 #include "vtk_kwiml.h"
 
@@ -67,8 +67,8 @@
 #define VTK_VARIANT 20
 #define VTK_OBJECT 21
 
-/* Storage for Unicode strings */
-#define VTK_UNICODE_STRING 22
+// deleted value
+//#define VTK_UNICODE_STRING 22 <==== do not use
 
 /*--------------------------------------------------------------------------*/
 /* Define a unique integer identifier for each vtkDataObject type.          */
@@ -115,6 +115,14 @@
 #define VTK_PARTITIONED_DATA_SET_COLLECTION 38
 #define VTK_UNIFORM_HYPER_TREE_GRID 39
 #define VTK_EXPLICIT_STRUCTURED_GRID 40
+#define VTK_DATA_OBJECT_TREE 41
+#define VTK_ABSTRACT_ELECTRONIC_DATA 42
+#define VTK_OPEN_QUBE_ELECTRONIC_DATA 43
+#define VTK_ANNOTATION 44
+#define VTK_ANNOTATION_LAYERS 45
+#define VTK_BSP_CUTS 46
+#define VTK_GEO_JSON_FEATURE 47
+#define VTK_IMAGE_STENCIL_DATA 48
 
 /*--------------------------------------------------------------------------*/
 /* Define a casting macro for use by the constants below.  */
@@ -171,15 +179,9 @@ typedef signed char vtkTypeInt8;
 #define VTK_TYPE_UINT8 VTK_UNSIGNED_CHAR
 #define VTK_TYPE_UINT8_MIN VTK_UNSIGNED_CHAR_MIN
 #define VTK_TYPE_UINT8_MAX VTK_UNSIGNED_CHAR_MAX
-#if VTK_TYPE_CHAR_IS_SIGNED
-#define VTK_TYPE_INT8 VTK_CHAR
-#define VTK_TYPE_INT8_MIN VTK_CHAR_MIN
-#define VTK_TYPE_INT8_MAX VTK_CHAR_MAX
-#else
 #define VTK_TYPE_INT8 VTK_SIGNED_CHAR
 #define VTK_TYPE_INT8_MIN VTK_SIGNED_CHAR_MIN
 #define VTK_TYPE_INT8_MAX VTK_SIGNED_CHAR_MAX
-#endif
 #else
 #error "No native data type can represent an 8-bit integer."
 #endif
@@ -253,12 +255,6 @@ typedef signed long vtkTypeInt64;
 #error "No native data type can represent a 64-bit integer."
 #endif
 
-#if !defined(VTK_LEGACY_REMOVE)
-// Provide this define to facilitate apps that need to support older
-// versions that do not have vtkMTimeType
-#define VTK_HAS_MTIME_TYPE
-#endif
-
 // If this is a 64-bit platform, or the user has indicated that 64-bit
 // timestamps should be used, select an unsigned 64-bit integer type
 // for use in MTime values. If possible, use 'unsigned long' as we have
@@ -364,11 +360,13 @@ typedef bool vtkTypeUBool;
  * is intended to handle vtkIdType, which does not have the same tag as its
  * underlying data type.
  * @note This method is only available when included from a C++ source file. */
+VTK_ABI_NAMESPACE_BEGIN
 inline vtkTypeBool vtkDataTypesCompare(int a, int b)
 {
   return (a == b ||
     ((a == VTK_ID_TYPE || a == VTK_ID_TYPE_IMPL) && (b == VTK_ID_TYPE || b == VTK_ID_TYPE_IMPL)));
 }
+VTK_ABI_NAMESPACE_END
 #endif
 
 /*--------------------------------------------------------------------------*/
