@@ -21,17 +21,20 @@ VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATE(unsigned long);
 
 #include "vtkObjectFactory.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkUnsignedLongArray);
+vtkStandardExtendedNewMacro(vtkUnsignedLongArray);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedLongArray::vtkUnsignedLongArray() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedLongArray::~vtkUnsignedLongArray() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkUnsignedLongArray::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->RealSuperclass::PrintSelf(os,indent);
+  this->RealSuperclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
