@@ -21,17 +21,20 @@ VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATE(unsigned short);
 
 #include "vtkObjectFactory.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkUnsignedShortArray);
+vtkStandardExtendedNewMacro(vtkUnsignedShortArray);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedShortArray::vtkUnsignedShortArray() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedShortArray::~vtkUnsignedShortArray() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkUnsignedShortArray::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->RealSuperclass::PrintSelf(os,indent);
+  this->RealSuperclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
