@@ -29,7 +29,6 @@
 #include "vtkStdString.h"
 #include "vtkStringArray.h"
 #include "vtkType.h"
-#include "vtkUnicodeString.h"
 #include "vtkVariantArray.h"
 
 #include "vtksys/SystemTools.hxx"
@@ -40,6 +39,7 @@
 
 // Implementation of vtkVariant's
 // fast-but-potentially-counterintuitive < operation
+VTK_ABI_NAMESPACE_BEGIN
 bool vtkVariantStrictWeakOrder::operator()(const vtkVariant& s1, const vtkVariant& s2) const
 {
   // First sort on type if they are different
@@ -70,9 +70,6 @@ bool vtkVariantStrictWeakOrder::operator()(const vtkVariant& s1, const vtkVarian
     case VTK_STRING:
       return (*(s1.Data.String) < *(s2.Data.String));
 
-    case VTK_UNICODE_STRING:
-      return (*(s1.Data.UnicodeString) < *(s2.Data.UnicodeString));
-
     case VTK_OBJECT:
       return (s1.Data.VTKObject < s2.Data.VTKObject);
 
@@ -149,10 +146,7 @@ bool vtkVariantStrictEquality::operator()(const vtkVariant& s1, const vtkVariant
         cerr << "Strings differ: '" << *(s1.Data.String) << "' and '" << *(s2.Data.String) << "'\n";
       }
       return (*(s1.Data.String) == *(s2.Data.String));
-    };
-
-    case VTK_UNICODE_STRING:
-      return (*(s1.Data.UnicodeString) == *(s2.Data.UnicodeString));
+    }
 
     case VTK_OBJECT:
       return (s1.Data.VTKObject == s2.Data.VTKObject);
@@ -235,9 +229,6 @@ vtkVariant::vtkVariant(const vtkVariant& other)
       case VTK_STRING:
         this->Data.String = new vtkStdString(*other.Data.String);
         break;
-      case VTK_UNICODE_STRING:
-        this->Data.UnicodeString = new vtkUnicodeString(*other.Data.UnicodeString);
-        break;
       case VTK_OBJECT:
         this->Data.VTKObject->Register(nullptr);
         break;
@@ -258,11 +249,6 @@ vtkVariant::vtkVariant(const vtkVariant& s2, unsigned int type)
         valid = true;
         break;
 
-      case VTK_UNICODE_STRING:
-        this->Data.UnicodeString = new vtkUnicodeString(s2.ToUnicodeString());
-        valid = true;
-        break;
-
       case VTK_OBJECT:
         this->Data.VTKObject = s2.ToVTKObject();
         if (this->Data.VTKObject)
@@ -346,9 +332,6 @@ vtkVariant& vtkVariant::operator=(const vtkVariant& other)
       case VTK_STRING:
         delete this->Data.String;
         break;
-      case VTK_UNICODE_STRING:
-        delete this->Data.UnicodeString;
-        break;
       case VTK_OBJECT:
         this->Data.VTKObject->Delete();
         break;
@@ -366,9 +349,6 @@ vtkVariant& vtkVariant::operator=(const vtkVariant& other)
       case VTK_STRING:
         this->Data.String = new vtkStdString(*other.Data.String);
         break;
-      case VTK_UNICODE_STRING:
-        this->Data.UnicodeString = new vtkUnicodeString(*other.Data.UnicodeString);
-        break;
       case VTK_OBJECT:
         this->Data.VTKObject->Register(nullptr);
         break;
@@ -386,9 +366,6 @@ vtkVariant::~vtkVariant()
       case VTK_STRING:
         delete this->Data.String;
         break;
-      case VTK_UNICODE_STRING:
-        delete this->Data.UnicodeString;
-        break;
       case VTK_OBJECT:
         this->Data.VTKObject->Delete();
         break;
@@ -513,13 +490,6 @@ vtkVariant::vtkVariant(vtkStdString value)
   this->Type = VTK_STRING;
 }
 
-vtkVariant::vtkVariant(const vtkUnicodeString& value)
-{
-  this->Data.UnicodeString = new vtkUnicodeString(value);
-  this->Valid = 1;
-  this->Type = VTK_UNICODE_STRING;
-}
-
 vtkVariant::vtkVariant(vtkObjectBase* value)
 {
   this->Valid = 0;
@@ -543,11 +513,6 @@ bool vtkVariant::IsString() const
   return this->Type == VTK_STRING;
 }
 
-bool vtkVariant::IsUnicodeString() const
-{
-  return this->Type == VTK_UNICODE_STRING;
-}
-
 bool vtkVariant::IsNumeric() const
 {
   return this->IsFloat() || this->IsDouble() || this->IsChar() || this->IsUnsignedChar() ||
@@ -611,16 +576,6 @@ bool vtkVariant::IsUnsignedLong() const
   return this->Type == VTK_UNSIGNED_LONG;
 }
 
-bool vtkVariant::Is__Int64() const
-{
-  return false;
-}
-
-bool vtkVariant::IsUnsigned__Int64() const
-{
-  return false;
-}
-
 bool vtkVariant::IsLongLong() const
 {
   return this->Type == VTK_LONG_LONG;
@@ -696,15 +651,11 @@ vtkStdString vtkVariant::ToString(int formatting, int precision) const
 {
   if (!this->IsValid())
   {
-    return vtkStdString();
+    return {};
   }
   if (this->IsString())
   {
-    return vtkStdString(*(this->Data.String));
-  }
-  if (this->IsUnicodeString())
-  {
-    return vtkUnicodeString(*(this->Data.UnicodeString)).utf8_str();
+    return *this->Data.String;
   }
   if (this->IsFloat())
   {
@@ -713,7 +664,7 @@ vtkStdString vtkVariant::ToString(int formatting, int precision) const
     SetFormattingOnStream(formatting, ostr);
     ostr << std::setprecision(precision);
     ostr << this->Data.Float;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsDouble())
   {
@@ -722,85 +673,85 @@ vtkStdString vtkVariant::ToString(int formatting, int precision) const
     SetFormattingOnStream(formatting, ostr);
     ostr << std::setprecision(precision);
     ostr << this->Data.Double;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsChar())
   {
     std::ostringstream ostr;
     ostr << this->Data.Char;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsUnsignedChar())
   {
     std::ostringstream ostr;
     ostr << static_cast<unsigned int>(this->Data.UnsignedChar);
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsSignedChar())
   {
     std::ostringstream ostr;
     ostr << this->Data.SignedChar;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsShort())
   {
     std::ostringstream ostr;
     ostr << this->Data.Short;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsUnsignedShort())
   {
     std::ostringstream ostr;
     ostr << this->Data.UnsignedShort;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsInt())
   {
     std::ostringstream ostr;
     ostr.imbue(std::locale::classic());
     ostr << this->Data.Int;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsUnsignedInt())
   {
     std::ostringstream ostr;
     ostr.imbue(std::locale::classic());
     ostr << this->Data.UnsignedInt;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsLong())
   {
     std::ostringstream ostr;
     ostr.imbue(std::locale::classic());
     ostr << this->Data.Long;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsUnsignedLong())
   {
     std::ostringstream ostr;
     ostr.imbue(std::locale::classic());
     ostr << this->Data.UnsignedLong;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsLongLong())
   {
     std::ostringstream ostr;
     ostr.imbue(std::locale::classic());
     ostr << this->Data.LongLong;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsUnsignedLongLong())
   {
     std::ostringstream ostr;
     ostr.imbue(std::locale::classic());
     ostr << this->Data.UnsignedLongLong;
-    return vtkStdString(ostr.str());
+    return ostr.str();
   }
   if (this->IsArray())
   {
     vtkAbstractArray* arr = vtkAbstractArray::SafeDownCast(this->Data.VTKObject);
     vtkArrayIterator* iter = arr->NewIterator();
-    vtkStdString str;
+    std::string str;
     switch (arr->GetDataType())
     {
       vtkArrayIteratorTemplateMacro(
@@ -811,25 +762,7 @@ vtkStdString vtkVariant::ToString(int formatting, int precision) const
   }
   vtkGenericWarningMacro(<< "Cannot convert unknown type (" << this->GetTypeAsString()
                          << ") to a string.");
-  return vtkStdString();
-}
-
-vtkUnicodeString vtkVariant::ToUnicodeString(int formatting, int precision) const
-{
-  if (!this->IsValid())
-  {
-    return vtkUnicodeString();
-  }
-  if (this->IsString())
-  {
-    return vtkUnicodeString::from_utf8(*this->Data.String);
-  }
-  if (this->IsUnicodeString())
-  {
-    return *this->Data.UnicodeString;
-  }
-
-  return vtkUnicodeString::from_utf8(this->ToString(formatting, precision));
+  return {};
 }
 
 vtkObjectBase* vtkVariant::ToVTKObject() const
@@ -920,6 +853,8 @@ T vtkVariantStringToNumeric(vtkStdString str, bool* valid, T* vtkNotUsed(ignored
 //------------------------------------------------------------------------------
 // Definition of ToNumeric
 
+VTK_ABI_NAMESPACE_END
+// NOLINTNEXTLINE(bugprone-suspicious-include)
 #include "vtkVariantToNumeric.cxx"
 
 //------------------------------------------------------------------------------
@@ -931,6 +866,7 @@ T vtkVariantStringToNumeric(vtkStdString str, bool* valid, T* vtkNotUsed(ignored
 
 #define vtkVariantToNumericInstantiateMacro(x) template x vtkVariant::ToNumeric<x>(bool*, x*) const
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkVariantToNumericInstantiateMacro(char);
 vtkVariantToNumericInstantiateMacro(float);
 vtkVariantToNumericInstantiateMacro(double);
@@ -945,11 +881,13 @@ vtkVariantToNumericInstantiateMacro(unsigned long);
 vtkVariantToNumericInstantiateMacro(long long);
 vtkVariantToNumericInstantiateMacro(unsigned long long);
 
+VTK_ABI_NAMESPACE_END
 #endif
 
 //------------------------------------------------------------------------------
 // Callers causing implicit instantiations of ToNumeric
 
+VTK_ABI_NAMESPACE_BEGIN
 float vtkVariant::ToFloat(bool* valid) const
 {
   return this->ToNumeric(valid, static_cast<float*>(nullptr));
@@ -1042,17 +980,7 @@ ostream& operator<<(ostream& os, const vtkVariant& val)
     case VTK_STRING:
       if (val.Data.String)
       {
-        os << "\"" << val.Data.String->c_str() << "\"";
-      }
-      else
-      {
-        os << "\"\"";
-      }
-      break;
-    case VTK_UNICODE_STRING:
-      if (val.Data.UnicodeString)
-      {
-        os << "\"" << val.Data.UnicodeString->utf8_str() << "\"";
+        os << "\"" << *val.Data.String << "\"";
       }
       else
       {
@@ -1111,3 +1039,4 @@ ostream& operator<<(ostream& os, const vtkVariant& val)
   }
   return os;
 }
+VTK_ABI_NAMESPACE_END
