@@ -14,27 +14,28 @@
 =========================================================================*/
 
 #include "vtkWeakReference.h"
-#include "vtkWeakPointer.h"
 #include "vtkObjectFactory.h"
+#include "vtkWeakPointer.h"
 
-//----------------------------------------------------------------------------
-vtkStandardNewMacro(vtkWeakReference)
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
+vtkStandardNewMacro(vtkWeakReference);
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkWeakReference::vtkWeakReference() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkWeakReference::~vtkWeakReference() = default;
 
-//----------------------------------------------------------------------------
-void vtkWeakReference::Set(vtkObject *object)
+//------------------------------------------------------------------------------
+void vtkWeakReference::Set(vtkObject* object)
 {
   this->Object = object;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkObject* vtkWeakReference::Get()
 {
   return this->Object;
 }
+VTK_ABI_NAMESPACE_END
