@@ -36,6 +36,7 @@
 #define KMAX(ext) ext[5]
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 void vtkAMRUtilities::PrintSelf(std::ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -280,7 +281,7 @@ void vtkAMRUtilities::StripGhostLayers(
 
   if (!vtkAMRUtilities::HasPartiallyOverlappingGhostCells(ghostedAMRData))
   {
-    strippedAMRData->ShallowCopy(ghostedAMRData);
+    strippedAMRData->CompositeShallowCopy(ghostedAMRData);
     return;
   }
 
@@ -292,7 +293,7 @@ void vtkAMRUtilities::StripGhostLayers(
   {
     blocksPerLevel[i] = ghostedAMRData->GetNumberOfDataSets(i);
   }
-  strippedAMRData->Initialize(static_cast<int>(blocksPerLevel.size()), &blocksPerLevel[0]);
+  strippedAMRData->Initialize(static_cast<int>(blocksPerLevel.size()), blocksPerLevel.data());
   strippedAMRData->SetOrigin(ghostedAMRData->GetOrigin());
   strippedAMRData->SetGridDescription(ghostedAMRData->GetGridDescription());
 
@@ -464,3 +465,4 @@ void vtkAMRUtilities::MergeGhostArrays(vtkDataArray* existingArray, vtkUnsignedC
     }
   }
 }
+VTK_ABI_NAMESPACE_END
