@@ -15,27 +15,27 @@
 
 #include "vtkAbstractElectronicData.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkAbstractElectronicData::vtkAbstractElectronicData()
   : Padding(0.0)
 {
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractElectronicData::~vtkAbstractElectronicData() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAbstractElectronicData::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Padding: " << this->Padding << "\n";
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractElectronicData::DeepCopy(vtkDataObject *obj)
+//------------------------------------------------------------------------------
+void vtkAbstractElectronicData::DeepCopy(vtkDataObject* obj)
 {
-  vtkAbstractElectronicData *aed =
-      vtkAbstractElectronicData::SafeDownCast(obj);
+  vtkAbstractElectronicData* aed = vtkAbstractElectronicData::SafeDownCast(obj);
   if (!aed)
   {
     vtkErrorMacro("Can only deep copy from vtkAbstractElectronicData "
@@ -49,3 +49,4 @@ void vtkAbstractElectronicData::DeepCopy(vtkDataObject *obj)
   // Copy ivars
   this->Padding = aed->Padding;
 }
+VTK_ABI_NAMESPACE_END
