@@ -20,7 +20,9 @@
 #include "vtkGenericDataSet.h"
 #include "vtkObjectFactory.h"
 #include <cassert>
+#include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAttributesErrorMetric);
 
 //------------------------------------------------------------------------------
@@ -267,3 +269,4 @@ void vtkAttributesErrorMetric::ComputeSquareAbsoluteAttributeTolerance()
     }
   }
 }
+VTK_ABI_NAMESPACE_END
