@@ -12,6 +12,7 @@
   PURPOSE.  See the above copyright notice for more information.
 
   =========================================================================*/
+
 #include "vtkBezierInterpolation.h"
 #include <array>
 #include <functional>
@@ -27,12 +28,10 @@
 #include "vtkVectorOperators.h"
 #include <numeric> // std::accumulate
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBezierInterpolation);
 
-vtkBezierInterpolation::vtkBezierInterpolation()
-  : vtkHigherOrderInterpolation()
-{
-}
+vtkBezierInterpolation::vtkBezierInterpolation() = default;
 
 vtkBezierInterpolation::~vtkBezierInterpolation() = default;
 
@@ -116,7 +115,7 @@ static vtkVector3i unflattenTetrahedron(const int deg, const vtkIdType flat)
   return { cv_tri[0], cv_tri[1], level };
 }
 
-int vtkBezierInterpolation::flattenSimplex(const int dim, const int deg, const vtkVector3i coord)
+int vtkBezierInterpolation::FlattenSimplex(const int dim, const int deg, const vtkVector3i coord)
 {
   switch (dim)
   {
@@ -131,14 +130,14 @@ int vtkBezierInterpolation::flattenSimplex(const int dim, const int deg, const v
       {
         num_before_level += NumberOfSimplexFunctions(2, deg - i);
       }
-      return num_before_level + flattenSimplex(2, deg - coord[2], coord);
+      return num_before_level + FlattenSimplex(2, deg - coord[2], coord);
     }
     default:
       throw "flattenSimplex unsupported dim";
   }
 }
 
-vtkVector3i vtkBezierInterpolation::unflattenSimplex(
+vtkVector3i vtkBezierInterpolation::UnFlattenSimplex(
   const int dim, const int deg, const vtkIdType flat)
 {
   switch (dim)
@@ -169,7 +168,7 @@ void iterateSimplex(
     {
       for (int i = 0, nfuncs = ((deg + 1) * (deg + 2) / 2); i < nfuncs; ++i)
       {
-        callback(vtkBezierInterpolation::unflattenSimplex(2, deg, i), i);
+        callback(vtkBezierInterpolation::UnFlattenSimplex(2, deg, i), i);
       }
     }
     break;
@@ -177,7 +176,7 @@ void iterateSimplex(
     {
       for (int i = 0, nfuncs = ((deg + 1) * (deg + 2) * (deg + 3) / 6); i < nfuncs; ++i)
       {
-        callback(vtkBezierInterpolation::unflattenSimplex(3, deg, i), i);
+        callback(vtkBezierInterpolation::UnFlattenSimplex(3, deg, i), i);
       }
     }
     break;
@@ -185,7 +184,7 @@ void iterateSimplex(
 }
 
 // FIXME this could be greatly optimized
-void vtkBezierInterpolation::deCasteljauSimplex(
+void vtkBezierInterpolation::DeCasteljauSimplex(
   const int dim, const int deg, const double pcoords[3], double* weights)
 {
   const int basis_func_n = NumberOfSimplexFunctions(dim, deg);
@@ -217,7 +216,7 @@ void vtkBezierInterpolation::deCasteljauSimplex(
             const vtkVector3i one_higher_coord = { sub_degree_coord[0] + lin_degree_coord[0],
               sub_degree_coord[1] + lin_degree_coord[1],
               sub_degree_coord[2] + lin_degree_coord[2] };
-            const int idx = flattenSimplex(dim, sub_degree + 1, one_higher_coord);
+            const int idx = FlattenSimplex(dim, sub_degree + 1, one_higher_coord);
             shape_funcs[lin_index] = coeffs[idx] * linear_basis[lin_index];
           });
         sub_coeffs[sub_index] = std::accumulate(shape_funcs.begin(), shape_funcs.end(), 0.);
@@ -231,22 +230,22 @@ void vtkBezierInterpolation::deCasteljauSimplex(
   }
 }
 
-void vtkBezierInterpolation::deCasteljauSimplexDeriv(
+void vtkBezierInterpolation::DeCasteljauSimplexDeriv(
   const int dim, const int deg, const double pcoords[3], double* weights)
 {
   const int num_funcs = NumberOfSimplexFunctions(dim, deg - 1);
   std::vector<double> evals(num_funcs);
-  deCasteljauSimplex(dim, deg - 1, pcoords, &evals[0]);
+  DeCasteljauSimplex(dim, deg - 1, pcoords, evals.data());
   for (int idim = 0; idim < dim; ++idim)
   {
     for (int ifunc = 0; ifunc < num_funcs; ++ifunc)
     {
-      const vtkVector3i coord = unflattenSimplex(dim, deg - 1, ifunc);
+      const vtkVector3i coord = UnFlattenSimplex(dim, deg - 1, ifunc);
       vtkVector3i next_coord = coord;
       next_coord[idim] += 1;
 
-      const int flat_coord = flattenSimplex(dim, deg, coord);
-      const int flat_next_coord = flattenSimplex(dim, deg, next_coord);
+      const int flat_coord = FlattenSimplex(dim, deg, coord);
+      const int flat_next_coord = FlattenSimplex(dim, deg, next_coord);
       weights[(num_funcs * idim) + ifunc] = deg * (evals[flat_next_coord] - evals[flat_coord]);
     }
   }
@@ -284,7 +283,7 @@ void vtkBezierInterpolation::EvaluateShapeAndGradient(
   std::vector<double> shape_deriv(order + 1);
 
   EvaluateShapeFunctions(order, pcoord, shape);
-  EvaluateShapeFunctions(order - 1, pcoord, &shape_deriv[0]);
+  EvaluateShapeFunctions(order - 1, pcoord, shape_deriv.data());
 
   for (int ifunc_l = 0; ifunc_l <= order; ++ifunc_l)
   {
@@ -382,3 +381,4 @@ void vtkBezierInterpolation::WedgeEvaluateDerivative(const int order[3], const d
   this->vtkHigherOrderInterpolation::WedgeEvaluateDerivative(order, pcoords, points, fieldVals,
     fieldDim, fieldDerivs, *tri, vtkBezierInterpolation::EvaluateShapeAndGradient);
 }
+VTK_ABI_NAMESPACE_END
