@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkBezierTetra.h"
 #include "vtkBezierInterpolation.h"
 
@@ -30,12 +27,10 @@
 #include "vtkPoints.h"
 #include "vtkTetra.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBezierTetra);
 //------------------------------------------------------------------------------
-vtkBezierTetra::vtkBezierTetra()
-  : vtkHigherOrderTetra()
-{
-}
+vtkBezierTetra::vtkBezierTetra() = default;
 
 //------------------------------------------------------------------------------
 vtkBezierTetra::~vtkBezierTetra() = default;
@@ -113,27 +108,14 @@ vtkCell* vtkBezierTetra::GetFace(int faceId)
   return result;
 }
 
-/**\brief EvaluateLocation Given a point_id. This is required by Bezier because the interior points
- * are non-interpolatory .
- */
-void vtkBezierTetra::EvaluateLocationProjectedNode(
-  int& subId, const vtkIdType point_id, double x[3], double* weights)
-{
-  this->vtkHigherOrderTetra::SetParametricCoords();
-  double pcoords[3];
-  this->PointParametricCoordinates->GetPoint(this->PointIds->FindIdLocation(point_id), pcoords);
-  this->vtkHigherOrderTetra::EvaluateLocation(subId, pcoords, x, weights);
-}
-
 /**\brief Set the rational weight of the cell, given a vtkDataSet
  */
 void vtkBezierTetra::SetRationalWeightsFromPointData(
   vtkPointData* point_data, const vtkIdType numPts)
 {
-  if (point_data->SetActiveAttribute(
-        "RationalWeights", vtkDataSetAttributes::AttributeTypes::RATIONALWEIGHTS) != -1)
+  vtkDataArray* v = point_data->GetRationalWeights();
+  if (v)
   {
-    vtkDataArray* v = point_data->GetRationalWeights();
     this->GetRationalWeights()->SetNumberOfTuples(numPts);
     for (vtkIdType i = 0; i < numPts; i++)
     {
@@ -152,14 +134,14 @@ void vtkBezierTetra::InterpolateFunctions(const double pcoords[3], double* weigh
   const vtkIdType nPoints = this->GetPoints()->GetNumberOfPoints();
   std::vector<double> coeffs(nPoints, 0.0);
 
-  vtkBezierInterpolation::deCasteljauSimplex(dim, deg, pcoords, &coeffs[0]);
+  vtkBezierInterpolation::DeCasteljauSimplex(dim, deg, pcoords, coeffs.data());
   for (vtkIdType i = 0; i < nPoints; ++i)
   {
-    vtkVector3i bv = vtkBezierInterpolation::unflattenSimplex(dim, deg, i);
+    vtkVector3i bv = vtkBezierInterpolation::UnFlattenSimplex(dim, deg, i);
     vtkIdType lbv[4] = { bv[0], bv[1], bv[2], deg - bv[0] - bv[1] - bv[2] };
     weights[Index(lbv, deg)] = coeffs[i];
   }
-  // If the unit cell has rational weigths: weights_i = weights_i * rationalWeights / sum( weights_i
+  // If the unit cell has rational weights: weights_i = weights_i * rationalWeights / sum( weights_i
   // * rationalWeights )
   const bool has_rational_weights = RationalWeights->GetNumberOfTuples() > 0;
   if (has_rational_weights)
@@ -184,10 +166,10 @@ void vtkBezierTetra::InterpolateDerivs(const double pcoords[3], double* derivs)
   const vtkIdType nPoints = this->GetPoints()->GetNumberOfPoints();
 
   std::vector<double> coeffs(nPoints, 0.0);
-  vtkBezierInterpolation::deCasteljauSimplexDeriv(dim, deg, pcoords, &coeffs[0]);
+  vtkBezierInterpolation::DeCasteljauSimplexDeriv(dim, deg, pcoords, coeffs.data());
   for (vtkIdType i = 0; i < nPoints; ++i)
   {
-    vtkVector3i bv = vtkBezierInterpolation::unflattenSimplex(dim, deg, i);
+    vtkVector3i bv = vtkBezierInterpolation::UnFlattenSimplex(dim, deg, i);
     vtkIdType lbv[4] = { bv[0], bv[1], bv[2], deg - bv[0] - bv[1] - bv[2] };
     for (int j = 0; j < dim; ++j)
     {
@@ -200,11 +182,12 @@ vtkDoubleArray* vtkBezierTetra::GetRationalWeights()
 {
   return RationalWeights.Get();
 }
-vtkHigherOrderCurve* vtkBezierTetra::getEdgeCell()
+vtkHigherOrderCurve* vtkBezierTetra::GetEdgeCell()
 {
   return EdgeCell;
 }
-vtkHigherOrderTriangle* vtkBezierTetra::getFaceCell()
+vtkHigherOrderTriangle* vtkBezierTetra::GetFaceCell()
 {
   return FaceCell;
 }
+VTK_ABI_NAMESPACE_END
