@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkBezierWedge.h"
 
 #include "vtkBezierCurve.h"
@@ -35,12 +32,10 @@
 #include "vtkVectorOperators.h"
 #include "vtkWedge.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBezierWedge);
 
-vtkBezierWedge::vtkBezierWedge()
-  : vtkHigherOrderWedge()
-{
-}
+vtkBezierWedge::vtkBezierWedge() = default;
 
 vtkBezierWedge::~vtkBezierWedge() = default;
 
@@ -155,24 +150,12 @@ vtkCell* vtkBezierWedge::GetFace(int faceId)
   }
 }
 
-/**\brief EvaluateLocation Given a point_id. This is required by Bezier because the interior points
- * are non-interpolatory .
- */
-void vtkBezierWedge::EvaluateLocationProjectedNode(
-  int& subId, const vtkIdType point_id, double x[3], double* weights)
-{
-  this->vtkHigherOrderWedge::SetParametricCoords();
-  double pcoords[3];
-  this->PointParametricCoordinates->GetPoint(this->PointIds->FindIdLocation(point_id), pcoords);
-  this->vtkHigherOrderWedge::EvaluateLocation(subId, pcoords, x, weights);
-}
-
 void vtkBezierWedge::InterpolateFunctions(const double pcoords[3], double* weights)
 {
   vtkBezierInterpolation::WedgeShapeFunctions(
     this->GetOrder(), this->GetOrder()[3], pcoords, weights);
 
-  // If the unit cell has rational weigths: weights_i = weights_i * rationalWeights / sum( weights_i
+  // If the unit cell has rational weights: weights_i = weights_i * rationalWeights / sum( weights_i
   // * rationalWeights )
   const bool has_rational_weights = RationalWeights->GetNumberOfTuples() > 0;
   if (has_rational_weights)
@@ -201,10 +184,9 @@ void vtkBezierWedge::InterpolateDerivs(const double pcoords[3], double* derivs)
 void vtkBezierWedge::SetRationalWeightsFromPointData(
   vtkPointData* point_data, const vtkIdType numPts)
 {
-  if (point_data->SetActiveAttribute(
-        "RationalWeights", vtkDataSetAttributes::AttributeTypes::RATIONALWEIGHTS) != -1)
+  vtkDataArray* v = point_data->GetRationalWeights();
+  if (v)
   {
-    vtkDataArray* v = point_data->GetRationalWeights();
     this->GetRationalWeights()->SetNumberOfTuples(numPts);
     for (vtkIdType i = 0; i < numPts; i++)
     {
@@ -219,19 +201,20 @@ vtkDoubleArray* vtkBezierWedge::GetRationalWeights()
 {
   return RationalWeights.Get();
 }
-vtkHigherOrderQuadrilateral* vtkBezierWedge::getBdyQuad()
+vtkHigherOrderQuadrilateral* vtkBezierWedge::GetBoundaryQuad()
 {
   return BdyQuad;
 };
-vtkHigherOrderTriangle* vtkBezierWedge::getBdyTri()
+vtkHigherOrderTriangle* vtkBezierWedge::GetBoundaryTri()
 {
   return BdyTri;
 };
-vtkHigherOrderCurve* vtkBezierWedge::getEdgeCell()
+vtkHigherOrderCurve* vtkBezierWedge::GetEdgeCell()
 {
   return EdgeCell;
 }
-vtkHigherOrderInterpolation* vtkBezierWedge::getInterp()
+vtkHigherOrderInterpolation* vtkBezierWedge::GetInterpolation()
 {
   return Interp;
 };
+VTK_ABI_NAMESPACE_END
