@@ -16,9 +16,6 @@
 // Thanks to Soeren Gebbert who developed this class and
 // integrated it into VTK 5.0.
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkBiQuadraticQuadraticHexahedron.h"
 
 #include "vtkBiQuadraticQuad.h"
@@ -33,6 +30,7 @@
 #include "vtkQuadraticQuad.h"
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBiQuadraticQuadraticHexahedron);
 
 //------------------------------------------------------------------------------
@@ -201,7 +199,7 @@ void vtkBiQuadraticQuadraticHexahedron::Subdivide(
   this->CellScalars->Resize(27);
   for (numMidPts = 0; numMidPts < 3; numMidPts++)
   {
-    this->InterpolationFunctions(MidPoints[numMidPts], weights);
+    vtkBiQuadraticQuadraticHexahedron::InterpolationFunctions(MidPoints[numMidPts], weights);
 
     x[0] = x[1] = x[2] = 0.0;
     s = 0.0;
@@ -256,8 +254,8 @@ int vtkBiQuadraticQuadraticHexahedron::EvaluatePosition(const double x[3], doubl
   for (iteration = converged = 0; !converged && (iteration < VTK_HEX_MAX_ITERATION); iteration++)
   {
     //  calculate element interpolation functions and derivatives
-    this->InterpolationFunctions(pcoords, weights);
-    this->InterpolationDerivs(pcoords, derivs);
+    vtkBiQuadraticQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
+    vtkBiQuadraticQuadraticHexahedron::InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     for (i = 0; i < 3; i++)
@@ -324,7 +322,7 @@ int vtkBiQuadraticQuadraticHexahedron::EvaluatePosition(const double x[3], doubl
     return -1;
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkBiQuadraticQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
 
   if (pcoords[0] >= -0.001 && pcoords[0] <= 1.001 && pcoords[1] >= -0.001 && pcoords[1] <= 1.001 &&
     pcoords[2] >= -0.001 && pcoords[2] <= 1.001)
@@ -372,7 +370,7 @@ void vtkBiQuadraticQuadraticHexahedron::EvaluateLocation(
   int i, j;
   double pt[3];
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkBiQuadraticQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
 
   x[0] = x[1] = x[2] = 0.0;
   for (i = 0; i < 24; i++)
@@ -533,7 +531,7 @@ void vtkBiQuadraticQuadraticHexahedron::JacobianInverse(
   double x[3];
 
   // compute interpolation function derivatives
-  this->InterpolationDerivs(pcoords, derivs);
+  vtkBiQuadraticQuadraticHexahedron::InterpolationDerivs(pcoords, derivs);
 
   // create Jacobian matrix
   m[0] = m0;
@@ -774,7 +772,7 @@ void vtkBiQuadraticQuadraticHexahedron::InterpolationDerivs(
   derivs[70] = ((1 - x * x) * y + x * x - 1) * z;
   derivs[71] = ((x * x - 1) * y + x * x - 1) * z;
 
-  // we compute derivatives in in [-1; 1] but we need them in [ 0; 1]
+  // we compute derivatives in [-1; 1] but we need them in [ 0; 1]
   for (int i = 0; i < 72; i++)
     derivs[i] *= 2;
 }
@@ -831,3 +829,4 @@ void vtkBiQuadraticQuadraticHexahedron::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Scalars:\n";
   this->Scalars->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
