@@ -23,6 +23,7 @@
 #include <limits> // for IntersectWithInfiniteLine
 #include <vector> // for IntersectWithPlane
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBox);
 
 // Construct the box centered at the origin and each side length 1.0.
@@ -319,28 +320,48 @@ void vtkBox::EvaluateGradient(double x[3], double n[3])
 // directions, coord[3] is the location of hit, and t is the parametric
 // coordinate along line. (Notes: the intersection ray dir[3] is NOT
 // normalized.  Valid intersections will only occur between 0<=t<=1.)
-char vtkBox::IntersectBox(
-  const double bounds[6], const double origin[3], const double dir[3], double coord[3], double& t)
+char vtkBox::IntersectBox(const double bounds[6], const double origin[3], const double dir[3],
+  double coord[3], double& t, const double tolerance)
 {
   bool inside = true;
   char quadrant[3];
   int i, whichPlane = 0;
   double maxT[3], candidatePlane[3];
 
+  // Make sure tolerance is non-zero
+  double tol = (tolerance <= 0 ? FLT_EPSILON : tolerance);
+
+  // Make sure bounds are not degenerate (i.e., have positive volume); pad by
+  // tolerance if it is.
+  double bds[6];
+  for (i = 0; i < 3; ++i)
+  {
+    if ((bounds[2 * i + 1] - bounds[2 * i]) > 0)
+    {
+      bds[2 * i] = bounds[2 * i];
+      bds[2 * i + 1] = bounds[2 * i + 1];
+    }
+    else
+    {
+      bds[2 * i] = bounds[2 * i] - tol;
+      bds[2 * i + 1] = bounds[2 * i + 1] + tol;
+    }
+  }
+
   //  First find closest planes
   //
   for (i = 0; i < 3; i++)
   {
-    if (origin[i] < bounds[2 * i])
+    if (origin[i] < bds[2 * i])
     {
       quadrant[i] = VTK_LEFT;
-      candidatePlane[i] = bounds[2 * i];
+      candidatePlane[i] = bds[2 * i];
       inside = false;
     }
-    else if (origin[i] > bounds[2 * i + 1])
+    else if (origin[i] > bds[2 * i + 1])
     {
       quadrant[i] = VTK_RIGHT;
-      candidatePlane[i] = bounds[2 * i + 1];
+      candidatePlane[i] = bds[2 * i + 1];
       inside = false;
     }
     else
@@ -402,7 +423,7 @@ char vtkBox::IntersectBox(
     if (whichPlane != i)
     {
       coord[i] = origin[i] + maxT[whichPlane] * dir[i];
-      if (coord[i] < bounds[2 * i] || coord[i] > bounds[2 * i + 1])
+      if ((coord[i] < bds[2 * i] - tol) || (coord[i] > bds[2 * i + 1] + tol))
       {
         return 0;
       }
@@ -881,3 +902,4 @@ vtkTypeBool vtkBox::IsBoxInFrustum(double planes[24], double bounds[6])
   // not sure so return true
   return true;
 }
+VTK_ABI_NAMESPACE_END
