@@ -39,6 +39,7 @@
 #include "vtkAbstractCellLinks.h"
 #include "vtkCommonDataModelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkCellArray;
 
@@ -52,20 +53,19 @@ public:
     vtkIdType* cells;
   };
 
-  //@{
+  ///@{
   /**
    * Standard methods to instantiate, print, and obtain type information.
    */
   static vtkCellLinks* New();
   vtkTypeMacro(vtkCellLinks, vtkAbstractCellLinks);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
-   * Build the link list array. All subclasses of vtkAbstractCellLinks
-   * must support this method.
+   * Build the link list array from the input dataset.
    */
-  void BuildLinks(vtkDataSet* data) override;
+  void BuildLinks() override;
 
   /**
    * Allocate the specified number of links (i.e., number of points) that
@@ -93,7 +93,7 @@ public:
    */
   vtkIdType* GetCells(vtkIdType ptId) { return this->Array[ptId].cells; }
 
-  //@{
+  ///@{
   /**
    * Select all cells with a point degree in the range [minDegree,maxDegree).
    * The degree is the number of cells using a point. The selection is
@@ -102,7 +102,7 @@ public:
    * be the maximum cell id referenced in the links.
    */
   void SelectCells(vtkIdType minMaxDegree[2], unsigned char* cellSelection) override;
-  //@}
+  ///@}
 
   /**
    * Insert a new point into the cell-links data structure. The size parameter
@@ -169,15 +169,7 @@ public:
   void DeepCopy(vtkAbstractCellLinks* src) override;
 
 protected:
-  vtkCellLinks()
-    : Array(nullptr)
-    , Size(0)
-    , MaxId(-1)
-    , Extend(1000)
-    , NumberOfPoints(0)
-    , NumberOfCells(0)
-  {
-  }
+  vtkCellLinks();
   ~vtkCellLinks() override;
 
   /**
@@ -264,4 +256,5 @@ inline void vtkCellLinks::ResizeCellList(vtkIdType ptId, int size)
   this->Array[ptId].cells = cells;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
