@@ -25,6 +25,7 @@
 #include <set>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkClosestNPointsStrategy);
 
 //------------------------------------------------------------------------------
@@ -70,7 +71,7 @@ vtkIdType vtkClosestNPointsStrategy::FindCell(double x[3], vtkCell* cell, vtkGen
     for (j = 0; j < numCells; j++)
     {
       cellId = this->CellIds->GetId(j);
-      if (this->VisitedCells.find(cellId) == this->VisitedCells.end())
+      if (!this->VisitedCells[cellId])
       {
         cell = this->SelectCell(this->PointSet, cellId, nullptr, gencell);
         ret = cell->EvaluatePosition(x, closest, subId, pcoords, dist2, weights);
@@ -78,7 +79,8 @@ vtkIdType vtkClosestNPointsStrategy::FindCell(double x[3], vtkCell* cell, vtkGen
         {
           return cellId;
         }
-        this->VisitedCells.insert(cellId);
+        this->VisitedCells[cellId] = true;
+        this->VisitedCellIds->InsertNextId(cellId);
       }
     }
   }
@@ -104,3 +106,4 @@ void vtkClosestNPointsStrategy::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
