@@ -32,6 +32,7 @@
 #include <unordered_map>
 #include <unordered_set>
 
+VTK_ABI_NAMESPACE_BEGIN
 static constexpr const char* DATASET_NODE_NAME = "dataset";
 
 //============================================================================
@@ -80,13 +81,13 @@ namespace
 {
 
 //------------------------------------------------------------------------------
-static bool IsAssemblyNode(const pugi::xml_node& node)
+bool IsAssemblyNode(const pugi::xml_node& node)
 {
   return (!vtkDataAssembly::IsNodeNameReserved(node.name()));
 }
 
 //------------------------------------------------------------------------------
-static bool IsDataSetNode(const pugi::xml_node& node)
+bool IsDataSetNode(const pugi::xml_node& node)
 {
   return strcmp(node.name(), DATASET_NODE_NAME) == 0;
 }
@@ -152,6 +153,41 @@ struct ValidationAndInitializationWalker : public pugi::xml_tree_walker
   }
 };
 
+//------------------------------------------------------------------------------
+// Walker used to offset all node "id"s.
+struct OffsetIdWalker : public pugi::xml_tree_walker
+{
+  int Offset;
+  OffsetIdWalker(int offset)
+    : Offset(offset)
+  {
+  }
+
+  void update(pugi::xml_node& node) const
+  {
+    if (IsAssemblyNode(node))
+    {
+      auto attr = node.attribute("id");
+      auto id = attr.as_uint(VTK_UNSIGNED_INT_MAX);
+      if (id != VTK_UNSIGNED_INT_MAX)
+      {
+        attr.set_value(id + this->Offset);
+      }
+    }
+  }
+
+  bool begin(pugi::xml_node& node) override
+  {
+    this->update(node);
+    return true;
+  }
+  bool for_each(pugi::xml_node& node) override
+  {
+    this->update(node);
+    return true;
+  }
+};
+
 //------------------------------------------------------------------------------
 class FindNodesWithNameVisitor : public vtkDataAssemblyVisitor
 {
@@ -238,10 +274,7 @@ public:
     const auto curids = this->GetCurrentDataSetIndices();
     std::copy(curids.begin(), curids.end(), std::back_inserter(this->DataSetIndices));
   }
-  bool GetTraverseSubtree(int nodeid) override
-  {
-    return this->TraverseSubtree || (nodeid == this->Root);
-  }
+  bool GetTraverseSubtree(int vtkNotUsed(nodeid)) override { return this->TraverseSubtree; }
 
 protected:
   GetDataSetIndicesVisitor() = default;
@@ -355,15 +388,10 @@ bool vtkDataAssembly::IsNodeNameValid(const char* name)
     return false;
   }
 
-  vtksys::RegularExpression regEx("[^a-zA-Z0-9\\-_.]");
-  if (regEx.find(name))
-  {
-    // found a non-acceptable character; names can contain letters,
-    // digits, hyphens, underscores, and periods.
-    return false;
-  }
-
-  return true;
+  vtksys::RegularExpression regEx("[^a-zA-Z0-9_.-]");
+  // search for non-acceptable characters; names can contain letters,
+  // digits, hyphens, underscores, and periods.
+  return !regEx.find(name);
 }
 
 //------------------------------------------------------------------------------
@@ -394,13 +422,11 @@ std::string vtkDataAssembly::MakeValidNodeName(const char* name)
     {
       result += name[cc];
     }
-    else
-    {
-      result += '_';
-    }
   }
 
-  if ((name[0] < 'a' || name[0] > 'z') && (name[0] < 'A' || name[0] > 'Z') && name[0] != '_')
+  if (result.empty() ||
+    ((result[0] < 'a' || result[0] > 'z') && (result[0] < 'A' || result[0] > 'Z') &&
+      result[0] != '_'))
   {
     return "_" + result;
   }
@@ -467,6 +493,47 @@ void vtkDataAssembly::DeepCopy(vtkDataAssembly* other)
   }
 }
 
+//------------------------------------------------------------------------------
+int vtkDataAssembly::AddSubtree(int parent, vtkDataAssembly* other, int otherParent)
+{
+  if (!other)
+  {
+    vtkErrorMacro("'other' cannot be nullptr.");
+    return -1;
+  }
+
+  auto& internals = (*this->Internals);
+  auto node = internals.FindNode(parent);
+  if (!node)
+  {
+    vtkErrorMacro("Parent node with id=" << parent << " not found.");
+    return -1;
+  }
+
+  auto& ointernals = (*other->Internals);
+  auto onode = ointernals.FindNode(otherParent);
+  if (!onode)
+  {
+    vtkErrorMacro("Note node with id=" << parent << " not found on 'other'");
+    return -1;
+  }
+
+  auto subtree = node.append_copy(onode);
+  if (otherParent == 0)
+  {
+    // remove type and version attributes.
+    subtree.remove_attribute(subtree.attribute("type"));
+    subtree.remove_attribute(subtree.attribute("version"));
+  }
+
+  // now update node ids on the copied subtree.
+  OffsetIdWalker walker(internals.MaxUniqueId + 1);
+  subtree.traverse(walker);
+
+  // reset internal datastructure (and also validate it)
+  return internals.ParseDocument(this);
+}
+
 //------------------------------------------------------------------------------
 int vtkDataAssembly::AddNode(const char* name, int parent)
 {
@@ -508,7 +575,7 @@ std::vector<int> vtkDataAssembly::AddNodes(const std::vector<std::string>& names
   {
     if (!vtkDataAssembly::IsNodeNameValid(name.c_str()))
     {
-      vtkErrorMacro("Invalid name specified '" << name.c_str() << "'.");
+      vtkErrorMacro("Invalid name specified '" << name << "'.");
       return std::vector<int>{};
     }
   }
@@ -522,7 +589,7 @@ std::vector<int> vtkDataAssembly::AddNodes(const std::vector<std::string>& names
     internals.NodeMap[child] = cnode;
     ids.push_back(child);
   }
-  if (ids.size() > 0)
+  if (!ids.empty())
   {
     this->Modified();
   }
@@ -661,7 +728,17 @@ bool vtkDataAssembly::AddDataSetIndices(int id, const std::vector<unsigned int>&
   {
     this->Modified();
   }
-  return true;
+  return modified;
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataAssembly::AddDataSetIndexRange(int id, unsigned int index_start, int count)
+{
+  // for now, we're doing this easy thing..at some point we may want to add
+  // support for storing ranges compactly.
+  std::vector<unsigned int> indices(count);
+  std::iota(indices.begin(), indices.end(), index_start);
+  return this->AddDataSetIndices(id, indices);
 }
 
 //------------------------------------------------------------------------------
@@ -730,7 +807,7 @@ bool vtkDataAssembly::RemoveAllDataSetIndices(int id, bool traverse_subtree /*=t
     dsnode.parent().remove_child(dsnode);
   }
 
-  if (to_remove.size() > 0)
+  if (!to_remove.empty())
   {
     this->Modified();
     return true;
@@ -804,6 +881,139 @@ int vtkDataAssembly::GetParent(int id) const
   return node.parent().attribute("id").as_int(-1);
 }
 
+//------------------------------------------------------------------------------
+bool vtkDataAssembly::HasAttribute(int id, const char* name) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  return (node.attribute(name));
+}
+
+//------------------------------------------------------------------------------
+void vtkDataAssembly::SetAttribute(int id, const char* name, const char* value)
+{
+  const auto& internals = (*this->Internals);
+  auto node = internals.FindNode(id);
+  auto attr = node.attribute(name);
+  if (!attr)
+  {
+    attr = node.append_attribute(name);
+  }
+  attr.set_value(value);
+  this->Modified();
+}
+
+//------------------------------------------------------------------------------
+void vtkDataAssembly::SetAttribute(int id, const char* name, int value)
+{
+  this->SetAttribute(id, name, std::to_string(value).c_str());
+}
+
+//------------------------------------------------------------------------------
+void vtkDataAssembly::SetAttribute(int id, const char* name, unsigned int value)
+{
+  this->SetAttribute(id, name, std::to_string(value).c_str());
+}
+
+//------------------------------------------------------------------------------
+#if VTK_ID_TYPE_IMPL != VTK_INT
+void vtkDataAssembly::SetAttribute(int id, const char* name, vtkIdType value)
+{
+  this->SetAttribute(id, name, std::to_string(value).c_str());
+}
+#endif
+
+//------------------------------------------------------------------------------
+bool vtkDataAssembly::GetAttribute(int id, const char* name, const char*& value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  if (auto attr = node.attribute(name))
+  {
+    value = attr.as_string();
+    return true;
+  }
+  return false;
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataAssembly::GetAttribute(int id, const char* name, int& value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  if (auto attr = node.attribute(name))
+  {
+    value = attr.as_int();
+    return true;
+  }
+  return false;
+}
+
+//------------------------------------------------------------------------------
+bool vtkDataAssembly::GetAttribute(int id, const char* name, unsigned int& value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  if (auto attr = node.attribute(name))
+  {
+    value = attr.as_uint();
+    return true;
+  }
+  return false;
+}
+
+//------------------------------------------------------------------------------
+#if VTK_ID_TYPE_IMPL != VTK_INT
+bool vtkDataAssembly::GetAttribute(int id, const char* name, vtkIdType& value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  if (auto attr = node.attribute(name))
+  {
+    value = static_cast<vtkIdType>(attr.as_llong());
+    return true;
+  }
+  return false;
+}
+#endif
+
+//------------------------------------------------------------------------------
+const char* vtkDataAssembly::GetAttributeOrDefault(
+  int id, const char* name, const char* default_value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  return node.attribute(name).as_string(default_value);
+}
+
+//------------------------------------------------------------------------------
+int vtkDataAssembly::GetAttributeOrDefault(int id, const char* name, int default_value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  return node.attribute(name).as_int(default_value);
+}
+
+//------------------------------------------------------------------------------
+unsigned int vtkDataAssembly::GetAttributeOrDefault(
+  int id, const char* name, unsigned int default_value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  return node.attribute(name).as_uint(default_value);
+}
+
+#if VTK_ID_TYPE_IMPL != VTK_INT
+//------------------------------------------------------------------------------
+vtkIdType vtkDataAssembly::GetAttributeOrDefault(
+  int id, const char* name, vtkIdType default_value) const
+{
+  const auto& internals = (*this->Internals);
+  const auto node = internals.FindNode(id);
+  return static_cast<vtkIdType>(node.attribute(name).as_llong(default_value));
+}
+#endif
+
 //------------------------------------------------------------------------------
 int vtkDataAssembly::FindFirstNodeWithName(const char* name, int traversal_order) const
 {
@@ -818,7 +1028,7 @@ int vtkDataAssembly::FindFirstNodeWithName(const char* name, int traversal_order
   {
     // catch the interrupt exception.
   }
-  return visitor->Matches.size() ? visitor->Matches.front() : -1;
+  return !visitor->Matches.empty() ? visitor->Matches.front() : -1;
 }
 
 //------------------------------------------------------------------------------
@@ -846,12 +1056,24 @@ std::vector<int> vtkDataAssembly::GetChildNodes(
 //------------------------------------------------------------------------------
 std::vector<unsigned int> vtkDataAssembly::GetDataSetIndices(
   int id, bool traverse_subtree, int traversal_order) const
+{
+  std::vector<int> ids;
+  ids.push_back(id);
+  return this->GetDataSetIndices(ids, traverse_subtree, traversal_order);
+}
+
+//------------------------------------------------------------------------------
+std::vector<unsigned int> vtkDataAssembly::GetDataSetIndices(
+  const std::vector<int>& ids, bool traverse_subtree, int traversal_order) const
 {
   vtkNew<GetDataSetIndicesVisitor> visitor;
   visitor->TraverseSubtree = traverse_subtree;
-  visitor->Root = id;
-  this->Visit(id, visitor,
-    traverse_subtree ? traversal_order : vtkDataAssembly::TraversalOrder::BreadthFirst);
+  for (const auto& nodeid : ids)
+  {
+    visitor->Root = nodeid;
+    this->Visit(nodeid, visitor,
+      traverse_subtree ? traversal_order : vtkDataAssembly::TraversalOrder::BreadthFirst);
+  }
 
   // uniquify dataset indices.
   auto& indices = visitor->DataSetIndices;
@@ -910,7 +1132,7 @@ void vtkDataAssembly::Visit(int id, vtkDataAssemblyVisitor* visitor, int travers
     visitor->Visit(id);
 
     fifo_visited.push_back(internals.NodeMap.at(id));
-    while (fifo_visited.size() > 0)
+    while (!fifo_visited.empty())
     {
       auto node = fifo_visited.front();
       fifo_visited.pop_front();
@@ -949,23 +1171,34 @@ std::vector<int> vtkDataAssembly::SelectNodes(
   for (const auto& query : path_queries)
   {
     vtkLogF(TRACE, "query='%s'", query.c_str());
-    auto set = internals.Document.select_nodes(query.c_str());
+    if (query.empty())
+    {
+      continue;
+    }
+    try
+    {
+      auto set = internals.Document.select_nodes(query.c_str());
 
-    auto notUsed = std::accumulate(set.begin(), set.end(), &visitor->UnorderedSelectedNodes,
-      [&internals](std::unordered_set<int>* result, const pugi::xpath_node& xnode) {
-        if (xnode.node() == internals.Document)
-        {
-          // note: if xpath matches the document, the xnode is the document and not the
-          // first-child and the attribute request fails.
-          result->insert(0);
-        }
-        else if (::IsAssemblyNode(xnode.node()))
-        {
-          result->insert(xnode.node().attribute("id").as_int(-1));
-        }
-        return result;
-      });
-    (void)notUsed;
+      auto notUsed = std::accumulate(set.begin(), set.end(), &visitor->UnorderedSelectedNodes,
+        [&internals](std::unordered_set<int>* result, const pugi::xpath_node& xnode) {
+          if (xnode.node() == internals.Document)
+          {
+            // note: if xpath matches the document, the xnode is the document and not the
+            // first-child and the attribute request fails.
+            result->insert(0);
+          }
+          else if (::IsAssemblyNode(xnode.node()))
+          {
+            result->insert(xnode.node().attribute("id").as_int(-1));
+          }
+          return result;
+        });
+      (void)notUsed;
+    }
+    catch (pugi::xpath_exception& exp)
+    {
+      vtkLogF(TRACE, "xpath exception: %s", exp.what());
+    }
   }
 
   this->Visit(visitor, traversal_order);
@@ -1007,15 +1240,8 @@ bool vtkDataAssembly::RemapDataSetIndices(
 //------------------------------------------------------------------------------
 void vtkDataAssembly::SubsetCopy(vtkDataAssembly* other, const std::vector<int>& selected_branches)
 {
-  if (other == nullptr)
-  {
-    this->Initialize();
-    return;
-  }
-
   this->Initialize();
-  this->SetRootNodeName(other->GetRootNodeName());
-  if (selected_branches.size() == 0)
+  if (other == nullptr)
   {
     return;
   }
@@ -1023,6 +1249,19 @@ void vtkDataAssembly::SubsetCopy(vtkDataAssembly* other, const std::vector<int>&
   auto& internals = (*this->Internals);
   const auto& ointernals = (*other->Internals);
 
+  if (selected_branches.empty())
+  {
+    auto src = ointernals.Document.first_child();
+    auto dest = internals.Document.first_child();
+
+    dest.set_name(src.name());
+    for (const auto& attribute : src.attributes())
+    {
+      dest.append_copy(attribute);
+    }
+    return;
+  }
+
   std::unordered_set<int> complete_subtree;
   std::unordered_set<int> partial_subtree;
 
@@ -1055,6 +1294,11 @@ void vtkDataAssembly::SubsetCopy(vtkDataAssembly* other, const std::vector<int>&
   std::function<void(const pugi::xml_node&, pugi::xml_node)> subset_copier;
   subset_copier = [&partial_subtree, &complete_subtree, &subset_copier](
                     const pugi::xml_node& src, pugi::xml_node dest) -> void {
+    // first, copy src attributes over.
+    for (const auto& attribute : src.attributes())
+    {
+      dest.append_copy(attribute);
+    }
     for (const auto& child : src.children())
     {
       if (::IsAssemblyNode(child))
@@ -1067,7 +1311,6 @@ void vtkDataAssembly::SubsetCopy(vtkDataAssembly* other, const std::vector<int>&
         else if (partial_subtree.find(id) != partial_subtree.end())
         {
           auto dest_child = dest.append_child(child.name());
-          dest_child.append_copy(child.attribute("id"));
           subset_copier(child, dest_child);
         }
       }
@@ -1091,3 +1334,4 @@ void vtkDataAssembly::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "XML Representation : " << endl << endl;
   this->Internals->Document.save(os, "    ");
 }
+VTK_ABI_NAMESPACE_END
