@@ -29,7 +29,7 @@
  * @sa
  * vtkDataSet vtkFieldData vtkDataObjectToDataSetFilter
  * vtkFieldDataToAttributeDataFilter
-*/
+ */
 
 #ifndef vtkDataObject_h
 #define vtkDataObject_h
@@ -37,6 +37,7 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkDataSetAttributes;
 class vtkFieldData;
@@ -50,26 +51,27 @@ class vtkInformationIntegerVectorKey;
 class vtkInformationStringKey;
 class vtkInformationVector;
 class vtkInformationInformationVectorKey;
+class vtkUnsignedCharArray;
 
-#define VTK_PIECES_EXTENT   0
-#define VTK_3D_EXTENT       1
-#define VTK_TIME_EXTENT     2
+#define VTK_PIECES_EXTENT 0
+#define VTK_3D_EXTENT 1
+#define VTK_TIME_EXTENT 2
 
 class VTKCOMMONDATAMODEL_EXPORT vtkDataObject : public vtkObject
 {
 public:
-  static vtkDataObject *New();
+  static vtkDataObject* New();
 
-  vtkTypeMacro(vtkDataObject,vtkObject);
+  vtkTypeMacro(vtkDataObject, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the information object associated with this data object.
    */
   vtkGetObjectMacro(Information, vtkInformation);
   virtual void SetInformation(vtkInformation*);
-  //@}
+  ///@}
 
   /**
    * Data objects are composite objects and need to check each part for MTime.
@@ -89,32 +91,31 @@ public:
    */
   void ReleaseData();
 
-  //@{
+  ///@{
   /**
    * Get the flag indicating the data has been released.
    */
-  vtkGetMacro(DataReleased,int);
-  //@}
+  vtkGetMacro(DataReleased, int);
+  ///@}
 
-
-  //@{
+  ///@{
   /**
    * Turn on/off flag to control whether every object releases its data
    * after being used by a filter.
    */
   static void SetGlobalReleaseDataFlag(int val);
-  void GlobalReleaseDataFlagOn() {this->SetGlobalReleaseDataFlag(1);};
-  void GlobalReleaseDataFlagOff() {this->SetGlobalReleaseDataFlag(0);};
+  void GlobalReleaseDataFlagOn() { this->SetGlobalReleaseDataFlag(1); }
+  void GlobalReleaseDataFlagOff() { this->SetGlobalReleaseDataFlag(0); }
   static int GetGlobalReleaseDataFlag();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Assign or retrieve a general field data to this data object.
    */
   virtual void SetFieldData(vtkFieldData*);
-  vtkGetObjectMacro(FieldData,vtkFieldData);
-  //@}
+  vtkGetObjectMacro(FieldData, vtkFieldData);
+  ///@}
 
   /**
    * Return class name of data type. This is one of VTK_STRUCTURED_GRID,
@@ -122,7 +123,7 @@ public:
    * VTK_RECTILINEAR_GRID (see vtkSetGet.h for definitions).
    * THIS METHOD IS THREAD SAFE
    */
-  virtual int GetDataObjectType() {return VTK_DATA_OBJECT;}
+  virtual int GetDataObjectType() { return VTK_DATA_OBJECT; }
 
   /**
    * Used by Threaded ports to determine if they should initiate an
@@ -143,8 +144,7 @@ public:
    * Copy from the pipeline information to the data object's own information.
    * Called right before the main execution pass.
    */
-  virtual void CopyInformationFromPipeline(vtkInformation* vtkNotUsed(info))
-  {}
+  virtual void CopyInformationFromPipeline(vtkInformation* vtkNotUsed(info)) {}
 
   /**
    * Copy information from this data object to the pipeline information.
@@ -159,23 +159,22 @@ public:
    * (FIELD_ASSOCIATION_POINTS or FIELD_ASSOCIATION_CELLS) and attribute
    * (SCALARS, VECTORS, NORMALS, TCOORDS, or TENSORS)
    */
-  static vtkInformation *GetActiveFieldInformation(vtkInformation *info,
-    int fieldAssociation, int attributeType);
+  static vtkInformation* GetActiveFieldInformation(
+    vtkInformation* info, int fieldAssociation, int attributeType);
 
   /**
    * Return the information object within the input information object's
    * field data corresponding to the specified association
    * (FIELD_ASSOCIATION_POINTS or FIELD_ASSOCIATION_CELLS) and name.
    */
-  static vtkInformation *GetNamedFieldInformation(vtkInformation *info,
-    int fieldAssociation, const char *name);
+  static vtkInformation* GetNamedFieldInformation(
+    vtkInformation* info, int fieldAssociation, const char* name);
 
   /**
    * Remove the info associated with an array
    */
-  static void RemoveNamedFieldInformation(vtkInformation *info,
-                                          int fieldAssociation,
-                                          const char *name);
+  static void RemoveNamedFieldInformation(
+    vtkInformation* info, int fieldAssociation, const char* name);
 
   /**
    * Set the named array to be the active field for the specified type
@@ -183,8 +182,8 @@ public:
    * (FIELD_ASSOCIATION_POINTS or FIELD_ASSOCIATION_CELLS).  Returns the
    * active field information object and creates on entry if one not found.
    */
-  static vtkInformation *SetActiveAttribute(vtkInformation *info,
-    int fieldAssociation, const char *attributeName, int attributeType);
+  static vtkInformation* SetActiveAttribute(
+    vtkInformation* info, int fieldAssociation, const char* attributeName, int attributeType);
 
   /**
    * Set the name, array type, number of components, and number of tuples
@@ -195,16 +194,14 @@ public:
    * arrayType, numComponents, or numTuples equal to -1, or name=nullptr the
    * value is not changed.
    */
-  static void SetActiveAttributeInfo(vtkInformation *info,
-    int fieldAssociation, int attributeType, const char *name, int arrayType,
-    int numComponents, int numTuples);
+  static void SetActiveAttributeInfo(vtkInformation* info, int fieldAssociation, int attributeType,
+    const char* name, int arrayType, int numComponents, int numTuples);
 
   /**
    * Convenience version of previous method for use (primarily) by the Imaging
    * filters. If arrayType or numComponents == -1, the value is not changed.
    */
-  static void SetPointDataActiveScalarInfo(vtkInformation *info,
-    int arrayType, int numComponents);
+  static void SetPointDataActiveScalarInfo(vtkInformation* info, int arrayType, int numComponents);
 
   /**
    * This method is called by the source when it executes to generate data.
@@ -218,16 +215,25 @@ public:
    * objects we just call Initialize. But for vtkImageData we leave the old
    * data in case the memory can be reused.
    */
-  virtual void PrepareForNewData() {this->Initialize();};
+  virtual void PrepareForNewData() { this->Initialize(); }
 
-  //@{
   /**
-   * Shallow and Deep copy.  These copy the data, but not any of the
-   * pipeline connections.
+   * The goal of the method is to copy the data up to the array pointers only.
+   * The implementation is delegated to the differenent subclasses.
+   * If you want to copy the actual data, @see DeepCopy.
+   *
+   * This method shallow copy the field data and copy the internal structure.
    */
-  virtual void ShallowCopy(vtkDataObject *src);
-  virtual void DeepCopy(vtkDataObject *src);
-  //@}
+  virtual void ShallowCopy(vtkDataObject* src);
+
+  /**
+   * The goal of the method is to copy the complete data from src into this object.
+   * The implementation is delegated to the differenent subclasses.
+   * If you want to copy the data up to the array pointers only, @see ShallowCopy.
+   *
+   * This method deep copy the field data and copy the internal structure.
+   */
+  virtual void DeepCopy(vtkDataObject* src);
 
   /**
    * The ExtentType will be left as VTK_PIECES_EXTENT for data objects
@@ -237,7 +243,7 @@ public:
    * and vtkStructuredGrid. The default is the have an extent in pieces,
    * with only one piece (no streaming possible).
    */
-  virtual int GetExtentType() { return VTK_PIECES_EXTENT; };
+  virtual int GetExtentType() { return VTK_PIECES_EXTENT; }
 
   /**
    * This method crops the data object (if necessary) so that the extent
@@ -290,9 +296,26 @@ public:
    * field data is stored as a vtkFieldData instance, not a
    * vtkDataSetAttributes instance. To retrieve field data, use
    * GetAttributesAsFieldData.
+   *
+   * @warning This method NEEDS to be
+   * overridden in subclasses to work as documented.
+   * If not, it returns nullptr for any type but FIELD.
    */
   virtual vtkDataSetAttributes* GetAttributes(int type);
 
+  /**
+   * Returns the ghost arrays of the data object of the specified
+   * attribute type. The type may be:
+   * <ul>
+   * <li>POINT    - Defined in vtkDataSet subclasses
+   * <li>CELL   - Defined in vtkDataSet subclasses.
+   * </ul>
+   * The other attribute types, will return nullptr since
+   * ghosts arrays are not defined for now outside of
+   * point or cell.
+   */
+  virtual vtkUnsignedCharArray* GetGhostArray(int type);
+
   /**
    * Returns the attributes of the data object as a vtkFieldData.
    * This returns non-null values in all the same cases as GetAttributes,
@@ -326,15 +349,15 @@ public:
 
   /**
    * Given an integer association type, this static method returns a string type
-   * for the attribute (i.e. type = 0: returns "Points").
+   * for the attribute (i.e. associationType = 0: returns "Points").
    */
   static const char* GetAssociationTypeAsString(int associationType);
 
   /**
-   * Given an integer association type, this static method returns a string type
-   * for the attribute (i.e. type = 0: returns "Points").
+   * Given a string association name, this static method returns an integer association type
+   * for the attribute (i.e. associationName = "Points": returns 0).
    */
-  static int GetAssociationTypeFromString(const char* associationType);
+  static int GetAssociationTypeFromString(const char* associationName);
 
   // \ingroup InformationKeys
   static vtkInformationStringKey* DATA_TYPE_NAME();
@@ -395,21 +418,20 @@ public:
   // \ingroup InformationKeys
   static vtkInformationDataObjectKey* SIL();
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkDataObject* GetData(vtkInformation* info);
-  static vtkDataObject* GetData(vtkInformationVector* v, int i=0);
-  //@}
+  static vtkDataObject* GetData(vtkInformationVector* v, int i = 0);
+  ///@}
 
 protected:
-
   vtkDataObject();
   ~vtkDataObject() override;
 
   // General field data associated with data object
-  vtkFieldData  *FieldData;
+  vtkFieldData* FieldData;
 
   // Keep track of data release during network execution
   int DataReleased;
@@ -422,12 +444,12 @@ protected:
 
 private:
   // Helper method for the ShallowCopy and DeepCopy methods.
-  void InternalDataObjectCopy(vtkDataObject *src);
+  void InternalDataObjectCopy(vtkDataObject* src);
 
 private:
   vtkDataObject(const vtkDataObject&) = delete;
   void operator=(const vtkDataObject&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
