@@ -21,10 +21,12 @@
 #include "vtkInformationIntegerKey.h"
 #include "vtkInformationStringKey.h"
 #include "vtkInformationVector.h"
+#include "vtkLegacy.h"
 #include "vtkMultiPieceDataSet.h"
 #include "vtkObjectFactory.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkDataObjectTree::vtkDataObjectTree()
 {
   this->Internals = new vtkDataObjectTreeInternals;
@@ -150,29 +152,28 @@ void vtkDataObjectTree::CopyStructure(vtkCompositeDataSet* compositeSource)
   {
     return;
   }
-  vtkDataObjectTree* source = vtkDataObjectTree::SafeDownCast(compositeSource);
-  if (source == this)
+  vtkDataObjectTree* dObjTree = vtkDataObjectTree::SafeDownCast(compositeSource);
+  if (dObjTree == this)
   {
     return;
   }
 
   this->Superclass::CopyStructure(compositeSource);
   this->Internals->Children.clear();
-  if (!source)
+
+  if (!dObjTree)
   {
     // WARNING:
     // If we copy the structure of from a non-tree composite data set
     // we create a special structure of two levels, the first level
     // is just a single multipiece and the second level are all the data sets.
     // This is likely to change in the future!
-    vtkMultiPieceDataSet* mds = vtkMultiPieceDataSet::New();
+    vtkNew<vtkMultiPieceDataSet> mds;
     this->SetChild(0, mds);
-    mds->Delete();
 
-    vtkInformation* info = vtkInformation::New();
+    vtkNew<vtkInformation> info;
     info->Set(vtkCompositeDataSet::NAME(), "All Blocks");
     this->SetChildMetaData(0, info);
-    info->FastDelete();
 
     int totalNumBlocks = 0;
     vtkCompositeDataIterator* iter = compositeSource->NewIterator();
@@ -184,36 +185,36 @@ void vtkDataObjectTree::CopyStructure(vtkCompositeDataSet* compositeSource)
     iter->Delete();
 
     mds->SetNumberOfChildren(totalNumBlocks);
-    return;
   }
-
-  this->Internals->Children.resize(source->Internals->Children.size());
-
-  vtkDataObjectTreeInternals::Iterator srcIter = source->Internals->Children.begin();
-  vtkDataObjectTreeInternals::Iterator myIter = this->Internals->Children.begin();
-  for (; srcIter != source->Internals->Children.end(); ++srcIter, ++myIter)
+  else
   {
-    vtkDataObjectTree* compositeSrc = vtkDataObjectTree::SafeDownCast(srcIter->DataObject);
-    if (compositeSrc)
-    {
-      if (vtkDataObjectTree* copy = this->CreateForCopyStructure(compositeSrc))
-      {
-        myIter->DataObject.TakeReference(copy);
-        copy->CopyStructure(compositeSrc);
-      }
-      else
-      {
-        vtkErrorMacro("CopyStructure has encountered an error and will fail!");
-      }
-    }
+    this->Internals->Children.resize(dObjTree->Internals->Children.size());
 
-    // shallow copy meta data.
-    if (srcIter->MetaData)
+    for (auto dObjTreeIter = dObjTree->Internals->Children.begin(),
+              thisIter = this->Internals->Children.begin();
+         dObjTreeIter != dObjTree->Internals->Children.end(); ++dObjTreeIter, ++thisIter)
     {
-      vtkInformation* info = vtkInformation::New();
-      info->Copy(srcIter->MetaData, /*deep=*/0);
-      myIter->MetaData = info;
-      info->FastDelete();
+      vtkDataObjectTree* subDObjTree = vtkDataObjectTree::SafeDownCast(dObjTreeIter->DataObject);
+      if (subDObjTree)
+      {
+        if (vtkDataObjectTree* copy = this->CreateForCopyStructure(subDObjTree))
+        {
+          thisIter->DataObject.TakeReference(copy);
+          copy->CopyStructure(subDObjTree);
+        }
+        else
+        {
+          vtkErrorMacro("CopyStructure has encountered an error and will fail!");
+        }
+      }
+
+      // shallow copy meta data.
+      if (dObjTreeIter->MetaData)
+      {
+        vtkNew<vtkInformation> info;
+        info->Copy(dObjTreeIter->MetaData, /*deep=*/0);
+        thisIter->MetaData = info;
+      }
     }
   }
   this->Modified();
@@ -470,7 +471,7 @@ int vtkDataObjectTree::HasMetaData(vtkCompositeDataIterator* compositeIter)
 }
 
 //------------------------------------------------------------------------------
-void vtkDataObjectTree::ShallowCopy(vtkDataObject* src)
+void vtkDataObjectTree::CompositeShallowCopy(vtkCompositeDataSet* src)
 {
   if (src == this)
   {
@@ -478,7 +479,7 @@ void vtkDataObjectTree::ShallowCopy(vtkDataObject* src)
   }
 
   this->Internals->Children.clear();
-  this->Superclass::ShallowCopy(src);
+  this->Superclass::CompositeShallowCopy(src);
 
   vtkDataObjectTree* from = vtkDataObjectTree::SafeDownCast(src);
   if (from)
@@ -490,10 +491,11 @@ void vtkDataObjectTree::ShallowCopy(vtkDataObject* src)
       vtkDataObject* child = from->GetChild(cc);
       if (child)
       {
-        if (child->IsA("vtkDataObjectTree"))
+        vtkDataObjectTree* childTree = vtkDataObjectTree::SafeDownCast(child);
+        if (childTree)
         {
-          vtkDataObject* clone = child->NewInstance();
-          clone->ShallowCopy(child);
+          vtkDataObjectTree* clone = childTree->NewInstance();
+          clone->CompositeShallowCopy(childTree);
           this->SetChild(cc, clone);
           clone->FastDelete();
         }
@@ -505,7 +507,7 @@ void vtkDataObjectTree::ShallowCopy(vtkDataObject* src)
       if (from->HasChildMetaData(cc))
       {
         vtkInformation* toInfo = this->GetChildMetaData(cc);
-        toInfo->Copy(from->GetChildMetaData(cc), /*deep=*/0);
+        toInfo->Copy(from->GetChildMetaData(cc), 0);
       }
     }
   }
@@ -548,6 +550,49 @@ void vtkDataObjectTree::DeepCopy(vtkDataObject* src)
   this->Modified();
 }
 
+//------------------------------------------------------------------------------
+void vtkDataObjectTree::ShallowCopy(vtkDataObject* src)
+{
+  if (src == this)
+  {
+    return;
+  }
+
+  this->Internals->Children.clear();
+  this->Superclass::ShallowCopy(src);
+
+  vtkDataObjectTree* from = vtkDataObjectTree::SafeDownCast(src);
+  if (from)
+  {
+    unsigned int numChildren = from->GetNumberOfChildren();
+    this->SetNumberOfChildren(numChildren);
+    for (unsigned int cc = 0; cc < numChildren; cc++)
+    {
+      vtkDataObject* child = from->GetChild(cc);
+      if (child)
+      {
+        auto clone = child->NewInstance();
+        clone->ShallowCopy(child);
+        this->SetChild(cc, clone);
+        clone->FastDelete();
+      }
+      if (from->HasChildMetaData(cc))
+      {
+        vtkInformation* toInfo = this->GetChildMetaData(cc);
+        toInfo->Copy(from->GetChildMetaData(cc), /*deep=*/0);
+      }
+    }
+  }
+  this->Modified();
+}
+
+//------------------------------------------------------------------------------
+void vtkDataObjectTree::RecursiveShallowCopy(vtkDataObject* src)
+{
+  VTK_LEGACY_REPLACED_BODY(RecursiveShallowCopy, "VTK 9.3", ShallowCopy);
+  this->ShallowCopy(src);
+}
+
 //------------------------------------------------------------------------------
 void vtkDataObjectTree::Initialize()
 {
@@ -628,3 +673,4 @@ void vtkDataObjectTree::PrintSelf(ostream& os, vtkIndent indent)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
