@@ -35,7 +35,9 @@
 
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkCompositeDataSet.h"
+#include "vtkDeprecation.h" // For VTK_DEPRECATED_IN_9_3_0
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataIterator;
 class vtkDataObjectTreeIterator;
 class vtkDataObjectTreeInternals;
@@ -83,8 +85,10 @@ public:
    */
   void SetDataSetFrom(vtkDataObjectTreeIterator* iter, vtkDataObject* dataObj);
 
+  // Needed because, otherwise vtkCompositeData::GetDataSet(unsigned int flatIndex) is hidden.
+  using Superclass::GetDataSet;
   /**
-   * Returns the dataset located at the positiong pointed by the iterator.
+   * Returns the dataset located at the position pointed by the iterator.
    * The iterator does not need to be iterating over this dataset itself. It can
    * be an iterator for composite dataset with similar structure (achieved by
    * using CopyStructure).
@@ -120,13 +124,20 @@ public:
    */
   void Initialize() override;
 
-  //@{
+  ///@{
   /**
-   * Shallow and Deep copy.
+   * CompositeShallow, Shallow and Deep copy.
    */
+  void CompositeShallowCopy(vtkCompositeDataSet* src) override;
   void ShallowCopy(vtkDataObject* src) override;
   void DeepCopy(vtkDataObject* src) override;
-  //@}
+  ///@}
+
+  /**
+   * @deprecated RecursiveShallowCopy method, @see ShallowCopy
+   */
+  VTK_DEPRECATED_IN_9_3_0("Please use ShallowCopy instead.")
+  void RecursiveShallowCopy(vtkDataObject* src) override;
 
   /**
    * Returns the total number of points of all blocks. This will
@@ -142,13 +153,18 @@ public:
    */
   vtkIdType GetNumberOfCells() override;
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkDataObjectTree* GetData(vtkInformation* info);
   static vtkDataObjectTree* GetData(vtkInformationVector* v, int i = 0);
-  //@}
+  ///@}
+
+  /**
+   * Overridden to return `VTK_DATA_OBJECT_TREE`.
+   */
+  int GetDataObjectType() override { return VTK_DATA_OBJECT_TREE; }
 
 protected:
   vtkDataObjectTree();
@@ -216,4 +232,5 @@ private:
   void operator=(const vtkDataObjectTree&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
