@@ -27,6 +27,7 @@
 #include "vtkCompositeDataIterator.h"
 #include "vtkSmartPointer.h" //to store data sets
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataObjectTree;
 class vtkDataObjectTreeInternals;
 class vtkDataObjectTreeIndex;
@@ -84,7 +85,7 @@ public:
    */
   unsigned int GetCurrentFlatIndex() override;
 
-  //@{
+  ///@{
   /**
    * If VisitOnlyLeaves is true, the iterator will only visit nodes
    * (sub-datasets) that are not composite. If it encounters a composite
@@ -98,9 +99,9 @@ public:
   vtkSetMacro(VisitOnlyLeaves, vtkTypeBool);
   vtkGetMacro(VisitOnlyLeaves, vtkTypeBool);
   vtkBooleanMacro(VisitOnlyLeaves, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If TraverseSubTree is set to true, the iterator will visit the entire tree
    * structure, otherwise it only visits the first level children. Set to 1 by
@@ -109,7 +110,7 @@ public:
   vtkSetMacro(TraverseSubTree, vtkTypeBool);
   vtkGetMacro(TraverseSubTree, vtkTypeBool);
   vtkBooleanMacro(TraverseSubTree, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkDataObjectTreeIterator();
@@ -144,6 +145,10 @@ private:
   class vtkInternals;
   vtkInternals* Internals;
   friend class vtkInternals;
+  /**
+   * Used to improve the speed of vtkDataObjectTree::SafeDownCast().
+   */
+  static bool IsDataObjectTree(vtkDataObject* dataObject);
 
   vtkTypeBool TraverseSubTree;
   vtkTypeBool VisitOnlyLeaves;
@@ -158,4 +163,5 @@ private:
   void UpdateLocation();
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
