@@ -42,7 +42,9 @@
 
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkDataObject.h"
+#include "vtkDeprecation.h" // for VTK_DEPRECATED_IN_9_3_0
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCell;
 class vtkCellData;
 class vtkCellIterator;
@@ -161,7 +163,7 @@ public:
    * THIS METHOD IS THREAD SAFE IF FIRST CALLED FROM A SINGLE THREAD AND
    * THE DATASET IS NOT MODIFIED
    *
-   * @warning This method MUST be overriden for performance reasons.
+   * @warning This method MUST be overridden for performance reasons.
    * Default implementation is very unefficient.
    */
   virtual vtkIdType GetCellSize(vtkIdType cellId);
@@ -184,6 +186,21 @@ public:
    */
   virtual void GetCellPoints(vtkIdType cellId, vtkIdList* ptIds) = 0;
 
+  /**
+   * Topological inquiry to get points defining cell.
+   *
+   * This function MAY use ptIds, which is an object that is created by each thread,
+   * to guarantee thread safety.
+   *
+   * @warning Subsequent calls to this method may invalidate previous call
+   * results.
+   *
+   * THIS METHOD IS THREAD SAFE IF FIRST CALLED FROM A SINGLE THREAD AND
+   * THE DATASET IS NOT MODIFIED
+   */
+  virtual void GetCellPoints(vtkIdType cellId, vtkIdType& npts, vtkIdType const*& pts,
+    vtkIdList* ptIds) VTK_SIZEHINT(pts, npts);
+
   /**
    * Topological inquiry to get cells using point.
    * THIS METHOD IS THREAD SAFE IF FIRST CALLED FROM A SINGLE THREAD AND
@@ -319,6 +336,13 @@ public:
    */
   double GetLength();
 
+  /**
+   * Return the squared length of the diagonal of the bounding box.
+   * THIS METHOD IS THREAD SAFE IF FIRST CALLED FROM A SINGLE THREAD AND
+   * THE DATASET IS NOT MODIFIED
+   */
+  double GetLength2();
+
   /**
    * Restore data object to initial state.
    * THIS METHOD IS NOT THREAD SAFE.
@@ -454,10 +478,12 @@ public:
    * We cache the pointer to the array to save a lookup involving string comparisons
    */
   vtkUnsignedCharArray* GetPointGhostArray();
+
   /**
    * Updates the pointer to the point ghost array.
    */
-  void UpdatePointGhostArrayCache();
+  VTK_DEPRECATED_IN_9_3_0("This function is deprecated. It has no effect.")
+  void UpdatePointGhostArrayCache() {}
 
   /**
    * Allocate ghost array for points.
@@ -469,10 +495,12 @@ public:
    * We cache the pointer to the array to save a lookup involving string comparisons
    */
   vtkUnsignedCharArray* GetCellGhostArray();
+
   /**
    * Updates the pointer to the cell ghost array.
    */
-  void UpdateCellGhostArrayCache();
+  VTK_DEPRECATED_IN_9_3_0("This function is deprecated. It has no effect.")
+  void UpdateCellGhostArrayCache() {}
 
   /**
    * Allocate ghost array for cells.
@@ -496,12 +524,6 @@ protected:
    */
   virtual void ComputeScalarRange();
 
-  /**
-   * Helper function that tests if any of the values in 'a' have bitFlag set.
-   * The test performed is (value & bitFlag).
-   */
-  bool IsAnyBitSet(vtkUnsignedCharArray* a, int bitFlag);
-
   vtkCellData* CellData;            // Scalars, vectors, etc. associated w/ each cell
   vtkPointData* PointData;          // Scalars, vectors, etc. associated w/ each point
   vtkCallbackCommand* DataObserver; // Observes changes to cell/point data
@@ -520,9 +542,13 @@ protected:
    * These arrays pointers are caches used to avoid a string comparison (when
    * getting ghost arrays using GetArray(name))
    */
+  VTK_DEPRECATED_IN_9_3_0("This member is deprecated. It's no longer used.")
   vtkUnsignedCharArray* PointGhostArray;
+  VTK_DEPRECATED_IN_9_3_0("This member is deprecated. It's no longer used.")
   vtkUnsignedCharArray* CellGhostArray;
+  VTK_DEPRECATED_IN_9_3_0("This member is deprecated. It's no longer used.")
   bool PointGhostArrayCached;
+  VTK_DEPRECATED_IN_9_3_0("This member is deprecated. It's no longer used.")
   bool CellGhostArrayCached;
   ///@}
 
@@ -535,8 +561,6 @@ private:
   static void OnDataModified(
     vtkObject* source, unsigned long eid, void* clientdata, void* calldata);
 
-  friend class vtkImageAlgorithmToDataSetFriendship;
-
 private:
   vtkDataSet(const vtkDataSet&) = delete;
   void operator=(const vtkDataSet&) = delete;
@@ -550,4 +574,5 @@ inline void vtkDataSet::GetPoint(vtkIdType id, double x[3])
   x[2] = pt[2];
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
