@@ -29,30 +29,31 @@
 
 #include <vector>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // class vtkDirectedGraph
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkDirectedGraph);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDirectedGraph::vtkDirectedGraph() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDirectedGraph::~vtkDirectedGraph() = default;
 
-//----------------------------------------------------------------------------
-vtkDirectedGraph *vtkDirectedGraph::GetData(vtkInformation *info)
+//------------------------------------------------------------------------------
+vtkDirectedGraph* vtkDirectedGraph::GetData(vtkInformation* info)
 {
-  return info? vtkDirectedGraph::SafeDownCast(info->Get(DATA_OBJECT())) : nullptr;
+  return info ? vtkDirectedGraph::SafeDownCast(info->Get(DATA_OBJECT())) : nullptr;
 }
 
-//----------------------------------------------------------------------------
-vtkDirectedGraph *vtkDirectedGraph::GetData(vtkInformationVector *v, int i)
+//------------------------------------------------------------------------------
+vtkDirectedGraph* vtkDirectedGraph::GetData(vtkInformationVector* v, int i)
 {
   return vtkDirectedGraph::GetData(v->GetInformationObject(i));
 }
 
-//----------------------------------------------------------------------------
-bool vtkDirectedGraph::IsStructureValid(vtkGraph *g)
+//------------------------------------------------------------------------------
+bool vtkDirectedGraph::IsStructureValid(vtkGraph* g)
 {
   if (!g)
   {
@@ -66,10 +67,8 @@ bool vtkDirectedGraph::IsStructureValid(vtkGraph *g)
   // Verify that each edge appears in exactly one in and one out edge list.
   std::vector<bool> in(g->GetNumberOfEdges(), false);
   std::vector<bool> out(g->GetNumberOfEdges(), false);
-  vtkSmartPointer<vtkInEdgeIterator> inIter =
-    vtkSmartPointer<vtkInEdgeIterator>::New();
-  vtkSmartPointer<vtkOutEdgeIterator> outIter =
-    vtkSmartPointer<vtkOutEdgeIterator>::New();
+  vtkSmartPointer<vtkInEdgeIterator> inIter = vtkSmartPointer<vtkInEdgeIterator>::New();
+  vtkSmartPointer<vtkOutEdgeIterator> outIter = vtkSmartPointer<vtkOutEdgeIterator>::New();
   for (vtkIdType v = 0; v < g->GetNumberOfVertices(); ++v)
   {
     g->GetInEdges(v, inIter);
@@ -95,7 +94,7 @@ bool vtkDirectedGraph::IsStructureValid(vtkGraph *g)
   }
   for (vtkIdType i = 0; i < g->GetNumberOfEdges(); ++i)
   {
-    if (in[i] == false || out[i] == false)
+    if (!in[i] || !out[i])
     {
       return false;
     }
@@ -104,8 +103,9 @@ bool vtkDirectedGraph::IsStructureValid(vtkGraph *g)
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDirectedGraph::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
