@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkGenericCell.h"
 
 #include "vtkBezierCurve.h"
@@ -63,12 +60,14 @@
 #include "vtkQuadraticWedge.h"
 #include "vtkTetra.h"
 #include "vtkTriQuadraticHexahedron.h"
+#include "vtkTriQuadraticPyramid.h"
 #include "vtkTriangle.h"
 #include "vtkTriangleStrip.h"
 #include "vtkVertex.h"
 #include "vtkVoxel.h"
 #include "vtkWedge.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGenericCell);
 
 //------------------------------------------------------------------------------
@@ -352,6 +351,9 @@ vtkCell* vtkGenericCell::InstantiateCell(int cellType)
     case VTK_TRIQUADRATIC_HEXAHEDRON:
       cell = vtkTriQuadraticHexahedron::New();
       break;
+    case VTK_TRIQUADRATIC_PYRAMID:
+      cell = vtkTriQuadraticPyramid::New();
+      break;
     case VTK_QUADRATIC_LINEAR_WEDGE:
       cell = vtkQuadraticLinearWedge::New();
       break;
@@ -496,3 +498,4 @@ void vtkGenericCell::SetPointIds(vtkIdList* pointIds)
     this->Cell->PointIds->Register(this);
   }
 }
+VTK_ABI_NAMESPACE_END
