@@ -25,6 +25,7 @@
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkGenericDataSet, Tessellator, vtkGenericCellTessellator);
 
 //------------------------------------------------------------------------------
@@ -45,6 +46,22 @@ vtkGenericDataSet::~vtkGenericDataSet()
   this->Attributes->Delete();
 }
 
+//------------------------------------------------------------------------------
+vtkIdType vtkGenericDataSet::GetNumberOfElements(int type)
+{
+  switch (type)
+  {
+    case vtkDataObject::POINT:
+      return this->GetNumberOfPoints();
+
+    case vtkDataObject::CELL:
+      return this->GetNumberOfCells();
+
+    default:
+      return this->Superclass::GetNumberOfElements(type);
+  }
+}
+
 //------------------------------------------------------------------------------
 void vtkGenericDataSet::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -217,3 +234,4 @@ vtkGenericDataSet* vtkGenericDataSet::GetData(vtkInformationVector* v, int i)
 {
   return vtkGenericDataSet::GetData(v->GetInformationObject(i));
 }
+VTK_ABI_NAMESPACE_END
