@@ -15,6 +15,7 @@
 #include "vtkGenericPointIterator.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkGenericPointIterator::vtkGenericPointIterator() = default;
 
 //------------------------------------------------------------------------------
@@ -25,3 +26,4 @@ void vtkGenericPointIterator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
