@@ -49,6 +49,7 @@
 #include <set>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 double vtkGraph::DefaultPoint[3] = { 0, 0, 0 };
 
 //------------------------------------------------------------------------------
@@ -128,7 +129,7 @@ double* vtkGraph::GetPoint(vtkIdType ptId)
   {
     return this->Points->GetPoint(ptId);
   }
-  return this->DefaultPoint;
+  return vtkGraph::DefaultPoint;
 }
 
 //------------------------------------------------------------------------------
@@ -155,7 +156,7 @@ void vtkGraph::GetPoint(vtkIdType ptId, double x[3])
   {
     for (int i = 0; i < 3; i++)
     {
-      x[i] = this->DefaultPoint[i];
+      x[i] = vtkGraph::DefaultPoint[i];
     }
   }
 }
@@ -322,7 +323,7 @@ void vtkGraph::GetOutEdges(vtkIdType v, const vtkOutEdgeType*& edges, vtkIdType&
   nedges = static_cast<vtkIdType>(this->Internals->Adjacency[index].OutEdges.size());
   if (nedges > 0)
   {
-    edges = &(this->Internals->Adjacency[index].OutEdges[0]);
+    edges = this->Internals->Adjacency[index].OutEdges.data();
   }
   else
   {
@@ -440,7 +441,7 @@ void vtkGraph::GetInEdges(vtkIdType v, const vtkInEdgeType*& edges, vtkIdType& n
   nedges = static_cast<vtkIdType>(this->Internals->Adjacency[index].InEdges.size());
   if (nedges > 0)
   {
-    edges = &(this->Internals->Adjacency[index].InEdges[0]);
+    edges = this->Internals->Adjacency[index].InEdges.data();
   }
   else
   {
@@ -936,7 +937,7 @@ void vtkGraph::GetEdgePoints(vtkIdType e, vtkIdType& npts, double*& pts)
   npts = static_cast<vtkIdType>(this->EdgePoints->Storage[e].size() / 3);
   if (npts > 0)
   {
-    pts = &this->EdgePoints->Storage[e][0];
+    pts = this->EdgePoints->Storage[e].data();
   }
   else
   {
@@ -2005,3 +2006,4 @@ ostream& operator<<(ostream& out, vtkEdgeBase e)
 {
   return out << e.Id;
 }
+VTK_ABI_NAMESPACE_END
