@@ -36,6 +36,7 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONDATAMODEL_EXPORT vtkGraphEdge : public vtkObject
 {
 public:
@@ -43,29 +44,29 @@ public:
   vtkTypeMacro(vtkGraphEdge, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The source of the edge.
    */
   vtkSetMacro(Source, vtkIdType);
   vtkGetMacro(Source, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The target of the edge.
    */
   vtkSetMacro(Target, vtkIdType);
   vtkGetMacro(Target, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The id of the edge.
    */
   vtkSetMacro(Id, vtkIdType);
   vtkGetMacro(Id, vtkIdType);
-  //@}
+  ///@}
 
 protected:
   vtkGraphEdge();
@@ -80,4 +81,5 @@ private:
   void operator=(const vtkGraphEdge&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
