@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkHexahedron.h"
 
 #include "vtkCellArray.h"
@@ -23,7 +20,6 @@
 #include "vtkDoubleArray.h"
 #include "vtkIncrementalPointLocator.h"
 #include "vtkLine.h"
-#include "vtkMarchingCubesTriangleCases.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
@@ -34,14 +30,15 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHexahedron);
 
 namespace
 {
-static const double VTK_DIVERGED = 1.e6;
-static const int VTK_HEX_MAX_ITERATION = 10;
-static const double VTK_HEX_CONVERGED = 1.e-05;
-static const double VTK_HEX_OUTSIDE_CELL_TOLERANCE = 1.e-06;
+const double VTK_DIVERGED = 1.e6;
+const int VTK_HEX_MAX_ITERATION = 10;
+const double VTK_HEX_CONVERGED = 1.e-05;
+const double VTK_HEX_OUTSIDE_CELL_TOLERANCE = 1.e-06;
 }
 
 //------------------------------------------------------------------------------
@@ -80,7 +77,7 @@ int vtkHexahedron::EvaluatePosition(const double x[3], double closestPoint[3], i
   // Efficient point access
   vtkDoubleArray* ptArray = static_cast<vtkDoubleArray*>(this->Points->GetData());
   const double* pts = ptArray->GetPointer(0);
-  const double *pt0, *pt1, *pt;
+  const double *pt0, *pt1;
 
   // compute a bound on the volume to get a scale for an acceptable determinant
   vtkIdType diagonals[4][2] = { { 0, 6 }, { 1, 7 }, { 2, 4 }, { 3, 5 } };
@@ -108,21 +105,21 @@ int vtkHexahedron::EvaluatePosition(const double x[3], double closestPoint[3], i
   for (iteration = 0; !converged && (iteration < VTK_HEX_MAX_ITERATION); iteration++)
   {
     //  calculate element interpolation functions and derivatives
-    this->InterpolationFunctions(pcoords, weights);
-    this->InterpolationDerivs(pcoords, derivs);
+    vtkHexahedron::InterpolationFunctions(pcoords, weights);
+    vtkHexahedron::InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     double fcol[3] = { 0, 0, 0 }, rcol[3] = { 0, 0, 0 }, scol[3] = { 0, 0, 0 },
            tcol[3] = { 0, 0, 0 };
     for (int i = 0; i < 8; i++)
     {
-      pt = pts + 3 * i;
       for (int j = 0; j < 3; j++)
       {
-        fcol[j] += pt[j] * weights[i];
-        rcol[j] += pt[j] * derivs[i];
-        scol[j] += pt[j] * derivs[i + 8];
-        tcol[j] += pt[j] * derivs[i + 16];
+        const double coord = pts[3 * i + j];
+        fcol[j] += coord * weights[i];
+        rcol[j] += coord * derivs[i];
+        scol[j] += coord * derivs[i + 8];
+        tcol[j] += coord * derivs[i + 16];
       }
     }
 
@@ -173,7 +170,7 @@ int vtkHexahedron::EvaluatePosition(const double x[3], double closestPoint[3], i
     return -1;
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkHexahedron::InterpolationFunctions(pcoords, weights);
 
   double lowerlimit = 0.0 - VTK_HEX_OUTSIDE_CELL_TOLERANCE;
   double upperlimit = 1.0 + VTK_HEX_OUTSIDE_CELL_TOLERANCE;
@@ -385,7 +382,7 @@ namespace
 //  |/_____\|
 //  0       3
 //
-static constexpr vtkIdType edges[vtkHexahedron::NumberOfEdges][2] = {
+constexpr vtkIdType edges[vtkHexahedron::NumberOfEdges][2] = {
   { 0, 1 }, // 0
   { 1, 2 }, // 1
   { 3, 2 }, // 2
@@ -399,16 +396,15 @@ static constexpr vtkIdType edges[vtkHexahedron::NumberOfEdges][2] = {
   { 3, 7 }, // 10
   { 2, 6 }, // 11
 };
-static constexpr vtkIdType faces[vtkHexahedron::NumberOfFaces]
-                                [vtkHexahedron::MaximumFaceSize + 1] = {
-                                  { 0, 4, 7, 3, -1 }, // 0
-                                  { 1, 2, 6, 5, -1 }, // 1
-                                  { 0, 1, 5, 4, -1 }, // 2
-                                  { 3, 7, 6, 2, -1 }, // 3
-                                  { 0, 3, 2, 1, -1 }, // 4
-                                  { 4, 5, 6, 7, -1 }, // 5
-                                };
-static constexpr vtkIdType edgeToAdjacentFaces[vtkHexahedron::NumberOfEdges][2] = {
+constexpr vtkIdType faces[vtkHexahedron::NumberOfFaces][vtkHexahedron::MaximumFaceSize + 1] = {
+  { 0, 4, 7, 3, -1 }, // 0
+  { 1, 2, 6, 5, -1 }, // 1
+  { 0, 1, 5, 4, -1 }, // 2
+  { 3, 7, 6, 2, -1 }, // 3
+  { 0, 3, 2, 1, -1 }, // 4
+  { 4, 5, 6, 7, -1 }, // 5
+};
+constexpr vtkIdType edgeToAdjacentFaces[vtkHexahedron::NumberOfEdges][2] = {
   { 2, 4 }, // 0
   { 1, 4 }, // 1
   { 3, 4 }, // 2
@@ -422,48 +418,48 @@ static constexpr vtkIdType edgeToAdjacentFaces[vtkHexahedron::NumberOfEdges][2]
   { 0, 3 }, // 10
   { 1, 3 }, // 11
 };
-static constexpr vtkIdType faceToAdjacentFaces[vtkHexahedron::NumberOfFaces]
-                                              [vtkHexahedron::MaximumFaceSize] = {
-                                                { 4, 2, 5, 3 }, // 0
-                                                { 4, 3, 5, 2 }, // 1
-                                                { 4, 1, 5, 0 }, // 2
-                                                { 0, 5, 1, 4 }, // 3
-                                                { 0, 3, 1, 2 }, // 4
-                                                { 2, 1, 0, 3 }, // 5
-                                              };
-static constexpr vtkIdType pointToIncidentEdges[vtkHexahedron::NumberOfPoints]
-                                               [vtkHexahedron::MaximumValence] = {
-                                                 { 0, 8, 3 },  // 0
-                                                 { 0, 1, 9 },  // 1
-                                                 { 1, 2, 11 }, // 2
-                                                 { 2, 3, 10 }, // 3
-                                                 { 7, 8, 4 },  // 4
-                                                 { 4, 9, 5 },  // 5
-                                                 { 5, 11, 6 }, // 6
-                                                 { 6, 10, 7 }, // 7
-                                               };
-static constexpr vtkIdType pointToIncidentFaces[vtkHexahedron::NumberOfPoints]
-                                               [vtkHexahedron::MaximumValence] = {
-                                                 { 2, 0, 4 }, // 0
-                                                 { 4, 1, 2 }, // 1
-                                                 { 4, 3, 1 }, // 2
-                                                 { 4, 0, 3 }, // 3
-                                                 { 5, 2, 0 }, // 4
-                                                 { 2, 1, 5 }, // 5
-                                                 { 1, 3, 5 }, // 6
-                                                 { 3, 0, 5 }, // 7
-                                               };
-static constexpr vtkIdType pointToOneRingPoints[vtkHexahedron::NumberOfPoints]
-                                               [vtkHexahedron::MaximumValence] = {
-                                                 { 1, 4, 3 }, // 0
-                                                 { 0, 2, 5 }, // 1
-                                                 { 1, 3, 6 }, // 2
-                                                 { 2, 0, 7 }, // 3
-                                                 { 5, 7, 0 }, // 4
-                                                 { 4, 1, 6 }, // 5
-                                                 { 5, 2, 7 }, // 6
-                                                 { 6, 3, 4 }, // 7
-                                               };
+constexpr vtkIdType faceToAdjacentFaces[vtkHexahedron::NumberOfFaces]
+                                       [vtkHexahedron::MaximumFaceSize] = {
+                                         { 4, 2, 5, 3 }, // 0
+                                         { 4, 3, 5, 2 }, // 1
+                                         { 4, 1, 5, 0 }, // 2
+                                         { 0, 5, 1, 4 }, // 3
+                                         { 0, 3, 1, 2 }, // 4
+                                         { 2, 1, 0, 3 }, // 5
+                                       };
+constexpr vtkIdType pointToIncidentEdges[vtkHexahedron::NumberOfPoints]
+                                        [vtkHexahedron::MaximumValence] = {
+                                          { 0, 8, 3 },  // 0
+                                          { 0, 1, 9 },  // 1
+                                          { 1, 2, 11 }, // 2
+                                          { 2, 3, 10 }, // 3
+                                          { 7, 8, 4 },  // 4
+                                          { 4, 9, 5 },  // 5
+                                          { 5, 11, 6 }, // 6
+                                          { 6, 10, 7 }, // 7
+                                        };
+constexpr vtkIdType pointToIncidentFaces[vtkHexahedron::NumberOfPoints]
+                                        [vtkHexahedron::MaximumValence] = {
+                                          { 2, 0, 4 }, // 0
+                                          { 4, 1, 2 }, // 1
+                                          { 4, 3, 1 }, // 2
+                                          { 4, 0, 3 }, // 3
+                                          { 5, 2, 0 }, // 4
+                                          { 2, 1, 5 }, // 5
+                                          { 1, 3, 5 }, // 6
+                                          { 3, 0, 5 }, // 7
+                                        };
+constexpr vtkIdType pointToOneRingPoints[vtkHexahedron::NumberOfPoints]
+                                        [vtkHexahedron::MaximumValence] = {
+                                          { 1, 4, 3 }, // 0
+                                          { 0, 2, 5 }, // 1
+                                          { 1, 3, 6 }, // 2
+                                          { 2, 0, 7 }, // 3
+                                          { 5, 7, 0 }, // 4
+                                          { 4, 1, 6 }, // 5
+                                          { 5, 2, 7 }, // 6
+                                          { 6, 3, 4 }, // 7
+                                        };
 }
 
 //------------------------------------------------------------------------------
@@ -504,8 +500,10 @@ bool vtkHexahedron::ComputeCentroid(
 
 // Marching cubes case table
 //
+VTK_ABI_NAMESPACE_END
 #include "vtkMarchingCubesTriangleCases.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 void vtkHexahedron::Contour(double value, vtkDataArray* cellScalars,
   vtkIncrementalPointLocator* locator, vtkCellArray* verts, vtkCellArray* lines,
   vtkCellArray* polys, vtkPointData* inPd, vtkPointData* outPd, vtkCellData* inCd, vtkIdType cellId,
@@ -513,7 +511,7 @@ void vtkHexahedron::Contour(double value, vtkDataArray* cellScalars,
 {
   static const int CASE_MASK[8] = { 1, 2, 4, 8, 16, 32, 64, 128 };
   vtkMarchingCubesTriangleCases* triCase;
-  EDGE_LIST* edge;
+  int* edge;
   int i, j, index;
   const vtkIdType* vert;
   int v1, v2, newCellId;
@@ -990,24 +988,6 @@ void vtkHexahedron::GetEdgeToAdjacentFaces(vtkIdType edgeId, const vtkIdType*& p
   pts = edgeToAdjacentFaces[edgeId];
 }
 
-//------------------------------------------------------------------------------
-void vtkHexahedron::GetEdgePoints(int edgeId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkHexahedron::GetEdgePoints(int, int*&), "VTK 9.0",
-    vtkHexahedron::GetEdgePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[edgeId]), std::end(faces[edgeId]));
-  pts = tmp.data();
-}
-
-//------------------------------------------------------------------------------
-void vtkHexahedron::GetFacePoints(int faceId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkHexahedron::GetFacePoints(int, int*&), "VTK 9.0",
-    vtkHexahedron::GetFacePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[faceId]), std::end(faces[faceId]));
-  pts = tmp.data();
-}
-
 //------------------------------------------------------------------------------
 void vtkHexahedron::GetEdgePoints(vtkIdType edgeId, const vtkIdType*& pts)
 {
@@ -1050,3 +1030,4 @@ void vtkHexahedron::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Quad:\n";
   this->Quad->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
