@@ -33,6 +33,7 @@
 #include "vtkSmartPointer.h" // For member variable.
 #include <functional>        //For std::function
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellData;
 class vtkDoubleArray;
 class vtkHexahedron;
@@ -104,9 +105,9 @@ public:
   int PointIndexFromIJK(int i, int j, int k);
   bool TransformApproxToCellParams(int subCell, double* pcoords);
   bool TransformFaceToCellParams(int bdyFace, double* pcoords);
-  virtual vtkHigherOrderCurve* getEdgeCell() = 0;
-  virtual vtkHigherOrderQuadrilateral* getFaceCell() = 0;
-  virtual vtkHigherOrderInterpolation* getInterp() = 0;
+  virtual vtkHigherOrderCurve* GetEdgeCell() = 0;
+  virtual vtkHigherOrderQuadrilateral* GetFaceCell() = 0;
+  virtual vtkHigherOrderInterpolation* GetInterpolation() = 0;
 
   static vtkIdType NodeNumberingMappingFromVTK8To9(
     const int order[3], const vtkIdType node_id_vtk8);
@@ -142,4 +143,5 @@ inline int vtkHigherOrderHexahedron::GetParametricCenter(double center[3])
   return 0;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkHigherOrderHexahedron_h
