@@ -27,6 +27,7 @@
 #include "vtkNonLinearCell.h"
 #include "vtkSmartPointer.h" // For member variable.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellData;
 class vtkDoubleArray;
 class vtkIdList;
@@ -93,14 +94,14 @@ public:
   static int PointIndexFromIJK(int i, int j, const int* order);
   bool TransformApproxToCellParams(int subCell, double* pcoords);
 
-  virtual vtkHigherOrderCurve* getEdgeCell() = 0;
+  virtual vtkHigherOrderCurve* GetEdgeCell() = 0;
 
 protected:
   vtkHigherOrderQuadrilateral();
   ~vtkHigherOrderQuadrilateral() override;
 
   vtkQuad* GetApprox();
-  // The verion of GetApproximateQuad between Lagrange and Bezier is different because Bezier is
+  // The version of GetApproximateQuad between Lagrange and Bezier is different because Bezier is
   // non-interpolatory
   void PrepareApproxData(
     vtkPointData* pd, vtkCellData* cd, vtkIdType cellId, vtkDataArray* cellScalars);
@@ -129,4 +130,5 @@ inline int vtkHigherOrderQuadrilateral::GetParametricCenter(double center[3])
   return 0;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkHigherOrderQuadrilateral_h
