@@ -12,6 +12,7 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
 #include "vtkHigherOrderTriangle.h"
 
 #include "vtkCellArray.h"
@@ -29,6 +30,7 @@
 #define ENABLE_CACHING
 #define SEVEN_POINT_TRIANGLE
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 vtkHigherOrderTriangle::vtkHigherOrderTriangle()
 {
@@ -591,7 +593,7 @@ void vtkHigherOrderTriangle::Derivatives(
   jI[0] = j0;
   jI[1] = j1;
   jI[2] = j2;
-  this->JacobianInverse(pcoords, jI, &fDs[0]);
+  this->JacobianInverse(pcoords, jI, fDs.data());
 
   // now compute derivates of values provided
   for (k = 0; k < dim; k++) // loop over values per vertex
@@ -745,7 +747,7 @@ double vtkHigherOrderTriangle::GetParametricDistance(const double pcoords[3])
 }
 
 //------------------------------------------------------------------------------
-double vtkHigherOrderTriangle::eta(vtkIdType n, vtkIdType chi, double sigma)
+double vtkHigherOrderTriangle::Eta(vtkIdType n, vtkIdType chi, double sigma)
 {
   double result = 1.;
   for (vtkIdType i = 1; i <= chi; i++)
@@ -756,7 +758,7 @@ double vtkHigherOrderTriangle::eta(vtkIdType n, vtkIdType chi, double sigma)
 }
 
 //------------------------------------------------------------------------------
-double vtkHigherOrderTriangle::d_eta(vtkIdType n, vtkIdType chi, double sigma)
+double vtkHigherOrderTriangle::Deta(vtkIdType n, vtkIdType chi, double sigma)
 {
   if (chi == 0)
   {
@@ -765,8 +767,8 @@ double vtkHigherOrderTriangle::d_eta(vtkIdType n, vtkIdType chi, double sigma)
   else
   {
     double chi_d = static_cast<double>(chi);
-    return (n / chi_d * eta(n, chi - 1, sigma) +
-      (n * sigma - chi_d + 1.) / chi_d * d_eta(n, chi - 1, sigma));
+    return (n / chi_d * Eta(n, chi - 1, sigma) +
+      (n * sigma - chi_d + 1.) / chi_d * Deta(n, chi - 1, sigma));
   }
 }
 
@@ -906,3 +908,4 @@ void vtkHigherOrderTriangle::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
