@@ -47,6 +47,7 @@
 #include <cassert> // Used internally
 #include <vector>  // std::vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkHyperTree;
 class vtkHyperTreeGrid;
 class vtkHyperTreeGridNonOrientedGeometryCursor;
@@ -69,32 +70,32 @@ public:
    */
   virtual void Initialize(vtkHyperTreeGrid* grid, vtkIdType treeIndex, bool create = false) = 0;
 
-  //@{
+  ///@{
   /**
    * Set the hyper tree grid to which the cursor is pointing.
    */
   vtkHyperTreeGrid* GetGrid();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return if a Tree pointing exist
    */
   bool HasTree();
-  //@}
+  ///@}
 
   /**
    * JB Return if a Tree pointing exist
    */
   bool HasTree(unsigned int icursor);
 
-  //@{
+  ///@{
   /**
    * Set the hyper tree to which the cursor is pointing.
    */
   vtkHyperTree* GetTree();
   vtkHyperTree* GetTree(unsigned int icursor);
-  //@}
+  ///@}
 
   /**
    * Return the index of the current vertex in the tree.
@@ -347,4 +348,5 @@ private:
   void operator=(const vtkHyperTreeGridNonOrientedSuperCursorLight&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
