@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkImageData.h"
 
 #include "vtkCellData.h"
@@ -33,9 +30,11 @@
 #include "vtkPixel.h"
 #include "vtkPointData.h"
 #include "vtkPoints.h"
+#include "vtkUnsignedCharArray.h"
 #include "vtkVertex.h"
 #include "vtkVoxel.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageData);
 vtkStandardExtendedNewMacro(vtkImageData);
 
@@ -191,6 +190,110 @@ void vtkImageData::PrepareForNewData()
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkImageData::GetCellDims(int cellDims[3])
+{
+  for (int i = 0; i < 3; ++i)
+  {
+    cellDims[i] = ((this->Dimensions[i] - 1) < 1) ? 1 : this->Dimensions[i] - 1;
+  }
+}
+
+namespace
+{
+class CellVisibility
+{
+public:
+  CellVisibility(vtkImageData* input)
+    : Input(input)
+  {
+  }
+  bool operator()(const vtkIdType id) { return !Input->IsCellVisible(id); }
+
+private:
+  vtkImageData* Input;
+};
+} // anonymous namespace
+
+//------------------------------------------------------------------------------
+void vtkImageData::GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds)
+{
+  int numPtIds = ptIds->GetNumberOfIds();
+
+  // Use special methods for speed
+  switch (numPtIds)
+  {
+    case 0:
+      cellIds->Reset();
+      return;
+
+    case 1:
+    case 2:
+    case 4: // vertex, edge, face neighbors
+      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->GetDimensions());
+      break;
+
+    default:
+      this->Superclass::GetCellNeighbors(cellId, ptIds, cellIds);
+  }
+
+  // If blanking, remove blanked cells.
+  if (this->GetPointGhostArray() || this->GetCellGhostArray())
+  {
+    vtkIdType* pCellIds = cellIds->GetPointer(0);
+    vtkIdType* end =
+      std::remove_if(pCellIds, pCellIds + cellIds->GetNumberOfIds(), CellVisibility(this));
+    cellIds->Resize(std::distance(pCellIds, end));
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkImageData::GetCellNeighbors(
+  vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds, int* seedLoc)
+{
+  int numPtIds = ptIds->GetNumberOfIds();
+
+  // Use special methods for speed
+  switch (numPtIds)
+  {
+    case 0:
+      cellIds->Reset();
+      return;
+
+    case 1:
+    case 2:
+    case 4: // vertex, edge, face neighbors
+      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->GetDimensions(), seedLoc);
+      break;
+
+    default:
+      this->Superclass::GetCellNeighbors(cellId, ptIds, cellIds);
+  }
+
+  // If blanking, remove blanked cells.
+  if (this->GetPointGhostArray() || this->GetCellGhostArray())
+  {
+    vtkIdType* pCellIds = cellIds->GetPointer(0);
+    vtkIdType* end =
+      std::remove_if(pCellIds, pCellIds + cellIds->GetNumberOfIds(), CellVisibility(this));
+    cellIds->Resize(std::distance(pCellIds, end));
+  }
+}
+
+//------------------------------------------------------------------------------
+unsigned char vtkImageData::IsPointVisible(vtkIdType pointId)
+{
+  return vtkStructuredData::IsPointVisible(pointId, this->GetPointGhostArray());
+}
+
+//------------------------------------------------------------------------------
+// Return non-zero if the specified cell is visible (i.e., not blanked)
+unsigned char vtkImageData::IsCellVisible(vtkIdType cellId)
+{
+  return vtkStructuredData::IsCellVisible(cellId, this->Dimensions, this->DataDescription,
+    this->GetCellGhostArray(), this->GetPointGhostArray());
+}
+
 //------------------------------------------------------------------------------
 template <class T>
 unsigned long vtkImageDataGetTypeSize(T*)
@@ -794,6 +897,36 @@ int vtkImageData::GetCellType(vtkIdType vtkNotUsed(cellId))
   }
 }
 
+//------------------------------------------------------------------------------
+vtkIdType vtkImageData::GetCellSize(vtkIdType vtkNotUsed(cellId))
+{
+  switch (this->DataDescription)
+  {
+    case VTK_EMPTY:
+      return 0;
+
+    case VTK_SINGLE_POINT:
+      return 1;
+
+    case VTK_X_LINE:
+    case VTK_Y_LINE:
+    case VTK_Z_LINE:
+      return 2;
+
+    case VTK_XY_PLANE:
+    case VTK_YZ_PLANE:
+    case VTK_XZ_PLANE:
+      return 4;
+
+    case VTK_XYZ_GRID:
+      return 8;
+
+    default:
+      vtkErrorMacro(<< "Bad data description!");
+      return 0;
+  }
+}
+
 //------------------------------------------------------------------------------
 void vtkImageData::ComputeBounds()
 {
@@ -1974,6 +2107,8 @@ void vtkImageData::SetExtent(int* extent)
     return;
   }
 
+  vtkStructuredData::GetDimensionsFromExtent(extent, this->Dimensions);
+
   this->SetDataDescription(description);
 
   this->Modified();
@@ -2044,7 +2179,7 @@ void vtkImageData::GetAxisUpdateExtent(int idx, int& min, int& max, const int* u
 //------------------------------------------------------------------------------
 unsigned long vtkImageData::GetActualMemorySize()
 {
-  return this->vtkDataSet::GetActualMemorySize();
+  return this->Superclass::GetActualMemorySize();
 }
 
 //------------------------------------------------------------------------------
@@ -2058,7 +2193,7 @@ void vtkImageData::ShallowCopy(vtkDataObject* dataObject)
   }
 
   // Do superclass
-  this->vtkDataSet::ShallowCopy(dataObject);
+  this->Superclass::ShallowCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
@@ -2073,7 +2208,7 @@ void vtkImageData::DeepCopy(vtkDataObject* dataObject)
   }
 
   // Do superclass
-  this->vtkDataSet::DeepCopy(dataObject);
+  this->Superclass::DeepCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
@@ -2483,3 +2618,17 @@ void vtkImageData::ComputeIndexToPhysicalMatrix(
   result[14] = 0;
   result[15] = 1;
 }
+
+//------------------------------------------------------------------------------
+bool vtkImageData::HasAnyBlankPoints()
+{
+  return this->PointData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENPOINT);
+}
+
+//------------------------------------------------------------------------------
+bool vtkImageData::HasAnyBlankCells()
+{
+  int cellBlanking = this->CellData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENCELL);
+  return cellBlanking || this->HasAnyBlankPoints();
+}
+VTK_ABI_NAMESPACE_END
