@@ -18,7 +18,7 @@
  *
  * vtkImageTransform is a helper class to transform the output of
  * image filters (i.e., filter that input vtkImageData) by applying the
- * Index to Physical transformation frmo the input image, which can
+ * Index to Physical transformation from the input image, which can
  * include origin, spacing, direction. The transformation process is
  * threaded with vtkSMPTools for performance.
  *
@@ -46,6 +46,7 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataArray;
 class vtkImageData;
 class vtkMatrix3x3;
@@ -55,16 +56,16 @@ class vtkPointSet;
 class VTKCOMMONDATAMODEL_EXPORT vtkImageTransform : public vtkObject
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for construction, type information, printing.
    */
   static vtkImageTransform* New();
   vtkTypeMacro(vtkImageTransform, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Given a vtkImageData (and hence its associated orientation
    * matrix), and an instance of vtkPointSet, transform its points, as
@@ -79,7 +80,7 @@ public:
   static void TransformPointSet(vtkImageData* im, vtkPointSet* ps);
   static void TransformPointSet(
     vtkImageData* im, vtkPointSet* ps, bool transNormals, bool transVectors);
-  //@}
+  ///@}
 
   /**
    * Given x-y-z points represented by a vtkDataArray,
@@ -116,4 +117,5 @@ private:
   void operator=(const vtkImageTransform&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
