@@ -32,6 +32,7 @@
 #include "vtkNew.h"          // For member variable.
 #include "vtkSmartPointer.h" // For member variable.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellData;
 class vtkDoubleArray;
 class vtkHexahedron;
@@ -56,9 +57,9 @@ public:
   vtkCell* GetFace(int faceId) override;
   void InterpolateFunctions(const double pcoords[3], double* weights) override;
   void InterpolateDerivs(const double pcoords[3], double* derivs) override;
-  vtkHigherOrderCurve* getEdgeCell() override;
-  vtkHigherOrderQuadrilateral* getFaceCell() override;
-  vtkHigherOrderInterpolation* getInterp() override;
+  vtkHigherOrderCurve* GetEdgeCell() override;
+  vtkHigherOrderQuadrilateral* GetFaceCell() override;
+  vtkHigherOrderInterpolation* GetInterpolation() override;
 
 protected:
   vtkHexahedron* GetApproximateHex(
@@ -75,4 +76,5 @@ private:
   void operator=(const vtkLagrangeHexahedron&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkLagrangeHexahedron_h
