@@ -24,6 +24,7 @@
 #include "vtkPointData.h"
 #include "vtkPoints.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkLine);
 
 //------------------------------------------------------------------------------
@@ -52,20 +53,13 @@ int vtkLine::EvaluatePosition(const double x[3], double closestPoint[3], int& su
   this->Points->GetPoint(1, a2);
 
   // DistanceToLine sets pcoords[0] to a value t
-  dist2 = this->DistanceToLine(x, a1, a2, pcoords[0], closestPoint);
+  dist2 = vtkLine::DistanceToLine(x, a1, a2, pcoords[0], closestPoint);
 
   // pcoords[0] == t, need weights to be 1-t and t
   weights[0] = 1.0 - pcoords[0];
   weights[1] = pcoords[0];
 
-  if (pcoords[0] < 0.0 || pcoords[0] > 1.0)
-  {
-    return 0;
-  }
-  else
-  {
-    return 1;
-  }
+  return (pcoords[0] >= 0.0 && pcoords[0] <= 1.0);
 }
 
 //------------------------------------------------------------------------------
@@ -93,7 +87,7 @@ void vtkLine::EvaluateLocation(
 // The parameters (u,v) are the parametric coordinates of the lines at the
 // position of closest approach.
 int vtkLine::Intersection(const double a1[3], const double a2[3], const double b1[3],
-  const double b2[3], double& u, double& v, const double tolerance)
+  const double b2[3], double& u, double& v, const double tolerance, int tolType)
 {
   double a21[3], b21[3], b1a1[3];
   double c[2];
@@ -119,7 +113,7 @@ int vtkLine::Intersection(const double a1[3], const double a2[3], const double b
   c[0] = vtkMath::Dot(a21, b1a1);
   c[1] = -vtkMath::Dot(b21, b1a1);
 
-  //  Solve the system of equations
+  //  Solve the system of equations. Check for colinearity.
   if (vtkMath::SolveLinearSystem(A, c, 2) == 0)
   {
     // The lines are colinear. Therefore, one of the four endpoints is the
@@ -142,63 +136,67 @@ int vtkLine::Intersection(const double a1[3], const double a2[3], const double b
       }
     }
     return OnLine;
-  }
-  else
+  } // if colinear
+
+  // The lines are not colinear, check for intersection.
+  // However if they are nearly parallel then the solution
+  // found by vtkMath::SolveLinearSystem may be very inaccurate.
+  // We hence need to check the solution against a tolerance criterion.
+  u = c[0];
+  v = c[1];
+  // calculate intersection point using u
+  double ptu[] = { a21[0], a21[1], a21[2] };
+  vtkMath::MultiplyScalar(ptu, u);
+  vtkMath::Add(ptu, a1, ptu);
+  // calculate intersection point using v
+  double ptv[] = { b21[0], b21[1], b21[2] };
+  vtkMath::MultiplyScalar(ptv, v);
+  vtkMath::Add(ptv, b1, ptv);
+  // difference between the two intersection points should ideally be zero
+  double diff[3];
+  vtkMath::Subtract(ptu, ptv, diff);
+  double diff2 = vtkMath::SquaredNorm(diff);
+
+  double tol2 = 0.0;
+  if (std::isfinite(tolerance))
   {
-    // The infinite lines do intersect.
-    // However if they are nearly parallel then the solution
-    // found by vtkMath::SolveLinearSystem may be very inaccurate.
-    // We hence need to check the solution against a tolerance criterion.
-    u = c[0];
-    v = c[1];
-    // calculate intersection point using u
-    double ptu[] = { a21[0], a21[1], a21[2] };
-    vtkMath::MultiplyScalar(ptu, u);
-    vtkMath::Add(ptu, a1, ptu);
-    // calculate intersection point using v
-    double ptv[] = { b21[0], b21[1], b21[2] };
-    vtkMath::MultiplyScalar(ptv, v);
-    vtkMath::Add(ptv, b1, ptv);
-    // difference between the two intersection points should ideally be zero
-    double diff[3];
-    vtkMath::Subtract(ptu, ptv, diff);
-    double diff2 = vtkMath::SquaredNorm(diff);
-    // compare diff > tolerance * max(nrm(ptu),nrm(ptv))
-    // but without taking square roots, hence square this equation
-    if (std::isfinite(tolerance) &&
-      (diff2 >
-        tolerance * tolerance * std::max(vtkMath::SquaredNorm(ptv), vtkMath::SquaredNorm(ptu))))
+    // compare either absolute or relative diff; hence either
+    // tolerance*tolerance or diff > tolerance * max(nrm(ptu),nrm(ptv))
+    // but without taking square roots.
+    tol2 = ((tolType == Absolute || tolType == AbsoluteFuzzy)
+        ? tolerance * tolerance
+        : tolerance * tolerance * std::max(vtkMath::SquaredNorm(ptv), vtkMath::SquaredNorm(ptu)));
+    if (diff2 > tol2)
     {
       return NoIntersect;
     }
-  }
+  } // valid tolerance
 
-  //  Check parametric coordinates for intersection.
+  // Check parametric coordinates for intersection within the two finite line
+  // segments specified. Special treatment is required to make sure that
+  // intersections near the line end points are not within tolerance.  Most
+  // intersections will occur within the 0<=u,v<=1 range, handle them as
+  // quickly as possible.
   if ((0.0 <= u) && (u <= 1.0) && (0.0 <= v) && (v <= 1.0))
   {
     return Intersect;
   }
-  else
+  // Otherwise the intersection may be within tolerance at one or both of the
+  // line end points. Note that we already know from previous calculations
+  // that the two points of intersection are within tol of each other; here
+  // we are checking whether they are on the line within the range
+  // (-tol <= u,v <= 1+tol).
+  else if (tolType >= RelativeFuzzy && tol2 > 0.0)
   {
-    return NoIntersect;
+    double uTol = sqrt(tol2 / vtkMath::SquaredNorm(a21));
+    double vTol = sqrt(tol2 / vtkMath::SquaredNorm(b21));
+    if ((-uTol <= u) && (u <= (1.0 + uTol)) && (-vTol <= v) && (v <= (1.0 + vTol)))
+    {
+      return Intersect;
+    }
   }
-}
 
-//------------------------------------------------------------------------------
-int vtkLine::Intersection3D(double a1[3], double a2[3], double b1[3], double b2[3], double& u,
-  double& v, const double tolerance)
-{
-  // Description:
-  // Performs intersection of two finite 3D lines. An intersection is found if
-  // the projection of the two lines onto the plane perpendicular to the cross
-  // product of the two lines intersect, and if the distance between the
-  // closest points of approach are within a relative tolerance. The parameters
-  // (u,v) are the parametric coordinates of the lines at the position of
-  // closest approach.
-  //
-  // Note: Legacy method; vtkLine::Intersection() now performs the check that the
-  // distance between the closest points is within a relative tolerance.
-  return vtkLine::Intersection(a1, a2, b1, b2, u, v, tolerance);
+  return NoIntersect;
 }
 
 int vtkLine::Inflate(double dist)
@@ -233,26 +231,12 @@ int vtkLine::CellBoundary(int vtkNotUsed(subId), const double pcoords[3], vtkIdL
   if (pcoords[0] >= 0.5)
   {
     pts->SetId(0, this->PointIds->GetId(1));
-    if (pcoords[0] > 1.0)
-    {
-      return 0;
-    }
-    else
-    {
-      return 1;
-    }
+    return (pcoords[0] <= 1.0);
   }
   else
   {
     pts->SetId(0, this->PointIds->GetId(0));
-    if (pcoords[0] < 0.0)
-    {
-      return 0;
-    }
-    else
-    {
-      return 1;
-    }
+    return (pcoords[0] >= 0.0);
   }
 }
 
@@ -633,7 +617,6 @@ int vtkLine::IntersectWithLine(const double p1[3], const double p2[3], double to
   double x[3], double pcoords[3], int& subId)
 {
   double a1[3], a2[3];
-  double projXYZ[3];
   int i;
 
   subId = 0;
@@ -647,20 +630,14 @@ int vtkLine::IntersectWithLine(const double p1[3], const double p2[3], double to
   // we then perform the tolerance check here using the absolute tolerance tol
   if (this->Intersection(p1, p2, a1, a2, t, pcoords[0], vtkMath::Inf()) == Intersect)
   {
+    double projXYZ[3];
     // make sure we are within tolerance
     for (i = 0; i < 3; i++)
     {
       x[i] = a1[i] + pcoords[0] * (a2[i] - a1[i]);
       projXYZ[i] = p1[i] + t * (p2[i] - p1[i]);
     }
-    if (vtkMath::Distance2BetweenPoints(x, projXYZ) <= tol * tol)
-    {
-      return 1;
-    }
-    else
-    {
-      return 0;
-    }
+    return (vtkMath::Distance2BetweenPoints(x, projXYZ) <= tol * tol);
   }
 
   else // check to see if it lies within tolerance
@@ -669,50 +646,22 @@ int vtkLine::IntersectWithLine(const double p1[3], const double p2[3], double to
     if (t < 0.0)
     {
       t = 0.0;
-      if (vtkLine::DistanceToLine(p1, a1, a2, pcoords[0], x) <= tol * tol)
-      {
-        return 1;
-      }
-      else
-      {
-        return 0;
-      }
+      return (vtkLine::DistanceToLine(p1, a1, a2, pcoords[0], x) <= tol * tol);
     }
     if (t > 1.0)
     {
       t = 1.0;
-      if (vtkLine::DistanceToLine(p2, a1, a2, pcoords[0], x) <= tol * tol)
-      {
-        return 1;
-      }
-      else
-      {
-        return 0;
-      }
+      return (vtkLine::DistanceToLine(p2, a1, a2, pcoords[0], x) <= tol * tol);
     }
     if (pcoords[0] < 0.0)
     {
       pcoords[0] = 0.0;
-      if (vtkLine::DistanceToLine(a1, p1, p2, t, x) <= tol * tol)
-      {
-        return 1;
-      }
-      else
-      {
-        return 0;
-      }
+      return (vtkLine::DistanceToLine(a1, p1, p2, t, x) <= tol * tol);
     }
     if (pcoords[0] > 1.0)
     {
       pcoords[0] = 1.0;
-      if (vtkLine::DistanceToLine(a2, p1, p2, t, x) <= tol * tol)
-      {
-        return 1;
-      }
-      else
-      {
-        return 0;
-      }
+      return (vtkLine::DistanceToLine(a2, p1, p2, t, x) <= tol * tol);
     }
   }
   return 0;
@@ -774,7 +723,7 @@ struct LINE_CASES_t
 };
 using LINE_CASES = struct LINE_CASES_t;
 
-static LINE_CASES lineCases[] = {
+LINE_CASES lineCases[] = {
   { { -1, -1 } },   // 0
   { { 100, 1 } },   // 1
   { { 0, 101 } },   // 2
@@ -895,3 +844,4 @@ void vtkLine::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
