@@ -18,6 +18,7 @@
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMultiPieceDataSet);
 //------------------------------------------------------------------------------
 vtkMultiPieceDataSet::vtkMultiPieceDataSet() = default;
@@ -42,3 +43,4 @@ void vtkMultiPieceDataSet::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
