@@ -15,13 +15,13 @@
 #include "vtkNonLinearCell.h"
 #include "vtkObjectFactory.h"
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkNonLinearCell::vtkNonLinearCell() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkNonLinearCell::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
-
+VTK_ABI_NAMESPACE_END
