@@ -15,6 +15,7 @@
 #include "vtkNonOverlappingAMR.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkNonOverlappingAMR);
 
 //------------------------------------------------------------------------------
@@ -24,7 +25,8 @@ vtkNonOverlappingAMR::vtkNonOverlappingAMR() = default;
 vtkNonOverlappingAMR::~vtkNonOverlappingAMR() = default;
 
 //------------------------------------------------------------------------------
-void vtkNonOverlappingAMR::PrintSelf(ostream& os, vtkIndent indent )
+void vtkNonOverlappingAMR::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
