@@ -22,14 +22,11 @@
 #include "vtkCellArray.h"
 #include "vtkCommand.h"
 #include "vtkDataSet.h"
-#include "vtkFloatArray.h"
 #include "vtkIdList.h"
 #include "vtkIdTypeArray.h"
-#include "vtkIntArray.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkOctreePointLocatorNode.h"
-#include "vtkPointSet.h"
 #include "vtkPoints.h"
 #include "vtkPolyData.h"
 
@@ -39,6 +36,7 @@
 #include <stack>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOctreePointLocator);
 
 // helper class for ordering the points in
@@ -280,7 +278,7 @@ void vtkOctreePointLocator::DivideRegion(vtkOctreePointLocatorNode* node, int* o
     counter += subOctantNumberOfPoints[i];
     if (!points[i].empty())
     {
-      memcpy(ordering + counter, &(points[i][0]), subOctantNumberOfPoints[i + 1] * sizeOfInt);
+      memcpy(ordering + counter, points[i].data(), subOctantNumberOfPoints[i + 1] * sizeOfInt);
     }
   }
   counter = 0;
@@ -295,19 +293,38 @@ void vtkOctreePointLocator::DivideRegion(vtkOctreePointLocatorNode* node, int* o
 //------------------------------------------------------------------------------
 void vtkOctreePointLocator::BuildLocator()
 {
-  if (!this->GetDataSet())
+  // don't rebuild if build time is newer than modified and dataset modified time
+  if (this->Top && this->BuildTime > this->MTime && this->BuildTime > this->DataSet->GetMTime())
   {
-    vtkErrorMacro("Must set a valid data set first.");
+    return;
+  }
+  // don't rebuild if UseExistingSearchStructure is ON and a search structure already exists
+  if (this->Top && this->UseExistingSearchStructure)
+  {
+    this->BuildTime.Modified();
+    vtkDebugMacro(<< "BuildLocator exited - UseExistingSearchStructure");
+    return;
+  }
+  this->BuildLocatorInternal();
+}
+
+//------------------------------------------------------------------------------
+void vtkOctreePointLocator::ForceBuildLocator()
+{
+  this->BuildLocatorInternal();
+}
+
+//------------------------------------------------------------------------------
+void vtkOctreePointLocator::BuildLocatorInternal()
+{
+  if (!this->DataSet || this->DataSet->GetNumberOfPoints() == 0)
+  {
+    vtkErrorMacro("No data set");
+    return;
   }
 
   int numPoints = this->GetDataSet()->GetNumberOfPoints();
 
-  if (numPoints < 1)
-  {
-    vtkErrorMacro(<< "No points to build from.");
-    return;
-  }
-
   if (numPoints >= VTK_INT_MAX)
   {
     // When point IDs are stored in an "int" instead of a vtkIdType,
@@ -320,11 +337,6 @@ void vtkOctreePointLocator::BuildLocator()
   }
 
   vtkDebugMacro(<< "Creating octree");
-
-  if ((this->BuildTime > this->MTime) && (this->BuildTime > this->DataSet->GetMTime()))
-  {
-    return;
-  }
   this->FreeSearchStructure();
 
   // Fix bounds - (1) push out a little if flat
@@ -470,8 +482,8 @@ vtkIdType vtkOctreePointLocator::FindClosestPoint(double x, double y, double z,
     double pt[3];
     this->Top->GetDistance2ToBoundary(x, y, z, pt, this->Top, 1);
 
-    double* min = this->Top->GetMinBounds();
-    double* max = this->Top->GetMaxBounds();
+    const double* min = this->Top->GetMinBounds();
+    const double* max = this->Top->GetMaxBounds();
 
     // GetDistance2ToBoundary will sometimes return a point *just*
     // *barely* outside the bounds of the region.  Move that point to
@@ -1066,8 +1078,8 @@ void vtkOctreePointLocator::AddPolys(
   vtkIdType idList[4];
   double x[3];
 
-  double* min = node->GetMinBounds();
-  double* max = node->GetMaxBounds();
+  const double* min = node->GetMinBounds();
+  const double* max = node->GetMaxBounds();
 
   x[0] = min[0];
   x[1] = max[1];
@@ -1289,3 +1301,4 @@ void vtkOctreePointLocator::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "MaxWidth: " << this->MaxWidth << endl;
   os << indent << "CreateCubicOctants: " << this->CreateCubicOctants << endl;
 }
+VTK_ABI_NAMESPACE_END
