@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkOrderedTriangulator.h"
 
 #include "vtkCellArray.h"
@@ -37,6 +34,7 @@
 #include <stack>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOrderedTriangulator);
 
 #ifdef _WIN32_WCE
@@ -52,12 +50,14 @@ inline void __cdecl operator delete(void*, void*)
 }
 #endif
 #else
+VTK_ABI_NAMESPACE_END
 #include <new>
 #endif
 
 // Classes are used to represent points, faces, and tetras-------------------
 // This data structure consists of points and tetras, with the face used
 // temporarily as a place holder during triangulation.
+VTK_ABI_NAMESPACE_BEGIN
 struct OTPoint;
 struct OTFace;
 struct OTTetra;
@@ -111,10 +111,7 @@ struct OTPoint
 };
 struct PointListType : public std::vector<OTPoint>
 {
-  PointListType()
-    : std::vector<OTPoint>()
-  {
-  }
+  PointListType() = default;
   OTPoint* GetPointer(int ptId) { return &(*(this->begin() + ptId)); }
 };
 typedef PointListType::iterator PointListIterator;
@@ -160,10 +157,7 @@ typedef std::list<OTTetra*> TetraListType;
 typedef std::list<OTTetra*>::iterator TetraListIterator;
 struct TetraStackType : public std::stack<OTTetra*>
 {
-  TetraStackType()
-    : std::stack<OTTetra*>()
-  {
-  }
+  TetraStackType() = default;
   void clear()
   {
     while (!this->empty())
@@ -1678,3 +1672,4 @@ void vtkOrderedTriangulator::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "UseTemplates: " << (this->UseTemplates ? "On\n" : "Off\n");
   os << indent << "NumberOfPoints: " << this->NumberOfPoints << endl;
 }
+VTK_ABI_NAMESPACE_END
