@@ -19,57 +19,51 @@
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPartitionedDataSet);
-//----------------------------------------------------------------------------
-vtkPartitionedDataSet::vtkPartitionedDataSet()
-{
-}
+//------------------------------------------------------------------------------
+vtkPartitionedDataSet::vtkPartitionedDataSet() = default;
 
-//----------------------------------------------------------------------------
-vtkPartitionedDataSet::~vtkPartitionedDataSet()
-{
-}
+//------------------------------------------------------------------------------
+vtkPartitionedDataSet::~vtkPartitionedDataSet() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPartitionedDataSet* vtkPartitionedDataSet::GetData(vtkInformation* info)
 {
-  return
-    info? vtkPartitionedDataSet::SafeDownCast(info->Get(DATA_OBJECT())) : nullptr;
+  return info ? vtkPartitionedDataSet::SafeDownCast(info->Get(DATA_OBJECT())) : nullptr;
 }
 
-//----------------------------------------------------------------------------
-vtkPartitionedDataSet* vtkPartitionedDataSet::GetData(vtkInformationVector* v,
-                                                      int i)
+//------------------------------------------------------------------------------
+vtkPartitionedDataSet* vtkPartitionedDataSet::GetData(vtkInformationVector* v, int i)
 {
   return vtkPartitionedDataSet::GetData(v->GetInformationObject(i));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPartitionedDataSet::SetNumberOfPartitions(unsigned int numPartitions)
 {
   this->Superclass::SetNumberOfChildren(numPartitions);
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkPartitionedDataSet::GetNumberOfPartitions()
 {
   return this->Superclass::GetNumberOfChildren();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataSet* vtkPartitionedDataSet::GetPartition(unsigned int idx)
 {
   return vtkDataSet::SafeDownCast(this->GetPartitionAsDataObject(idx));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataObject* vtkPartitionedDataSet::GetPartitionAsDataObject(unsigned int idx)
 {
   return this->Superclass::GetChild(idx);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPartitionedDataSet::SetPartition(unsigned int idx, vtkDataObject* partition)
 {
   if (partition && partition->IsA("vtkCompositeDataSet"))
@@ -81,7 +75,7 @@ void vtkPartitionedDataSet::SetPartition(unsigned int idx, vtkDataObject* partit
   this->Superclass::SetChild(idx, partition);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPartitionedDataSet::RemoveNullPartitions()
 {
   unsigned int next = 0;
@@ -106,8 +100,9 @@ void vtkPartitionedDataSet::RemoveNullPartitions()
   this->SetNumberOfPartitions(next);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPartitionedDataSet::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
