@@ -30,11 +30,13 @@
 
 #include "vtkPlane.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONDATAMODEL_EXPORT vtkPlaneCollection : public vtkCollection
 {
 public:
   vtkTypeMacro(vtkPlaneCollection, vtkCollection);
   static vtkPlaneCollection* New();
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Add a plane to the list.
@@ -80,5 +82,5 @@ inline vtkPlane* vtkPlaneCollection::GetNextItem()
   return static_cast<vtkPlane*>(this->GetNextItemAsObject());
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
-// VTK-HeaderTest-Exclude: vtkPlaneCollection.h
