@@ -24,6 +24,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkPointsProjectedHull.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPlanesIntersection);
 
 // Experiment shows that we get plane equation values on the
@@ -648,7 +649,7 @@ void vtkPlanesIntersection::ComputeRegionVertices()
       {
         this->planesMatrix(i, j, k, M);
 
-        int notInvertible = this->Invert3x3(M);
+        int notInvertible = vtkPlanesIntersection::Invert3x3(M);
 
         if (notInvertible)
         {
@@ -900,3 +901,4 @@ void vtkPlanesIntersection::PrintSelf(ostream& os, vtkIndent indent)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
