@@ -60,6 +60,7 @@
 #include "vtkGenericCell.h" // For GetCell
 #include "vtkPoints.h"      // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractPointLocator;
 class vtkAbstractCellLocator;
 
@@ -72,15 +73,15 @@ public:
   static vtkPointSet* New();
   static vtkPointSet* ExtendedNew();
 
-  //@{
+  ///@{
   /**
-   * Standard methdos for type information and printing.
+   * Standard methods for type information and printing.
    */
   vtkTypeMacro(vtkPointSet, vtkDataSet);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether this dataset is editable after creation. Meaning, once
    * the points and cells are defined, can the dataset be incrementally
@@ -93,7 +94,7 @@ public:
   vtkSetMacro(Editable, bool);
   vtkGetMacro(Editable, bool);
   vtkBooleanMacro(Editable, bool);
-  //@}
+  ///@}
 
   /**
    * Reset to an empty state and free any memory.
@@ -105,7 +106,7 @@ public:
    */
   void CopyStructure(vtkDataSet* pd) override;
 
-  //@{
+  ///@{
   /**
    * See vtkDataSet for additional information.
    */
@@ -117,30 +118,31 @@ public:
     double pcoords[3], double* weights) override;
   vtkIdType FindCell(double x[3], vtkCell* cell, vtkGenericCell* gencell, vtkIdType cellId,
     double tol2, int& subId, double pcoords[3], double* weights) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This method always returns 0, as there are no cells in a `vtkPointSet`.
    */
   vtkIdType GetNumberOfCells() override { return 0; }
   int GetMaxCellSize() override { return 0; }
-  //@}
+  ///@}
 
   using Superclass::GetCell;
   /**
    * This method always return a `vtkEmptyCell`, as there is no cell in a
    * `vtkPointSet`.
    */
-  vtkCell* GetCell(vtkIdType) override { return this->EmptyCell; }
+  vtkCell* GetCell(vtkIdType) override;
 
-  //@{
+  ///@{
   /**
    * This method resets parameter idList, as there is no cell in a `vtkPointSet`.
    */
+  using vtkDataSet::GetCellPoints;
   void GetCellPoints(vtkIdType, vtkIdList* idList) override { idList->Reset(); }
   void GetPointCells(vtkIdType, vtkIdList* idList) override { idList->Reset(); }
-  //@}
+  ///@}
 
   /**
    * This method sets cell to be an empty cell.
@@ -153,6 +155,12 @@ public:
    */
   int GetCellType(vtkIdType) override { return VTK_EMPTY_CELL; }
 
+  /**
+   * This method always returns 1, as all cells are point in a pure
+   * `vtkPointSet`.
+   */
+  vtkIdType GetCellSize(vtkIdType) override { return 1; }
+
   /**
    * See vtkDataSet for additional information.
    * WARNING: Just don't use this error-prone method, the returned pointer
@@ -166,14 +174,14 @@ public:
    */
   vtkCellIterator* NewCellIterator() override;
 
-  //@{
+  ///@{
   /**
    * Build the internal point locator . In a multi-threaded environment, call
    * this method in a single thread before using FindCell() or FindPoint().
    */
   void BuildPointLocator();
   void BuildLocator() { this->BuildPointLocator(); }
-  //@}
+  ///@}
 
   /**
    * Build the cell locator. In a multi-threaded environment,
@@ -181,7 +189,7 @@ public:
    */
   void BuildCellLocator();
 
-  //@{
+  ///@{
   /**
    * Set / get an instance of vtkAbstractPointLocator which is used to
    * support the FindPoint() and FindCell() methods. By default a
@@ -190,16 +198,16 @@ public:
    */
   virtual void SetPointLocator(vtkAbstractPointLocator*);
   vtkGetObjectMacro(PointLocator, vtkAbstractPointLocator);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / get an instance of vtkAbstractCellLocator which may be used
-   * when a vtkCellLocatorStrategy is used during a FindCelloperation.
+   * when a vtkCellLocatorStrategy is used during a FindCell() operation.
    */
   virtual void SetCellLocator(vtkAbstractCellLocator*);
   vtkGetObjectMacro(CellLocator, vtkAbstractCellLocator);
-  //@}
+  ///@}
 
   /**
    * Get MTime which also considers its vtkPoints MTime.
@@ -216,13 +224,13 @@ public:
    */
   void Squeeze() override;
 
-  //@{
+  ///@{
   /**
    * Specify point array to define point coordinates.
    */
   virtual void SetPoints(vtkPoints*);
   vtkGetObjectMacro(Points, vtkPoints);
-  //@}
+  ///@}
 
   /**
    * Return the actual size of the data in kibibytes (1024 bytes). This number
@@ -234,29 +242,28 @@ public:
    */
   unsigned long GetActualMemorySize() override;
 
-  //@{
+  ///@{
   /**
    * Shallow and Deep copy.
    */
   void ShallowCopy(vtkDataObject* src) override;
   void DeepCopy(vtkDataObject* src) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Overwritten to handle the data/locator loop
    */
-  void Register(vtkObjectBase* o) override;
-  void UnRegister(vtkObjectBase* o) override;
-  //@}
+  bool UsesGarbageCollector() const override { return true; }
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkPointSet* GetData(vtkInformation* info);
   static vtkPointSet* GetData(vtkInformationVector* v, int i = 0);
-  //@}
+  ///@}
 
 protected:
   vtkPointSet();
@@ -289,4 +296,5 @@ inline vtkIdType vtkPointSet::GetNumberOfPoints()
   }
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
