@@ -19,6 +19,7 @@
 #include "vtkCellArrayIterator.h"
 #include "vtkCellData.h"
 #include "vtkEmptyCell.h"
+#include "vtkGarbageCollector.h"
 #include "vtkGenericCell.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -31,6 +32,7 @@
 #include "vtkPolyVertex.h"
 #include "vtkPolygon.h"
 #include "vtkQuad.h"
+#include "vtkSMPThreadLocalObject.h"
 #include "vtkSMPTools.h"
 #include "vtkSmartPointer.h"
 #include "vtkTriangle.h"
@@ -43,14 +45,17 @@
 // vtkPolyDataInternals.h methods:
 namespace vtkPolyData_detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 vtkStandardNewMacro(CellMap);
 
 CellMap::CellMap() = default;
 CellMap::~CellMap() = default;
 
+VTK_ABI_NAMESPACE_END
 } // end namespace vtkPolyData_detail
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolyData);
 vtkStandardExtendedNewMacro(vtkPolyData);
 
@@ -133,19 +138,26 @@ void vtkPolyData::CopyStructure(vtkDataSet* ds)
   vtkPolyData* pd = vtkPolyData::SafeDownCast(ds);
   if (!pd)
   {
-    vtkErrorMacro("Input dataset is not a polydata!");
+    vtkErrorMacro("Input dataset is not a " << this->GetClassName());
     return;
   }
-
-  vtkPointSet::CopyStructure(ds);
+  this->Superclass::CopyStructure(ds);
 
   this->Verts = pd->Verts;
   this->Lines = pd->Lines;
   this->Polys = pd->Polys;
   this->Strips = pd->Strips;
+  this->Cells = pd->Cells;
+}
 
-  this->Cells = nullptr;
-  this->Links = nullptr;
+//------------------------------------------------------------------------------
+vtkIdType vtkPolyData::GetCellIdRelativeToCellArray(vtkIdType cellId)
+{
+  if (!this->Cells)
+  {
+    this->BuildCells();
+  }
+  return this->Cells->GetTag(cellId).GetCellId();
 }
 
 //------------------------------------------------------------------------------
@@ -296,30 +308,6 @@ void vtkPolyData::GetCell(vtkIdType cellId, vtkGenericCell* cell)
   assert(cells != nullptr);
   cells->GetCellAtId(tag.GetCellId(), cell->PointIds);
   this->Points->GetPoints(cell->PointIds, cell->Points);
-
-  // some validation code (that existed previously).
-  const auto numPts = cell->GetNumberOfPoints();
-  switch (tag.GetCellType())
-  {
-    case VTK_VERTEX:
-      assert(numPts == 1);
-      break;
-
-    case VTK_LINE:
-      assert(numPts == 2);
-      break;
-    case VTK_TRIANGLE:
-      assert(numPts == 3);
-      break;
-
-    case VTK_QUAD:
-      assert(numPts == 4);
-      break;
-
-    default:
-      (void)numPts;
-      break;
-  }
 }
 
 //------------------------------------------------------------------------------
@@ -395,6 +383,28 @@ void vtkPolyData::CopyCells(vtkPolyData* pd, vtkIdList* idList, vtkIncrementalPo
   cell->Delete();
 }
 
+//------------------------------------------------------------------------------
+// Support GetCellBounds()
+namespace
+{ // anonymous
+struct ComputeCellBoundsVisitor
+{
+  // vtkCellArray::Visit entry point:
+  template <typename CellStateT>
+  void operator()(CellStateT& state, vtkPoints* points, vtkIdType cellId, double bounds[6]) const
+  {
+    using IdType = typename CellStateT::ValueType;
+
+    const IdType beginOffset = state.GetBeginOffset(cellId);
+    const IdType endOffset = state.GetEndOffset(cellId);
+    const IdType numPts = endOffset - beginOffset;
+
+    const auto pointIds = state.GetConnectivity()->GetPointer(beginOffset);
+    vtkBoundingBox::ComputeBounds(points, pointIds, numPts, bounds);
+  }
+};
+} // anonymous
+
 //------------------------------------------------------------------------------
 // Fast implementation of GetCellBounds().  Bounds are calculated without
 // constructing a cell. This method is expected to be thread-safe.
@@ -412,48 +422,9 @@ void vtkPolyData::GetCellBounds(vtkIdType cellId, double bounds[6])
     return;
   }
 
-  vtkIdType numPts;
-  const vtkIdType* pts;
   vtkCellArray* cells = this->GetCellArrayInternal(tag);
-  vtkSmartPointer<vtkCellArrayIterator> iter;
-  if (cells->IsStorageShareable())
-  {
-    // much faster and thread-safe if storage is shareable
-    cells->GetCellAtId(tag.GetCellId(), numPts, pts);
-  }
-  else
-  {
-    // guaranteed thread safe
-    iter = vtk::TakeSmartPointer(cells->NewIterator());
-    iter->GetCellAtId(tag.GetCellId(), numPts, pts);
-  }
-
-  // carefully compute the bounds
-  double x[3];
-  if (numPts)
-  {
-    this->Points->GetPoint(pts[0], x);
-    bounds[0] = x[0];
-    bounds[2] = x[1];
-    bounds[4] = x[2];
-    bounds[1] = x[0];
-    bounds[3] = x[1];
-    bounds[5] = x[2];
-    for (vtkIdType i = 1; i < numPts; ++i)
-    {
-      this->Points->GetPoint(pts[i], x);
-      bounds[0] = std::min(x[0], bounds[0]);
-      bounds[1] = std::max(x[0], bounds[1]);
-      bounds[2] = std::min(x[1], bounds[2]);
-      bounds[3] = std::max(x[1], bounds[3]);
-      bounds[4] = std::min(x[2], bounds[4]);
-      bounds[5] = std::max(x[2], bounds[5]);
-    }
-  }
-  else
-  {
-    vtkMath::UninitializeBounds(bounds);
-  }
+  const vtkIdType localCellId = tag.GetCellId();
+  cells->Visit(ComputeCellBoundsVisitor{}, this->Points, localCellId, bounds);
 }
 
 //------------------------------------------------------------------------------
@@ -466,9 +437,9 @@ void vtkPolyData::ComputeCellsBounds()
   if (this->GetMeshMTime() > this->CellsBoundsTime)
   {
     // If there are no cells, uninitialize the bounds.
-    vtkIdType numPts = this->GetNumberOfPoints();
-    vtkIdType numCells = this->GetNumberOfCells();
-    if (numCells <= 0)
+    const vtkIdType numPts = this->GetNumberOfPoints();
+    const vtkIdType numPDCells = this->GetNumberOfCells();
+    if (numPDCells <= 0)
     {
       vtkMath::UninitializeBounds(this->CellsBounds);
       return;
@@ -478,7 +449,7 @@ void vtkPolyData::ComputeCellsBounds()
     this->CellsBoundsTime.Modified();
 
     // Make sure this vtkPolyData has points.
-    if (this->Points == nullptr || numPts <= 0)
+    if (this->Points == nullptr || numPts <= 0 || numPDCells <= 0)
     {
       vtkMath::UninitializeBounds(this->CellsBounds);
       return;
@@ -487,56 +458,74 @@ void vtkPolyData::ComputeCellsBounds()
     // With cells available, loop over the cells of the polydata.
     // Mark points that are used by one or more cells. Unmarked
     // points do not contribute.
-    unsigned char* ptUses = new unsigned char[numPts];
-    std::fill_n(ptUses, numPts, 0); // initially unvisited
-
-    vtkCellArray* cellA[4];
-    cellA[0] = this->GetVerts();
-    cellA[1] = this->GetLines();
-    cellA[2] = this->GetPolys();
-    cellA[3] = this->GetStrips();
+    vtkCellArray* cellArrays[4] = { this->GetVerts(), this->GetLines(), this->GetPolys(),
+      this->GetStrips() };
 
     // Process each cell array separately. Note that threading is only used
     // if the model is big enough (since there is a cost to spinning up the
     // thread pool).
-    for (auto ca = 0; ca < 4; ca++)
+    static constexpr int VTK_SMP_THRESHOLD = 250000;
+
+    // Create uses array initialized to 0
+    vtkSMPThreadLocalObject<vtkIdList> tlCellPointIds;
+    if (numPDCells > VTK_SMP_THRESHOLD)
     {
-      if ((numCells = cellA[ca]->GetNumberOfCells()) > 250000)
+      // Create uses array initialized to 0 and supporting threaded access
+      std::atomic<unsigned char>* ptUses = new std::atomic<unsigned char>[numPts]();
+      for (const auto& cellArray : cellArrays)
       {
-        // Lambda to threaded compute bounds
-        vtkSMPTools::For(0, numCells, [&](vtkIdType cellId, vtkIdType endCellId) {
+        const auto numCells = cellArray->GetNumberOfCells();
+        if (numCells <= 0)
+        {
+          continue;
+        }
+        // Lambda to threaded mark used points
+        vtkSMPTools::For(0, numCells, [&](vtkIdType beginCellId, vtkIdType endCellId) {
+          auto cellPointIds = tlCellPointIds.Local();
           vtkIdType npts, ptIdx;
           const vtkIdType* pts;
-          auto iter = vtk::TakeSmartPointer(cellA[ca]->NewIterator());
-          for (; cellId < endCellId; ++cellId)
+          for (vtkIdType cellId = beginCellId; cellId < endCellId; ++cellId)
           {
-            iter->GetCellAtId(cellId, npts, pts); // thread-safe
+            cellArray->GetCellAtId(cellId, npts, pts, cellPointIds);
             for (ptIdx = 0; ptIdx < npts; ++ptIdx)
             {
-              ptUses[pts[ptIdx]] = 1;
+              // memory_order_relaxed is safe here, since we're not using the atomics for
+              // synchronization.
+              ptUses[pts[ptIdx]].store(1, std::memory_order_relaxed);
             }
           }
         }); // end lambda
       }
-      else if (numCells > 0) // serial
+      vtkBoundingBox::ComputeBounds(this->Points, ptUses, this->CellsBounds);
+      delete[] ptUses;
+    }
+    else
+    {
+      // Create point uses array initialized to 0
+      unsigned char* ptUses = new unsigned char[numPts]();
+      for (const auto& cellArray : cellArrays)
       {
+        const auto numCells = cellArray->GetNumberOfCells();
+        if (numCells <= 0)
+        {
+          continue;
+        }
+        auto cellPointIds = tlCellPointIds.Local();
         vtkIdType npts, ptIdx;
         const vtkIdType* pts;
-        for (auto cellId = 0; cellId < numCells; ++cellId)
+        for (vtkIdType cellId = 0; cellId < numCells; ++cellId)
         {
-          cellA[ca]->GetCellAtId(cellId, npts, pts);
+          cellArray->GetCellAtId(cellId, npts, pts, cellPointIds);
           for (ptIdx = 0; ptIdx < npts; ++ptIdx)
           {
             ptUses[pts[ptIdx]] = 1;
           }
         }
-      }
-    } // for all cell arrays
-
-    // Perform the bounding box computation
-    vtkBoundingBox::ComputeBounds(this->Points, ptUses, this->CellsBounds);
-    delete[] ptUses;
-  }
+      } // for all cell arrays
+      vtkBoundingBox::ComputeBounds(this->Points, ptUses, this->CellsBounds);
+      delete[] ptUses;
+    } // serial
+  }   // if modified mesh
 }
 
 //------------------------------------------------------------------------------
@@ -553,7 +542,7 @@ void vtkPolyData::GetCellsBounds(double bounds[6])
 // Set the cell array defining vertices.
 void vtkPolyData::SetVerts(vtkCellArray* v)
 {
-  if (v == this->DummyContainer.Dummy)
+  if (v == vtkPolyData::DummyContainer.Dummy)
   {
     v = nullptr;
   }
@@ -576,7 +565,7 @@ vtkCellArray* vtkPolyData::GetVerts()
 {
   if (!this->Verts)
   {
-    return this->DummyContainer.Dummy;
+    return vtkPolyData::DummyContainer.Dummy;
   }
   else
   {
@@ -588,7 +577,7 @@ vtkCellArray* vtkPolyData::GetVerts()
 // Set the cell array defining lines.
 void vtkPolyData::SetLines(vtkCellArray* l)
 {
-  if (l == this->DummyContainer.Dummy)
+  if (l == vtkPolyData::DummyContainer.Dummy)
   {
     l = nullptr;
   }
@@ -611,7 +600,7 @@ vtkCellArray* vtkPolyData::GetLines()
 {
   if (!this->Lines)
   {
-    return this->DummyContainer.Dummy;
+    return vtkPolyData::DummyContainer.Dummy;
   }
   else
   {
@@ -623,7 +612,7 @@ vtkCellArray* vtkPolyData::GetLines()
 // Set the cell array defining polygons.
 void vtkPolyData::SetPolys(vtkCellArray* p)
 {
-  if (p == this->DummyContainer.Dummy)
+  if (p == vtkPolyData::DummyContainer.Dummy)
   {
     p = nullptr;
   }
@@ -646,7 +635,7 @@ vtkCellArray* vtkPolyData::GetPolys()
 {
   if (!this->Polys)
   {
-    return this->DummyContainer.Dummy;
+    return vtkPolyData::DummyContainer.Dummy;
   }
   else
   {
@@ -658,7 +647,7 @@ vtkCellArray* vtkPolyData::GetPolys()
 // Set the cell array defining triangle strips.
 void vtkPolyData::SetStrips(vtkCellArray* s)
 {
-  if (s == this->DummyContainer.Dummy)
+  if (s == vtkPolyData::DummyContainer.Dummy)
   {
     s = nullptr;
   }
@@ -682,7 +671,7 @@ vtkCellArray* vtkPolyData::GetStrips()
 {
   if (!this->Strips)
   {
-    return this->DummyContainer.Dummy;
+    return vtkPolyData::DummyContainer.Dummy;
   }
   else
   {
@@ -836,6 +825,8 @@ void vtkPolyData::DeleteCells()
   this->Cells = nullptr;
 }
 
+VTK_ABI_NAMESPACE_END
+
 namespace
 {
 
@@ -845,7 +836,8 @@ struct BuildCellsImpl
   // VTKCellType. The functor must ensure that the input size and returned cell
   // type are valid for the target cell array or throw a std::runtime_error.
   template <typename CellStateT, typename SizeToTypeFunctor>
-  void operator()(CellStateT& state, vtkPolyData_detail::CellMap* map, SizeToTypeFunctor&& typer)
+  void operator()(CellStateT& state, vtkPolyData_detail::CellMap* map, vtkIdType beginCellId,
+    SizeToTypeFunctor&& typer)
   {
     const vtkIdType numCells = state.GetNumberOfCells();
     if (numCells == 0)
@@ -853,20 +845,24 @@ struct BuildCellsImpl
       return;
     }
 
-    if (!map->ValidateCellId(numCells - 1))
+    if (!vtkPolyData_detail::CellMap::ValidateCellId(numCells - 1))
     {
       throw std::runtime_error("Cell map storage capacity exceeded.");
     }
 
-    for (vtkIdType cellId = 0; cellId < numCells; ++cellId)
-    {
-      map->InsertNextCell(cellId, typer(state.GetCellSize(cellId)));
-    }
+    vtkSMPTools::For(0, numCells, [&](vtkIdType begin, vtkIdType end) {
+      for (vtkIdType cellId = begin, globalCellId = beginCellId + begin; cellId < end;
+           ++cellId, ++globalCellId)
+      {
+        map->InsertCell(globalCellId, cellId, typer(state.GetCellSize(cellId)));
+      }
+    });
   }
 };
 
 } // end anon namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 // Create data structure that allows random access of cells.
 void vtkPolyData::BuildCells()
@@ -886,67 +882,43 @@ void vtkPolyData::BuildCells()
   const vtkIdType nCells = nVerts + nLines + nPolys + nStrips;
 
   this->Cells = vtkSmartPointer<CellMap>::New();
-  this->Cells->SetCapacity(nCells);
+  this->Cells->SetNumberOfCells(nCells);
 
-  try
+  vtkIdType beginCellId = 0;
+  if (nVerts > 0)
   {
-    if (nVerts > 0)
-    {
-      verts->Visit(BuildCellsImpl{}, this->Cells, [](vtkIdType size) -> VTKCellType {
-        if (size < 1)
-        {
-          throw std::runtime_error("Invalid cell size for verts.");
-        }
-        return size == 1 ? VTK_VERTEX : VTK_POLY_VERTEX;
-      });
-    }
-
-    if (nLines > 0)
-    {
-      lines->Visit(BuildCellsImpl{}, this->Cells, [](vtkIdType size) -> VTKCellType {
-        if (size < 2)
-        {
-          throw std::runtime_error("Invalid cell size for lines.");
-        }
-        return size == 2 ? VTK_LINE : VTK_POLY_LINE;
-      });
-    }
-
-    if (nPolys > 0)
-    {
-      polys->Visit(BuildCellsImpl{}, this->Cells, [](vtkIdType size) -> VTKCellType {
-        if (size < 3)
-        {
-          throw std::runtime_error("Invalid cell size for polys.");
-        }
-
-        switch (size)
-        {
-          case 3:
-            return VTK_TRIANGLE;
-          case 4:
-            return VTK_QUAD;
-          default:
-            return VTK_POLYGON;
-        }
-      });
-    }
-
-    if (nStrips > 0)
-    {
-      strips->Visit(BuildCellsImpl{}, this->Cells, [](vtkIdType size) -> VTKCellType {
-        if (size < 3)
-        {
-          throw std::runtime_error("Invalid cell size for polys.");
-        }
-        return VTK_TRIANGLE_STRIP;
-      });
-    }
+    verts->Visit(BuildCellsImpl{}, this->Cells, beginCellId,
+      [](vtkIdType size) -> VTKCellType { return size == 1 ? VTK_VERTEX : VTK_POLY_VERTEX; });
+    beginCellId += nVerts;
   }
-  catch (std::runtime_error& e)
+
+  if (nLines > 0)
   {
-    this->Cells = nullptr;
-    vtkErrorMacro("Error while constructing cell map: " << e.what());
+    lines->Visit(BuildCellsImpl{}, this->Cells, beginCellId,
+      [](vtkIdType size) -> VTKCellType { return size == 2 ? VTK_LINE : VTK_POLY_LINE; });
+    beginCellId += nLines;
+  }
+
+  if (nPolys > 0)
+  {
+    polys->Visit(BuildCellsImpl{}, this->Cells, beginCellId, [](vtkIdType size) -> VTKCellType {
+      switch (size)
+      {
+        case 3:
+          return VTK_TRIANGLE;
+        case 4:
+          return VTK_QUAD;
+        default:
+          return VTK_POLYGON;
+      }
+    });
+    beginCellId += nPolys;
+  }
+
+  if (nStrips > 0)
+  {
+    strips->Visit(BuildCellsImpl{}, this->Cells, beginCellId,
+      [](vtkIdType vtkNotUsed(size)) -> VTKCellType { return VTK_TRIANGLE_STRIP; });
   }
 }
 //------------------------------------------------------------------------------
@@ -964,18 +936,46 @@ void vtkPolyData::BuildLinks(int initialSize)
   {
     this->BuildCells();
   }
-
-  this->Links = vtkSmartPointer<vtkCellLinks>::New();
-  if (initialSize > 0)
+  if (!this->Points)
+  {
+    return;
+  }
+  if (!this->Links)
+  {
+    this->Links = vtkSmartPointer<vtkCellLinks>::New();
+    if (initialSize > 0)
+    {
+      this->Links->Allocate(initialSize);
+    }
+    this->Links->SetDataSet(this);
+  }
+  else if (initialSize > 0)
   {
     this->Links->Allocate(initialSize);
+    this->Links->SetDataSet(this);
   }
-  else
+  else if (this->Points->GetMTime() > this->Links->GetMTime())
   {
-    this->Links->Allocate(this->GetNumberOfPoints());
+    this->Links->SetDataSet(this);
   }
+  this->Links->BuildLinks();
+}
 
-  this->Links->BuildLinks(this);
+//------------------------------------------------------------------------------
+void vtkPolyData::SetLinks(vtkAbstractCellLinks* links)
+{
+  if (this->Links != links)
+  {
+    if (auto cellLinks = vtkCellLinks::SafeDownCast(links))
+    {
+      this->Links = cellLinks;
+      this->Modified();
+    }
+    else
+    {
+      vtkErrorMacro("Only vtkCellLinks are currently supported.");
+    }
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -1437,6 +1437,13 @@ int vtkPolyData::IsEdge(vtkIdType p1, vtkIdType p2)
   return 0;
 }
 
+//------------------------------------------------------------------------------
+void vtkPolyData::ReportReferences(vtkGarbageCollector* collector)
+{
+  this->Superclass::ReportReferences(collector);
+  vtkGarbageCollectorReport(collector, this->Links, "Links");
+}
+
 //------------------------------------------------------------------------------
 unsigned long vtkPolyData::GetActualMemorySize()
 {
@@ -1473,9 +1480,13 @@ void vtkPolyData::ShallowCopy(vtkDataObject* dataObject)
 {
   vtkPolyData* polyData = vtkPolyData::SafeDownCast(dataObject);
   if (this == polyData)
+  {
     return;
+  }
 
-  if (polyData != nullptr)
+  // Do superclass
+  this->Superclass::ShallowCopy(dataObject);
+  if (polyData)
   {
     this->SetVerts(polyData->GetVerts());
     this->SetLines(polyData->GetLines());
@@ -1485,39 +1496,58 @@ void vtkPolyData::ShallowCopy(vtkDataObject* dataObject)
     // I do not know if this is correct but.
     // Me either! But it's been 20 years so I think it'll be ok.
     this->Cells = polyData->Cells;
-    this->Links = polyData->Links;
   }
-
-  // Do superclass
-  this->vtkPointSet::ShallowCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
 void vtkPolyData::DeepCopy(vtkDataObject* dataObject)
 {
   auto mkhold = vtkMemkindRAII(this->GetIsInMemkind());
+
+  vtkPolyData* polyData = vtkPolyData::SafeDownCast(dataObject);
   // Do superclass We have to do this BEFORE we call BuildLinks, else
   // there are no points to build the links on (the parent DeepCopy
   // copies the points)
-  this->vtkPointSet::DeepCopy(dataObject);
+  this->Superclass::DeepCopy(dataObject);
 
-  vtkPolyData* polyData = vtkPolyData::SafeDownCast(dataObject);
-
-  if (polyData != nullptr)
+  if (polyData)
   {
-    this->Verts = vtkSmartPointer<vtkCellArray>::New();
-    this->Verts->DeepCopy(polyData->GetVerts());
-
-    this->Lines = vtkSmartPointer<vtkCellArray>::New();
-    this->Lines->DeepCopy(polyData->GetLines());
-
-    this->Polys = vtkSmartPointer<vtkCellArray>::New();
-    this->Polys->DeepCopy(polyData->GetPolys());
-
-    this->Strips = vtkSmartPointer<vtkCellArray>::New();
-    this->Strips->DeepCopy(polyData->GetStrips());
-
-    // only instantiate this if the input dataset has one
+    if (polyData->Verts)
+    {
+      this->Verts = vtkSmartPointer<vtkCellArray>::New();
+      this->Verts->DeepCopy(polyData->Verts);
+    }
+    else
+    {
+      this->Verts = nullptr;
+    }
+    if (polyData->Lines)
+    {
+      this->Lines = vtkSmartPointer<vtkCellArray>::New();
+      this->Lines->DeepCopy(polyData->Lines);
+    }
+    else
+    {
+      this->Lines = nullptr;
+    }
+    if (polyData->Polys)
+    {
+      this->Polys = vtkSmartPointer<vtkCellArray>::New();
+      this->Polys->DeepCopy(polyData->Polys);
+    }
+    else
+    {
+      this->Polys = nullptr;
+    }
+    if (polyData->Strips)
+    {
+      this->Strips = vtkSmartPointer<vtkCellArray>::New();
+      this->Strips->DeepCopy(polyData->Strips);
+    }
+    else
+    {
+      this->Strips = nullptr;
+    }
     if (polyData->Cells)
     {
       this->Cells = vtkSmartPointer<CellMap>::New();
@@ -1527,14 +1557,14 @@ void vtkPolyData::DeepCopy(vtkDataObject* dataObject)
     {
       this->Cells = nullptr;
     }
-
-    if (this->Links)
-    {
-      this->Links = nullptr;
-    }
     if (polyData->Links)
     {
-      this->BuildLinks();
+      this->Links = vtkSmartPointer<vtkCellLinks>::Take(polyData->Links->NewInstance());
+      this->Links->DeepCopy(polyData->Links);
+    }
+    else
+    {
+      this->Links = nullptr;
     }
 
     this->CellsBoundsTime = polyData->CellsBoundsTime;
@@ -1546,6 +1576,9 @@ void vtkPolyData::DeepCopy(vtkDataObject* dataObject)
   }
 }
 
+static constexpr unsigned char MASKED_CELL_VALUE = vtkDataSetAttributes::HIDDENCELL |
+  vtkDataSetAttributes::DUPLICATECELL | vtkDataSetAttributes::REFINEDCELL;
+
 //------------------------------------------------------------------------------
 void vtkPolyData::RemoveGhostCells()
 {
@@ -1561,123 +1594,199 @@ void vtkPolyData::RemoveGhostCells()
     vtkErrorMacro("Poorly formed ghost array.");
     return;
   }
+  vtkIdType numCells = this->GetNumberOfCells();
+  vtkIdType numPoints = this->GetNumberOfPoints();
+
+  if (!numCells || !numPoints)
+  {
+    return;
+  }
+
+  // check if there are any cells to delete
+  if (!this->CellData->HasAnyGhostBitSet(MASKED_CELL_VALUE))
+  {
+    return;
+  }
+
   unsigned char* cellGhosts = temp->GetPointer(0);
 
-  vtkIdType numCells = this->GetNumberOfCells();
+  vtkNew<vtkPolyData> newPD;
+  vtkNew<vtkCellArray> newVerts, newLines, newPolys, newStrips;
+  vtkPointData* newPointData = newPD->GetPointData();
+  vtkCellData* newCellData = newPD->GetCellData();
 
-  vtkIntArray* types = vtkIntArray::New();
-  types->SetNumberOfValues(numCells);
-
-  for (vtkIdType i = 0; i < numCells; i++)
+#ifdef VTK_USE_64BIT_IDS
+  if (!(numPoints >> 31))
   {
-    types->SetValue(i, this->GetCellType(i));
+    newVerts->ConvertTo32BitStorage();
+    newLines->ConvertTo32BitStorage();
+    newPolys->ConvertTo32BitStorage();
+    newStrips->ConvertTo32BitStorage();
   }
+#endif
 
-  this->DeleteCells();
+  newVerts->Allocate(this->GetNumberOfVerts());
+  newLines->Allocate(this->GetNumberOfLines());
+  newPolys->Allocate(this->GetNumberOfPolys());
+  newStrips->Allocate(this->GetNumberOfStrips());
 
-  // we have to make new copies of Verts, Lines, Polys
-  // and Strips since they may be shared with other polydata
-  vtkSmartPointer<vtkCellArray> verts;
-  if (this->Verts)
-  {
-    verts = this->Verts;
-    verts->InitTraversal();
-    this->Verts = vtkSmartPointer<vtkCellArray>::New();
-  }
-
-  vtkSmartPointer<vtkCellArray> lines;
-  if (this->Lines)
-  {
-    lines = this->Lines;
-    lines->InitTraversal();
-    this->Lines = vtkSmartPointer<vtkCellArray>::New();
-  }
-
-  vtkSmartPointer<vtkCellArray> polys;
-  if (this->Polys)
-  {
-    polys = this->Polys;
-    polys->InitTraversal();
-    this->Polys = vtkSmartPointer<vtkCellArray>::New();
-  }
-
-  vtkSmartPointer<vtkCellArray> strips;
-  if (this->Strips)
-  {
-    strips = this->Strips;
-    strips->InitTraversal();
-    this->Strips = vtkSmartPointer<vtkCellArray>::New();
-  }
-
-  vtkCellData* newCellData = vtkCellData::New();
-  // ensure that all attributes are copied over, including global ids.
   newCellData->CopyAllOn(vtkDataSetAttributes::COPYTUPLE);
   newCellData->CopyAllocate(this->CellData, numCells);
 
+  newPointData->CopyAllOn(vtkDataSetAttributes::COPYTUPLE);
+  newPointData->CopyAllocate(this->PointData, numCells);
+
+  vtkNew<vtkPoints> newPoints;
+  newPoints->SetDataType(this->GetPoints()->GetDataType());
+  newPoints->Allocate(numPoints);
+
+  vtkNew<vtkIdList> pointMap;
+  pointMap->SetNumberOfIds(numPoints);
+  vtkSMPTools::Fill(pointMap->begin(), pointMap->end(), -1);
+
   const vtkIdType* pts;
+  double* x;
   vtkIdType n;
 
   vtkIdType cellId;
+  vtkNew<vtkIdList> newCellPoints;
+
+  newPD->SetPoints(newPoints);
+  newPD->SetVerts(newVerts);
+  newPD->SetLines(newLines);
+  newPD->SetPolys(newPolys);
+  newPD->SetStrips(newStrips);
+
+  if (this->Verts)
+  {
+    this->Verts->InitTraversal();
+  }
+  if (this->Lines)
+  {
+    this->Lines->InitTraversal();
+  }
+  if (this->Polys)
+  {
+    this->Polys->InitTraversal();
+  }
+  if (this->Strips)
+  {
+    this->Strips->InitTraversal();
+  }
 
   for (vtkIdType i = 0; i < numCells; i++)
   {
-    int type = types->GetValue(i);
+    int type = this->GetCellType(i);
 
     if (type == VTK_VERTEX || type == VTK_POLY_VERTEX)
     {
-      verts->GetNextCell(n, pts);
+      this->Verts->GetNextCell(n, pts);
 
-      if (!(cellGhosts[i] &
-            (vtkDataSetAttributes::DUPLICATECELL | vtkDataSetAttributes::HIDDENCELL)))
+      if (!(cellGhosts[i] & MASKED_CELL_VALUE))
       {
-        cellId = this->InsertNextCell(type, n, pts);
+        for (vtkIdType id = 0; id < n; ++id)
+        {
+          vtkIdType ptId = pts[id];
+          vtkIdType newId;
+          if ((newId = pointMap->GetId(ptId)) == -1)
+          {
+            x = this->GetPoint(ptId);
+            newId = newPoints->InsertNextPoint(x);
+            pointMap->SetId(ptId, newId);
+            newPointData->CopyData(this->PointData, ptId, newId);
+          }
+          newCellPoints->InsertId(id, newId);
+        }
+
+        cellId = newPD->InsertNextCell(type, newCellPoints);
         newCellData->CopyData(this->CellData, i, cellId);
+        newCellPoints->Reset();
       }
     }
     else if (type == VTK_LINE || type == VTK_POLY_LINE)
     {
-      lines->GetNextCell(n, pts);
+      this->Lines->GetNextCell(n, pts);
 
-      if (!(cellGhosts[i] &
-            (vtkDataSetAttributes::DUPLICATECELL | vtkDataSetAttributes::HIDDENCELL)))
+      if (!(cellGhosts[i] & MASKED_CELL_VALUE))
       {
-        cellId = this->InsertNextCell(type, n, pts);
+        for (vtkIdType id = 0; id < n; ++id)
+        {
+          vtkIdType newId;
+          vtkIdType ptId = pts[id];
+          if ((newId = pointMap->GetId(ptId)) == -1)
+          {
+            x = this->GetPoint(ptId);
+            newId = newPoints->InsertNextPoint(x);
+            pointMap->SetId(ptId, newId);
+            newPointData->CopyData(this->PointData, ptId, newId);
+          }
+          newCellPoints->InsertId(id, newId);
+        }
+
+        cellId = newPD->InsertNextCell(type, newCellPoints);
         newCellData->CopyData(this->CellData, i, cellId);
+        newCellPoints->Reset();
       }
     }
     else if (type == VTK_POLYGON || type == VTK_TRIANGLE || type == VTK_QUAD)
     {
-      polys->GetNextCell(n, pts);
+      this->Polys->GetNextCell(n, pts);
 
-      if (!(cellGhosts[i] &
-            (vtkDataSetAttributes::DUPLICATECELL | vtkDataSetAttributes::HIDDENCELL)))
+      if (!(cellGhosts[i] & MASKED_CELL_VALUE))
       {
-        cellId = this->InsertNextCell(type, n, pts);
+        for (vtkIdType id = 0; id < n; ++id)
+        {
+          vtkIdType ptId = pts[id];
+          vtkIdType newId;
+          if ((newId = pointMap->GetId(ptId)) == -1)
+          {
+            x = this->GetPoint(ptId);
+            newId = newPoints->InsertNextPoint(x);
+            pointMap->SetId(ptId, newId);
+            newPointData->CopyData(this->PointData, ptId, newId);
+          }
+          newCellPoints->InsertId(id, newId);
+        }
+
+        cellId = newPD->InsertNextCell(type, newCellPoints);
         newCellData->CopyData(this->CellData, i, cellId);
+        newCellPoints->Reset();
       }
     }
     else if (type == VTK_TRIANGLE_STRIP)
     {
-      strips->GetNextCell(n, pts);
+      this->Strips->GetNextCell(n, pts);
 
-      if (!(cellGhosts[i] &
-            (vtkDataSetAttributes::DUPLICATECELL | vtkDataSetAttributes::HIDDENCELL)))
+      if (!(cellGhosts[i] & MASKED_CELL_VALUE))
       {
-        cellId = this->InsertNextCell(type, n, pts);
+        for (vtkIdType id = 0; id < n; ++id)
+        {
+          vtkIdType ptId = pts[id];
+          vtkIdType newId;
+          if ((newId = pointMap->GetId(ptId)) == -1)
+          {
+            x = this->GetPoint(ptId);
+            newId = newPoints->InsertNextPoint(x);
+            pointMap->SetId(ptId, newId);
+            newPointData->CopyData(this->PointData, ptId, newId);
+          }
+          newCellPoints->InsertId(id, newId);
+        }
+
+        cellId = newPD->InsertNextCell(type, newCellPoints);
         newCellData->CopyData(this->CellData, i, cellId);
+        newCellPoints->Reset();
       }
     }
   }
 
   newCellData->Squeeze();
+  newPointData->Squeeze();
 
-  this->CellData->ShallowCopy(newCellData);
-  newCellData->Delete();
+  this->ShallowCopy(newPD);
 
-  types->Delete();
-
-  // If there are no more ghost levels, then remove all arrays.
   this->CellData->RemoveArray(vtkDataSetAttributes::GhostArrayName());
+  this->PointData->RemoveArray(vtkDataSetAttributes::GhostArrayName());
 
   this->Squeeze();
 }
@@ -2080,3 +2189,4 @@ vtkMTimeType vtkPolyData::GetMTime()
   }
   return time;
 }
+VTK_ABI_NAMESPACE_END
