@@ -63,13 +63,13 @@
 #define vtkPolyData_h
 
 #include "vtkCommonDataModelModule.h" // For export macro
-#include "vtkDeprecation.h"           // for VTK_DEPRECATED_IN_9_0_0
 #include "vtkPointSet.h"
 
 #include "vtkCellArray.h"         // Needed for inline methods
 #include "vtkCellLinks.h"         // Needed for inline methods
 #include "vtkPolyDataInternals.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkVertex;
 class vtkPolyVertex;
 class vtkLine;
@@ -101,7 +101,7 @@ public:
    */
   void CopyStructure(vtkDataSet* ds) override;
 
-  //@{
+  ///@{
   /**
    * Standard vtkDataSet interface.
    */
@@ -110,9 +110,10 @@ public:
   vtkCell* GetCell(vtkIdType cellId) override;
   void GetCell(vtkIdType cellId, vtkGenericCell* cell) override;
   int GetCellType(vtkIdType cellId) override;
+  vtkIdType GetCellSize(vtkIdType cellId) override;
   void GetCellBounds(vtkIdType cellId, double bounds[6]) override;
   void GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds) override;
-  //@}
+  ///@}
 
   /**
    * Copy cells listed in idList from pd, including points, point data,
@@ -149,7 +150,7 @@ public:
    * not return the same bounds as before. This behavior is probably the one you want
    * when using bounds.
    *
-   * The previous behavior is still availble through vtkPolyData::ComputeCellsBounds()
+   * The previous behavior is still available through vtkPolyData::ComputeCellsBounds()
    * and vtkPolyData::GetCellsBounds(). This is mainly used for rendering purpose.
    */
   void ComputeCellsBounds();
@@ -174,6 +175,13 @@ public:
    */
   int GetMaxCellSize() override;
 
+  /**
+   * Maps the cell at position `cellId` inside the `vtkPolyData` to its location in the
+   * corresponding cell array. For instance, if cell `cellId` is a line, then this method returns
+   * the position of this cell in the `Lines` cell array.
+   */
+  vtkIdType GetCellIdRelativeToCellArray(vtkIdType cellId);
+
   /**
    * Set the cell array defining vertices.
    */
@@ -219,7 +227,7 @@ public:
    */
   vtkCellArray* GetStrips();
 
-  //@{
+  ///@{
   /**
    * Return the number of primitives of a particular type held.
    */
@@ -227,7 +235,7 @@ public:
   vtkIdType GetNumberOfLines() { return (this->Lines ? this->Lines->GetNumberOfCells() : 0); }
   vtkIdType GetNumberOfPolys() { return (this->Polys ? this->Polys->GetNumberOfCells() : 0); }
   vtkIdType GetNumberOfStrips() { return (this->Strips ? this->Strips->GetNumberOfCells() : 0); }
-  //@}
+  ///@}
 
   /**
    * Preallocate memory for the internal cell arrays. Each of the internal
@@ -372,6 +380,16 @@ public:
    */
   void BuildLinks(int initialSize = 0);
 
+  ///@{
+  /**
+   * Set/Get the links that you created possibly without using BuildLinks.
+   *
+   * Note: Only vtkCellLinks are currently supported.
+   */
+  virtual void SetLinks(vtkAbstractCellLinks* links);
+  vtkGetSmartPointerMacro(Links, vtkAbstractCellLinks);
+  ///@}
+
   /**
    * Release data structure that allows random access of the cells. This must
    * be done before a 2nd call to BuildLinks(). DeleteCells implicitly deletes
@@ -384,17 +402,14 @@ public:
    */
   void DeleteLinks();
 
-  //@{
+  ///@{
   /**
    * Special (efficient) operations on poly data. Use carefully (i.e., make
    * sure that BuildLinks() has been called).
    */
   void GetPointCells(vtkIdType ptId, vtkIdType& ncells, vtkIdType*& cells)
     VTK_SIZEHINT(cells, ncells);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkPolyData::GetPointCells::vtkIdType, vtkIdType&, vtkIdType*&)")
-  void GetPointCells(vtkIdType ptId, unsigned short& ncells, vtkIdType*& cells)
-    VTK_SIZEHINT(cells, ncells);
-  //@}
+  ///@}
 
   /**
    * Get the neighbors at an edge. More efficient than the general
@@ -411,10 +426,29 @@ public:
    * results.
    *
    * The @a pts pointer must not be modified.
+   *
+   * Note: This method MAY NOT be thread-safe. (See GetCellAtId at vtkCellArray)
    */
   unsigned char GetCellPoints(vtkIdType cellId, vtkIdType& npts, vtkIdType const*& pts)
     VTK_SIZEHINT(pts, npts);
 
+  /**
+   * Get a list of point ids that define a cell.
+   * Requires the the cells have been built with BuildCells.
+   *
+   * This function MAY use ptIds, which is an object that is created by each thread,
+   * to guarantee thread safety.
+   *
+   * @warning Subsequent calls to this method may invalidate previous call
+   * results.
+   *
+   * The @a pts pointer must not be modified.
+   *
+   * Note: This method is thread-safe.
+   */
+  void GetCellPoints(vtkIdType cellId, vtkIdType& npts, vtkIdType const*& pts, vtkIdList* ptIds)
+    VTK_SIZEHINT(pts, npts) override;
+
   /**
    * Given three vertices, determine whether it's a triangle. Make sure
    * BuildLinks() has been called first.
@@ -448,11 +482,20 @@ public:
   void ReplaceCell(vtkIdType cellId, int npts, const vtkIdType pts[]) VTK_SIZEHINT(pts, npts);
   /**@}*/
 
+  ///@{
   /**
    * Replace a point in the cell connectivity list with a different point. Use this
    * method only when the dataset is set as Editable.
+   *
+   * The version with cellPointIds avoids allocating/deallocating a vtkIdList at each call
+   * internally.
+   *
+   * THIS METHOD IS THREAD SAFE IF BuildCells() IS FIRST CALLED FROM A SINGLE THREAD.
    */
   void ReplaceCellPoint(vtkIdType cellId, vtkIdType oldPtId, vtkIdType newPtId);
+  void ReplaceCellPoint(
+    vtkIdType cellId, vtkIdType oldPtId, vtkIdType newPtId, vtkIdList* cellPointIds);
+  ///@}
 
   /**
    * Reverse the order of point ids defining the cell. Use this
@@ -460,14 +503,14 @@ public:
    */
   void ReverseCell(vtkIdType cellId);
 
-  //@{
+  ///@{
   /**
    * Mark a point/cell as deleted from this vtkPolyData. Use this
    * method only when the dataset is set as Editable.
    */
   void DeletePoint(vtkIdType ptId);
   void DeleteCell(vtkIdType cellId);
-  //@}
+  ///@}
 
   /**
    * The cells marked by calls to DeleteCell are stored in the Cell Array
@@ -479,7 +522,7 @@ public:
    */
   void RemoveDeletedCells();
 
-  //@{
+  ///@{
   /**
    * Add a point to the cell data structure (after cell pointers have been
    * built). This method adds the point and then allocates memory for the
@@ -490,7 +533,7 @@ public:
    */
   vtkIdType InsertNextLinkedPoint(int numLinks);
   vtkIdType InsertNextLinkedPoint(double x[3], int numLinks);
-  //@}
+  ///@}
 
   /**
    * Add a new cell to the cell data structure (after cell pointers have been
@@ -559,13 +602,13 @@ public:
    */
   void Initialize() override;
 
-  //@{
+  ///@{
   /**
    * Get the piece and the number of pieces. Similar to extent in 3D.
    */
   virtual int GetPiece();
   virtual int GetNumberOfPieces();
-  //@}
+  ///@}
 
   /**
    * Get the ghost level.
@@ -582,13 +625,13 @@ public:
    */
   unsigned long GetActualMemorySize() override;
 
-  //@{
+  ///@{
   /**
    * Shallow and Deep copy.
    */
   void ShallowCopy(vtkDataObject* src) override;
   void DeepCopy(vtkDataObject* src) override;
-  //@}
+  ///@}
 
   /**
    * This method will remove any cell that is marked as ghost
@@ -598,13 +641,13 @@ public:
    */
   void RemoveGhostCells();
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkPolyData* GetData(vtkInformation* info);
   static vtkPolyData* GetData(vtkInformationVector* v, int i = 0);
-  //@}
+  ///@}
 
   /**
    * Scalar field critical point classification (for manifold 2D meshes).
@@ -668,6 +711,8 @@ protected:
   vtkPolyData();
   ~vtkPolyData() override;
 
+  void ReportReferences(vtkGarbageCollector*) override;
+
   using TaggedCellId = vtkPolyData_detail::TaggedCellId;
   using CellMap = vtkPolyData_detail::CellMap;
 
@@ -707,16 +752,6 @@ protected:
   vtkTimeStamp CellsBoundsTime;
 
 private:
-  // Hide these from the user and the compiler.
-
-  /**
-   * For legacy compatibility. Do not use.
-   */
-  void GetCellNeighbors(vtkIdType cellId, vtkIdList& ptIds, vtkIdList& cellIds)
-  {
-    this->GetCellNeighbors(cellId, &ptIds, &cellIds);
-  }
-
   void Cleanup();
 
 private:
@@ -731,13 +766,6 @@ inline void vtkPolyData::GetPointCells(vtkIdType ptId, vtkIdType& ncells, vtkIdT
   cells = this->Links->GetCells(ptId);
 }
 
-inline void vtkPolyData::GetPointCells(vtkIdType ptId, unsigned short& ncells, vtkIdType*& cells)
-{
-  VTK_LEGACY_BODY(vtkPolyData::GetPointCells, "VTK 9.0");
-  ncells = static_cast<unsigned short>(this->Links->GetNcells(ptId));
-  cells = this->Links->GetCells(ptId);
-}
-
 //------------------------------------------------------------------------------
 inline vtkIdType vtkPolyData::GetNumberOfCells()
 {
@@ -755,6 +783,39 @@ inline int vtkPolyData::GetCellType(vtkIdType cellId)
   return static_cast<int>(this->Cells->GetTag(cellId).GetCellType());
 }
 
+//------------------------------------------------------------------------------
+inline vtkIdType vtkPolyData::GetCellSize(vtkIdType cellId)
+{
+  if (!this->Cells)
+  {
+    this->BuildCells();
+  }
+  switch (this->GetCellType(cellId))
+  {
+    case VTK_EMPTY_CELL:
+      return 0;
+    case VTK_VERTEX:
+      return 1;
+    case VTK_LINE:
+      return 2;
+    case VTK_TRIANGLE:
+      return 3;
+    case VTK_QUAD:
+      return 4;
+    case VTK_POLY_VERTEX:
+      return this->Verts ? this->Verts->GetCellSize(this->GetCellIdRelativeToCellArray(cellId)) : 0;
+    case VTK_POLY_LINE:
+      return this->Lines ? this->Lines->GetCellSize(this->GetCellIdRelativeToCellArray(cellId)) : 0;
+    case VTK_POLYGON:
+      return this->Polys ? this->Polys->GetCellSize(this->GetCellIdRelativeToCellArray(cellId)) : 0;
+    case VTK_TRIANGLE_STRIP:
+      return this->Strips ? this->Strips->GetCellSize(this->GetCellIdRelativeToCellArray(cellId))
+                          : 0;
+  }
+  vtkWarningMacro(<< "Cell type not supported.");
+  return 0;
+}
+
 //------------------------------------------------------------------------------
 inline int vtkPolyData::IsTriangle(int v1, int v2, int v3)
 {
@@ -868,16 +929,30 @@ inline vtkCellArray* vtkPolyData::GetCellArrayInternal(vtkPolyData::TaggedCellId
 inline void vtkPolyData::ReplaceCellPoint(vtkIdType cellId, vtkIdType oldPtId, vtkIdType newPtId)
 {
   vtkNew<vtkIdList> ids;
-  this->GetCellPoints(cellId, ids);
-  for (vtkIdType i = 0; i < ids->GetNumberOfIds(); i++)
+  this->ReplaceCellPoint(cellId, oldPtId, newPtId, ids);
+}
+
+//------------------------------------------------------------------------------
+inline void vtkPolyData::ReplaceCellPoint(
+  vtkIdType cellId, vtkIdType oldPtId, vtkIdType newPtId, vtkIdList* cellPointIds)
+{
+  if (!this->Cells)
   {
-    if (ids->GetId(i) == oldPtId)
+    this->BuildCells();
+  }
+  vtkIdType npts;
+  const vtkIdType* pts;
+  this->GetCellPoints(cellId, npts, pts, cellPointIds);
+  for (vtkIdType i = 0; i < npts; i++)
+  {
+    if (pts[i] == oldPtId)
     {
-      ids->SetId(i, newPtId);
+      const TaggedCellId tag = this->Cells->GetTag(cellId);
+      vtkCellArray* cells = this->GetCellArrayInternal(tag);
+      cells->ReplaceCellPointAtId(tag.GetCellId(), i, newPtId);
       break;
     }
   }
-  this->ReplaceCell(cellId, static_cast<int>(ids->GetNumberOfIds()), ids->GetPointer(0));
 }
 
 //------------------------------------------------------------------------------
@@ -902,4 +977,25 @@ inline unsigned char vtkPolyData::GetCellPoints(
   return tag.GetCellType();
 }
 
+//------------------------------------------------------------------------------
+inline void vtkPolyData::GetCellPoints(
+  vtkIdType cellId, vtkIdType& npts, vtkIdType const*& pts, vtkIdList* ptIds)
+{
+  if (!this->Cells)
+  {
+    this->BuildCells();
+  }
+
+  const TaggedCellId tag = this->Cells->GetTag(cellId);
+  if (tag.IsDeleted())
+  {
+    npts = 0;
+    pts = nullptr;
+  }
+
+  vtkCellArray* cells = this->GetCellArrayInternal(tag);
+  cells->GetCellAtId(tag.GetCellId(), npts, pts, ptIds);
+}
+
+VTK_ABI_NAMESPACE_END
 #endif
