@@ -14,15 +14,18 @@
 =========================================================================*/
 #include "vtkPolygon.h"
 
+#include "vtkBoundingBox.h"
 #include "vtkBox.h"
 #include "vtkCellArray.h"
 #include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
 #include "vtkIncrementalPointLocator.h"
 #include "vtkLine.h"
+#include "vtkLogger.h"
 #include "vtkMath.h"
 #include "vtkMathUtilities.h"
 #include "vtkMergePoints.h"
+#include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPlane.h"
 #include "vtkPoints.h"
@@ -33,8 +36,11 @@
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolygon);
 
+#define VTK_POLYGON_TOL 1.e-08 // Absolute tolerance for testing near polygon boundary
+
 //------------------------------------------------------------------------------
 // Instantiate polygon.
 vtkPolygon::vtkPolygon()
@@ -46,9 +52,9 @@ vtkPolygon::vtkPolygon()
   this->TriScalars = vtkDoubleArray::New();
   this->TriScalars->Allocate(3);
   this->Line = vtkLine::New();
-  this->Tolerance = 0.0;
+  this->Tolerance = 1.0e-06;
+  this->Tol = 0.0; // Internal tolerance derived from this->Tolerance
   this->SuccessfulTriangulation = 0;
-  this->Normal[0] = this->Normal[1] = this->Normal[2] = 0.0;
   this->UseMVCInterpolation = false;
 }
 
@@ -62,6 +68,20 @@ vtkPolygon::~vtkPolygon()
   this->Line->Delete();
 }
 
+//------------------------------------------------------------------------------
+// Compute the internal tolerance Tol from Tolerance and other geometric
+// information.
+void vtkPolygon::ComputeTolerance()
+{
+  const double* bounds = this->GetBounds();
+
+  double d = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
+    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
+    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
+
+  this->Tol = this->Tolerance * d;
+}
+
 //------------------------------------------------------------------------------
 double vtkPolygon::ComputeArea()
 {
@@ -244,7 +264,7 @@ void vtkPolygon::ComputeNormal(int numPts, double* pts, double n[3])
 // Determine whether or not a polygon is convex from a points list and a list
 // of point ids that index into the points list. Parameter pts can be nullptr,
 // indicating that the polygon indexing is {0, 1, ..., numPts-1}.
-bool vtkPolygon::IsConvex(vtkPoints* p, int numPts, vtkIdType* pts)
+bool vtkPolygon::IsConvex(vtkPoints* p, int numPts, const vtkIdType* pts)
 {
   int i;
   double v[3][3], *v0 = v[0], *v1 = v[1], *v2 = v[2], *tmp, a[3], aMag, b[3], bMag;
@@ -336,7 +356,7 @@ int vtkPolygon::EvaluatePosition(const double x[3], double closestPoint[3], int&
 {
   int i;
   double p0[3], p10[3], l10, p20[3], l20, n[3], cp[3];
-  double ray[3];
+  double ray[3], bounds[6];
 
   subId = 0;
   this->ParameterizePolygon(p0, p10, l10, p20, l20, n);
@@ -351,9 +371,16 @@ int vtkPolygon::EvaluatePosition(const double x[3], double closestPoint[3], int&
   pcoords[1] = vtkMath::Dot(ray, p20) / (l20 * l20);
   pcoords[2] = 0.0;
 
+  // Make sure that the bounding box has non-zero volume, so that all
+  // bounding box sides have non-zero thickness. This prevents tolerancing
+  // issues when the polygon lies exactly on a coordinate plane.
+  vtkBoundingBox bbox(this->GetBounds());
+  bbox.InflateSlice(VTK_POLYGON_TOL);
+  bbox.GetBounds(bounds);
+
   if (pcoords[0] >= 0.0 && pcoords[0] <= 1.0 && pcoords[1] >= 0.0 && pcoords[1] <= 1.0 &&
-    (this->PointInPolygon(cp, this->Points->GetNumberOfPoints(),
-       static_cast<vtkDoubleArray*>(this->Points->GetData())->GetPointer(0), this->GetBounds(),
+    (vtkPolygon::PointInPolygon(cp, this->Points->GetNumberOfPoints(),
+       static_cast<vtkDoubleArray*>(this->Points->GetData())->GetPointer(0), bounds,
        n) == VTK_POLYGON_INSIDE))
   {
     if (closestPoint)
@@ -638,207 +665,149 @@ int vtkPolygon::ParameterizePolygon(
   return 1;
 }
 
-#define VTK_POLYGON_CERTAIN 1
-#define VTK_POLYGON_UNCERTAIN 0
-#define VTK_POLYGON_RAY_TOL 1.e-03 // Tolerance for ray firing
-#define VTK_POLYGON_MAX_ITER 10    // Maximum iterations for ray-firing
-#define VTK_POLYGON_VOTE_THRESHOLD 2
+// Support the PointInPolygon algorithm. Determine on which side a point is
+// positioned wrt an oriented edge.
+namespace
+{
+
+// Given the line (p0,p1), determine if a point x is located to the left
+// of, on, or to the right of a line (with the function returning >0, ==0, or
+// <0 respectively).  The points are assumed 3D points, but projected into
+// one of x-y-z planes; hence the indices axis0 and axis1 specify which plane
+// the computation is to be performed on.
+inline double PointLocation(int axis0, int axis1, double* p0, double* p1, double* x)
+{
+  return (((p1[axis0] - p0[axis0]) * (x[axis1] - p0[axis1])) -
+    ((x[axis0] - p0[axis0]) * (p1[axis1] - p0[axis1])));
+}
+}
 
 //------------------------------------------------------------------------------
-// Determine whether point is inside polygon. Function uses ray-casting
-// to determine if point is inside polygon. Works for arbitrary polygon shape
-// (e.g., non-convex). Returns 0 if point is not in polygon; 1 if it is.
-// Can also return -1 to indicate degenerate polygon. Note: a point in
-// bounding box check is NOT performed prior to in/out check. You may want
-// to do this to improve performance.
+// Determine whether a point is inside a polygon. The function uses a winding
+// number calculation generalized to the 3D plane one which the polygon
+// resides. Returns 0 if point is not in the polygon; 1 if it is inside.  Can
+// also return -1 to indicate a degenerate polygon. This implementation is
+// inspired by Dan Sunday's algorithm found in the book Practical Geometry
+// Algorithms.
 int vtkPolygon::PointInPolygon(double x[3], int numPts, double* pts, double bounds[6], double* n)
 {
-  double *x1, *x2, xray[3], u, v;
-  double rayMag, mag = 1, ray[3];
-  int testResult, status, numInts, i;
-  int iterNumber;
-  int maxComp, comps[2];
-  int deltaVotes;
-  // do a quick bounds check
+  // Do a quick bounds check to throw out trivial cases.
+  // winding plane.
   if (x[0] < bounds[0] || x[0] > bounds[1] || x[1] < bounds[2] || x[1] > bounds[3] ||
     x[2] < bounds[4] || x[2] > bounds[5])
   {
     return VTK_POLYGON_OUTSIDE;
   }
 
-  //
-  //  Define a ray to fire.  The ray is a random ray normal to the
-  //  normal of the face.  The length of the ray is a function of the
-  //  size of the face bounding box.
-  //
-  for (i = 0; i < 3; i++)
+  //  Check that the normal is non-zero.
+  if (vtkMath::Norm(n) <= FLT_EPSILON)
   {
-    ray[i] = (bounds[2 * i + 1] - bounds[2 * i]) * 1.1 +
-      fabs((bounds[2 * i + 1] + bounds[2 * i]) / 2.0 - x[i]);
+    return VTK_POLYGON_FAILURE;
   }
 
-  if ((rayMag = vtkMath::Norm(ray)) == 0.0)
+  // Assess whether the point lies on the boundary of the polygon. Points on
+  // the boundary are considered inside the polygon. Need to define a small
+  // tolerance relative to the bounding box diagonal length of the polygon.
+  double tol2 = VTK_POLYGON_TOL *
+    ((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
+      (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
+      (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
+  tol2 *= tol2;
+  tol2 = (tol2 == 0.0 ? FLT_EPSILON : tol2);
+
+  for (int i = 0; i < numPts; i++)
   {
-    return VTK_POLYGON_OUTSIDE;
+    // Check coincidence to polygon vertices
+    double* p0 = pts + 3 * i;
+    if (vtkMath::Distance2BetweenPoints(x, p0) <= tol2)
+    {
+      return VTK_POLYGON_INSIDE;
+    }
+
+    // Check coincidence to polygon edges
+    double* p1 = pts + 3 * ((i + 1) % numPts);
+    double t;
+    double d2 = vtkLine::DistanceToLine(x, p0, p1, t);
+    if (d2 <= tol2 && 0.0 < t && t < 1.0)
+    {
+      return VTK_POLYGON_INSIDE;
+    }
   }
 
-  //  Get the maximum component of the normal.
-  //
+  // If here, begin computation of the winding number. This method works for
+  // points/polygons arbitrarily oriented in 3D space.  Hence a projection
+  // onto one of the x-y-z coordinate planes using the maximum normal
+  // component. The computation will be performed in the (axis0,axis1) plane.
+  int axis0, axis1;
   if (fabs(n[0]) > fabs(n[1]))
   {
     if (fabs(n[0]) > fabs(n[2]))
     {
-      maxComp = 0;
-      comps[0] = 1;
-      comps[1] = 2;
+      axis0 = 1;
+      axis1 = 2;
     }
     else
     {
-      maxComp = 2;
-      comps[0] = 0;
-      comps[1] = 1;
+      axis0 = 0;
+      axis1 = 1;
     }
   }
   else
   {
     if (fabs(n[1]) > fabs(n[2]))
     {
-      maxComp = 1;
-      comps[0] = 0;
-      comps[1] = 2;
+      axis0 = 0;
+      axis1 = 2;
     }
     else
     {
-      maxComp = 2;
-      comps[0] = 0;
-      comps[1] = 1;
+      axis0 = 0;
+      axis1 = 1;
     }
   }
 
-  //  Check that max component is non-zero
-  //
-  if (n[maxComp] == 0.0)
+  // Compute the winding number wn. If after processing all polygon edges
+  // wn==0, then the point is outside.  Otherwise, the point is inside the
+  // polygon. Process all polygon edges determining if there are ascending or
+  // descending crossings of the line axis1=constant.
+  int wn = 0;
+  for (int i = 0; i < numPts; i++)
   {
-    return VTK_POLYGON_FAILURE;
-  }
+    double* p0 = pts + 3 * i;
+    double* p1 = pts + 3 * ((i + 1) % numPts);
 
-  //  Enough information has been acquired to determine the random ray.
-  //  Random rays are generated until one is satisfactory (i.e.,
-  //  produces a ray of non-zero magnitude).  Also, since more than one
-  //  ray may need to be fired, the ray-firing occurs in a large loop.
-  //
-  //  The variable iterNumber counts the number of iterations and is
-  //  limited by the defined variable VTK_POLYGON_MAX_ITER.
-  //
-  //  The variable deltaVotes keeps track of the number of votes for
-  //  "in" versus "out" of the face.  When delta_vote > 0, more votes
-  //  have counted for "in" than "out".  When delta_vote < 0, more votes
-  //  have counted for "out" than "in".  When the delta_vote exceeds or
-  //  equals the defined variable VTK_POLYGON_VOTE_THRESHOLD, than the
-  //  appropriate "in" or "out" status is returned.
-  //
-  for (deltaVotes = 0, iterNumber = 1;
-       (iterNumber < VTK_POLYGON_MAX_ITER) && (abs(deltaVotes) < VTK_POLYGON_VOTE_THRESHOLD);
-       iterNumber++)
-  {
-    //
-    //  Generate ray
-    //
-    bool rayOK;
-    for (rayOK = false; rayOK == false;)
+    if (p0[axis1] <= x[axis1])
     {
-      ray[comps[0]] = vtkMath::Random(-rayMag, rayMag);
-      ray[comps[1]] = vtkMath::Random(-rayMag, rayMag);
-      ray[maxComp] = -(n[comps[0]] * ray[comps[0]] + n[comps[1]] * ray[comps[1]]) / n[maxComp];
-      if ((mag = vtkMath::Norm(ray)) > rayMag * VTK_TOL)
+      if (p1[axis1] > x[axis1]) // if an upward crossing
       {
-        rayOK = true;
-      }
-    }
-
-    //  The ray must be appropriately sized.
-    //
-    for (i = 0; i < 3; i++)
-    {
-      xray[i] = x[i] + (rayMag / mag) * ray[i];
-    }
-
-    //  The ray may now be fired against all the edges
-    //
-    for (numInts = 0, testResult = VTK_POLYGON_CERTAIN, i = 0; i < numPts; i++)
-    {
-      x1 = pts + 3 * i;
-      x2 = pts + 3 * ((i + 1) % numPts);
-
-      //   Fire the ray and compute the number of intersections.  Be careful
-      //   of degenerate cases (e.g., ray intersects at vertex).
-      //
-
-      if ((status = vtkLine::Intersection(x, xray, x1, x2, u, v)) == vtkLine::Intersect)
-      {
-        // This test checks for vertex and edge intersections
-        // For example
-        //  Vertex intersection
-        //    (u=0 v=0), (u=0 v=1), (u=1 v=0), (u=1 v=0)
-        //  Edge intersection
-        //    (u=0 v!=0 v!=1), (u=1 v!=0 v!=1)
-        //    (u!=0 u!=1 v=0), (u!=0 u!=1 v=1)
-        if ((VTK_POLYGON_RAY_TOL < u) && (u < 1.0 - VTK_POLYGON_RAY_TOL) &&
-          (VTK_POLYGON_RAY_TOL < v) && (v < 1.0 - VTK_POLYGON_RAY_TOL))
+        if (PointLocation(axis0, axis1, p0, p1, x) > 0) // if x left of edge
         {
-          numInts++;
-        }
-        else
-        {
-          testResult = VTK_POLYGON_UNCERTAIN;
+          ++wn; // a valid up intersect, increment the winding number
         }
       }
-      else if (status == VTK_POLYGON_ON_LINE)
-      {
-        testResult = VTK_POLYGON_UNCERTAIN;
-      }
     }
-    if (testResult == VTK_POLYGON_CERTAIN)
+    else
     {
-      if (numInts % 2 == 0)
+      if (p1[axis1] <= x[axis1]) // if a downward crossing
       {
-        --deltaVotes;
-      }
-      else
-      {
-        ++deltaVotes;
+        if (PointLocation(axis0, axis1, p0, p1, x) < 0) // if x right of edge
+        {
+          --wn; // a valid down intersect, decrement the winding number
+        }
       }
     }
-  } // try another ray
+  } // Over all polygon edges
 
-  //   If the number of intersections is odd, the point is in the polygon.
-  //
-  if (deltaVotes < 0)
-  {
-    return VTK_POLYGON_OUTSIDE;
-  }
-  else
-  {
-    return VTK_POLYGON_INSIDE;
-  }
+  // A winding number==0 is outside the polygon
+  return ((wn == 0 ? VTK_POLYGON_OUTSIDE : VTK_POLYGON_INSIDE));
 }
 
-#define VTK_POLYGON_TOLERANCE 1.0e-06
-
 //------------------------------------------------------------------------------
 // Triangulate polygon.
 //
 int vtkPolygon::Triangulate(vtkIdList* outTris)
 {
-  const double* bounds = this->GetBounds();
-
-  double d = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
-    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
-    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
-  this->Tolerance = VTK_POLYGON_TOLERANCE * d;
   this->SuccessfulTriangulation = 1;
-
-  this->Tris->Reset();
   int success = this->EarCutTriangulation();
 
   if (!success) // degenerate triangle encountered
@@ -1048,8 +1017,6 @@ int vtkPolygon::BoundedTriangulate(vtkIdList* outTris, double tolerance)
 
   for (i = 0; i < numPts; i++)
   {
-    this->Tris->Reset();
-
     success = this->UnbiasedEarCutTriangulation(i);
 
     if (!success)
@@ -1088,6 +1055,11 @@ int vtkPolygon::BoundedTriangulate(vtkIdList* outTris, double tolerance)
   return success;
 }
 
+// Special triangulation helper class. At some point, we may want to split this
+// outside of vtkPolygon. It could be generalized for different polygon
+// triangulation methods.
+namespace
+{ // anonymous
 //------------------------------------------------------------------------------
 // Special structures for building loops. This is a double-linked list.
 typedef struct _vtkPolyVertex
@@ -1102,15 +1074,20 @@ typedef struct _vtkPolyVertex
 class vtkPolyVertexList
 { // structure to support triangulation
 public:
-  vtkPolyVertexList(vtkIdList* ptIds, vtkPoints* pts, double tol2);
+  vtkPolyVertexList(vtkIdList* ptIds, vtkPoints* pts, double tol2, int measure);
   ~vtkPolyVertexList();
 
   int ComputeNormal();
   double ComputeMeasure(vtkLocalPolyVertex* vtx);
   void RemoveVertex(vtkLocalPolyVertex* vtx, vtkIdList* ids, vtkPriorityQueue* queue = nullptr);
   void RemoveVertex(int i, vtkIdList* ids, vtkPriorityQueue* queue = nullptr);
-  int CanRemoveVertex(vtkLocalPolyVertex* vtx, double tol);
-  int CanRemoveVertex(int id, double tol);
+  int CanRemoveVertex(vtkLocalPolyVertex* vtx);
+  int CanRemoveVertex(int id);
+  int SimpleTriangulation(vtkIdList* ids); // Handle trivial triangulation cases
+
+  double Tol;
+  double Tol2;
+  int Measure;
 
   int NumberOfVerts;
   vtkLocalPolyVertex* Array;
@@ -1120,8 +1097,12 @@ public:
 
 //------------------------------------------------------------------------------
 // tolerance is squared
-vtkPolyVertexList::vtkPolyVertexList(vtkIdList* ptIds, vtkPoints* pts, double tol2)
+vtkPolyVertexList::vtkPolyVertexList(vtkIdList* ptIds, vtkPoints* pts, double tol2, int measure)
 {
+  this->Tol2 = tol2;
+  this->Tol = (tol2 > 0.0 ? sqrt(tol2) : 0.0);
+  this->Measure = measure;
+
   int numVerts = ptIds->GetNumberOfIds();
   this->NumberOfVerts = numVerts;
   this->Array = new vtkLocalPolyVertex[numVerts];
@@ -1249,10 +1230,13 @@ int vtkPolyVertexList::ComputeNormal()
 }
 
 //------------------------------------------------------------------------------
-// The measure is the ratio of triangle perimeter^2 to area;
-// the sign of the measure is determined by dotting the local
-// vector with the normal (concave features return a negative
-// measure).
+// Different measures are supported. Historically, the measure was the ratio
+// of triangle perimeter^2 to area (PERIMETER2_TO_AREA_RATIO).  The other
+// select for "best quality" triangles (BEST_QUALITY), and the largest dot
+// product (DOT_PRODUCT - a measure of apex angle).  The measure is used in a
+// priority queue to select the next vertex to remove, hence smaller,
+// positive numbers are selected first. Note that concave vertices, or zero
+// area vertices, return a negative measure.
 double vtkPolyVertexList::ComputeMeasure(vtkLocalPolyVertex* vtx)
 {
   double v1[3], v2[3], v3[3], v4[3], area, perimeter;
@@ -1272,20 +1256,68 @@ double vtkPolyVertexList::ComputeMeasure(vtkLocalPolyVertex* vtx)
   {
     return (vtx->measure = -VTK_DOUBLE_MAX); // concave or bad triangle
   }
-  else
+
+  // If here, the vertex is convex and the area of the triangle is positive.
+  // Compute the specified measure.
+  if (this->Measure == vtkPolygon::PERIMETER2_TO_AREA_RATIO)
   {
+    // This measure sucks as triangles become "needle-like" but works fine
+    // when the triangle is more flattened.
     perimeter = vtkMath::Norm(v1) + vtkMath::Norm(v2) + vtkMath::Norm(v3);
     return (vtx->measure = perimeter * perimeter / area);
   }
+  else if (this->Measure == vtkPolygon::DOT_PRODUCT)
+  {
+    vtkMath::Normalize(v1);
+    vtkMath::Normalize(v2);
+    return (vtx->measure = (1.0 + vtkMath::Dot(v1, v2)));
+  }
+  else if (this->Measure == vtkPolygon::BEST_QUALITY)
+  {
+    // Best quality: ratio of maximum edge length to height.
+    // This is a greedy triangulation algorithm, so it may
+    // not produce the mesh with the best total quality. However,
+    // in greedy fashion it will select the next triangle with the
+    // best quality. It is an expensive operation.
+    double l1 = vtkMath::Norm(v1);
+    double l2 = vtkMath::Norm(v2);
+    double l3 = vtkMath::Norm(v3);
+    int longestEdge = (l1 > l2 ? (l1 > l3 ? 1 : 3) : (l2 > l3 ? 2 : 3));
+    double shortest, longest;
+    if (longestEdge == 1)
+    {
+      longest = l1;
+      shortest = vtkLine::DistanceToLine(vtx->next->x, vtx->x, vtx->previous->x);
+    }
+    else if (longestEdge == 2)
+    {
+      longest = l2;
+      shortest = vtkLine::DistanceToLine(vtx->previous->x, vtx->x, vtx->next->x);
+    }
+    else
+    {
+      longest = l3;
+      shortest = vtkLine::DistanceToLine(vtx->x, vtx->previous->x, vtx->next->x);
+    }
+
+    // sqrt(3)/2 = 0.866025404 comes from equilateral triangle
+    return (vtx->measure = (0.866025404 - (shortest / longest)));
+  }
+  else
+  {
+    vtkLog(WARNING, "Measure not supported");
+    return -1.0;
+  }
 }
 
 //------------------------------------------------------------------------------
 // returns != 0 if vertex can be removed. Uses half-space
 // comparison to determine whether ear-cut is valid, and may
 // resort to line-plane intersections to resolve possible
-// instersections with ear-cut.
-int vtkPolyVertexList::CanRemoveVertex(vtkLocalPolyVertex* currentVtx, double tolerance)
+// intersections with ear-cut.
+int vtkPolyVertexList::CanRemoveVertex(vtkLocalPolyVertex* currentVtx)
 {
+  double tolerance = this->Tol;
   int i, sign, currentSign;
   double v[3], sN[3], *sPt, val, s, t;
   vtkLocalPolyVertex *previous, *next, *vtx;
@@ -1332,7 +1364,8 @@ int vtkPolyVertexList::CanRemoveVertex(vtkLocalPolyVertex* currentVtx, double to
       {
         oneNegative = (sign < 0 ? 1 : 0); // very important
       }
-      if (vtkLine::Intersection(sPt, next->x, vtx->x, vtx->previous->x, s, t) != 0)
+      if (vtkLine::Intersection(
+            sPt, next->x, vtx->x, vtx->previous->x, s, t, tolerance, vtkLine::AbsoluteFuzzy) != 0)
       {
         return 0;
       }
@@ -1358,26 +1391,73 @@ int vtkPolyVertexList::CanRemoveVertex(vtkLocalPolyVertex* currentVtx, double to
 // comparison to determine whether ear-cut is valid, and may
 // resort to line-plane intersections to resolve possible
 // instersections with ear-cut.
-int vtkPolyVertexList::CanRemoveVertex(int id, double tolerance)
+int vtkPolyVertexList::CanRemoveVertex(int id)
 {
-  return this->CanRemoveVertex(this->Array + id, tolerance);
+  return this->CanRemoveVertex(this->Array + id);
 }
 
 //------------------------------------------------------------------------------
-// Triangulation method based on ear-cutting. Triangles, or ears, are
-// cut off from the polygon based on the angle of the vertex. Small
-// angles (narrow triangles) are cut off first. This implementation uses
-// a priority queue to cut off ears with smallest angles. Also, the
-// algorithm works in 3D (the points don't have to be projected into
-// 2D, and the ordering direction of the points is nor important as
-// long as the polygon edges do not self intersect).
-int vtkPolygon::EarCutTriangulation()
+// Handles some trivial triangulation cases. Returns 0 if cannot triangulate
+// the current polygon. NOTE: the original implementation had a special case
+// for four vertices, but this affects the way some quads are tessellated,
+// which in turn causes differences in vtkTriangleFilter, which many tests
+// depend on. So adding a special case for four vertices requires more
+// work than might be anticipated.
+int vtkPolyVertexList::SimpleTriangulation(vtkIdList* tris)
 {
-  vtkPolyVertexList poly(this->PointIds, this->Points, this->Tolerance * this->Tolerance);
+  // Just output the single triangle
+  if (this->NumberOfVerts == 3)
+  {
+    tris->InsertNextId(this->Array[0].id);
+    tris->InsertNextId(this->Array[1].id);
+    tris->InsertNextId(this->Array[2].id);
+    return 1;
+  }
+
+  // Four points are split into two triangles. Watch out for the
+  // concave case (i.e., quad looks like a arrowhead).
+  else if (NumberOfVerts == 4)
+  {
+    return 0;
+  } // if simple cases
+
+  return 0;
+}
+} // anonymous namespace
+
+//------------------------------------------------------------------------------
+// Triangulation method based on ear-cutting. Triangles, or ears, are
+// repeatedly cut off from the polygon based on a measure of the
+// vertex. Vertices must be convex, but different measures will produce
+// different triangulations. While the algorithm works in 3D (the points
+// don't have to be projected into 2D), it is assumed the polygon is planar -
+// if not, poor results may occur.
+int vtkPolygon::EarCutTriangulation(int measure)
+{
+  // Initialize the list of output triangles
+  this->Tris->Reset();
+
+  // Make sure there are at least 3 vertices
+  if (this->PointIds->GetNumberOfIds() < 3)
+  {
+    return (this->SuccessfulTriangulation = 0);
+  }
+
+  // Compute the tolerance local to this polygon
+  this->ComputeTolerance();
+
+  // Establish a more convenient structure for the triangulation process
+  vtkPolyVertexList poly(this->PointIds, this->Points, this->Tol * this->Tol, measure);
   vtkLocalPolyVertex* vtx;
   int i, id;
 
-  // First compute the polygon normal the correct way
+  // Check for trivial triangulation cases
+  if (poly.SimpleTriangulation(this->Tris))
+  {
+    return (this->SuccessfulTriangulation = 1);
+  }
+
+  // The polygon normal is needed during triangulation
   //
   if (!poly.ComputeNormal())
   {
@@ -1386,7 +1466,7 @@ int vtkPolygon::EarCutTriangulation()
 
   // Now compute the angles between edges incident to each
   // vertex. Place the structure into a priority queue (those
-  // vertices with smallest angle are to be removed first).
+  // vertices with smallest measure are to be removed first).
   //
   vtkPriorityQueue* VertexQueue = vtkPriorityQueue::New();
   VertexQueue->Allocate(poly.NumberOfVerts);
@@ -1401,28 +1481,21 @@ int vtkPolygon::EarCutTriangulation()
 
   // For each vertex in the priority queue, and as long as there
   // are three or more vertices, remove the vertex (if possible)
-  // and create a new triangle. If the number of vertices in the
-  // queue is equal to the number of vertices, then the polygon
-  // is convex and triangle removal can proceed without intersection
-  // checks.
+  // and create a new triangle. NOTE: at one time this code checked the
+  // number of verts in the removal queue, and if it was equal to the number
+  // of remaining vertices, it assumed a convex polygon and indiscrimately
+  // removed vertices. This tends to produce bad results as some triangles
+  // were nearly flat etc. so the code was removed.
   //
   int numInQueue;
   while (poly.NumberOfVerts > 2 && (numInQueue = VertexQueue->GetNumberOfItems()) > 0)
   {
-    if (numInQueue == poly.NumberOfVerts) // convex, pop away
+    id = VertexQueue->Pop(); // removes it, even if can't be split
+    if (poly.CanRemoveVertex(id))
     {
-      id = VertexQueue->Pop();
       poly.RemoveVertex(id, this->Tris, VertexQueue);
-    } // convex
-    else
-    {
-      id = VertexQueue->Pop(); // removes it, even if can't be split
-      if (poly.CanRemoveVertex(id, this->Tolerance))
-      {
-        poly.RemoveVertex(id, this->Tris, VertexQueue);
-      }
-    } // concave
-  }   // while
+    }
+  } // while
 
   // Clean up
   VertexQueue->Delete();
@@ -1435,16 +1508,30 @@ int vtkPolygon::EarCutTriangulation()
 }
 
 //------------------------------------------------------------------------------
-// Triangulation method based on ear-cutting. Triangles, or ears, are
-// cut off from the polygon. This implementation does not bias the
-// selection of ears; it sequentially progresses through each vertex
-// starting at a user-defined seed value.
-int vtkPolygon::UnbiasedEarCutTriangulation(int seed)
+// Copies the results of triangulation into provided id list
+int vtkPolygon::EarCutTriangulation(vtkIdList* outTris, int measure)
 {
-  vtkPolyVertexList poly(this->PointIds, this->Points, this->Tolerance * this->Tolerance);
+  int success = this->EarCutTriangulation(measure);
+  outTris->DeepCopy(this->Tris);
+  return success;
+}
+
+//------------------------------------------------------------------------------
+// Triangulation method based on ear-cutting. Triangles, or ears, are cut off
+// from the polygon. This implementation does not bias the selection of ears;
+// it sequentially progresses through each vertex starting at a user-defined
+// seed value.
+int vtkPolygon::UnbiasedEarCutTriangulation(int seed, int measure)
+{
+  // Compute the tolerance local to this polygon
+  this->ComputeTolerance();
+
+  // Establish a more convenient structure for triangulation
+  vtkPolyVertexList poly(this->PointIds, this->Points, this->Tol * this->Tol, measure);
 
   // First compute the polygon normal the correct way
   //
+  this->Tris->Reset();
   if (!poly.ComputeNormal())
   {
     return (this->SuccessfulTriangulation = 0);
@@ -1457,7 +1544,7 @@ int vtkPolygon::UnbiasedEarCutTriangulation(int seed)
 
   while (poly.NumberOfVerts > 2)
   {
-    if (poly.CanRemoveVertex(vtx, this->Tolerance))
+    if (poly.CanRemoveVertex(vtx))
     {
       poly.RemoveVertex(vtx, this->Tris);
     }
@@ -1480,6 +1567,15 @@ int vtkPolygon::UnbiasedEarCutTriangulation(int seed)
   return (this->SuccessfulTriangulation = 1);
 }
 
+//------------------------------------------------------------------------------
+// Copies the results of triangulation into provided id list
+int vtkPolygon::UnbiasedEarCutTriangulation(int seed, vtkIdList* outTris, int measure)
+{
+  int success = this->UnbiasedEarCutTriangulation(seed, measure);
+  outTris->DeepCopy(this->Tris);
+  return success;
+}
+
 //------------------------------------------------------------------------------
 int vtkPolygon::CellBoundary(int vtkNotUsed(subId), const double pcoords[3], vtkIdList* pts)
 {
@@ -1558,17 +1654,7 @@ void vtkPolygon::Contour(double value, vtkDataArray* cellScalars,
 
   this->TriScalars->SetNumberOfTuples(3);
 
-  const double* bounds = this->GetBounds();
-
-  double d = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
-    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
-    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
-  this->Tolerance = VTK_POLYGON_TOLERANCE * d;
   this->SuccessfulTriangulation = 1;
-  this->ComputeNormal(this->Points, this->Normal);
-
-  this->Tris->Reset();
-
   success = this->EarCutTriangulation();
 
   if (!success) // Just skip for now.
@@ -1664,21 +1750,11 @@ int vtkPolygon::IntersectWithLine(const double p1[3], const double p2[3], double
 int vtkPolygon::Triangulate(int vtkNotUsed(index), vtkIdList* ptIds, vtkPoints* pts)
 {
   int i, success;
-  double *bounds, d;
 
   pts->Reset();
   ptIds->Reset();
 
-  bounds = this->GetBounds();
-  d = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
-    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
-    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
-  this->Tolerance = VTK_POLYGON_TOLERANCE * d;
   this->SuccessfulTriangulation = 1;
-  this->ComputeNormal(this->Points, this->Normal);
-
-  this->Tris->Reset();
-
   success = this->EarCutTriangulation();
 
   if (!success) // Indicate possible failure
@@ -1800,17 +1876,7 @@ void vtkPolygon::Clip(double value, vtkDataArray* cellScalars, vtkIncrementalPoi
 
   this->TriScalars->SetNumberOfTuples(3);
 
-  const double* bounds = this->GetBounds();
-  double d = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
-    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
-    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
-  this->Tolerance = VTK_POLYGON_TOLERANCE * d;
-
   this->SuccessfulTriangulation = 1;
-  this->ComputeNormal(this->Points, this->Normal);
-
-  this->Tris->Reset();
-
   success = this->EarCutTriangulation();
 
   if (success) // clip triangles
@@ -2005,8 +2071,6 @@ void vtkPolygon::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Tolerance: " << this->Tolerance << "\n";
   os << indent << "SuccessfulTriangulation: " << this->SuccessfulTriangulation << "\n";
   os << indent << "UseMVCInterpolation: " << this->UseMVCInterpolation << "\n";
-  os << indent << "Normal: (" << this->Normal[0] << ", " << this->Normal[1] << ", "
-     << this->Normal[2] << ")\n";
   os << indent << "Tris:\n";
   this->Tris->PrintSelf(os, indent.GetNextIndent());
   os << indent << "Triangle:\n";
@@ -2204,3 +2268,4 @@ int vtkPolygon::IntersectConvex2DCells(
     return 0;
   }
 }
+VTK_ABI_NAMESPACE_END
