@@ -29,7 +29,7 @@
  * definitely cause problems, especially in severely warped situations.
  *
  * @sa
- * vtkCell3D vtkConvecPointSet vtkMeanValueCoordinatesInterpolator
+ * vtkCell3D vtkConvexPointSet vtkMeanValueCoordinatesInterpolator
  */
 
 #ifndef vtkPolyhedron_h
@@ -38,6 +38,7 @@
 #include "vtkCell3D.h"
 #include "vtkCommonDataModelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdTypeArray;
 class vtkCellArray;
 class vtkTriangle;
@@ -57,16 +58,16 @@ class vtkPointLocator;
 class VTKCOMMONDATAMODEL_EXPORT vtkPolyhedron : public vtkCell3D
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard new methods.
    */
   static vtkPolyhedron* New();
   vtkTypeMacro(vtkPolyhedron, vtkCell3D);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * See vtkCell3D API for description of these methods.
    * @warning These method are unimplemented in vtkPolyhedron
@@ -75,27 +76,11 @@ public:
   {
     vtkWarningMacro(<< "vtkPolyhedron::GetEdgePoints Not Implemented");
   }
-  // @deprecated Replaced by GetEdgePoints(vtkIdType, const vtkIdType*&) as of VTK 9.0
-  VTK_DEPRECATED_IN_9_0_0("Replaced by vtkPolyhedron::GetEdgePoints(vtkIdType, const vtkIdType*&)")
-  void GetEdgePoints(int vtkNotUsed(edgeId), int*& vtkNotUsed(pts)) override
-  {
-    vtkErrorMacro(<< "vtkPolyhedron::GetEdgePoints Not Implemented. "
-                     "Also note that this signature is deprecated. "
-                     "Please use GetEdgePoints(vtkIdType, const vtkIdType*& instead");
-  };
   vtkIdType GetFacePoints(vtkIdType vtkNotUsed(faceId), const vtkIdType*& vtkNotUsed(pts)) override
   {
     vtkWarningMacro(<< "vtkPolyhedron::GetFacePoints Not Implemented");
     return 0;
   }
-  // @deprecated Replaced by GetFacePoints(vtkIdType, const vtkIdType*&) as of VTK 9.0
-  VTK_DEPRECATED_IN_9_0_0("Replaced by vtkPolyhedron::GetFacePoints(vtkIdType, const vtkIdType*&)")
-  void GetFacePoints(int vtkNotUsed(faceId), int*& vtkNotUsed(pts)) override
-  {
-    vtkWarningMacro(<< "vtkPolyhedron::GetFacePoints Not Implemented. "
-                       "Also note that this signature is deprecated. "
-                       "Please use GetFacePoints(vtkIdType, const vtkIdType*& instead");
-  };
   void GetEdgeToAdjacentFaces(
     vtkIdType vtkNotUsed(edgeId), const vtkIdType*& vtkNotUsed(pts)) override
   {
@@ -125,7 +110,7 @@ public:
     vtkWarningMacro(<< "vtkPolyhedron::GetCentroid Not Implemented");
     return false;
   }
-  //@}
+  ///@}
 
   /**
    * See vtkCell3D API for description of this method.
@@ -143,7 +128,7 @@ public:
   int RequiresInitialization() override { return 1; }
   void Initialize() override;
 
-  //@{
+  ///@{
   /**
    * A polyhedron is represented internally by a set of polygonal faces.
    * These faces can be processed to explicitly determine edges.
@@ -152,7 +137,7 @@ public:
   vtkCell* GetEdge(int) override;
   int GetNumberOfFaces() override;
   vtkCell* GetFace(int faceId) override;
-  //@}
+  ///@}
 
   /**
    * Satisfy the vtkCell API. This method contours the input polyhedron and outputs
@@ -245,7 +230,7 @@ public:
    */
   int IsPrimaryCell() override { return 1; }
 
-  //@{
+  ///@{
   /**
    * Compute the interpolation functions/derivatives
    * (aka shape functions/derivatives). Here we use the MVC calculation
@@ -253,9 +238,9 @@ public:
    */
   void InterpolateFunctions(const double x[3], double* sf) override;
   void InterpolateDerivs(const double x[3], double* derivs) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods supporting the definition of faces. Note that the GetFaces()
    * returns a list of faces in vtkCellArray form; use the method
@@ -267,7 +252,7 @@ public:
   int RequiresExplicitFaceRepresentation() override { return 1; }
   void SetFaces(vtkIdType* faces) override;
   vtkIdType* GetFaces() override;
-  //@}
+  ///@}
 
   /**
    * A method particular to vtkPolyhedron. It determines whether a point x[3]
@@ -361,4 +346,5 @@ inline int vtkPolyhedron::GetParametricCenter(double pcoords[3])
   return 0;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
