@@ -20,6 +20,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkPoints.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQuadraticEdge);
 
 //------------------------------------------------------------------------------
@@ -100,7 +101,7 @@ int vtkQuadraticEdge::EvaluatePosition(const double x[3], double closestPoint[3]
     else
     {
       // Compute weights only
-      this->InterpolationFunctions(pcoords, weights);
+      vtkQuadraticEdge::InterpolationFunctions(pcoords, weights);
     }
   }
 
@@ -117,7 +118,7 @@ void vtkQuadraticEdge::EvaluateLocation(
   this->Points->GetPoint(1, a1);
   this->Points->GetPoint(2, a2); // midside node
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkQuadraticEdge::InterpolationFunctions(pcoords, weights);
 
   for (i = 0; i < 3; i++)
   {
@@ -275,3 +276,4 @@ void vtkQuadraticEdge::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Line:\n";
   this->Line->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
