@@ -34,6 +34,7 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkNonLinearCell.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLine;
 class vtkDoubleArray;
 
@@ -89,7 +90,7 @@ public:
 
   static void InterpolationFunctions(const double pcoords[3], double weights[3]);
   static void InterpolationDerivs(const double pcoords[3], double derivs[3]);
-  //@{
+  ///@{
   /**
    * Compute the interpolation functions/derivatives
    * (aka shape functions/derivatives)
@@ -102,7 +103,7 @@ public:
   {
     vtkQuadraticEdge::InterpolationDerivs(pcoords, derivs);
   }
-  //@}
+  ///@}
 
 protected:
   vtkQuadraticEdge();
@@ -123,4 +124,5 @@ inline int vtkQuadraticEdge::GetParametricCenter(double pcoords[3])
   return 0;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
