@@ -37,6 +37,7 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkNonLinearCell.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkQuadraticEdge;
 class vtkQuadraticQuad;
 class vtkHexahedron;
@@ -49,7 +50,7 @@ public:
   vtkTypeMacro(vtkQuadraticHexahedron, vtkNonLinearCell);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Implement the vtkCell API. See the vtkCell API for descriptions
    * of these methods.
@@ -60,7 +61,7 @@ public:
   int GetNumberOfFaces() override { return 6; }
   vtkCell* GetEdge(int) override;
   vtkCell* GetFace(int) override;
-  //@}
+  ///@}
 
   int CellBoundary(int subId, const double pcoords[3], vtkIdList* pts) override;
   void Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPointLocator* locator,
@@ -92,7 +93,7 @@ public:
 
   static void InterpolationFunctions(const double pcoords[3], double weights[20]);
   static void InterpolationDerivs(const double pcoords[3], double derivs[60]);
-  //@{
+  ///@{
   /**
    * Compute the interpolation functions/derivatives
    * (aka shape functions/derivatives)
@@ -105,8 +106,8 @@ public:
   {
     vtkQuadraticHexahedron::InterpolationDerivs(pcoords, derivs);
   }
-  //@}
-  //@{
+  ///@}
+  ///@{
   /**
    * Return the ids of the vertices defining edge/face (`edgeId`/`faceId').
    * Ids are related to the cell, not to the dataset.
@@ -116,7 +117,7 @@ public:
    */
   static const vtkIdType* GetEdgeArray(vtkIdType edgeId);
   static const vtkIdType* GetFaceArray(vtkIdType faceId);
-  //@}
+  ///@}
 
   /**
    * Given parametric coordinates compute inverse Jacobian transformation
@@ -145,4 +146,5 @@ private:
   void operator=(const vtkQuadraticHexahedron&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
