@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkQuadraticPyramid.h"
 
 #include "vtkCellData.h"
@@ -30,6 +27,7 @@
 #include "vtkQuadraticTriangle.h"
 #include "vtkTetra.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQuadraticPyramid);
 
 //------------------------------------------------------------------------------
@@ -169,9 +167,9 @@ vtkCell* vtkQuadraticPyramid::GetFace(int faceId)
 //------------------------------------------------------------------------------
 namespace
 {
-static const double VTK_DIVERGED = 1.e6;
-static const int VTK_PYRAMID_MAX_ITERATION = 20;
-static const double VTK_PYRAMID_CONVERGED = 1.e-03;
+const double VTK_DIVERGED = 1.e6;
+const int VTK_PYRAMID_MAX_ITERATION = 20;
+const double VTK_PYRAMID_CONVERGED = 1.e-03;
 }
 
 int vtkQuadraticPyramid::EvaluatePosition(const double* x, double closestPoint[3], int& subId,
@@ -208,7 +206,7 @@ int vtkQuadraticPyramid::EvaluatePosition(const double* x, double closestPoint[3
   {
     pcoords[0] = pcoords[1] = 0;
     pcoords[2] = 1;
-    this->InterpolationFunctions(pcoords, weights);
+    vtkQuadraticPyramid::InterpolationFunctions(pcoords, weights);
     if (closestPoint)
     {
       memcpy(closestPoint, x, 3 * sizeof(double));
@@ -246,8 +244,8 @@ int vtkQuadraticPyramid::EvaluatePosition(const double* x, double closestPoint[3
   for (int iteration = 0; !converged && (iteration < VTK_PYRAMID_MAX_ITERATION); iteration++)
   {
     //  calculate element interpolation functions and derivatives
-    this->InterpolationFunctions(pcoords, weights);
-    this->InterpolationDerivs(pcoords, derivs);
+    vtkQuadraticPyramid::InterpolationFunctions(pcoords, weights);
+    vtkQuadraticPyramid::InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     double fcol[3] = { 0, 0, 0 }, rcol[3] = { 0, 0, 0 }, scol[3] = { 0, 0, 0 },
@@ -313,7 +311,7 @@ int vtkQuadraticPyramid::EvaluatePosition(const double* x, double closestPoint[3
     return -1;
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkQuadraticPyramid::InterpolationFunctions(pcoords, weights);
 
   // This is correct in that the XY parametric coordinate plane "shrinks"
   // while Z increases and X and Y always are between 0 and 1.
@@ -364,7 +362,7 @@ void vtkQuadraticPyramid::EvaluateLocation(
   int i, j;
   double pt[3];
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkQuadraticPyramid::InterpolationFunctions(pcoords, weights);
 
   x[0] = x[1] = x[2] = 0.0;
   for (i = 0; i < 13; i++)
@@ -417,7 +415,7 @@ void vtkQuadraticPyramid::Subdivide(
 
   // New midpoint is at center of the quadrilateral face
   double midPoint[3] = { 0.5, 0.5, 0.0 };
-  this->InterpolationFunctions(midPoint, weights);
+  vtkQuadraticPyramid::InterpolationFunctions(midPoint, weights);
 
   double x[3] = { 0., 0., 0. };
   double s = 0.0;
@@ -519,7 +517,7 @@ int vtkQuadraticPyramid::IntersectWithLine(
     else
     {
       // No need to set the PointIds. They are set in the Face constructor
-      // Points need to be set to correspond with the contructor's PointIds.
+      // Points need to be set to correspond with the constructor's PointIds.
       for (int i = 0; i < 8; i++)
       {
         this->Face->Points->SetPoint(i, this->Points->GetPoint(PyramidFaces[faceNum][i]));
@@ -630,7 +628,7 @@ void vtkQuadraticPyramid::JacobianInverse(
   double x[3];
 
   // compute interpolation function derivatives
-  this->InterpolationDerivs(pcoords, derivs);
+  vtkQuadraticPyramid::InterpolationDerivs(pcoords, derivs);
 
   // create Jacobian matrix
   m[0] = m0;
@@ -850,7 +848,7 @@ void vtkQuadraticPyramid::InterpolationDerivs(const double pcoords[3], double de
   derivs[37] = -0.5 * (1 + r) * (1 + s) * t;
   derivs[38] = -0.5 * (1 - r) * (1 + s) * t;
 
-  // we compute derivatives in in [-1; 1] but we need them in [ 0; 1]
+  // we compute derivatives in [-1; 1] but we need them in [ 0; 1]
   for (int i = 0; i < 39; i++)
     derivs[i] *= 2;
 }
@@ -899,3 +897,4 @@ void vtkQuadraticPyramid::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Scalars:\n";
   this->Scalars->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
