@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkQuadraticTetra.h"
 
 #include "vtkDoubleArray.h"
@@ -26,6 +23,7 @@
 #include "vtkQuadraticTriangle.h"
 #include "vtkTetra.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQuadraticTetra);
 
 //------------------------------------------------------------------------------
@@ -131,9 +129,9 @@ vtkCell* vtkQuadraticTetra::GetFace(int faceId)
 //------------------------------------------------------------------------------
 namespace
 {
-static const double VTK_DIVERGED = 1.e6;
-static const int VTK_TETRA_MAX_ITERATION = 20;
-static const double VTK_TETRA_CONVERGED = 1.e-05;
+const double VTK_DIVERGED = 1.e6;
+const int VTK_TETRA_MAX_ITERATION = 20;
+const double VTK_TETRA_CONVERGED = 1.e-05;
 }
 
 int vtkQuadraticTetra::EvaluatePosition(const double* x, double closestPoint[3], int& subId,
@@ -167,8 +165,8 @@ int vtkQuadraticTetra::EvaluatePosition(const double* x, double closestPoint[3],
   for (int iteration = 0; !converged && (iteration < VTK_TETRA_MAX_ITERATION); iteration++)
   {
     //  calculate element interpolation functions and derivatives
-    this->InterpolationFunctions(pcoords, weights);
-    this->InterpolationDerivs(pcoords, derivs);
+    vtkQuadraticTetra::InterpolationFunctions(pcoords, weights);
+    vtkQuadraticTetra::InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     double fcol[3] = { 0, 0, 0 }, rcol[3] = { 0, 0, 0 }, scol[3] = { 0, 0, 0 },
@@ -233,7 +231,7 @@ int vtkQuadraticTetra::EvaluatePosition(const double* x, double closestPoint[3],
     return -1;
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkQuadraticTetra::InterpolationFunctions(pcoords, weights);
 
   if (pcoords[0] >= -0.001 && pcoords[0] <= 1.001 && pcoords[1] >= -0.001 && pcoords[1] <= 1.001 &&
     pcoords[2] >= -0.001 && pcoords[2] <= 1.001 && pcoords[0] + pcoords[1] + pcoords[2] <= 1.001)
@@ -281,7 +279,7 @@ void vtkQuadraticTetra::EvaluateLocation(
   int i, j;
   double pt[3];
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkQuadraticTetra::InterpolationFunctions(pcoords, weights);
 
   x[0] = x[1] = x[2] = 0.0;
   for (i = 0; i < 10; i++)
@@ -421,7 +419,7 @@ void vtkQuadraticTetra::JacobianInverse(
   double x[3];
 
   // compute interpolation function derivatives
-  this->InterpolationDerivs(pcoords, derivs);
+  vtkQuadraticTetra::InterpolationDerivs(pcoords, derivs);
 
   // create Jacobian matrix
   m[0] = m0;
@@ -654,3 +652,4 @@ void vtkQuadraticTetra::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Scalars:\n";
   this->Scalars->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
