@@ -13,12 +13,11 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkRectilinearGrid.h"
 
+#include "vtkArrayDispatch.h"
 #include "vtkCellData.h"
+#include "vtkDataArrayRange.h"
 #include "vtkDoubleArray.h"
 #include "vtkGenericCell.h"
 #include "vtkInformation.h"
@@ -29,10 +28,12 @@
 #include "vtkPixel.h"
 #include "vtkPointData.h"
 #include "vtkPoints.h"
+#include "vtkSMPTools.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkVertex.h"
 #include "vtkVoxel.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRectilinearGrid);
 vtkStandardExtendedNewMacro(vtkRectilinearGrid);
 
@@ -253,7 +254,7 @@ vtkCell* vtkRectilinearGrid::GetCell(int iMin, int jMin, int kMin)
   int d01 = this->Dimensions[0] * this->Dimensions[1];
   double x[3];
 
-  iMin = iMax = jMin = jMax = kMin = kMax = 0;
+  iMax = jMax = kMax = 0;
 
   switch (this->DataDescription)
   {
@@ -522,18 +523,155 @@ void vtkRectilinearGrid::GetCellBounds(vtkIdType cellId, double bounds[6])
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkRectilinearGrid::GetCellDims(int cellDims[3])
+{
+  for (int i = 0; i < 3; ++i)
+  {
+    cellDims[i] = ((this->Dimensions[i] - 1) < 1) ? 1 : this->Dimensions[i] - 1;
+  }
+}
+
+//------------------------------------------------------------------------------
+unsigned char vtkRectilinearGrid::IsPointVisible(vtkIdType pointId)
+{
+  return vtkStructuredData::IsPointVisible(pointId, this->GetPointGhostArray());
+}
+
+//------------------------------------------------------------------------------
+// Return non-zero if the specified cell is visible (i.e., not blanked)
+unsigned char vtkRectilinearGrid::IsCellVisible(vtkIdType cellId)
+{
+  return vtkStructuredData::IsCellVisible(cellId, this->Dimensions, this->DataDescription,
+    this->GetCellGhostArray(), this->GetPointGhostArray());
+}
+
+namespace
+{
+//------------------------------------------------------------------------------
+template <typename ArrayTypeX, typename ArrayTypeY, typename ArrayTypeZ>
+class MergeCoordinatesFunctor
+{
+  ArrayTypeX* ArrayX;
+  ArrayTypeY* ArrayY;
+  ArrayTypeZ* ArrayZ;
+  vtkDoubleArray* Vector;
+  std::array<int, 3> Dimensions;
+  vtkIdType DataDescription;
+
+public:
+  MergeCoordinatesFunctor(ArrayTypeX* arrayX, ArrayTypeY* arrayY, ArrayTypeZ* arrayZ,
+    vtkDoubleArray* vector, int dimensions[3], vtkIdType dataDescription)
+    : ArrayX(arrayX)
+    , ArrayY(arrayY)
+    , ArrayZ(arrayZ)
+    , Vector(vector)
+    , Dimensions({ dimensions[0], dimensions[1], dimensions[2] })
+    , DataDescription(dataDescription)
+  {
+  }
+
+  void operator()(vtkIdType begin, vtkIdType end)
+  {
+    // mark out ranges as single component for better perf
+    const auto& inX = vtk::DataArrayValueRange<1>(this->ArrayX);
+    const auto& inY = vtk::DataArrayValueRange<1>(this->ArrayY);
+    const auto& inZ = vtk::DataArrayValueRange<1>(this->ArrayZ);
+    auto outVector = vtk::DataArrayTupleRange<3>(this->Vector, begin, end);
+
+    vtkIdType ptId = begin;
+    int loc[3];
+    for (auto point : outVector)
+    {
+      switch (this->DataDescription)
+      {
+        case VTK_SINGLE_POINT:
+          loc[0] = loc[1] = loc[2] = 0;
+          break;
+
+        case VTK_X_LINE:
+          loc[1] = loc[2] = 0;
+          loc[0] = ptId;
+          break;
+
+        case VTK_Y_LINE:
+          loc[0] = loc[2] = 0;
+          loc[1] = ptId;
+          break;
+
+        case VTK_Z_LINE:
+          loc[0] = loc[1] = 0;
+          loc[2] = ptId;
+          break;
+
+        case VTK_XY_PLANE:
+          loc[2] = 0;
+          loc[0] = ptId % this->Dimensions[0];
+          loc[1] = ptId / this->Dimensions[0];
+          break;
+
+        case VTK_YZ_PLANE:
+          loc[0] = 0;
+          loc[1] = ptId % this->Dimensions[1];
+          loc[2] = ptId / this->Dimensions[1];
+          break;
+
+        case VTK_XZ_PLANE:
+          loc[1] = 0;
+          loc[0] = ptId % this->Dimensions[0];
+          loc[2] = ptId / this->Dimensions[0];
+          break;
+
+        case VTK_XYZ_GRID:
+          loc[0] = ptId % this->Dimensions[0];
+          loc[1] = (ptId / this->Dimensions[0]) % this->Dimensions[1];
+          loc[2] = ptId / (this->Dimensions[0] * this->Dimensions[1]);
+          break;
+
+        default:
+          loc[0] = loc[1] = loc[2] = 0;
+          break;
+      }
+      point[0] = static_cast<double>(inX[loc[0]]);
+      point[1] = static_cast<double>(inY[loc[1]]);
+      point[2] = static_cast<double>(inZ[loc[2]]);
+      ptId++;
+    }
+  }
+};
+
+//------------------------------------------------------------------------------
+struct MergeCoordinatesWorker
+{
+  template <typename ArrayTypeX, typename ArrayTypeY, typename ArrayTypeZ>
+  void operator()(ArrayTypeX* arrayX, ArrayTypeY* arrayY, ArrayTypeZ* arrayZ,
+    vtkDoubleArray* vector, int dimensions[3], vtkIdType dataDescription)
+  {
+    MergeCoordinatesFunctor<ArrayTypeX, ArrayTypeY, ArrayTypeZ> functor(
+      arrayX, arrayY, arrayZ, vector, dimensions, dataDescription);
+    vtkSMPTools::For(0, vector->GetNumberOfTuples(), functor);
+  }
+};
+}
+
 //------------------------------------------------------------------------------
 void vtkRectilinearGrid::GetPoints(vtkPoints* pnts)
 {
   assert("pre: points object should not be nullptr" && (pnts != nullptr));
 
   pnts->Initialize();
-  pnts->SetNumberOfPoints(this->GetNumberOfPoints());
-  vtkIdType pntIdx = 0;
-  for (; pntIdx < this->GetNumberOfPoints(); ++pntIdx)
+  vtkNew<vtkDoubleArray> coords;
+  coords->SetNumberOfComponents(3);
+  coords->SetNumberOfTuples(this->GetNumberOfPoints());
+  MergeCoordinatesWorker mergeCoordinatesWorker;
+  using Dispatcher = vtkArrayDispatch::Dispatch3BySameValueType<vtkArrayDispatch::Reals>;
+  if (!Dispatcher::Execute(this->XCoordinates, this->YCoordinates, this->ZCoordinates,
+        mergeCoordinatesWorker, coords.Get(), this->Dimensions, this->DataDescription))
   {
-    pnts->SetPoint(pntIdx, this->GetPoint(pntIdx));
-  } // END for all points
+    mergeCoordinatesWorker(this->XCoordinates, this->YCoordinates, this->ZCoordinates, coords.Get(),
+      this->Dimensions, this->DataDescription);
+  }
+  pnts->SetData(coords.Get());
 }
 
 //------------------------------------------------------------------------------
@@ -750,7 +888,7 @@ vtkIdType vtkRectilinearGrid::FindCell(double x[3], vtkCell* vtkNotUsed(cell),
     return -1;
   }
 
-  this->Voxel->InterpolationFunctions(pcoords, weights);
+  vtkVoxel::InterpolationFunctions(pcoords, weights);
 
   //
   //  From this location get the cell id
@@ -775,7 +913,7 @@ vtkCell* vtkRectilinearGrid::FindAndGetCell(double x[3], vtkCell* vtkNotUsed(cel
   //
   // Get the parametric coordinates and weights for interpolation
   //
-  this->Voxel->InterpolationFunctions(pcoords, weights);
+  vtkVoxel::InterpolationFunctions(pcoords, weights);
   //
   // Get the cell
   //
@@ -814,6 +952,36 @@ int vtkRectilinearGrid::GetCellType(vtkIdType vtkNotUsed(cellId))
   }
 }
 
+//------------------------------------------------------------------------------
+vtkIdType vtkRectilinearGrid::GetCellSize(vtkIdType vtkNotUsed(cellId))
+{
+  switch (this->DataDescription)
+  {
+    case VTK_EMPTY:
+      return 0;
+
+    case VTK_SINGLE_POINT:
+      return 1;
+
+    case VTK_X_LINE:
+    case VTK_Y_LINE:
+    case VTK_Z_LINE:
+      return 2;
+
+    case VTK_XY_PLANE:
+    case VTK_YZ_PLANE:
+    case VTK_XZ_PLANE:
+      return 4;
+
+    case VTK_XYZ_GRID:
+      return 8;
+
+    default:
+      vtkErrorMacro(<< "Bad data description!");
+      return VTK_EMPTY_CELL;
+  }
+}
+
 //------------------------------------------------------------------------------
 void vtkRectilinearGrid::ComputeBounds()
 {
@@ -855,6 +1023,87 @@ void vtkRectilinearGrid::ComputeBounds()
   }
 }
 
+namespace
+{
+class CellVisibility
+{
+public:
+  CellVisibility(vtkRectilinearGrid* input)
+    : Input(input)
+  {
+  }
+  bool operator()(const vtkIdType id) { return !Input->IsCellVisible(id); }
+
+private:
+  vtkRectilinearGrid* Input;
+};
+} // anonymous namespace
+
+//------------------------------------------------------------------------------
+void vtkRectilinearGrid::GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds)
+{
+  int numPtIds = ptIds->GetNumberOfIds();
+
+  // Use special methods for speed
+  switch (numPtIds)
+  {
+    case 0:
+      cellIds->Reset();
+      return;
+
+    case 1:
+    case 2:
+    case 4: // vertex, edge, face neighbors
+      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->GetDimensions());
+      break;
+
+    default:
+      this->Superclass::GetCellNeighbors(cellId, ptIds, cellIds);
+  }
+
+  // If blanking, remove blanked cells.
+  if (this->GetPointGhostArray() || this->GetCellGhostArray())
+  {
+    vtkIdType* pCellIds = cellIds->GetPointer(0);
+    vtkIdType* end =
+      std::remove_if(pCellIds, pCellIds + cellIds->GetNumberOfIds(), CellVisibility(this));
+    cellIds->Resize(std::distance(pCellIds, end));
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkRectilinearGrid::GetCellNeighbors(
+  vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds, int* seedLoc)
+{
+  int numPtIds = ptIds->GetNumberOfIds();
+
+  // Use special methods for speed
+  switch (numPtIds)
+  {
+    case 0:
+      cellIds->Reset();
+      return;
+
+    case 1:
+    case 2:
+    case 4: // vertex, edge, face neighbors
+      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->GetDimensions(), seedLoc);
+      break;
+
+    default:
+      this->Superclass::GetCellNeighbors(cellId, ptIds, cellIds);
+  }
+
+  // If blanking, remove blanked cells.
+  if (this->GetPointGhostArray() || this->GetCellGhostArray())
+  {
+    vtkIdType* pCellIds = cellIds->GetPointer(0);
+    vtkIdType* end =
+      std::remove_if(pCellIds, pCellIds + cellIds->GetNumberOfIds(), CellVisibility(this));
+    cellIds->Resize(std::distance(pCellIds, end));
+  }
+}
+
 //------------------------------------------------------------------------------
 // Set dimensions of rectilinear grid dataset.
 void vtkRectilinearGrid::SetDimensions(int i, int j, int k)
@@ -888,9 +1137,7 @@ void vtkRectilinearGrid::SetExtent(int extent[6])
   this->DataDescription = description;
 
   this->Modified();
-  this->Dimensions[0] = extent[1] - extent[0] + 1;
-  this->Dimensions[1] = extent[3] - extent[2] + 1;
-  this->Dimensions[2] = extent[5] - extent[4] + 1;
+  vtkStructuredData::GetDimensionsFromExtent(extent, this->Dimensions);
 }
 
 //------------------------------------------------------------------------------
@@ -973,7 +1220,7 @@ int vtkRectilinearGrid::ComputeStructuredCoordinates(double x[3], int ijk[3], do
 //------------------------------------------------------------------------------
 unsigned long vtkRectilinearGrid::GetActualMemorySize()
 {
-  unsigned long size = this->vtkDataSet::GetActualMemorySize();
+  unsigned long size = this->Superclass::GetActualMemorySize();
 
   if (this->XCoordinates)
   {
@@ -993,28 +1240,6 @@ unsigned long vtkRectilinearGrid::GetActualMemorySize()
   return size;
 }
 
-//------------------------------------------------------------------------------
-void vtkRectilinearGrid::GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds)
-{
-  int numPtIds = ptIds->GetNumberOfIds();
-
-  // Use special methods for speed
-  switch (numPtIds)
-  {
-    case 0:
-      cellIds->Reset();
-      return;
-
-    case 1:
-    case 2:
-    case 4: // vertex, edge, face neighbors
-      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->Dimensions);
-      break;
-
-    default:
-      this->vtkDataSet::GetCellNeighbors(cellId, ptIds, cellIds);
-  }
-}
 //------------------------------------------------------------------------------
 void vtkRectilinearGrid::ShallowCopy(vtkDataObject* dataObject)
 {
@@ -1032,7 +1257,7 @@ void vtkRectilinearGrid::ShallowCopy(vtkDataObject* dataObject)
   }
 
   // Do superclass
-  this->vtkDataSet::ShallowCopy(dataObject);
+  this->Superclass::ShallowCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
@@ -1063,7 +1288,7 @@ void vtkRectilinearGrid::DeepCopy(vtkDataObject* dataObject)
   }
 
   // Do superclass
-  this->vtkDataSet::DeepCopy(dataObject);
+  this->Superclass::DeepCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
@@ -1337,3 +1562,17 @@ int vtkRectilinearGrid::GetNumberOfScalarComponents()
   }
   return 1;
 }
+
+//------------------------------------------------------------------------------
+bool vtkRectilinearGrid::HasAnyBlankPoints()
+{
+  return this->PointData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENPOINT);
+}
+
+//------------------------------------------------------------------------------
+bool vtkRectilinearGrid::HasAnyBlankCells()
+{
+  int cellBlanking = this->CellData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENCELL);
+  return cellBlanking || this->HasAnyBlankPoints();
+}
+VTK_ABI_NAMESPACE_END
