@@ -1,11 +1,11 @@
 /*=========================================================================
 
-  Program:   ParaView
+  Program:   Visualization Toolkit
   Module:    vtkSelection.cxx
 
-  Copyright (c) Kitware, Inc.
+  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
-  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
+  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -14,7 +14,6 @@
 =========================================================================*/
 #include "vtkSelection.h"
 
-#include "vtkAbstractArray.h"
 #include "vtkFieldData.h"
 #include "vtkInformation.h"
 #include "vtkInformationIntegerKey.h"
@@ -30,33 +29,20 @@
 #include "vtkTable.h"
 
 #include <vtksys/RegularExpression.hxx>
-#include <vtksys/SystemTools.hxx>
 
 #include <atomic>
 #include <cassert>
 #include <cctype>
-#include <iterator>
 #include <map>
 #include <memory>
 #include <sstream>
 #include <string>
 #include <vector>
 
-namespace
-{
-// since certain compilers don't support std::to_string yet
-template <typename T>
-std::string convert_to_string(const T& val)
-{
-  std::ostringstream str;
-  str << val;
-  return str.str();
-}
-}
-
 //============================================================================
 namespace parser
 {
+VTK_ABI_NAMESPACE_BEGIN
 class Node
 {
 public:
@@ -68,19 +54,18 @@ public:
 
 class NodeVariable : public Node
 {
-  vtkSignedCharArray* Data;
+  signed char* Data;
   std::string Name;
 
 public:
   NodeVariable(vtkSignedCharArray* data, const std::string& name)
-    : Data(data)
+    : Data(data ? data->GetPointer(0) : nullptr)
     , Name(name)
   {
   }
   bool Evaluate(vtkIdType offset) const override
   {
-    assert(this->Data == nullptr || this->Data->GetNumberOfValues() > offset);
-    return this->Data ? (this->Data->GetValue(offset) != 0) : false;
+    return this->Data ? this->Data[offset] != 0 : false;
   }
   void Print(ostream& os) const override { os << this->Name; }
 };
@@ -157,8 +142,36 @@ public:
     os << ")";
   }
 };
+
+class NodeXor : public Node
+{
+  std::shared_ptr<Node> ChildA;
+  std::shared_ptr<Node> ChildB;
+
+public:
+  NodeXor(const std::shared_ptr<Node>& nodeA, const std::shared_ptr<Node>& nodeB)
+    : ChildA(nodeA)
+    , ChildB(nodeB)
+  {
+  }
+  bool Evaluate(vtkIdType offset) const override
+  {
+    assert(this->ChildA && this->ChildB);
+    return this->ChildA->Evaluate(offset) ^ this->ChildB->Evaluate(offset);
+  }
+  void Print(ostream& os) const override
+  {
+    os << "(";
+    this->ChildA->Print(os);
+    os << " ^ ";
+    this->ChildB->Print(os);
+    os << ")";
+  }
+};
+VTK_ABI_NAMESPACE_END
 } // namespace parser
 
+VTK_ABI_NAMESPACE_BEGIN
 //============================================================================
 class vtkSelection::vtkInternals
 {
@@ -183,7 +196,7 @@ class vtkSelection::vtkInternals
       op_stack.pop_back();
       return true;
     }
-    else if (op_stack.back() == '|' || op_stack.back() == '&')
+    else if (op_stack.back() == '|' || op_stack.back() == '^' || op_stack.back() == '&')
     {
       if (var_stack.size() < 2)
       {
@@ -199,7 +212,11 @@ class vtkSelection::vtkInternals
       {
         var_stack.push_back(std::make_shared<parser::NodeOr>(a, b));
       }
-      else
+      else if (op_stack.back() == '^')
+      {
+        var_stack.push_back(std::make_shared<parser::NodeXor>(a, b));
+      }
+      else // if (op_stack.back() == '&')
       {
         var_stack.push_back(std::make_shared<parser::NodeAnd>(a, b));
       }
@@ -216,7 +233,9 @@ class vtkSelection::vtkInternals
     switch (op)
     {
       case '|':
-        return -15;
+        return -16;
+      case '^':
+        return -15; // https://stackoverflow.com/a/36320208
       case '&':
         return -14;
       case '!':
@@ -254,6 +273,7 @@ public:
         case '(':
         case ')':
         case '|':
+        case '^':
         case '&':
         case '!':
           if (!accumated_text.empty())
@@ -300,7 +320,7 @@ public:
         // pop the opening paren.
         op_stack.pop_back();
       }
-      else if (term[0] == '&' || term[0] == '|' || term[0] == '!')
+      else if (term[0] == '&' || term[0] == '^' || term[0] == '|' || term[0] == '!')
       {
         while (!op_stack.empty() && (precedence(term[0]) < precedence(op_stack.back())) &&
           this->ApplyBack(op_stack, var_stack))
@@ -329,8 +349,7 @@ vtkStandardNewMacro(vtkSelection);
 
 //------------------------------------------------------------------------------
 vtkSelection::vtkSelection()
-  : Expression()
-  , Internals(new vtkSelection::vtkInternals())
+  : Internals(new vtkSelection::vtkInternals())
 {
   this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_PIECES_EXTENT);
   this->Information->Set(vtkDataObject::DATA_PIECE_NUMBER(), -1);
@@ -403,10 +422,10 @@ std::string vtkSelection::AddNode(vtkSelectionNode* node)
   }
 
   static std::atomic<uint64_t> counter(0U);
-  std::string name = std::string("node") + convert_to_string(++counter);
+  std::string name = std::string("node") + std::to_string(++counter);
   while (internals.Items.find(name) != internals.Items.end())
   {
-    name = std::string("node") + convert_to_string(++counter);
+    name = std::string("node") + std::to_string(++counter);
   }
 
   this->SetNode(name, node);
@@ -501,10 +520,11 @@ void vtkSelection::PrintSelf(ostream& os, vtkIndent indent)
   unsigned int numNodes = this->GetNumberOfNodes();
   os << indent << "Number of nodes: " << numNodes << endl;
   os << indent << "Nodes: " << endl;
-  for (unsigned int i = 0; i < numNodes; i++)
+  size_t counter = 0;
+  for (const auto& nodePair : this->Internals->Items)
   {
-    os << indent << "Node #" << i << endl;
-    this->GetNode(i)->PrintSelf(os, indent.GetNextIndent());
+    os << indent << "Node #" << counter++ << endl;
+    nodePair.second->PrintSelf(os, indent.GetNextIndent());
   }
 }
 
@@ -544,9 +564,9 @@ void vtkSelection::DeepCopy(vtkDataObject* src)
 //------------------------------------------------------------------------------
 void vtkSelection::Union(vtkSelection* s)
 {
-  for (unsigned int n = 0; n < s->GetNumberOfNodes(); ++n)
+  for (const auto& nodePair : s->Internals->Items)
   {
-    this->Union(s->GetNode(n));
+    this->Union(nodePair.second);
   }
 }
 
@@ -554,12 +574,12 @@ void vtkSelection::Union(vtkSelection* s)
 void vtkSelection::Union(vtkSelectionNode* node)
 {
   bool merged = false;
-  for (unsigned int tn = 0; tn < this->GetNumberOfNodes(); ++tn)
+  for (const auto& nodePair : this->Internals->Items)
   {
-    vtkSelectionNode* tnode = this->GetNode(tn);
-    if (tnode->EqualProperties(node))
+    auto& selNode = nodePair.second;
+    if (selNode->EqualProperties(node))
     {
-      tnode->UnionSelectionList(node);
+      selNode->UnionSelectionList(node);
       merged = true;
       break;
     }
@@ -575,9 +595,9 @@ void vtkSelection::Union(vtkSelectionNode* node)
 //------------------------------------------------------------------------------
 void vtkSelection::Subtract(vtkSelection* s)
 {
-  for (unsigned int n = 0; n < s->GetNumberOfNodes(); ++n)
+  for (const auto& nodePair : s->Internals->Items)
   {
-    this->Subtract(s->GetNode(n));
+    this->Subtract(nodePair.second);
   }
 }
 
@@ -585,13 +605,13 @@ void vtkSelection::Subtract(vtkSelection* s)
 void vtkSelection::Subtract(vtkSelectionNode* node)
 {
   bool subtracted = false;
-  for (unsigned int tn = 0; tn < this->GetNumberOfNodes(); ++tn)
+  for (const auto& nodePair : this->Internals->Items)
   {
-    vtkSelectionNode* tnode = this->GetNode(tn);
+    vtkSelectionNode* selNode = nodePair.second;
 
-    if (tnode->EqualProperties(node))
+    if (selNode->EqualProperties(node))
     {
-      tnode->SubtractSelectionList(node);
+      selNode->SubtractSelectionList(node);
       subtracted = true;
     }
   }
@@ -626,8 +646,62 @@ vtkSelection* vtkSelection::GetData(vtkInformationVector* v, int i)
 }
 
 //------------------------------------------------------------------------------
-vtkSmartPointer<vtkSignedCharArray> vtkSelection::Evaluate(
-  vtkSignedCharArray* const* values, unsigned int num_values) const
+struct vtkSelection::EvaluateFunctor
+{
+  std::array<signed char, 2>& Range;
+  std::shared_ptr<parser::Node> Tree;
+  signed char* Result;
+
+  EvaluateFunctor(std::array<signed char, 2>& range, std::shared_ptr<parser::Node> tree,
+    vtkSignedCharArray* result)
+    : Range(range)
+    , Tree(tree)
+    , Result(result->GetPointer(0))
+  {
+    this->Range = { VTK_SIGNED_CHAR_MAX, VTK_SIGNED_CHAR_MIN };
+  }
+
+  void Initialize(){};
+
+  void operator()(vtkIdType begin, vtkIdType end)
+  {
+    for (vtkIdType i = begin; i < end; ++i)
+    {
+      this->Result[i] = static_cast<signed char>(this->Tree->Evaluate(i));
+      if (this->Range[0] == VTK_SIGNED_CHAR_MAX && this->Result[i] == 0)
+      {
+        this->Range[0] = 0;
+      }
+      else if (this->Range[1] == VTK_SIGNED_CHAR_MIN && this->Result[i] == 1)
+      {
+        this->Range[1] = 1;
+      }
+    }
+  }
+
+  void Reduce()
+  {
+    if (this->Range[0] == VTK_SIGNED_CHAR_MAX)
+    {
+      if (this->Range[1] == VTK_SIGNED_CHAR_MIN)
+      {
+        this->Range[0] = 0;
+      }
+      else
+      {
+        this->Range[0] = this->Range[1];
+      }
+    }
+    if (this->Range[1] == VTK_SIGNED_CHAR_MIN)
+    {
+      this->Range[1] = 0;
+    }
+  }
+};
+
+//------------------------------------------------------------------------------
+vtkSmartPointer<vtkSignedCharArray> vtkSelection::Evaluate(vtkSignedCharArray* const* values,
+  unsigned int num_values, std::array<signed char, 2>& range) const
 {
   std::map<std::string, vtkSignedCharArray*> values_map;
 
@@ -676,14 +750,9 @@ vtkSmartPointer<vtkSignedCharArray> vtkSelection::Evaluate(
   if (tree && (!values_map.empty()))
   {
     auto result = vtkSmartPointer<vtkSignedCharArray>::New();
-    result->SetNumberOfComponents(1);
-    result->SetNumberOfTuples(numVals);
-    vtkSMPTools::For(0, numVals, [&](vtkIdType start, vtkIdType end) {
-      for (vtkIdType idx = start; idx < end; ++idx)
-      {
-        result->SetTypedComponent(idx, 0, tree->Evaluate(idx));
-      }
-    });
+    result->SetNumberOfValues(numVals);
+    EvaluateFunctor functor(range, tree, result);
+    vtkSMPTools::For(0, numVals, functor);
     return result;
   }
   else if (!tree)
@@ -704,10 +773,11 @@ void vtkSelection::Dump(ostream& os)
 {
   vtkSmartPointer<vtkTable> tmpTable = vtkSmartPointer<vtkTable>::New();
   cerr << "==Selection==" << endl;
-  for (unsigned int i = 0; i < this->GetNumberOfNodes(); ++i)
+  size_t counter = 0;
+  for (const auto& nodePair : this->Internals->Items)
   {
-    os << "===Node " << i << "===" << endl;
-    vtkSelectionNode* node = this->GetNode(i);
+    os << "===Node " << counter++ << "===" << endl;
+    vtkSelectionNode* node = nodePair.second;
     os << "ContentType: ";
     switch (node->GetContentType())
     {
@@ -776,3 +846,4 @@ void vtkSelection::Dump(ostream& os)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
