@@ -1,11 +1,11 @@
 /*=========================================================================
 
-  Program:   ParaView
+  Program:   Visualization Toolkit
   Module:    vtkSelectionNode.cxx
 
-  Copyright (c) Kitware, Inc.
+  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
-  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
+  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
 
      This software is distributed WITHOUT ANY WARRANTY; without even
      the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
@@ -24,6 +24,7 @@
 #include "vtkInformationIterator.h"
 #include "vtkInformationObjectBaseKey.h"
 #include "vtkInformationStringKey.h"
+#include "vtkInformationStringVectorKey.h"
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 #include "vtkSmartPointer.h"
@@ -33,11 +34,11 @@
 #include <utility>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSelectionNode);
 vtkCxxSetObjectMacro(vtkSelectionNode, SelectionData, vtkDataSetAttributes);
 
-const char vtkSelectionNode ::ContentTypeNames[vtkSelectionNode::NUM_CONTENT_TYPES][14] = {
-  "SELECTIONS", // deprecated
+const char vtkSelectionNode ::ContentTypeNames[vtkSelectionNode::NUM_CONTENT_TYPES][16] = {
   "GLOBALIDS",
   "PEDIGREEIDS",
   "VALUES",
@@ -46,6 +47,7 @@ const char vtkSelectionNode ::ContentTypeNames[vtkSelectionNode::NUM_CONTENT_TYP
   "LOCATIONS",
   "THRESHOLDS",
   "BLOCKS",
+  "BLOCK_SELECTORS",
   "QUERY",
   "USER",
 };
@@ -73,10 +75,13 @@ vtkInformationKeyMacro(vtkSelectionNode, EPSILON, Double);
 vtkInformationKeyMacro(vtkSelectionNode, ZBUFFER_VALUE, Double);
 vtkInformationKeyMacro(vtkSelectionNode, CONTAINING_CELLS, Integer);
 vtkInformationKeyMacro(vtkSelectionNode, CONNECTED_LAYERS, Integer);
+vtkInformationKeyMacro(vtkSelectionNode, CONNECTED_LAYERS_REMOVE_SEED, Integer);
+vtkInformationKeyMacro(vtkSelectionNode, CONNECTED_LAYERS_REMOVE_INTERMEDIATE_LAYERS, Integer);
 vtkInformationKeyMacro(vtkSelectionNode, PIXEL_COUNT, Integer);
 vtkInformationKeyMacro(vtkSelectionNode, INVERSE, Integer);
-vtkInformationKeyMacro(vtkSelectionNode, INDEXED_VERTICES, Integer);
 vtkInformationKeyMacro(vtkSelectionNode, COMPONENT_NUMBER, Integer);
+vtkInformationKeyMacro(vtkSelectionNode, ASSEMBLY_NAME, String);
+vtkInformationKeyMacro(vtkSelectionNode, SELECTORS, StringVector);
 
 //------------------------------------------------------------------------------
 vtkSelectionNode::vtkSelectionNode()
@@ -216,7 +221,9 @@ int vtkSelectionNode::GetContentType()
 //------------------------------------------------------------------------------
 const char* vtkSelectionNode::GetContentTypeAsString(int type)
 {
-  return vtkSelectionNode::ContentTypeNames[type];
+  return type >= 0 && type < vtkSelectionNode::NUM_CONTENT_TYPES
+    ? vtkSelectionNode::ContentTypeNames[type]
+    : "(invalid)";
 }
 
 //------------------------------------------------------------------------------
@@ -238,7 +245,21 @@ int vtkSelectionNode::GetFieldType()
 //------------------------------------------------------------------------------
 const char* vtkSelectionNode::GetFieldTypeAsString(int type)
 {
-  return vtkSelectionNode::FieldTypeNames[type];
+  return type >= 0 && type < NUM_FIELD_TYPES ? vtkSelectionNode::FieldTypeNames[type] : "(invalid)";
+}
+
+//------------------------------------------------------------------------------
+int vtkSelectionNode::GetFieldTypeFromString(const char* type)
+{
+  for (int cc = 0; type != nullptr && cc < NUM_FIELD_TYPES; ++cc)
+  {
+    if (strcmp(vtkSelectionNode::FieldTypeNames[cc], type) == 0)
+    {
+      return cc;
+    }
+  }
+
+  return NUM_FIELD_TYPES;
 }
 
 //------------------------------------------------------------------------------
@@ -249,7 +270,7 @@ bool vtkSelectionNode::EqualProperties(vtkSelectionNode* other, bool fullcompare
     return false;
   }
 
-  vtkSmartPointer<vtkInformationIterator> iterSelf = vtkSmartPointer<vtkInformationIterator>::New();
+  vtkNew<vtkInformationIterator> iterSelf;
 
   iterSelf->SetInformation(this->Properties);
 
@@ -257,8 +278,7 @@ bool vtkSelectionNode::EqualProperties(vtkSelectionNode* other, bool fullcompare
   for (iterSelf->InitTraversal(); !iterSelf->IsDoneWithTraversal(); iterSelf->GoToNextItem())
   {
     vtkInformationKey* key = iterSelf->GetCurrentKey();
-    vtkInformationIntegerKey* ikey = vtkInformationIntegerKey::SafeDownCast(key);
-    vtkInformationObjectBaseKey* okey = vtkInformationObjectBaseKey::SafeDownCast(key);
+    auto ikey = static_cast<vtkInformationIntegerKey*>(key);
     if (ikey)
     {
       if (!otherProperties->Has(ikey) || this->Properties->Get(ikey) != otherProperties->Get(ikey))
@@ -266,11 +286,16 @@ bool vtkSelectionNode::EqualProperties(vtkSelectionNode* other, bool fullcompare
         return false;
       }
     }
-    if (okey)
+    else
     {
-      if (!otherProperties->Has(okey) || this->Properties->Get(okey) != otherProperties->Get(okey))
+      auto okey = static_cast<vtkInformationObjectBaseKey*>(key);
+      if (okey)
       {
-        return false;
+        if (!otherProperties->Has(okey) ||
+          this->Properties->Get(okey) != otherProperties->Get(okey))
+        {
+          return false;
+        }
       }
     }
   }
@@ -327,6 +352,7 @@ void vtkSelectionNode::UnionSelectionList(vtkSelectionNode* other)
     case LOCATIONS:
     case THRESHOLDS:
     case BLOCKS:
+    case BLOCK_SELECTORS:
     {
       vtkDataSetAttributes* fd1 = this->GetSelectionData();
       vtkDataSetAttributes* fd2 = other->GetSelectionData();
@@ -463,7 +489,7 @@ void vtkSelectionNode::SubtractSelectionList(vtkSelectionNode* other)
     {
       vtkErrorMacro(<< "Do not know how to subtract the given content type " << type << ".");
     }
-  };
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -530,3 +556,4 @@ int vtkSelectionNode::ConvertAttributeTypeToSelectionField(int attrType)
       return vtkSelectionNode::CELL;
   }
 }
+VTK_ABI_NAMESPACE_END
