@@ -87,7 +87,7 @@
  *   `BLOCK_SELECTORS`, `PROCESS_ID` etc. are needed to correctly identify the
  *   chosen element(s) in case of composite or distributed datasets.
  *
- * * `vtkSelectionNode::FRUSTUM: this type is used to define a frustum in world
+ * * `vtkSelectionNode::FRUSTUM`: this type is used to define a frustum in world
  *   coordinates that identifies the selected elements. In this case, the
  *   selection list is a vtkDoubleArray with 32 values specifying the 8 frustum
  *   corners in homogeneous world coordinates.
@@ -152,8 +152,15 @@
  *
  * * `vtkSelectionNode::CONNECTED_LAYERS()`: a qualifier used to expand the
  *   definition of selected elements to connected elements for the specified
- *   number of layers. Layers can be positive or negative to grow or shrink the
- *   selection respectively.
+ *   number of layers. Layers can only be positive to grow the selection.
+ *
+ * * `vtkSelectionNode::CONNECTED_LAYERS_REMOVE_SEED()`: this qualifier indicates
+ *   that when using a number of CONNECTED_LAYERS >= 1, the initial selection will
+ *   not be kept.
+ *
+ * * `vtkSelectionNode::CONNECTED_LAYERS_REMOVE_INTERMEDIATE_LAYERS()`: this qualifier
+ *   indicates that when using a number of CONNECTED_LAYERS >= 2, the intermediate layers
+ *   will not be kept.
  *
  * * `vtkSelectionNode::INVERSE()`: a qualifier that causes the selection to be
  *   inverted i.e. all elements not chosen by the criteria are to be treated
@@ -214,9 +221,9 @@
 #define vtkSelectionNode_h
 
 #include "vtkCommonDataModelModule.h" // For export macro
-#include "vtkDeprecation.h"           // for deprecation
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkDataSetAttributes;
 class vtkInformation;
@@ -406,6 +413,18 @@ public:
    */
   static vtkInformationIntegerKey* CONNECTED_LAYERS();
 
+  /**
+   * When specified and also using CONNECTED_LAYERS(), this indicates
+   * if the initial selection should be kept or not.
+   */
+  static vtkInformationIntegerKey* CONNECTED_LAYERS_REMOVE_SEED();
+
+  /**
+   * When specified and also using CONNECTED_LAYERS(), this indicates
+   * if the intermediate layers should be kept or not.
+   */
+  static vtkInformationIntegerKey* CONNECTED_LAYERS_REMOVE_INTERMEDIATE_LAYERS();
+
   /**
    * When ContentType==THRESHOLDS  or ContentType==VALUES
    * i.e. threshold and value based selections, it is
@@ -480,12 +499,6 @@ public:
   static vtkInformationIntegerKey* HIERARCHICAL_INDEX();
   ///@}
 
-  /**
-   * @deprecated no longer relevant.
-   */
-  VTK_DEPRECATED_IN_9_1_0("no longer relevant")
-  static vtkInformationIntegerKey* INDEXED_VERTICES();
-
   /**
    * Merges the selection list between self and the other. Assumes that both has
    * identical properties.
@@ -523,4 +536,5 @@ private:
   void operator=(const vtkSelectionNode&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
