@@ -47,29 +47,26 @@
 #include "vtkCommonDataModelModule.h"   // For export macro
 #include "vtkStaticCellLinksTemplate.h" // For implementations
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkCellArray;
 
 class VTKCOMMONDATAMODEL_EXPORT vtkStaticCellLinks : public vtkAbstractCellLinks
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, type manipulation and printing.
    */
   static vtkStaticCellLinks* New();
   vtkTypeMacro(vtkStaticCellLinks, vtkAbstractCellLinks);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
-   * Build the link list array. Satisfy the superclass API.
+   * Build the link list array from the input dataset.
    */
-  void BuildLinks(vtkDataSet* ds) override
-  {
-    this->Impl->SetSequentialProcessing(this->SequentialProcessing);
-    this->Impl->BuildLinks(ds);
-  }
+  void BuildLinks() override;
 
   /**
    * Get the number of cells using the point specified by ptId.
@@ -87,7 +84,7 @@ public:
    */
   vtkIdType* GetCells(vtkIdType ptId) { return this->Impl->GetCells(ptId); }
 
-  //@{
+  ///@{
   /**
    * Select all cells with a point degree in the range [minDegree,maxDegree).
    * The degree is the number of cells using a point. The selection is
@@ -99,12 +96,16 @@ public:
   {
     return this->Impl->SelectCells(minMaxDegree, cellSelection);
   }
-  //@}
+  ///@}
 
   /**
    * Make sure any previously created links are cleaned up.
    */
-  void Initialize() override { this->Impl->Initialize(); }
+  void Initialize() override
+  {
+    this->Impl->Initialize();
+    this->Modified();
+  }
 
   /**
    * Reclaim any unused memory.
@@ -130,7 +131,7 @@ public:
    * Standard DeepCopy method.  Since this object contains no reference
    * to other objects, there is no ShallowCopy.
    */
-  void DeepCopy(vtkAbstractCellLinks* src) override { this->Impl->DeepCopy(src); }
+  void DeepCopy(vtkAbstractCellLinks* src) override;
 
 protected:
   vtkStaticCellLinks();
@@ -143,4 +144,5 @@ private:
   void operator=(const vtkStaticCellLinks&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
