@@ -45,25 +45,30 @@
 #ifndef vtkStaticCellLinksTemplate_h
 #define vtkStaticCellLinksTemplate_h
 
+#include "vtkABINamespace.h"
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkPolyData;
 class vtkUnstructuredGrid;
 class vtkExplicitStructuredGrid;
 class vtkCellArray;
+VTK_ABI_NAMESPACE_END
 
 #include "vtkAbstractCellLinks.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 template <typename TIds>
 class vtkStaticCellLinksTemplate
 {
 public:
-  //@{
+  ///@{
   /**
    * Instantiate and destructor methods.
    */
   vtkStaticCellLinksTemplate();
   ~vtkStaticCellLinksTemplate();
-  //@}
+  ///@}
 
   /**
    * Make sure any previously created links are cleaned up.
@@ -98,19 +103,20 @@ public:
   void ThreadedBuildLinks(
     const vtkIdType numPts, const vtkIdType numCells, vtkCellArray* cellArray);
 
-  //@{
+  ///@{
   /**
    * Get the number of cells using the point specified by ptId.
    */
   TIds GetNumberOfCells(vtkIdType ptId) { return (this->Offsets[ptId + 1] - this->Offsets[ptId]); }
   vtkIdType GetNcells(vtkIdType ptId) { return (this->Offsets[ptId + 1] - this->Offsets[ptId]); }
-  //@}
+  ///@}
 
   /**
    * Indicate whether the point ids provided defines at least one cell, or a
    * portion of a cell.
    */
-  bool MatchesCell(vtkIdType npts, const vtkIdType* pts);
+  template <typename TGivenIds>
+  bool MatchesCell(TGivenIds npts, const TGivenIds* pts);
 
   /**
    * Return a list of cell ids using the point specified by ptId.
@@ -123,22 +129,34 @@ public:
    */
   void GetCells(vtkIdType npts, const vtkIdType* pts, vtkIdList* cells);
 
-  //@{
+  /**
+   * Return the total number of links represented after the links have
+   * been built.
+   */
+  TIds GetLinksSize() { return this->LinksSize; }
+
+  /**
+   * Obtain the offsets into the internal links array. This is useful for
+   * parallel computing.
+   */
+  TIds GetOffset(vtkIdType ptId) { return this->Offsets[ptId]; }
+
+  ///@{
   /**
    * Support vtkAbstractCellLinks API.
    */
   unsigned long GetActualMemorySize();
   void DeepCopy(vtkAbstractCellLinks* src);
   void SelectCells(vtkIdType minMaxDegree[2], unsigned char* cellSelection);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control whether to thread or serial process.
    */
   void SetSequentialProcessing(vtkTypeBool seq) { this->SequentialProcessing = seq; }
   vtkTypeBool GetSequentialProcessing() { return this->SequentialProcessing; }
-  //@}
+  ///@}
 
 protected:
   // The various templated data members
@@ -159,6 +177,7 @@ private:
   void operator=(const vtkStaticCellLinksTemplate&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #include "vtkStaticCellLinksTemplate.txx"
 
 #endif
