@@ -32,6 +32,7 @@
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStaticPointLocator);
 
 // There are stack-allocated bucket neighbor lists. This is the initial
@@ -613,7 +614,7 @@ struct BucketList : public vtkBucketList
       {
         for (; curPt->Bucket == prevPt->Bucket && curPt <= endBatchPt; ++curPt)
         {
-          ; // advance
+          // advance
         }
         // Fill in any gaps in the offset array
         std::fill_n(
@@ -1025,7 +1026,7 @@ struct BucketList : public vtkBucketList
     }
 
     // Now group the points into contiguous runs within buckets (recall that
-    // sorting is occuring based on bin/bucket id).
+    // sorting is occurring based on bin/bucket id).
     vtkSMPTools::Sort(this->Map, this->Map + this->NumPts);
 
     // Build the offsets into the Map. The offsets are the positions of
@@ -1405,7 +1406,7 @@ void BucketList<TIds>::FindClosestNPoints(int N, const double x[3], vtkIdList* r
 }
 
 //------------------------------------------------------------------------------
-// The Radius defines a block of buckets which the sphere of radis R may
+// The Radius defines a block of buckets which the sphere of radius R may
 // touch.
 template <typename TIds>
 void BucketList<TIds>::FindPointsWithinRadius(double R, const double x[3], vtkIdList* result)
@@ -1954,23 +1955,41 @@ void vtkStaticPointLocator::FreeSearchStructure()
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkStaticPointLocator::BuildLocator()
+{
+  // don't rebuild if build time is newer than modified and dataset modified time
+  if (this->Buckets && this->BuildTime > this->MTime && this->BuildTime > this->DataSet->GetMTime())
+  {
+    return;
+  }
+  // don't rebuild if UseExistingSearchStructure is ON and a search structure already exists
+  if (this->Buckets && this->UseExistingSearchStructure)
+  {
+    this->BuildTime.Modified();
+    vtkDebugMacro(<< "BuildLocator exited - UseExistingSearchStructure");
+    return;
+  }
+  this->BuildLocatorInternal();
+}
+
+//------------------------------------------------------------------------------
+void vtkStaticPointLocator::ForceBuildLocator()
+{
+  this->BuildLocatorInternal();
+}
+
 //------------------------------------------------------------------------------
 //  Method to form subdivision of space based on the points provided and
 //  subject to the constraints of levels and NumberOfPointsPerBucket.
 //  The result is directly addressable and of uniform subdivision.
 //
-void vtkStaticPointLocator::BuildLocator()
+void vtkStaticPointLocator::BuildLocatorInternal()
 {
   int ndivs[3];
   int i;
   vtkIdType numPts;
 
-  if ((this->Buckets != nullptr) && (this->BuildTime > this->MTime) &&
-    (this->BuildTime > this->DataSet->GetMTime()))
-  {
-    return;
-  }
-
   vtkDebugMacro(<< "Hashing points...");
   this->Level = 1; // only single lowest level - from superclass
 
@@ -1981,11 +2000,7 @@ void vtkStaticPointLocator::BuildLocator()
   }
 
   //  Make sure the appropriate data is available
-  //
-  if (this->Buckets)
-  {
-    this->FreeSearchStructure();
-  }
+  this->FreeSearchStructure();
 
   // Size the root bucket.  Initialize bucket data structure, compute
   // level and divisions. The GetBounds() method below can be very slow;
@@ -2018,7 +2033,6 @@ void vtkStaticPointLocator::BuildLocator()
     static_cast<vtkIdType>(ndivs[1]) * static_cast<vtkIdType>(ndivs[2]);
 
   //  Compute width of bucket in three directions
-  //
   for (i = 0; i < 3; i++)
   {
     this->H[i] = (this->Bounds[2 * i + 1] - this->Bounds[2 * i]) / static_cast<double>(ndivs[i]);
@@ -2027,7 +2041,6 @@ void vtkStaticPointLocator::BuildLocator()
   // Instantiate the locator. The type is related to the maximum point id.
   // This is done for performance (e.g., the sort is faster) and significant
   // memory savings.
-  //
   if (numPts >= VTK_INT_MAX || numBuckets >= VTK_INT_MAX)
   {
     this->LargeIds = true;
@@ -2049,15 +2062,17 @@ void vtkStaticPointLocator::BuildLocator()
 //  Method to form subdivision of space based on the points provided and
 //  subject to the constraints of levels and NumberOfPointsPerBucket.
 //  The result is directly addressable and of uniform subdivision.
-//
+
 void vtkStaticPointLocator::BuildLocator(const double* inBounds)
 {
   int ndivs[3];
   int i;
   vtkIdType numPts;
 
-  if ((this->Buckets != nullptr) && (this->BuildTime > this->MTime) &&
-    (this->BuildTime > this->DataSet->GetMTime()))
+  // don't rebuild if build time is newer than modified and dataset modified time
+  if (this->Buckets &&
+    (this->UseExistingSearchStructure ||
+      (this->BuildTime > this->MTime && this->BuildTime > this->DataSet->GetMTime())))
   {
     return;
   }
@@ -2379,3 +2394,4 @@ void vtkStaticPointLocator::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Traversal Order: " << (this->TraversalOrder ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
