@@ -30,6 +30,7 @@
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStaticPointLocator2D);
 
 // There are stack-allocated bucket neighbor lists. This is the initial
@@ -540,7 +541,7 @@ struct BucketList2D : public vtkBucketList2D
       {
         for (; curPt->Bucket == prevPt->Bucket && curPt <= endBatchPt; ++curPt)
         {
-          ; // advance
+          // advance
         }
         // Fill in any gaps in the offset array
         std::fill_n(
@@ -1090,7 +1091,7 @@ FOUND_N:
 }
 
 //------------------------------------------------------------------------------
-// The Radius defines a block of buckets which the sphere of radis R may
+// The Radius defines a block of buckets which the sphere of radius R may
 // touch.
 template <typename TIds>
 void BucketList2D<TIds>::FindPointsWithinRadius(double R, const double x[3], vtkIdList* result)
@@ -1739,23 +1740,41 @@ void vtkStaticPointLocator2D::FreeSearchStructure()
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkStaticPointLocator2D::BuildLocator()
+{
+  // don't rebuild if build time is newer than modified and dataset modified time
+  if (this->Buckets && this->BuildTime > this->MTime && this->BuildTime > this->DataSet->GetMTime())
+  {
+    return;
+  }
+  // don't rebuild if UseExistingSearchStructure is ON and a search structure already exists
+  if (this->Buckets && this->UseExistingSearchStructure)
+  {
+    this->BuildTime.Modified();
+    vtkDebugMacro(<< "BuildLocator exited - UseExistingSearchStructure");
+    return;
+  }
+  this->BuildLocatorInternal();
+}
+
+//------------------------------------------------------------------------------
+void vtkStaticPointLocator2D::ForceBuildLocator()
+{
+  this->BuildLocatorInternal();
+}
+
 //------------------------------------------------------------------------------
 //  Method to form subdivision of space based on the points provided and
 //  subject to the constraints of levels and NumberOfPointsPerBucket.
 //  The result is directly addressable and of uniform subdivision.
 //
-void vtkStaticPointLocator2D::BuildLocator()
+void vtkStaticPointLocator2D::BuildLocatorInternal()
 {
   int ndivs[3];
   int i;
   vtkIdType numPts;
 
-  if ((this->Buckets != nullptr) && (this->BuildTime > this->MTime) &&
-    (this->BuildTime > this->DataSet->GetMTime()))
-  {
-    return;
-  }
-
   vtkDebugMacro(<< "Hashing points...");
   this->Level = 1; // only single lowest level - from superclass
 
@@ -2068,3 +2087,4 @@ void vtkStaticPointLocator2D::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Large IDs: " << this->LargeIds << "\n";
 }
+VTK_ABI_NAMESPACE_END
