@@ -32,7 +32,9 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
+class vtkUnsignedCharArray;
 
 #define VTK_UNCHANGED 0
 #define VTK_SINGLE_POINT 1
@@ -49,8 +51,9 @@ class VTKCOMMONDATAMODEL_EXPORT vtkStructuredData : public vtkObject
 {
 public:
   vtkTypeMacro(vtkStructuredData, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the dimensions of a regular, rectangular dataset. The input is
    * the new dimensions (inDim) and the current dimensions (dim). The function
@@ -58,26 +61,26 @@ public:
    * improperly specified a -1 is returned. If the dimensions are unchanged, a
    * value of 100 is returned.
    */
-  static int SetDimensions(int inDim[3], int dim[3]);
-  static int SetExtent(int inExt[6], int ext[6]);
-  //@}
+  static int SetDimensions(VTK_FUTURE_CONST int inDim[3], int dim[3]);
+  static int SetExtent(VTK_FUTURE_CONST int inExt[6], int ext[6]);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Returns the data description given the dimensions (eg. VTK_SINGLE_POINT,
    * VTK_X_LINE, VTK_XY_PLANE etc.)
    */
   static int GetDataDescription(int dims[3]);
   static int GetDataDescriptionFromExtent(int ext[6]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return the topological dimension of the data (e.g., 0, 1, 2, or 3D).
    */
   static int GetDataDimension(int dataDescription);
   static int GetDataDimension(int ext[6]);
-  //@}
+  ///@}
 
   /**
    * Given the grid extent, this method returns the total number of points
@@ -108,6 +111,18 @@ public:
   static void GetDimensionsFromExtent(
     const int ext[6], int dims[3], int dataDescription = VTK_EMPTY);
 
+  /**
+   * Return non-zero value if specified point is visible.
+   */
+  static bool IsPointVisible(vtkIdType cellId, vtkUnsignedCharArray* ghosts);
+
+  /**
+   * Return non-zero value if specified cell is visible.
+   */
+  static bool IsCellVisible(vtkIdType cellId, VTK_FUTURE_CONST int dimensions[3],
+    int dataDescription, vtkUnsignedCharArray* cellGhostArray,
+    vtkUnsignedCharArray* pointGhostArray = nullptr);
+
   /**
    * Returns the cell dimensions, i.e., the number of cells along the i,j,k
    * for the grid with the given grid extent. Note, the grid extent is the
@@ -149,7 +164,7 @@ public:
   /**
    * Get the cells using a point. (See vtkDataSet for more info.)
    */
-  static void GetPointCells(vtkIdType ptId, vtkIdList* cellIds, int dim[3]);
+  static void GetPointCells(vtkIdType ptId, vtkIdList* cellIds, VTK_FUTURE_CONST int dim[3]);
 
   /**
    * Get the cells using the points ptIds, exclusive of the cell cellId.
@@ -242,7 +257,7 @@ protected:
     return ((static_cast<vtkIdType>(k) * N2 + j) * N1 + i);
   }
 
-  //@{
+  ///@{
   /**
    * Returns the structured coordinates (i,j,k) for the given linear index of
    * a grid with N1 and N2 dimensions along its principal directions.
@@ -257,7 +272,7 @@ protected:
     j = static_cast<int>((idx - k * N12) / N1);
     i = static_cast<int>(idx - k * N12 - j * N1);
   }
-  //@}
+  ///@}
 
   // Want to avoid importing <algorithm> in the header...
   template <typename T>
@@ -431,6 +446,5 @@ inline void vtkStructuredData::ComputePointStructuredCoordsForExtent(
   vtkStructuredData::GetGlobalStructuredCoordinates(lijk, ext, ijk);
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkStructuredData.h
