@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkStructuredGrid.h"
 
 #include "vtkCellData.h"
@@ -32,12 +29,10 @@
 #include "vtkUnsignedCharArray.h"
 #include "vtkVertex.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStructuredGrid);
 vtkStandardExtendedNewMacro(vtkStructuredGrid);
 
-unsigned char vtkStructuredGrid::MASKED_CELL_VALUE =
-  vtkDataSetAttributes::HIDDENCELL | vtkDataSetAttributes::REFINEDCELL;
-
 #define vtkAdjustBoundsMacro(A, B)                                                                 \
   A[0] = (B[0] < A[0] ? B[0] : A[0]);                                                              \
   A[1] = (B[0] > A[1] ? B[0] : A[1]);                                                              \
@@ -46,6 +41,7 @@ unsigned char vtkStructuredGrid::MASKED_CELL_VALUE =
   A[4] = (B[2] < A[4] ? B[2] : A[4]);                                                              \
   A[5] = (B[2] > A[5] ? B[2] : A[5])
 
+//------------------------------------------------------------------------------
 vtkStructuredGrid::vtkStructuredGrid()
 {
   this->Vertex = vtkVertex::New();
@@ -54,13 +50,16 @@ vtkStructuredGrid::vtkStructuredGrid()
   this->Hexahedron = vtkHexahedron::New();
   this->EmptyCell = vtkEmptyCell::New();
 
-  this->Dimensions[0] = 0;
-  this->Dimensions[1] = 0;
-  this->Dimensions[2] = 0;
+#if !defined(VTK_LEGACY_REMOVE)
+  this->Dimensions[0] = 0.0;
+  this->Dimensions[1] = 0.0;
+  this->Dimensions[2] = 0.0;
+#endif
+
   this->DataDescription = VTK_EMPTY;
 
-  int extent[6] = { 0, -1, 0, -1, 0, -1 };
-  memcpy(this->Extent, extent, 6 * sizeof(int));
+  const int extent[6] = { 0, -1, 0, -1, 0, -1 };
+  memcpy(this->Extent, extent, sizeof(extent));
 
   this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_3D_EXTENT);
   this->Information->Set(vtkDataObject::DATA_EXTENT(), this->Extent, 6);
@@ -81,13 +80,15 @@ vtkStructuredGrid::~vtkStructuredGrid()
 void vtkStructuredGrid::CopyStructure(vtkDataSet* ds)
 {
   vtkStructuredGrid* sg = static_cast<vtkStructuredGrid*>(ds);
-  vtkPointSet::CopyStructure(ds);
-  int i;
+  Superclass::CopyStructure(ds);
 
-  for (i = 0; i < 3; i++)
+#if !defined(VTK_LEGACY_REMOVE)
+  for (int i = 0; i < 3; i++)
   {
     this->Dimensions[i] = sg->Dimensions[i];
   }
+#endif
+
   this->SetExtent(sg->GetExtent());
 
   this->DataDescription = sg->DataDescription;
@@ -96,13 +97,11 @@ void vtkStructuredGrid::CopyStructure(vtkDataSet* ds)
   {
     // there is blanking
     this->GetPointData()->AddArray(ds->GetPointGhostArray());
-    this->PointGhostArray = nullptr;
   }
   if (ds->HasAnyBlankCells())
   {
     // there is blanking
     this->GetCellData()->AddArray(ds->GetCellGhostArray());
-    this->CellGhostArray = nullptr;
   }
 }
 
@@ -153,14 +152,45 @@ int vtkStructuredGrid::GetCellType(vtkIdType cellId)
   }
 }
 
+//------------------------------------------------------------------------------
+vtkIdType vtkStructuredGrid::GetCellSize(vtkIdType cellId)
+{
+  // see whether the cell is blanked
+  if (!this->IsCellVisible(cellId))
+  {
+    return 0;
+  }
+
+  switch (this->DataDescription)
+  {
+    case VTK_EMPTY:
+      return 0;
+
+    case VTK_SINGLE_POINT:
+      return 1;
+
+    case VTK_X_LINE:
+    case VTK_Y_LINE:
+    case VTK_Z_LINE:
+      return 2;
+
+    case VTK_XY_PLANE:
+    case VTK_YZ_PLANE:
+    case VTK_XZ_PLANE:
+      return 4;
+
+    case VTK_XYZ_GRID:
+      return 8;
+
+    default:
+      vtkErrorMacro(<< "Bad data description!");
+      return 0;
+  }
+}
+
 //------------------------------------------------------------------------------
 vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
 {
-  vtkCell* cell = nullptr;
-  vtkIdType idx;
-  int i, j, k;
-  int d01, offset1, offset2;
-
   // Make sure data is defined
   if (!this->Points)
   {
@@ -168,15 +198,21 @@ vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
     return nullptr;
   }
 
+  // Get dimensions
+  int dims[3];
+  this->GetDimensions(dims);
+
+  vtkCell* cell = nullptr;
+  vtkIdType idx;
+  int i, j, k;
+  int d01, offset1, offset2;
+
   // see whether the cell is blanked
   if (!this->IsCellVisible(cellId))
   {
     return this->EmptyCell;
   }
 
-  // Update dimensions
-  this->GetDimensions();
-
   switch (this->DataDescription)
   {
     case VTK_EMPTY:
@@ -207,11 +243,11 @@ vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
 
     case VTK_XY_PLANE:
       cell = this->Quad;
-      i = cellId % (this->Dimensions[0] - 1);
-      j = cellId / (this->Dimensions[0] - 1);
-      idx = i + j * this->Dimensions[0];
+      i = cellId % (dims[0] - 1);
+      j = cellId / (dims[0] - 1);
+      idx = i + j * dims[0];
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -221,11 +257,11 @@ vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
 
     case VTK_YZ_PLANE:
       cell = this->Quad;
-      j = cellId % (this->Dimensions[1] - 1);
-      k = cellId / (this->Dimensions[1] - 1);
-      idx = j + k * this->Dimensions[1];
+      j = cellId % (dims[1] - 1);
+      k = cellId / (dims[1] - 1);
+      idx = j + k * dims[1];
       offset1 = 1;
-      offset2 = this->Dimensions[1];
+      offset2 = dims[1];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -235,11 +271,11 @@ vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
 
     case VTK_XZ_PLANE:
       cell = this->Quad;
-      i = cellId % (this->Dimensions[0] - 1);
-      k = cellId / (this->Dimensions[0] - 1);
-      idx = i + k * this->Dimensions[0];
+      i = cellId % (dims[0] - 1);
+      k = cellId / (dims[0] - 1);
+      idx = i + k * dims[0];
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -249,13 +285,13 @@ vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
 
     case VTK_XYZ_GRID:
       cell = this->Hexahedron;
-      d01 = this->Dimensions[0] * this->Dimensions[1];
-      i = cellId % (this->Dimensions[0] - 1);
-      j = (cellId / (this->Dimensions[0] - 1)) % (this->Dimensions[1] - 1);
-      k = cellId / ((this->Dimensions[0] - 1) * (this->Dimensions[1] - 1));
-      idx = i + j * this->Dimensions[0] + k * d01;
+      d01 = dims[0] * dims[1];
+      i = cellId % (dims[0] - 1);
+      j = (cellId / (dims[0] - 1)) % (dims[1] - 1);
+      k = cellId / ((dims[0] - 1) * (dims[1] - 1));
+      idx = i + j * dims[0] + k * d01;
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -287,11 +323,6 @@ vtkCell* vtkStructuredGrid::GetCell(vtkIdType cellId)
 //------------------------------------------------------------------------------
 vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
 {
-  vtkIdType cellId = i + (j + (k * (this->Dimensions[1] - 1))) * (this->Dimensions[0] - 1);
-  vtkCell* cell = nullptr;
-  vtkIdType idx;
-  int d01, offset1, offset2;
-
   // Make sure data is defined
   if (!this->Points)
   {
@@ -299,15 +330,21 @@ vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
     return nullptr;
   }
 
+  // Get dimensions
+  int dims[3];
+  this->GetDimensions(dims);
+
+  vtkIdType cellId = i + (j + (k * (dims[1] - 1))) * (dims[0] - 1);
+  vtkCell* cell = nullptr;
+  vtkIdType idx;
+  int d01, offset1, offset2;
+
   // see whether the cell is blanked
   if (!this->IsCellVisible(cellId))
   {
     return this->EmptyCell;
   }
 
-  // Update dimensions
-  this->GetDimensions();
-
   switch (this->DataDescription)
   {
     case VTK_EMPTY:
@@ -338,9 +375,9 @@ vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
 
     case VTK_XY_PLANE:
       cell = this->Quad;
-      idx = i + j * this->Dimensions[0];
+      idx = i + j * dims[0];
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -350,9 +387,9 @@ vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
 
     case VTK_YZ_PLANE:
       cell = this->Quad;
-      idx = j + k * this->Dimensions[1];
+      idx = j + k * dims[1];
       offset1 = 1;
-      offset2 = this->Dimensions[1];
+      offset2 = dims[1];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -362,9 +399,9 @@ vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
 
     case VTK_XZ_PLANE:
       cell = this->Quad;
-      idx = i + k * this->Dimensions[0];
+      idx = i + k * dims[0];
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -374,10 +411,10 @@ vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
 
     case VTK_XYZ_GRID:
       cell = this->Hexahedron;
-      d01 = this->Dimensions[0] * this->Dimensions[1];
-      idx = i + j * this->Dimensions[0] + k * d01;
+      d01 = dims[0] * dims[1];
+      idx = i + j * dims[0] + k * d01;
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -409,17 +446,22 @@ vtkCell* vtkStructuredGrid::GetCell(int i, int j, int k)
 //------------------------------------------------------------------------------
 void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
 {
-  vtkIdType idx;
-  int i, j, k;
-  int d01, offset1, offset2;
-  double x[3];
-
   // Make sure data is defined
   if (!this->Points)
   {
     vtkErrorMacro(<< "No data");
+    return;
   }
 
+  // Get dimensions
+  int dims[3];
+  this->GetDimensions(dims);
+
+  vtkIdType idx;
+  int i, j, k;
+  int d01, offset1, offset2;
+  double x[3];
+
   // see whether the cell is blanked
   if (!this->IsCellVisible(cellId))
   {
@@ -427,9 +469,6 @@ void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
     return;
   }
 
-  // Update dimensions
-  this->GetDimensions();
-
   switch (this->DataDescription)
   {
     case VTK_EMPTY:
@@ -461,11 +500,11 @@ void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
 
     case VTK_XY_PLANE:
       cell->SetCellTypeToQuad();
-      i = cellId % (this->Dimensions[0] - 1);
-      j = cellId / (this->Dimensions[0] - 1);
-      idx = i + j * this->Dimensions[0];
+      i = cellId % (dims[0] - 1);
+      j = cellId / (dims[0] - 1);
+      idx = i + j * dims[0];
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -475,11 +514,11 @@ void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
 
     case VTK_YZ_PLANE:
       cell->SetCellTypeToQuad();
-      j = cellId % (this->Dimensions[1] - 1);
-      k = cellId / (this->Dimensions[1] - 1);
-      idx = j + k * this->Dimensions[1];
+      j = cellId % (dims[1] - 1);
+      k = cellId / (dims[1] - 1);
+      idx = j + k * dims[1];
       offset1 = 1;
-      offset2 = this->Dimensions[1];
+      offset2 = dims[1];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -489,11 +528,11 @@ void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
 
     case VTK_XZ_PLANE:
       cell->SetCellTypeToQuad();
-      i = cellId % (this->Dimensions[0] - 1);
-      k = cellId / (this->Dimensions[0] - 1);
-      idx = i + k * this->Dimensions[0];
+      i = cellId % (dims[0] - 1);
+      k = cellId / (dims[0] - 1);
+      idx = i + k * dims[0];
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -503,13 +542,13 @@ void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
 
     case VTK_XYZ_GRID:
       cell->SetCellTypeToHexahedron();
-      d01 = this->Dimensions[0] * this->Dimensions[1];
-      i = cellId % (this->Dimensions[0] - 1);
-      j = (cellId / (this->Dimensions[0] - 1)) % (this->Dimensions[1] - 1);
-      k = cellId / ((this->Dimensions[0] - 1) * (this->Dimensions[1] - 1));
-      idx = i + j * this->Dimensions[0] + k * d01;
+      d01 = dims[0] * dims[1];
+      i = cellId % (dims[0] - 1);
+      j = (cellId / (dims[0] - 1)) % (dims[1] - 1);
+      k = cellId / ((dims[0] - 1) * (dims[1] - 1));
+      idx = i + j * dims[0] + k * d01;
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       cell->PointIds->SetId(0, idx);
       cell->PointIds->SetId(1, idx + offset1);
@@ -539,13 +578,6 @@ void vtkStructuredGrid::GetCell(vtkIdType cellId, vtkGenericCell* cell)
 // constructing a cell.
 void vtkStructuredGrid::GetCellBounds(vtkIdType cellId, double bounds[6])
 {
-  vtkIdType idx = 0;
-  int i, j, k;
-  vtkIdType d01;
-  int offset1 = 0;
-  int offset2 = 0;
-  double x[3];
-
   // Make sure data is defined
   if (!this->Points)
   {
@@ -553,10 +585,18 @@ void vtkStructuredGrid::GetCellBounds(vtkIdType cellId, double bounds[6])
     return;
   }
 
-  vtkMath::UninitializeBounds(bounds);
+  // Get dimensions
+  int dims[3];
+  this->GetDimensions(dims);
 
-  // Update dimensions
-  this->GetDimensions();
+  vtkIdType idx = 0;
+  int i, j, k;
+  vtkIdType d01;
+  int offset1 = 0;
+  int offset2 = 0;
+  double x[3];
+
+  vtkMath::UninitializeBounds(bounds);
 
   switch (this->DataDescription)
   {
@@ -586,27 +626,27 @@ void vtkStructuredGrid::GetCellBounds(vtkIdType cellId, double bounds[6])
     case VTK_XZ_PLANE:
       if (this->DataDescription == VTK_XY_PLANE)
       {
-        i = cellId % (this->Dimensions[0] - 1);
-        j = cellId / (this->Dimensions[0] - 1);
-        idx = i + j * this->Dimensions[0];
+        i = cellId % (dims[0] - 1);
+        j = cellId / (dims[0] - 1);
+        idx = i + j * dims[0];
         offset1 = 1;
-        offset2 = this->Dimensions[0];
+        offset2 = dims[0];
       }
       else if (this->DataDescription == VTK_YZ_PLANE)
       {
-        j = cellId % (this->Dimensions[1] - 1);
-        k = cellId / (this->Dimensions[1] - 1);
-        idx = j + k * this->Dimensions[1];
+        j = cellId % (dims[1] - 1);
+        k = cellId / (dims[1] - 1);
+        idx = j + k * dims[1];
         offset1 = 1;
-        offset2 = this->Dimensions[1];
+        offset2 = dims[1];
       }
       else if (this->DataDescription == VTK_XZ_PLANE)
       {
-        i = cellId % (this->Dimensions[0] - 1);
-        k = cellId / (this->Dimensions[0] - 1);
-        idx = i + k * this->Dimensions[0];
+        i = cellId % (dims[0] - 1);
+        k = cellId / (dims[0] - 1);
+        idx = i + k * dims[0];
         offset1 = 1;
-        offset2 = this->Dimensions[0];
+        offset2 = dims[0];
       }
 
       this->Points->GetPoint(idx, x);
@@ -626,13 +666,13 @@ void vtkStructuredGrid::GetCellBounds(vtkIdType cellId, double bounds[6])
       break;
 
     case VTK_XYZ_GRID:
-      d01 = this->Dimensions[0] * this->Dimensions[1];
-      i = cellId % (this->Dimensions[0] - 1);
-      j = (cellId / (this->Dimensions[0] - 1)) % (this->Dimensions[1] - 1);
-      k = cellId / ((this->Dimensions[0] - 1) * (this->Dimensions[1] - 1));
-      idx = i + j * this->Dimensions[0] + k * d01;
+      d01 = dims[0] * dims[1];
+      i = cellId % (dims[0] - 1);
+      j = (cellId / (dims[0] - 1)) % (dims[1] - 1);
+      k = cellId / ((dims[0] - 1) * (dims[1] - 1));
+      idx = i + j * dims[0] + k * d01;
       offset1 = 1;
-      offset2 = this->Dimensions[0];
+      offset2 = dims[0];
 
       this->Points->GetPoint(idx, x);
       bounds[0] = bounds[1] = x[0];
@@ -718,20 +758,18 @@ void vtkStructuredGrid::UnBlankCell(vtkIdType cellId)
 //------------------------------------------------------------------------------
 unsigned char vtkStructuredGrid::IsPointVisible(vtkIdType pointId)
 {
-  vtkUnsignedCharArray* ghosts = this->GetPointGhostArray();
-  if (ghosts && (ghosts->GetValue(pointId) & vtkDataSetAttributes::HIDDENPOINT))
-  {
-    return 0;
-  }
-  return 1;
+  return vtkStructuredData::IsPointVisible(pointId, this->GetPointGhostArray());
 }
 
 //------------------------------------------------------------------------------
 void vtkStructuredGrid::GetCellDims(int cellDims[3])
 {
+  int dims[3];
+  this->GetDimensions(dims);
+
   for (int i = 0; i < 3; ++i)
   {
-    cellDims[i] = ((this->Dimensions[i] - 1) < 1) ? 1 : this->Dimensions[i] - 1;
+    cellDims[i] = ((dims[i] - 1) < 1) ? 1 : dims[i] - 1;
   }
 }
 
@@ -739,124 +777,11 @@ void vtkStructuredGrid::GetCellDims(int cellDims[3])
 // Return non-zero if the specified cell is visible (i.e., not blanked)
 unsigned char vtkStructuredGrid::IsCellVisible(vtkIdType cellId)
 {
-  vtkUnsignedCharArray* ghosts = this->GetCellGhostArray();
-  if (ghosts && (ghosts->GetValue(cellId) & MASKED_CELL_VALUE))
-  {
-    return 0;
-  }
+  int dims[3];
+  this->GetDimensions(dims);
 
-  if (!this->GetPointGhostArray())
-  {
-    return (this->DataDescription == VTK_EMPTY) ? 0 : 1;
-  }
-
-  // Update dimensions
-  this->GetDimensions();
-
-  int numIds = 0;
-  vtkIdType ptIds[8];
-  int iMin, iMax, jMin, jMax, kMin, kMax;
-  vtkIdType d01 = this->Dimensions[0] * this->Dimensions[1];
-  iMin = iMax = jMin = jMax = kMin = kMax = 0;
-
-  switch (this->DataDescription)
-  {
-    case VTK_EMPTY:
-      return 0;
-
-    case VTK_SINGLE_POINT: // cellId can only be = 0
-      numIds = 1;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      break;
-
-    case VTK_X_LINE:
-      iMin = cellId;
-      iMax = cellId + 1;
-      numIds = 2;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMax + jMin * this->Dimensions[0] + kMin * d01;
-      break;
-
-    case VTK_Y_LINE:
-      jMin = cellId;
-      jMax = cellId + 1;
-      numIds = 2;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMin + jMax * this->Dimensions[0] + kMin * d01;
-      break;
-
-    case VTK_Z_LINE:
-      kMin = cellId;
-      kMax = cellId + 1;
-      numIds = 2;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMin + jMin * this->Dimensions[0] + kMax * d01;
-      break;
-
-    case VTK_XY_PLANE:
-      iMin = cellId % (this->Dimensions[0] - 1);
-      iMax = iMin + 1;
-      jMin = cellId / (this->Dimensions[0] - 1);
-      jMax = jMin + 1;
-      numIds = 4;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMax + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[2] = iMax + jMax * this->Dimensions[0] + kMin * d01;
-      ptIds[3] = iMin + jMax * this->Dimensions[0] + kMin * d01;
-      break;
-
-    case VTK_YZ_PLANE:
-      jMin = cellId % (this->Dimensions[1] - 1);
-      jMax = jMin + 1;
-      kMin = cellId / (this->Dimensions[1] - 1);
-      kMax = kMin + 1;
-      numIds = 4;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMin + jMax * this->Dimensions[0] + kMin * d01;
-      ptIds[2] = iMin + jMax * this->Dimensions[0] + kMax * d01;
-      ptIds[3] = iMin + jMin * this->Dimensions[0] + kMax * d01;
-      break;
-
-    case VTK_XZ_PLANE:
-      iMin = cellId % (this->Dimensions[0] - 1);
-      iMax = iMin + 1;
-      kMin = cellId / (this->Dimensions[0] - 1);
-      kMax = kMin + 1;
-      numIds = 4;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMax + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[2] = iMax + jMin * this->Dimensions[0] + kMax * d01;
-      ptIds[3] = iMin + jMin * this->Dimensions[0] + kMax * d01;
-      break;
-
-    case VTK_XYZ_GRID:
-      iMin = cellId % (this->Dimensions[0] - 1);
-      iMax = iMin + 1;
-      jMin = (cellId / (this->Dimensions[0] - 1)) % (this->Dimensions[1] - 1);
-      jMax = jMin + 1;
-      kMin = cellId / ((this->Dimensions[0] - 1) * (this->Dimensions[1] - 1));
-      kMax = kMin + 1;
-      numIds = 8;
-      ptIds[0] = iMin + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[1] = iMax + jMin * this->Dimensions[0] + kMin * d01;
-      ptIds[2] = iMax + jMax * this->Dimensions[0] + kMin * d01;
-      ptIds[3] = iMin + jMax * this->Dimensions[0] + kMin * d01;
-      ptIds[4] = iMin + jMin * this->Dimensions[0] + kMax * d01;
-      ptIds[5] = iMax + jMin * this->Dimensions[0] + kMax * d01;
-      ptIds[6] = iMax + jMax * this->Dimensions[0] + kMax * d01;
-      ptIds[7] = iMin + jMax * this->Dimensions[0] + kMax * d01;
-      break;
-  }
-
-  for (int i = 0; i < numIds; i++)
-  {
-    if (!this->IsPointVisible(ptIds[i]))
-    {
-      return 0;
-    }
-  }
-
-  return 1;
+  return vtkStructuredData::IsCellVisible(
+    cellId, dims, this->DataDescription, this->GetCellGhostArray(), this->GetPointGhostArray());
 }
 
 //------------------------------------------------------------------------------
@@ -868,20 +793,21 @@ void vtkStructuredGrid::SetDimensions(int i, int j, int k)
 
 //------------------------------------------------------------------------------
 // Set dimensions of structured grid dataset.
-void vtkStructuredGrid::SetDimensions(const int dim[3])
+void vtkStructuredGrid::SetDimensions(const int dims[3])
 {
-  this->SetExtent(0, dim[0] - 1, 0, dim[1] - 1, 0, dim[2] - 1);
+  this->SetExtent(0, dims[0] - 1, 0, dims[1] - 1, 0, dims[2] - 1);
 }
 
 //------------------------------------------------------------------------------
 // Get the points defining a cell. (See vtkDataSet for more info.)
 void vtkStructuredGrid::GetCellPoints(vtkIdType cellId, vtkIdList* ptIds)
 {
-  // Update dimensions
-  this->GetDimensions();
+  // Get dimensions
+  int dims[3];
+  this->GetDimensions(dims);
 
   int iMin, iMax, jMin, jMax, kMin, kMax;
-  vtkIdType d01 = this->Dimensions[0] * this->Dimensions[1];
+  vtkIdType d01 = dims[0] * dims[1];
 
   ptIds->Reset();
   iMin = iMax = jMin = jMax = kMin = kMax = 0;
@@ -893,95 +819,93 @@ void vtkStructuredGrid::GetCellPoints(vtkIdType cellId, vtkIdList* ptIds)
 
     case VTK_SINGLE_POINT: // cellId can only be = 0
       ptIds->SetNumberOfIds(1);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
       break;
 
     case VTK_X_LINE:
       iMin = cellId;
       iMax = cellId + 1;
       ptIds->SetNumberOfIds(2);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMax + jMin * this->Dimensions[0] + kMin * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMax + jMin * dims[0] + kMin * d01);
       break;
 
     case VTK_Y_LINE:
       jMin = cellId;
       jMax = cellId + 1;
       ptIds->SetNumberOfIds(2);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMin + jMax * this->Dimensions[0] + kMin * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMin + jMax * dims[0] + kMin * d01);
       break;
 
     case VTK_Z_LINE:
       kMin = cellId;
       kMax = cellId + 1;
       ptIds->SetNumberOfIds(2);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMin + jMin * this->Dimensions[0] + kMax * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMin + jMin * dims[0] + kMax * d01);
       break;
 
     case VTK_XY_PLANE:
-      iMin = cellId % (this->Dimensions[0] - 1);
+      iMin = cellId % (dims[0] - 1);
       iMax = iMin + 1;
-      jMin = cellId / (this->Dimensions[0] - 1);
+      jMin = cellId / (dims[0] - 1);
       jMax = jMin + 1;
       ptIds->SetNumberOfIds(4);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMax + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(2, iMax + jMax * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(3, iMin + jMax * this->Dimensions[0] + kMin * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMax + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(2, iMax + jMax * dims[0] + kMin * d01);
+      ptIds->SetId(3, iMin + jMax * dims[0] + kMin * d01);
       break;
 
     case VTK_YZ_PLANE:
-      jMin = cellId % (this->Dimensions[1] - 1);
+      jMin = cellId % (dims[1] - 1);
       jMax = jMin + 1;
-      kMin = cellId / (this->Dimensions[1] - 1);
+      kMin = cellId / (dims[1] - 1);
       kMax = kMin + 1;
       ptIds->SetNumberOfIds(4);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMin + jMax * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(2, iMin + jMax * this->Dimensions[0] + kMax * d01);
-      ptIds->SetId(3, iMin + jMin * this->Dimensions[0] + kMax * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMin + jMax * dims[0] + kMin * d01);
+      ptIds->SetId(2, iMin + jMax * dims[0] + kMax * d01);
+      ptIds->SetId(3, iMin + jMin * dims[0] + kMax * d01);
       break;
 
     case VTK_XZ_PLANE:
-      iMin = cellId % (this->Dimensions[0] - 1);
+      iMin = cellId % (dims[0] - 1);
       iMax = iMin + 1;
-      kMin = cellId / (this->Dimensions[0] - 1);
+      kMin = cellId / (dims[0] - 1);
       kMax = kMin + 1;
       ptIds->SetNumberOfIds(4);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMax + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(2, iMax + jMin * this->Dimensions[0] + kMax * d01);
-      ptIds->SetId(3, iMin + jMin * this->Dimensions[0] + kMax * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMax + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(2, iMax + jMin * dims[0] + kMax * d01);
+      ptIds->SetId(3, iMin + jMin * dims[0] + kMax * d01);
       break;
 
     case VTK_XYZ_GRID:
-      iMin = cellId % (this->Dimensions[0] - 1);
+      iMin = cellId % (dims[0] - 1);
       iMax = iMin + 1;
-      jMin = (cellId / (this->Dimensions[0] - 1)) % (this->Dimensions[1] - 1);
+      jMin = (cellId / (dims[0] - 1)) % (dims[1] - 1);
       jMax = jMin + 1;
-      kMin = cellId / ((this->Dimensions[0] - 1) * (this->Dimensions[1] - 1));
+      kMin = cellId / ((dims[0] - 1) * (dims[1] - 1));
       kMax = kMin + 1;
       ptIds->SetNumberOfIds(8);
-      ptIds->SetId(0, iMin + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(1, iMax + jMin * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(2, iMax + jMax * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(3, iMin + jMax * this->Dimensions[0] + kMin * d01);
-      ptIds->SetId(4, iMin + jMin * this->Dimensions[0] + kMax * d01);
-      ptIds->SetId(5, iMax + jMin * this->Dimensions[0] + kMax * d01);
-      ptIds->SetId(6, iMax + jMax * this->Dimensions[0] + kMax * d01);
-      ptIds->SetId(7, iMin + jMax * this->Dimensions[0] + kMax * d01);
+      ptIds->SetId(0, iMin + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(1, iMax + jMin * dims[0] + kMin * d01);
+      ptIds->SetId(2, iMax + jMax * dims[0] + kMin * d01);
+      ptIds->SetId(3, iMin + jMax * dims[0] + kMin * d01);
+      ptIds->SetId(4, iMin + jMin * dims[0] + kMax * d01);
+      ptIds->SetId(5, iMax + jMin * dims[0] + kMax * d01);
+      ptIds->SetId(6, iMax + jMax * dims[0] + kMax * d01);
+      ptIds->SetId(7, iMin + jMax * dims[0] + kMax * d01);
       break;
   }
 }
 
 //------------------------------------------------------------------------------
-void vtkStructuredGrid::SetExtent(int extent[6])
+void vtkStructuredGrid::SetExtent(VTK_FUTURE_CONST int extent[6])
 {
-  int description;
-
-  description = vtkStructuredData::SetExtent(extent, this->Extent);
+  int description = vtkStructuredData::SetExtent(extent, this->Extent);
 
   if (description < 0) // improperly specified
   {
@@ -996,9 +920,10 @@ void vtkStructuredGrid::SetExtent(int extent[6])
   this->DataDescription = description;
 
   this->Modified();
-  this->Dimensions[0] = extent[1] - extent[0] + 1;
-  this->Dimensions[1] = extent[3] - extent[2] + 1;
-  this->Dimensions[2] = extent[5] - extent[4] + 1;
+
+#if !defined(VTK_LEGACY_REMOVE)
+  vtkStructuredData::GetDimensionsFromExtent(extent, this->Dimensions);
+#endif
 }
 
 //------------------------------------------------------------------------------
@@ -1016,20 +941,26 @@ void vtkStructuredGrid::SetExtent(int xMin, int xMax, int yMin, int yMax, int zM
   this->SetExtent(extent);
 }
 
+//------------------------------------------------------------------------------
+#if !defined(VTK_LEGACY_REMOVE)
 int* vtkStructuredGrid::GetDimensions()
 {
   this->GetDimensions(this->Dimensions);
   return this->Dimensions;
 }
+#endif
 
-void vtkStructuredGrid::GetDimensions(int dim[3])
+//------------------------------------------------------------------------------
+void vtkStructuredGrid::GetDimensions(int dims[3])
 {
   const int* extent = this->Extent;
-  dim[0] = extent[1] - extent[0] + 1;
-  dim[1] = extent[3] - extent[2] + 1;
-  dim[2] = extent[5] - extent[4] + 1;
+  dims[0] = extent[1] - extent[0] + 1;
+  dims[1] = extent[3] - extent[2] + 1;
+  dims[2] = extent[5] - extent[4] + 1;
 }
 
+namespace
+{
 class CellVisibility
 {
 public:
@@ -1042,12 +973,16 @@ public:
 private:
   vtkStructuredGrid* Input;
 };
+} // anonymous namespace
 
 //------------------------------------------------------------------------------
 void vtkStructuredGrid::GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds)
 {
   int numPtIds = ptIds->GetNumberOfIds();
 
+  int dims[3];
+  this->GetDimensions(dims);
+
   // Use special methods for speed
   switch (numPtIds)
   {
@@ -1058,11 +993,11 @@ void vtkStructuredGrid::GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtk
     case 1:
     case 2:
     case 4: // vertex, edge, face neighbors
-      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->GetDimensions());
+      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, dims);
       break;
 
     default:
-      this->vtkDataSet::GetCellNeighbors(cellId, ptIds, cellIds);
+      this->Superclass::GetCellNeighbors(cellId, ptIds, cellIds);
   }
 
   // If blanking, remove blanked cells.
@@ -1081,6 +1016,9 @@ void vtkStructuredGrid::GetCellNeighbors(
 {
   int numPtIds = ptIds->GetNumberOfIds();
 
+  int dims[3];
+  this->GetDimensions(dims);
+
   // Use special methods for speed
   switch (numPtIds)
   {
@@ -1091,11 +1029,11 @@ void vtkStructuredGrid::GetCellNeighbors(
     case 1:
     case 2:
     case 4: // vertex, edge, face neighbors
-      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, this->GetDimensions(), seedLoc);
+      vtkStructuredData::GetCellNeighbors(cellId, ptIds, cellIds, dims, seedLoc);
       break;
 
     default:
-      this->vtkDataSet::GetCellNeighbors(cellId, ptIds, cellIds);
+      this->Superclass::GetCellNeighbors(cellId, ptIds, cellIds);
   }
 
   // If blanking, remove blanked cells.
@@ -1111,7 +1049,7 @@ void vtkStructuredGrid::GetCellNeighbors(
 //------------------------------------------------------------------------------
 unsigned long vtkStructuredGrid::GetActualMemorySize()
 {
-  return this->vtkPointSet::GetActualMemorySize();
+  return this->Superclass::GetActualMemorySize();
 }
 
 //------------------------------------------------------------------------------
@@ -1122,7 +1060,7 @@ void vtkStructuredGrid::ShallowCopy(vtkDataObject* dataObject)
   {
     this->InternalStructuredGridCopy(grid);
   }
-  this->vtkPointSet::ShallowCopy(dataObject);
+  this->Superclass::ShallowCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
@@ -1134,24 +1072,22 @@ void vtkStructuredGrid::DeepCopy(vtkDataObject* dataObject)
   {
     this->InternalStructuredGridCopy(grid);
   }
-  this->vtkPointSet::DeepCopy(dataObject);
+  this->Superclass::DeepCopy(dataObject);
 }
 
 //------------------------------------------------------------------------------
 // This copies all the local variables (but not objects).
 void vtkStructuredGrid::InternalStructuredGridCopy(vtkStructuredGrid* src)
 {
-  int idx;
-
   this->DataDescription = src->DataDescription;
 
-  // Update dimensions
-  this->GetDimensions();
-
-  for (idx = 0; idx < 3; ++idx)
+#if !defined(VTK_LEGACY_REMOVE)
+  for (int idx = 0; idx < 3; ++idx)
   {
     this->Dimensions[idx] = src->Dimensions[idx];
   }
+#endif
+
   memcpy(this->Extent, src->GetExtent(), 6 * sizeof(int));
 }
 
@@ -1259,16 +1195,8 @@ void vtkStructuredGrid::Crop(const int* updateExtent)
   }
   else
   {
-    vtkStructuredGrid* newGrid;
-    vtkPointData *inPD, *outPD;
-    vtkCellData *inCD, *outCD;
-    int outSize, jOffset, kOffset;
-    vtkIdType idx, newId;
-    vtkPoints *newPts, *inPts;
-    int inInc1, inInc2;
-
     // Get the points.  Protect against empty data objects.
-    inPts = this->GetPoints();
+    vtkPoints* inPts = this->GetPoints();
     if (inPts == nullptr)
     {
       return;
@@ -1276,35 +1204,35 @@ void vtkStructuredGrid::Crop(const int* updateExtent)
 
     vtkDebugMacro(<< "Cropping Grid");
 
-    newGrid = vtkStructuredGrid::New();
-    inPD = this->GetPointData();
-    inCD = this->GetCellData();
-    outPD = newGrid->GetPointData();
-    outCD = newGrid->GetCellData();
+    vtkStructuredGrid* newGrid = vtkStructuredGrid::New();
+    vtkPointData* inPD = this->GetPointData();
+    vtkCellData* inCD = this->GetCellData();
+    vtkPointData* outPD = newGrid->GetPointData();
+    vtkCellData* outCD = newGrid->GetCellData();
 
     // Allocate necessary objects
     //
     newGrid->SetExtent(uExt);
-    outSize = (uExt[1] - uExt[0] + 1) * (uExt[3] - uExt[2] + 1) * (uExt[5] - uExt[4] + 1);
-    newPts = inPts->NewInstance();
+    int outSize = (uExt[1] - uExt[0] + 1) * (uExt[3] - uExt[2] + 1) * (uExt[5] - uExt[4] + 1);
+    vtkPoints* newPts = inPts->NewInstance();
     newPts->SetDataType(inPts->GetDataType());
     newPts->SetNumberOfPoints(outSize);
     outPD->CopyAllocate(inPD, outSize, outSize);
     outCD->CopyAllocate(inCD, outSize, outSize);
 
     // Traverse this data and copy point attributes to output
-    newId = 0;
-    inInc1 = (extent[1] - extent[0] + 1);
-    inInc2 = inInc1 * (extent[3] - extent[2] + 1);
+    vtkIdType newId = 0;
+    int inInc1 = (extent[1] - extent[0] + 1);
+    int inInc2 = inInc1 * (extent[3] - extent[2] + 1);
     for (k = uExt[4]; k <= uExt[5]; ++k)
     {
-      kOffset = (k - extent[4]) * inInc2;
+      int kOffset = (k - extent[4]) * inInc2;
       for (j = uExt[2]; j <= uExt[3]; ++j)
       {
-        jOffset = (j - extent[2]) * inInc1;
+        int jOffset = (j - extent[2]) * inInc1;
         for (i = uExt[0]; i <= uExt[1]; ++i)
         {
-          idx = (i - extent[0]) + jOffset + kOffset;
+          vtkIdType idx = (i - extent[0]) + jOffset + kOffset;
           newPts->SetPoint(newId, inPts->GetPoint(idx));
           outPD->CopyData(inPD, idx, newId++);
         }
@@ -1317,13 +1245,13 @@ void vtkStructuredGrid::Crop(const int* updateExtent)
     inInc2 = inInc1 * (extent[3] - extent[2]);
     for (k = uExt[4]; k < uExt[5]; ++k)
     {
-      kOffset = (k - extent[4]) * inInc2;
+      int kOffset = (k - extent[4]) * inInc2;
       for (j = uExt[2]; j < uExt[3]; ++j)
       {
-        jOffset = (j - extent[2]) * inInc1;
+        int jOffset = (j - extent[2]) * inInc1;
         for (i = uExt[0]; i < uExt[1]; ++i)
         {
-          idx = (i - extent[0]) + jOffset + kOffset;
+          vtkIdType idx = (i - extent[0]) + jOffset + kOffset;
           outCD->CopyData(inCD, idx, newId++);
         }
       }
@@ -1343,9 +1271,9 @@ void vtkStructuredGrid::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
-  int dim[3];
-  this->GetDimensions(dim);
-  os << indent << "Dimensions: (" << dim[0] << ", " << dim[1] << ", " << dim[2] << ")\n";
+  int dims[3];
+  this->GetDimensions(dims);
+  os << indent << "Dimensions: (" << dims[0] << ", " << dims[1] << ", " << dims[2] << ")\n";
 
   const int* extent = this->Extent;
   os << indent << "Extent: " << extent[0] << ", " << extent[1] << ", " << extent[2] << ", "
@@ -1392,9 +1320,9 @@ void vtkStructuredGrid::GetPoint(int i, int j, int k, double p[3], bool adjustFo
   }
   else
   {
-    int dim[3];
-    this->GetDimensions(dim);
-    id = vtkStructuredData::ComputePointId(dim, pos);
+    int dims[3];
+    this->GetDimensions(dims);
+    id = vtkStructuredData::ComputePointId(dims, pos);
   }
 
   this->GetPoint(id, p);
@@ -1403,12 +1331,13 @@ void vtkStructuredGrid::GetPoint(int i, int j, int k, double p[3], bool adjustFo
 //------------------------------------------------------------------------------
 bool vtkStructuredGrid::HasAnyBlankPoints()
 {
-  return IsAnyBitSet(this->GetPointGhostArray(), vtkDataSetAttributes::HIDDENPOINT);
+  return this->PointData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENPOINT);
 }
 
 //------------------------------------------------------------------------------
 bool vtkStructuredGrid::HasAnyBlankCells()
 {
-  int cellBlanking = IsAnyBitSet(this->GetCellGhostArray(), vtkDataSetAttributes::HIDDENCELL);
+  int cellBlanking = this->CellData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENCELL);
   return cellBlanking || this->HasAnyBlankPoints();
 }
+VTK_ABI_NAMESPACE_END
