@@ -15,6 +15,7 @@
 #include "vtkStructuredPointsCollection.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStructuredPointsCollection);
 
 //------------------------------------------------------------------------------
@@ -22,3 +23,4 @@ void vtkStructuredPointsCollection::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
