@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkTetra.h"
 
 #include "vtkCellArray.h"
@@ -32,6 +29,7 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTetra);
 
 //------------------------------------------------------------------------------
@@ -148,7 +146,7 @@ bool vtkTetra::ComputeCentroid(vtkPoints* points, const vtkIdType* pointIds, dou
   centroid[0] = centroid[1] = centroid[2] = 0.0;
   if (!pointIds)
   {
-    for (vtkIdType i = 0; i < vtkTetra::MaximumFaceSize; ++i)
+    for (vtkIdType i = 0; i < vtkTetra::NumberOfPoints; ++i)
     {
       points->GetPoint(i, p);
       centroid[0] += p[0];
@@ -158,7 +156,7 @@ bool vtkTetra::ComputeCentroid(vtkPoints* points, const vtkIdType* pointIds, dou
   }
   else
   {
-    for (vtkIdType i = 0; i < vtkTetra::MaximumFaceSize; ++i)
+    for (vtkIdType i = 0; i < vtkTetra::NumberOfPoints; ++i)
     {
       points->GetPoint(pointIds[i], p);
       centroid[0] += p[0];
@@ -166,9 +164,9 @@ bool vtkTetra::ComputeCentroid(vtkPoints* points, const vtkIdType* pointIds, dou
       centroid[2] += p[2];
     }
   }
-  centroid[0] /= vtkTetra::MaximumFaceSize;
-  centroid[1] /= vtkTetra::MaximumFaceSize;
-  centroid[2] /= vtkTetra::MaximumFaceSize;
+  centroid[0] /= vtkTetra::NumberOfPoints;
+  centroid[1] /= vtkTetra::NumberOfPoints;
+  centroid[2] /= vtkTetra::NumberOfPoints;
   return true;
 }
 
@@ -292,7 +290,7 @@ namespace
 //   |/___\|
 //   0     1
 //
-static constexpr vtkIdType edges[vtkTetra::NumberOfEdges][2] = {
+constexpr vtkIdType edges[vtkTetra::NumberOfEdges][2] = {
   { 0, 1 }, // 0
   { 1, 2 }, // 1
   { 2, 0 }, // 2
@@ -300,13 +298,13 @@ static constexpr vtkIdType edges[vtkTetra::NumberOfEdges][2] = {
   { 1, 3 }, // 4
   { 2, 3 }, // 5
 };
-static constexpr vtkIdType faces[vtkTetra::NumberOfFaces][vtkTetra::MaximumFaceSize + 1] = {
+constexpr vtkIdType faces[vtkTetra::NumberOfFaces][vtkTetra::MaximumFaceSize + 1] = {
   { 0, 1, 3, -1 }, // 0
   { 1, 2, 3, -1 }, // 1
   { 2, 0, 3, -1 }, // 2
   { 0, 2, 1, -1 }, // 3
 };
-static constexpr vtkIdType edgeToAdjacentFaces[vtkTetra::NumberOfEdges][2] = {
+constexpr vtkIdType edgeToAdjacentFaces[vtkTetra::NumberOfEdges][2] = {
   { 0, 3 }, // 0
   { 1, 3 }, // 1
   { 2, 3 }, // 2
@@ -314,43 +312,38 @@ static constexpr vtkIdType edgeToAdjacentFaces[vtkTetra::NumberOfEdges][2] = {
   { 0, 1 }, // 4
   { 1, 2 }, // 5
 };
-static constexpr vtkIdType faceToAdjacentFaces[vtkTetra::NumberOfFaces]
-                                              [vtkTetra::MaximumFaceSize] = {
-                                                { 3, 1, 2 }, // 0
-                                                { 3, 2, 0 }, // 1
-                                                { 3, 0, 1 }, // 2
-                                                { 2, 1, 0 }, // 3
-                                              };
-static constexpr vtkIdType pointToIncidentEdges[vtkTetra::NumberOfPoints]
-                                               [vtkTetra::MaximumValence] = {
-                                                 { 0, 3, 2 }, // 0
-                                                 { 0, 1, 4 }, // 1
-                                                 { 1, 2, 5 }, // 2
-                                                 { 3, 4, 5 }, // 3
-                                               };
-static constexpr vtkIdType pointToIncidentFaces[vtkTetra::NumberOfPoints]
-                                               [vtkTetra::MaximumValence] = {
-                                                 { 0, 2, 3 }, // 0
-                                                 { 3, 1, 0 }, // 1
-                                                 { 3, 2, 1 }, // 2
-                                                 { 0, 1, 2 }, // 3
-                                               };
-static constexpr vtkIdType pointToOneRingPoints[vtkTetra::NumberOfPoints]
-                                               [vtkTetra::MaximumValence] = {
-                                                 { 1, 3, 2 }, // 0
-                                                 { 0, 2, 3 }, // 1
-                                                 { 1, 0, 3 }, // 2
-                                                 { 0, 1, 2 }, // 3
-                                               };
+constexpr vtkIdType faceToAdjacentFaces[vtkTetra::NumberOfFaces][vtkTetra::MaximumFaceSize] = {
+  { 3, 1, 2 }, // 0
+  { 3, 2, 0 }, // 1
+  { 3, 0, 1 }, // 2
+  { 2, 1, 0 }, // 3
+};
+constexpr vtkIdType pointToIncidentEdges[vtkTetra::NumberOfPoints][vtkTetra::MaximumValence] = {
+  { 0, 3, 2 }, // 0
+  { 0, 1, 4 }, // 1
+  { 1, 2, 5 }, // 2
+  { 3, 4, 5 }, // 3
+};
+constexpr vtkIdType pointToIncidentFaces[vtkTetra::NumberOfPoints][vtkTetra::MaximumValence] = {
+  { 0, 2, 3 }, // 0
+  { 3, 1, 0 }, // 1
+  { 3, 2, 1 }, // 2
+  { 0, 1, 2 }, // 3
+};
+constexpr vtkIdType pointToOneRingPoints[vtkTetra::NumberOfPoints][vtkTetra::MaximumValence] = {
+  { 1, 3, 2 }, // 0
+  { 0, 2, 3 }, // 1
+  { 1, 0, 3 }, // 2
+  { 0, 1, 2 }, // 3
+};
 
-typedef int EDGE_LIST;
 struct TRIANGLE_CASES_t
 {
-  EDGE_LIST edges[7];
+  int edges[7];
 };
 using TRIANGLE_CASES = struct TRIANGLE_CASES_t;
 
-static TRIANGLE_CASES triCases[] = {
+TRIANGLE_CASES triCases[] = {
   { { -1, -1, -1, -1, -1, -1, -1 } },
   { { 3, 0, 2, -1, -1, -1, -1 } },
   { { 1, 0, 4, -1, -1, -1, -1 } },
@@ -377,7 +370,7 @@ void vtkTetra::Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPo
 {
   static const int CASE_MASK[4] = { 1, 2, 4, 8 };
   TRIANGLE_CASES* triCase;
-  EDGE_LIST* edge;
+  int* edge;
   int i, j, index, v1, v2, newCellId;
   const vtkIdType* vert;
   vtkIdType pts[3];
@@ -528,19 +521,12 @@ const vtkIdType* vtkTetra::GetFaceArray(vtkIdType faceId)
 //------------------------------------------------------------------------------
 vtkCell* vtkTetra::GetFace(int faceId)
 {
-  const vtkIdType* verts;
-
-  verts = faces[faceId];
-
-  // load point id's
-  this->Triangle->PointIds->SetId(0, this->PointIds->GetId(verts[0]));
-  this->Triangle->PointIds->SetId(1, this->PointIds->GetId(verts[1]));
-  this->Triangle->PointIds->SetId(2, this->PointIds->GetId(verts[2]));
-
-  // load coordinates
-  this->Triangle->Points->SetPoint(0, this->Points->GetPoint(verts[0]));
-  this->Triangle->Points->SetPoint(1, this->Points->GetPoint(verts[1]));
-  this->Triangle->Points->SetPoint(2, this->Points->GetPoint(verts[2]));
+  const vtkIdType* verts = ::faces[faceId];
+  for (int i = 0; i < 3; ++i)
+  {
+    this->Triangle->PointIds->SetId(i, this->PointIds->GetId(verts[i]));
+    this->Triangle->Points->SetPoint(i, this->Points->GetPoint(verts[i]));
+  }
 
   return this->Triangle;
 }
@@ -553,23 +539,15 @@ int vtkTetra::IntersectWithLine(const double p1[3], const double p2[3], double t
   double x[3], double pcoords[3], int& subId)
 {
   int intersection = 0;
-  double pt1[3], pt2[3], pt3[3];
-  double tTemp;
-  double pc[3], xTemp[3];
-  int faceNum;
 
   t = VTK_DOUBLE_MAX;
-  for (faceNum = 0; faceNum < 4; faceNum++)
+  for (int faceNum = 0; faceNum < 4; faceNum++)
   {
-    this->Points->GetPoint(faces[faceNum][0], pt1);
-    this->Points->GetPoint(faces[faceNum][1], pt2);
-    this->Points->GetPoint(faces[faceNum][2], pt3);
+    vtkCell* face = this->GetFace(faceNum);
 
-    this->Triangle->Points->SetPoint(0, pt1);
-    this->Triangle->Points->SetPoint(1, pt2);
-    this->Triangle->Points->SetPoint(2, pt3);
-
-    if (this->Triangle->IntersectWithLine(p1, p2, tol, tTemp, xTemp, pc, subId))
+    double pcTemp[3], xTemp[3];
+    double tTemp = VTK_DOUBLE_MAX;
+    if (face->IntersectWithLine(p1, p2, tol, tTemp, xTemp, pcTemp, subId))
     {
       intersection = 1;
       if (tTemp < t)
@@ -581,27 +559,27 @@ int vtkTetra::IntersectWithLine(const double p1[3], const double p2[3], double t
         switch (faceNum)
         {
           case 0:
-            pcoords[0] = pc[0];
-            pcoords[1] = pc[1];
-            pcoords[2] = 0.0;
+            pcoords[0] = pcTemp[0];
+            pcoords[1] = 0.0;
+            pcoords[2] = pcTemp[1];
             break;
 
           case 1:
-            pcoords[0] = 0.0;
-            pcoords[1] = pc[1];
-            pcoords[2] = 0.0;
+            pcoords[0] = 1.0 - pcTemp[0] - pcTemp[1];
+            pcoords[1] = pcTemp[0];
+            pcoords[2] = pcTemp[1];
             break;
 
           case 2:
-            pcoords[0] = pc[0];
-            pcoords[1] = 0.0;
-            pcoords[2] = 0.0;
+            pcoords[0] = 0.0;
+            pcoords[1] = 1 - pcTemp[0] - pcTemp[1];
+            pcoords[2] = pcTemp[1];
             break;
 
           case 3:
-            pcoords[0] = pc[0];
-            pcoords[1] = pc[1];
-            pcoords[2] = pc[2];
+            pcoords[0] = pcTemp[0];
+            pcoords[1] = pcTemp[1];
+            pcoords[2] = pcTemp[2];
             break;
         }
       }
@@ -949,16 +927,11 @@ int vtkTetra::JacobianInverse(double** inverse, double derivs[12])
   // now find the inverse
   if (vtkMath::InvertMatrix(m, inverse, 3) == 0)
   {
-#define VTK_MAX_WARNS 3
-    static int numWarns = 0;
-    if (numWarns++ < VTK_MAX_WARNS)
-    {
-      vtkErrorMacro(<< "Jacobian inverse not found");
-      vtkErrorMacro(<< "Matrix:(" << m[0][0] << "," << m[0][1] << "," << m[0][2] << " " << m[1][0]
-                    << "," << m[1][1] << "," << m[1][2] << " " << m[2][0] << "," << m[2][1] << ","
-                    << m[2][2] << ")");
-      return 0;
-    }
+    vtkErrorMacro(<< "Jacobian inverse not found"
+                  << "Matrix:(" << m[0][0] << "," << m[0][1] << "," << m[0][2] << " " << m[1][0]
+                  << "," << m[1][1] << "," << m[1][2] << " " << m[2][0] << "," << m[2][1] << ","
+                  << m[2][2] << ")");
+    return 0;
   }
 
   return 1;
@@ -1003,24 +976,6 @@ void vtkTetra::GetEdgeToAdjacentFaces(vtkIdType edgeId, const vtkIdType*& pts)
   pts = edgeToAdjacentFaces[edgeId];
 }
 
-//------------------------------------------------------------------------------
-void vtkTetra::GetEdgePoints(int edgeId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkTetra::GetEdgePoints(int, int*&), "VTK 9.0",
-    vtkTetra::GetEdgePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[edgeId]), std::end(faces[edgeId]));
-  pts = tmp.data();
-}
-
-//------------------------------------------------------------------------------
-void vtkTetra::GetFacePoints(int faceId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkTetra::GetFacePoints(int, int*&), "VTK 9.0",
-    vtkTetra::GetFacePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[faceId]), std::end(faces[faceId]));
-  pts = tmp.data();
-}
-
 //------------------------------------------------------------------------------
 void vtkTetra::GetEdgePoints(vtkIdType edgeId, const vtkIdType*& pts)
 {
@@ -1255,3 +1210,4 @@ void vtkTetra::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Triangle:\n";
   this->Triangle->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
