@@ -16,9 +16,6 @@
 // Thanks to Soeren Gebbert who developed this class and
 // integrated it into VTK 5.0.
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkTriQuadraticHexahedron.h"
 
 #include "vtkBiQuadraticQuad.h"
@@ -29,6 +26,7 @@
 #include "vtkPoints.h"
 #include "vtkQuadraticEdge.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTriQuadraticHexahedron);
 
 //------------------------------------------------------------------------------
@@ -172,8 +170,8 @@ int vtkTriQuadraticHexahedron::EvaluatePosition(const double* x, double* closest
   for (iteration = converged = 0; !converged && (iteration < VTK_HEX_MAX_ITERATION); iteration++)
   {
     //  calculate element interpolation functions and derivatives
-    this->InterpolationFunctions(pcoords, weights);
-    this->InterpolationDerivs(pcoords, derivs);
+    vtkTriQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
+    vtkTriQuadraticHexahedron::InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     for (i = 0; i < 3; i++)
@@ -240,7 +238,7 @@ int vtkTriQuadraticHexahedron::EvaluatePosition(const double* x, double* closest
     return -1;
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkTriQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
 
   if (pcoords[0] >= -0.001 && pcoords[0] <= 1.001 && pcoords[1] >= -0.001 && pcoords[1] <= 1.001 &&
     pcoords[2] >= -0.001 && pcoords[2] <= 1.001)
@@ -288,7 +286,7 @@ void vtkTriQuadraticHexahedron::EvaluateLocation(
   int i, j;
   double pt[3];
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkTriQuadraticHexahedron::InterpolationFunctions(pcoords, weights);
 
   x[0] = x[1] = x[2] = 0.0;
   for (i = 0; i < 27; i++)
@@ -448,7 +446,7 @@ void vtkTriQuadraticHexahedron::JacobianInverse(
   double x[3];
 
   // compute interpolation function derivatives
-  this->InterpolationDerivs(pcoords, derivs);
+  vtkTriQuadraticHexahedron::InterpolationDerivs(pcoords, derivs);
 
   // create Jacobian matrix
   m[0] = m0;
@@ -690,7 +688,7 @@ void vtkTriQuadraticHexahedron::InterpolationDerivs(const double pcoords[3], dou
   derivs[79] = g2r * g2s * g3t_t;
   derivs[80] = g2r * g2s * g2t_t;
 
-  // we compute derivatives in in [-1; 1] but we need them in [ 0; 1]
+  // we compute derivatives in [-1; 1] but we need them in [ 0; 1]
   for (int i = 0; i < 81; i++)
     derivs[i] *= 2;
 }
@@ -745,3 +743,4 @@ void vtkTriQuadraticHexahedron::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Scalars:\n";
   this->Scalars->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
