@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkUniformGrid.h"
 
 #include "vtkAMRBox.h"
@@ -36,6 +33,7 @@
 #include "vtkVertex.h"
 #include "vtkVoxel.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkUniformGrid);
 
 unsigned char vtkUniformGrid::MASKED_CELL_VALUE =
@@ -181,13 +179,11 @@ void vtkUniformGrid::CopyStructure(vtkDataSet* ds)
   {
     // there is blanking
     this->GetPointData()->AddArray(ds->GetPointGhostArray());
-    this->PointGhostArray = nullptr;
   }
   if (ds->HasAnyBlankCells())
   {
     // we assume there is blanking
     this->GetCellData()->AddArray(ds->GetCellGhostArray());
-    this->CellGhostArray = nullptr;
   }
 }
 
@@ -568,7 +564,7 @@ vtkIdType vtkUniformGrid::FindCell(double x[3], vtkCell* vtkNotUsed(cell),
     return -1;
   }
 
-  this->Voxel->InterpolationFunctions(pcoords, weights);
+  vtkVoxel::InterpolationFunctions(pcoords, weights);
 
   //
   //  From this location get the cell id
@@ -1079,12 +1075,13 @@ vtkUniformGrid* vtkUniformGrid::GetData(vtkInformationVector* v, int i)
 //------------------------------------------------------------------------------
 bool vtkUniformGrid::HasAnyBlankPoints()
 {
-  return IsAnyBitSet(this->GetPointGhostArray(), vtkDataSetAttributes::HIDDENPOINT);
+  return this->PointData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENPOINT);
 }
 
 //------------------------------------------------------------------------------
 bool vtkUniformGrid::HasAnyBlankCells()
 {
-  int cellBlanking = IsAnyBitSet(this->GetCellGhostArray(), vtkDataSetAttributes::HIDDENCELL);
+  int cellBlanking = this->CellData->HasAnyGhostBitSet(vtkDataSetAttributes::HIDDENCELL);
   return cellBlanking || this->HasAnyBlankPoints();
 }
+VTK_ABI_NAMESPACE_END
