@@ -30,13 +30,15 @@
 #ifndef vtkUniformHyperTreeGrid_h
 #define vtkUniformHyperTreeGrid_h
 
-#include "limits.h" // UINT_MAX
-
-#include <memory> // std::shared_ptr
+#include <algorithm> // std::min/std::max
+#include <cmath>     // std::round
+#include <limits>    // std::numeric_limits
+#include <memory>    // std::shared_ptr
 
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkHyperTreeGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDoubleArray;
 class vtkHyperTreeGridScales;
 
@@ -60,22 +62,22 @@ public:
 
   void Initialize() override;
 
-  //@{
+  ///@{
   /**
    * Set/Get origin of grid
    */
   vtkSetVector3Macro(Origin, double);
   vtkGetVector3Macro(Origin, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get scale of root cells along each direction
    */
   void SetGridScale(double, double, double);
   void SetGridScale(double*);
   vtkGetVector3Macro(GridScale, double);
-  //@}
+  ///@}
 
   /**
    * Set all scales at once when root cells are d-cubes
@@ -89,7 +91,7 @@ public:
    */
   double* GetBounds() VTK_SIZEHINT(6) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the grid coordinates in the x-direction.
    * NB: Set method deactivated in the case of uniform grids.
@@ -102,9 +104,9 @@ public:
     throw std::domain_error("Cannot use GetZCoordinates on UniformHyperTreeGrid");
   }
   */
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the grid coordinates in the y-direction.
    * NB: Set method deactivated in the case of uniform grids.
@@ -117,9 +119,9 @@ public:
     throw std::domain_error("Cannot use GetZCoordinates on UniformHyperTreeGrid");
   }
   */
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the grid coordinates in the z-direction.
    * NB: Set method deactivated in the case of uniform grids.
@@ -133,15 +135,15 @@ public:
   }
   */
   // JB A faire pour les autre Get !
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * JB Augented services on Coordinates.
    */
   void CopyCoordinates(const vtkHyperTreeGrid* output) override;
   void SetFixedCoordinates(unsigned int axis, double value) override;
-  //@}
+  ///@}
 
   /**
    * Convert the global index of a root to its Spacial coordinates origin and size.
@@ -195,41 +197,39 @@ protected:
    */
   double GridScale[3];
 
-  //@{
+  ///@{
   /**
    * Keep track of whether coordinates have been explicitly computed
    */
   bool ComputedXCoordinates;
   bool ComputedYCoordinates;
   bool ComputedZCoordinates;
-  //@}
+  ///@}
 
-  unsigned int FindDichotomicX(double value) const override
+  unsigned int FindDichotomic(double value, unsigned char dim, double tol) const
   {
-    if (value < this->Origin[0] ||
-      value > this->Origin[0] + this->GridScale[0] * (this->GetDimensions()[0] - 1))
+    unsigned int maxIdx = this->GetDimensions()[dim] - 1;
+    if (value < (this->Origin[dim] - tol) ||
+      value > (this->Origin[dim] + tol + this->GridScale[dim] * maxIdx))
     {
-      return UINT_MAX;
+      return std::numeric_limits<unsigned int>::max();
     }
-    return round((value - this->Origin[0]) / this->GridScale[0]);
+
+    long idx = std::round((value - this->Origin[dim]) / this->GridScale[dim]);
+    return std::min(std::max(idx, 0l), static_cast<long>(maxIdx));
   }
-  unsigned int FindDichotomicY(double value) const override
+
+  unsigned int FindDichotomicX(double value, double tolerance = 0.0) const override
   {
-    if (value < this->Origin[1] ||
-      value > this->Origin[1] + this->GridScale[1] * (this->GetDimensions()[1] - 1))
-    {
-      return UINT_MAX;
-    }
-    return round((value - this->Origin[1]) / this->GridScale[1]);
+    return this->FindDichotomic(value, 0, tolerance);
   }
-  unsigned int FindDichotomicZ(double value) const override
+  unsigned int FindDichotomicY(double value, double tolerance = 0.0) const override
   {
-    if (value < this->Origin[2] ||
-      value > this->Origin[2] + this->GridScale[2] * (this->GetDimensions()[2] - 1))
-    {
-      return UINT_MAX;
-    }
-    return round((value - this->Origin[2]) / this->GridScale[2]);
+    return this->FindDichotomic(value, 1, tolerance);
+  }
+  unsigned int FindDichotomicZ(double value, double tolerance = 0.0) const override
+  {
+    return this->FindDichotomic(value, 2, tolerance);
   }
 
   /**
@@ -242,4 +242,5 @@ private:
   void operator=(const vtkUniformHyperTreeGrid&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
