@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkVoxel.h"
 
 #include "vtkBox.h"
@@ -24,7 +21,6 @@
 #include "vtkDataArrayRange.h"
 #include "vtkIncrementalPointLocator.h"
 #include "vtkLine.h"
-#include "vtkMarchingCubesTriangleCases.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPixel.h"
@@ -34,6 +30,7 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkVoxel);
 
 //------------------------------------------------------------------------------
@@ -150,7 +147,7 @@ int vtkVoxel::EvaluatePosition(const double x[3], double closestPoint[3], int& s
       closestPoint[2] = x[2];
     }
     dist2 = 0.0; // inside voxel
-    this->InterpolationFunctions(pcoords, weights);
+    vtkVoxel::InterpolationFunctions(pcoords, weights);
     return 1;
   }
   else
@@ -198,7 +195,7 @@ void vtkVoxel::EvaluateLocation(
       pcoords[2] * (pt4[i] - pt1[i]);
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkVoxel::InterpolationFunctions(pcoords, weights);
 }
 
 //------------------------------------------------------------------------------
@@ -369,7 +366,7 @@ namespace
 //  0       1
 //
 
-static constexpr vtkIdType edges[vtkVoxel::NumberOfEdges][2] = {
+constexpr vtkIdType edges[vtkVoxel::NumberOfEdges][2] = {
   { 0, 1 }, // 0
   { 1, 3 }, // 1
   { 2, 3 }, // 2
@@ -384,7 +381,7 @@ static constexpr vtkIdType edges[vtkVoxel::NumberOfEdges][2] = {
   { 3, 7 }, // 11
 };
 // define in terms vtkPixel understands
-static constexpr vtkIdType faces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize + 1] = {
+constexpr vtkIdType faces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize + 1] = {
   { 2, 0, 6, 4, -1 }, // 0
   { 1, 3, 5, 7, -1 }, // 1
   { 0, 1, 4, 5, -1 }, // 2
@@ -392,7 +389,7 @@ static constexpr vtkIdType faces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceS
   { 1, 0, 3, 2, -1 }, // 4
   { 4, 5, 6, 7, -1 }, // 5
 };
-static constexpr vtkIdType edgeToAdjacentFaces[vtkVoxel::NumberOfEdges][2] = {
+constexpr vtkIdType edgeToAdjacentFaces[vtkVoxel::NumberOfEdges][2] = {
   { 2, 4 }, // 0
   { 1, 4 }, // 1
   { 3, 4 }, // 2
@@ -406,63 +403,61 @@ static constexpr vtkIdType edgeToAdjacentFaces[vtkVoxel::NumberOfEdges][2] = {
   { 0, 3 }, // 10
   { 1, 3 }, // 11
 };
-static constexpr vtkIdType faceToAdjacentFaces[vtkVoxel::NumberOfFaces]
-                                              [vtkVoxel::MaximumFaceSize] = {
-                                                { 5, 3, 4, 2 }, // 0
-                                                { 4, 3, 5, 2 }, // 1
-                                                { 4, 1, 5, 0 }, // 2
-                                                { 4, 0, 5, 1 }, // 3
-                                                { 2, 0, 3, 1 }, // 4
-                                                { 2, 1, 3, 0 }, // 5
-                                              };
-static constexpr vtkIdType pointToIncidentEdges[vtkVoxel::NumberOfPoints]
-                                               [vtkVoxel::MaximumValence] = {
-                                                 { 0, 8, 3 },  // 0
-                                                 { 0, 1, 9 },  // 1
-                                                 { 2, 3, 10 }, // 2
-                                                 { 1, 2, 11 }, // 3
-                                                 { 4, 7, 8 },  // 4
-                                                 { 4, 9, 5 },  // 5
-                                                 { 6, 10, 7 }, // 6
-                                                 { 5, 11, 6 }, // 7
-                                               };
-static constexpr vtkIdType pointToIncidentFaces[vtkVoxel::NumberOfPoints]
-                                               [vtkVoxel::MaximumValence] = {
-                                                 { 2, 0, 4 }, // 0
-                                                 { 4, 1, 2 }, // 1
-                                                 { 4, 0, 3 }, // 2
-                                                 { 4, 3, 1 }, // 3
-                                                 { 5, 0, 2 }, // 4
-                                                 { 2, 1, 5 }, // 5
-                                                 { 3, 0, 5 }, // 6
-                                                 { 1, 3, 5 }, // 7
-                                               };
-static constexpr vtkIdType pointToOneRingPoints[vtkVoxel::NumberOfPoints]
-                                               [vtkVoxel::MaximumValence] = {
-                                                 { 1, 4, 2 }, // 0
-                                                 { 0, 3, 5 }, // 1
-                                                 { 3, 0, 6 }, // 2
-                                                 { 1, 2, 7 }, // 3
-                                                 { 5, 6, 0 }, // 4
-                                                 { 4, 1, 7 }, // 5
-                                                 { 7, 2, 4 }, // 6
-                                                 { 5, 3, 6 }, // 7
-                                               };
+constexpr vtkIdType faceToAdjacentFaces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize] = {
+  { 5, 3, 4, 2 }, // 0
+  { 4, 3, 5, 2 }, // 1
+  { 4, 1, 5, 0 }, // 2
+  { 4, 0, 5, 1 }, // 3
+  { 2, 0, 3, 1 }, // 4
+  { 2, 1, 3, 0 }, // 5
+};
+constexpr vtkIdType pointToIncidentEdges[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
+  { 0, 8, 3 },  // 0
+  { 0, 1, 9 },  // 1
+  { 2, 3, 10 }, // 2
+  { 1, 2, 11 }, // 3
+  { 4, 7, 8 },  // 4
+  { 4, 9, 5 },  // 5
+  { 6, 10, 7 }, // 6
+  { 5, 11, 6 }, // 7
+};
+constexpr vtkIdType pointToIncidentFaces[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
+  { 2, 0, 4 }, // 0
+  { 4, 1, 2 }, // 1
+  { 4, 0, 3 }, // 2
+  { 4, 3, 1 }, // 3
+  { 5, 0, 2 }, // 4
+  { 2, 1, 5 }, // 5
+  { 3, 0, 5 }, // 6
+  { 1, 3, 5 }, // 7
+};
+constexpr vtkIdType pointToOneRingPoints[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
+  { 1, 4, 2 }, // 0
+  { 0, 3, 5 }, // 1
+  { 3, 0, 6 }, // 2
+  { 1, 2, 7 }, // 3
+  { 5, 6, 0 }, // 4
+  { 4, 1, 7 }, // 5
+  { 7, 2, 4 }, // 6
+  { 5, 3, 6 }, // 7
+};
 }
 
 //----------------------------------------------------------------------------
 //
 // Marching cubes case table
 //
+VTK_ABI_NAMESPACE_END
 #include "vtkMarchingCubesTriangleCases.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 void vtkVoxel::Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPointLocator* locator,
   vtkCellArray* verts, vtkCellArray* lines, vtkCellArray* polys, vtkPointData* inPd,
   vtkPointData* outPd, vtkCellData* inCd, vtkIdType cellId, vtkCellData* outCd)
 {
   static const int CASE_MASK[8] = { 1, 2, 4, 8, 16, 32, 64, 128 };
   vtkMarchingCubesTriangleCases* triCase;
-  EDGE_LIST* edge;
+  int* edge;
   int i, j, index;
   const vtkIdType* vert;
   static const int vertMap[8] = { 0, 1, 3, 2, 4, 5, 7, 6 };
@@ -588,8 +583,8 @@ vtkCell* vtkVoxel::GetFace(int faceId)
 //
 // Intersect voxel with line using "bounding box" intersection.
 //
-int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double vtkNotUsed(tol),
-  double& t, double x[3], double pcoords[3], int& subId)
+int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double tol, double& t,
+  double x[3], double pcoords[3], int& subId)
 {
   double minPt[3], maxPt[3];
   double bounds[6];
@@ -608,7 +603,7 @@ int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double v
     bounds[2 * i + 1] = maxPt[i];
   }
 
-  if (!vtkBox::IntersectBox(bounds, p1, p21, x, t))
+  if (!vtkBox::IntersectBox(bounds, p1, p21, x, t, tol))
   {
     return 0;
   }
@@ -818,24 +813,6 @@ void vtkVoxel::GetEdgeToAdjacentFaces(vtkIdType edgeId, const vtkIdType*& pts)
   pts = edgeToAdjacentFaces[edgeId];
 }
 
-//------------------------------------------------------------------------------
-void vtkVoxel::GetEdgePoints(int edgeId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkVoxel::GetEdgePoints(int, int*&), "VTK 9.0",
-    vtkVoxel::GetEdgePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[edgeId]), std::end(faces[edgeId]));
-  pts = tmp.data();
-}
-
-//------------------------------------------------------------------------------
-void vtkVoxel::GetFacePoints(int faceId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkVoxel::GetFacePoints(int, int*&), "VTK 9.0",
-    vtkVoxel::GetFacePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[faceId]), std::end(faces[faceId]));
-  pts = tmp.data();
-}
-
 //------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetEdgeToAdjacentFacesArray(vtkIdType edgeId)
 {
@@ -919,3 +896,4 @@ void vtkVoxel::PrintSelf(ostream& os, vtkIndent indent)
     os << "None\n";
   }
 }
+VTK_ABI_NAMESPACE_END
