@@ -31,6 +31,7 @@
 #include "vtkCell3D.h"
 #include "vtkCommonDataModelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLine;
 class vtkPixel;
 class vtkIncrementalPointLocator;
@@ -42,20 +43,14 @@ public:
   vtkTypeMacro(vtkVoxel, vtkCell3D);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * See vtkCell3D API for description of these methods.
    * @warning Face points of vtkVoxel are not sorted properly.
    * {pts[0], pts[1], pts[3], pts[2]} forms consecutive points of one face.
    */
   void GetEdgePoints(vtkIdType edgeId, const vtkIdType*& pts) override;
-  // @deprecated Replaced by GetEdgePoints(vtkIdType, const vtkIdType*&) as of VTK 9.0
-  VTK_DEPRECATED_IN_9_0_0("Replaced by vtkVoxel::GetEdgePoints(vtkIdType, const vtkIdType*&)")
-  void GetEdgePoints(int edgeId, int*& pts) override;
   vtkIdType GetFacePoints(vtkIdType faceId, const vtkIdType*& pts) override;
-  // @deprecated Replaced by GetFacePoints(vtkIdType, const vtkIdType*&) as of VTK 9.0
-  VTK_DEPRECATED_IN_9_0_0("Replaced by vtkVoxel::GetFacePoints(vtkIdType, const vtkIdType*&)")
-  void GetFacePoints(int faceId, int*& pts) override;
   void GetEdgeToAdjacentFaces(vtkIdType edgeId, const vtkIdType*& pts) override;
   vtkIdType GetFaceToAdjacentFaces(vtkIdType faceId, const vtkIdType*& faces) override;
   vtkIdType GetPointToIncidentEdges(vtkIdType pointId, const vtkIdType*& edges) override;
@@ -64,7 +59,7 @@ public:
   double* GetParametricCoords() override;
   bool GetCentroid(double centroid[3]) const override;
   bool IsInsideOut() override;
-  //@}
+  ///@}
 
   /**
    * Computes exact bounding sphere of this voxel.
@@ -99,7 +94,7 @@ public:
    */
   static constexpr vtkIdType MaximumValence = 3;
 
-  //@{
+  ///@{
   /**
    * See the vtkCell API for descriptions of these methods.
    */
@@ -121,7 +116,7 @@ public:
   int Triangulate(int index, vtkIdList* ptIds, vtkPoints* pts) override;
   void Derivatives(
     int subId, const double pcoords[3], const double* values, int dim, double* derivs) override;
-  //@}
+  ///@}
 
   /**
    * Inflates voxel by moving every faces by dist. Since normals are not
@@ -134,7 +129,7 @@ public:
   int Inflate(double dist) override;
 
   static void InterpolationDerivs(const double pcoords[3], double derivs[24]);
-  //@{
+  ///@{
   /**
    * Compute the interpolation functions/derivatives
    * (aka shape functions/derivatives)
@@ -147,7 +142,7 @@ public:
   {
     vtkVoxel::InterpolationDerivs(pcoords, derivs);
   }
-  //@}
+  ///@}
 
   /**
    * Compute the interpolation functions.
@@ -165,7 +160,7 @@ public:
    */
   static int* GetTriangleCases(int caseId);
 
-  //@{
+  ///@{
   /**
    * Return the ids of the vertices defining edge/face (`edgeId`/`faceId').
    * Ids are related to the cell, not to the dataset.
@@ -176,7 +171,7 @@ public:
    */
   static const vtkIdType* GetEdgeArray(vtkIdType edgeId) VTK_SIZEHINT(2);
   static const vtkIdType* GetFaceArray(vtkIdType faceId) VTK_SIZEHINT(4);
-  //@}
+  ///@}
 
   /**
    * Static method version of GetEdgeToAdjacentFaces.
@@ -220,4 +215,5 @@ private:
   vtkPixel* Pixel;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
