@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkWedge.h"
 
 #include "vtkCellArray.h"
@@ -33,11 +30,12 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkWedge);
 
 namespace
 {
-static const double VTK_DIVERGED = 1.e6;
+const double VTK_DIVERGED = 1.e6;
 //------------------------------------------------------------------------------
 // Wedge topology:
 //
@@ -51,7 +49,7 @@ static const double VTK_DIVERGED = 1.e6;
 //    |/_______\|
 //    0         1
 //
-static vtkIdType edges[vtkWedge::NumberOfEdges][2] = {
+vtkIdType edges[vtkWedge::NumberOfEdges][2] = {
   { 0, 1 }, // 0
   { 1, 2 }, // 1
   { 2, 0 }, // 2
@@ -62,14 +60,14 @@ static vtkIdType edges[vtkWedge::NumberOfEdges][2] = {
   { 1, 4 }, // 7
   { 2, 5 }, // 8
 };
-static vtkIdType faces[vtkWedge::NumberOfFaces][vtkWedge::MaximumFaceSize + 1] = {
+vtkIdType faces[vtkWedge::NumberOfFaces][vtkWedge::MaximumFaceSize + 1] = {
   { 0, 1, 2, -1, -1 }, // 0
   { 3, 5, 4, -1, -1 }, // 1
   { 0, 3, 4, 1, -1 },  // 2
   { 1, 4, 5, 2, -1 },  // 3
   { 2, 5, 3, 0, -1 },  // 4
 };
-static constexpr vtkIdType edgeToAdjacentFaces[vtkWedge::NumberOfEdges][2] = {
+constexpr vtkIdType edgeToAdjacentFaces[vtkWedge::NumberOfEdges][2] = {
   { 0, 2 }, // 0
   { 0, 3 }, // 1
   { 0, 3 }, // 2
@@ -80,42 +78,38 @@ static constexpr vtkIdType edgeToAdjacentFaces[vtkWedge::NumberOfEdges][2] = {
   { 2, 3 }, // 7
   { 3, 4 }, // 8
 };
-static constexpr vtkIdType faceToAdjacentFaces[vtkWedge::NumberOfFaces]
-                                              [vtkWedge::MaximumFaceSize] = {
-                                                { 4, 3, 2, -1 }, // 0
-                                                { 2, 3, 4, -1 }, // 1
-                                                { 0, 3, 1, 4 },  // 2
-                                                { 0, 4, 1, 2 },  // 3
-                                                { 0, 2, 1, 3 },  // 4
-                                              };
-static constexpr vtkIdType pointToIncidentEdges[vtkWedge::NumberOfPoints]
-                                               [vtkWedge::MaximumValence] = {
-                                                 { 0, 6, 2 }, // 0
-                                                 { 0, 1, 7 }, // 1
-                                                 { 1, 2, 8 }, // 2
-                                                 { 3, 5, 6 }, // 3
-                                                 { 3, 7, 4 }, // 4
-                                                 { 4, 8, 5 }, // 5
-                                               };
-static constexpr vtkIdType pointToIncidentFaces[vtkWedge::NumberOfPoints]
-                                               [vtkWedge::MaximumValence] = {
-                                                 { 2, 4, 0 }, // 0
-                                                 { 0, 3, 2 }, // 1
-                                                 { 0, 4, 3 }, // 2
-                                                 { 1, 4, 2 }, // 3
-                                                 { 2, 3, 1 }, // 4
-                                                 { 3, 4, 1 }, // 5
-                                               };
-static constexpr vtkIdType pointToOneRingPoints[vtkWedge::NumberOfPoints]
-                                               [vtkWedge::MaximumValence] = {
-                                                 { 1, 3, 2 }, // 0
-                                                 { 0, 2, 4 }, // 1
-                                                 { 1, 0, 5 }, // 2
-                                                 { 4, 5, 0 }, // 3
-                                                 { 3, 1, 5 }, // 4
-                                                 { 4, 2, 3 }, // 5
-                                               };
-static constexpr vtkIdType numberOfPointsInFace[vtkWedge::NumberOfFaces] = {
+constexpr vtkIdType faceToAdjacentFaces[vtkWedge::NumberOfFaces][vtkWedge::MaximumFaceSize] = {
+  { 4, 3, 2, -1 }, // 0
+  { 2, 3, 4, -1 }, // 1
+  { 0, 3, 1, 4 },  // 2
+  { 0, 4, 1, 2 },  // 3
+  { 0, 2, 1, 3 },  // 4
+};
+constexpr vtkIdType pointToIncidentEdges[vtkWedge::NumberOfPoints][vtkWedge::MaximumValence] = {
+  { 0, 6, 2 }, // 0
+  { 0, 1, 7 }, // 1
+  { 1, 2, 8 }, // 2
+  { 3, 5, 6 }, // 3
+  { 3, 7, 4 }, // 4
+  { 4, 8, 5 }, // 5
+};
+constexpr vtkIdType pointToIncidentFaces[vtkWedge::NumberOfPoints][vtkWedge::MaximumValence] = {
+  { 2, 4, 0 }, // 0
+  { 0, 3, 2 }, // 1
+  { 0, 4, 3 }, // 2
+  { 1, 4, 2 }, // 3
+  { 2, 3, 1 }, // 4
+  { 3, 4, 1 }, // 5
+};
+constexpr vtkIdType pointToOneRingPoints[vtkWedge::NumberOfPoints][vtkWedge::MaximumValence] = {
+  { 1, 3, 2 }, // 0
+  { 0, 2, 4 }, // 1
+  { 1, 0, 5 }, // 2
+  { 4, 5, 0 }, // 3
+  { 3, 1, 5 }, // 4
+  { 4, 2, 3 }, // 5
+};
+constexpr vtkIdType numberOfPointsInFace[vtkWedge::NumberOfFaces] = {
   3, // 0
   3, // 1
   4, // 2
@@ -225,7 +219,7 @@ int vtkWedge::EvaluatePosition(const double x[3], double closestPoint[3], int& s
   // Efficient point access
   vtkDoubleArray* pointArray = static_cast<vtkDoubleArray*>(this->Points->GetData());
   const double* pts = pointArray->GetPointer(0);
-  const double *pt0, *pt1, *pt;
+  const double *pt0, *pt1;
 
   // compute a bound on the volume to get a scale for an acceptable determinant
   double longestEdge = 0;
@@ -252,21 +246,21 @@ int vtkWedge::EvaluatePosition(const double x[3], double closestPoint[3], int& s
   for (int iteration = 0; !converged && (iteration < VTK_WEDGE_MAX_ITERATION); iteration++)
   {
     //  calculate element interpolation functions and derivatives
-    this->InterpolationFunctions(pcoords, weights);
-    this->InterpolationDerivs(pcoords, derivs);
+    vtkWedge::InterpolationFunctions(pcoords, weights);
+    vtkWedge::InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     double fcol[3] = { 0, 0, 0 }, rcol[3] = { 0, 0, 0 }, scol[3] = { 0, 0, 0 },
            tcol[3] = { 0, 0, 0 };
     for (int i = 0; i < 6; i++)
     {
-      pt = pts + 3 * i;
       for (int j = 0; j < 3; j++)
       {
-        fcol[j] += pt[j] * weights[i];
-        rcol[j] += pt[j] * derivs[i];
-        scol[j] += pt[j] * derivs[i + 6];
-        tcol[j] += pt[j] * derivs[i + 12];
+        const double coord = pts[3 * i + j];
+        fcol[j] += coord * weights[i];
+        rcol[j] += coord * derivs[i];
+        scol[j] += coord * derivs[i + 6];
+        tcol[j] += coord * derivs[i + 12];
       }
     }
 
@@ -316,7 +310,7 @@ int vtkWedge::EvaluatePosition(const double x[3], double closestPoint[3], int& s
     return -1;
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkWedge::InterpolationFunctions(pcoords, weights);
 
   if (pcoords[0] >= -0.001 && pcoords[0] <= 1.001 && pcoords[1] >= -0.001 && pcoords[1] <= 1.001 &&
     pcoords[2] >= -0.001 && pcoords[2] <= 1.001 && pcoords[0] + pcoords[1] <= 1.001)
@@ -364,7 +358,7 @@ void vtkWedge::EvaluateLocation(
   int i, j;
   double pt[3];
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkWedge::InterpolationFunctions(pcoords, weights);
 
   x[0] = x[1] = x[2] = 0.0;
   for (i = 0; i < 6; i++)
@@ -457,14 +451,13 @@ int vtkWedge::CellBoundary(int vtkNotUsed(subId), const double pcoords[3], vtkId
 
 namespace
 { // required so we don't violate ODR
-typedef int EDGE_LIST;
 struct TRIANGLE_CASES_t
 {
-  EDGE_LIST edges[13];
+  int edges[13];
 };
 using TRIANGLE_CASES = struct TRIANGLE_CASES_t;
 
-static TRIANGLE_CASES triCases[] = {
+TRIANGLE_CASES triCases[] = {
   { { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 } }, // 0
   { { 0, 6, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 } },    // 1
   { { 0, 1, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 } },    // 2
@@ -539,7 +532,7 @@ void vtkWedge::Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPo
 {
   static const int CASE_MASK[6] = { 1, 2, 4, 8, 16, 32 };
   TRIANGLE_CASES* triCase;
-  EDGE_LIST* edge;
+  int* edge;
   int i, j, index, v1, v2, newCellId;
   const vtkIdType* vert;
   vtkIdType pts[3];
@@ -981,15 +974,10 @@ int vtkWedge::JacobianInverse(const double pcoords[3], double** inverse, double
   // now find the inverse
   if (vtkMath::InvertMatrix(m, inverse, 3) == 0)
   {
-#define VTK_MAX_WARNS 3
-    static int numWarns = 0;
-    if (numWarns++ < VTK_MAX_WARNS)
-    {
-      vtkErrorMacro(<< "Jacobian inverse not found");
-      vtkErrorMacro(<< "Matrix:" << m[0][0] << " " << m[0][1] << " " << m[0][2] << m[1][0] << " "
-                    << m[1][1] << " " << m[1][2] << m[2][0] << " " << m[2][1] << " " << m[2][2]);
-      return 0;
-    }
+    vtkErrorMacro(<< "Jacobian inverse not found"
+                  << "Matrix:" << m[0][0] << " " << m[0][1] << " " << m[0][2] << m[1][0] << " "
+                  << m[1][1] << " " << m[1][2] << m[2][0] << " " << m[2][1] << " " << m[2][2]);
+    return 0;
   }
 
   return 1;
@@ -1034,24 +1022,6 @@ void vtkWedge::GetEdgeToAdjacentFaces(vtkIdType edgeId, const vtkIdType*& pts)
   pts = edgeToAdjacentFaces[edgeId];
 }
 
-//------------------------------------------------------------------------------
-void vtkWedge::GetEdgePoints(int edgeId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkWedge::GetEdgePoints(int, int*&), "VTK 9.0",
-    vtkWedge::GetEdgePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[edgeId]), std::end(faces[edgeId]));
-  pts = tmp.data();
-}
-
-//------------------------------------------------------------------------------
-void vtkWedge::GetFacePoints(int faceId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkWedge::GetFacePoints(int, int*&), "VTK 9.0",
-    vtkWedge::GetFacePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[faceId]), std::end(faces[faceId]));
-  pts = tmp.data();
-}
-
 //------------------------------------------------------------------------------
 void vtkWedge::GetEdgePoints(vtkIdType edgeId, const vtkIdType*& pts)
 {
@@ -1094,3 +1064,4 @@ void vtkWedge::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Quad:\n";
   this->Quad->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
