@@ -28,11 +28,7 @@ public:
   vtkTypeMacro(vtkTestAlgorithm, vtkPassInputTypeAlgorithm);
 
 protected:
-  vtkTestAlgorithm()
-    : Superclass()
-  {
-    this->SetNumberOfOutputPorts(2);
-  }
+  vtkTestAlgorithm() { this->SetNumberOfOutputPorts(2); }
 
   int FillInputPortInformation(int vtkNotUsed(port), vtkInformation* info) override
   {
@@ -112,7 +108,7 @@ void AddPerBlockFieldData(vtkCompositeDataSet* data)
       array->SetValue(0, iter->GetCurrentFlatIndex());
       array->SetName("compositeIndexBasedData");
       fd->AddArray(array);
-      std::cout << "Assinging field data " << iter->GetCurrentFlatIndex() << std::endl;
+      std::cout << "Assigning field data " << iter->GetCurrentFlatIndex() << std::endl;
     }
   }
 }
