@@ -35,6 +35,7 @@
 #include "vtkCommonExecutionModelModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkAlgorithmInternals;
 class vtkAlgorithmOutput;
@@ -194,6 +195,11 @@ public:
   bool UsesGarbageCollector() const override { return true; }
   ///@}
 
+  /**
+   *  Set AbortExecute Flag and update LastAbortTime.
+   */
+  void SetAbortExecuteAndUpdateTime();
+
   ///@{
   /**
    * Set/Get the AbortExecute flag for the process object. Process objects
@@ -218,6 +224,36 @@ public:
    */
   void UpdateProgress(double amount);
 
+  /**
+   * Checks to see if this filter should abort.
+   */
+  bool CheckAbort();
+
+  ///@{
+  /**
+   * Set/get a Container algorithm for this algorithm. Allows this algorithm
+   * to check to abort status of its Container algorithm as well as have access
+   * to its Container's information.
+   */
+  void SetContainerAlgorithm(vtkAlgorithm* containerAlg)
+  {
+    this->ContainerAlgorithm = containerAlg;
+  };
+  vtkAlgorithm* GetContainerAlgorithm() { return this->ContainerAlgorithm; };
+  ///@}
+
+  ///@{
+  /**
+   * Set/Get an internal variable used to communicate between the algorithm and
+   * executive. If the executive sees this value is set, it will initialize
+   * the output data and pass the ABORTED flag downstream.
+   *
+   * CheckAbort sets this value to true if the function returns true.
+   */
+  vtkSetMacro(AbortOutput, bool);
+  vtkGetMacro(AbortOutput, bool);
+  ///@}
+
   ///@{
   /**
    * Specify the shift and scale values to use to apply to the progress amount
@@ -257,7 +293,7 @@ public:
   ///@}
 
   // left public for performance since it is used in inner loops
-  vtkTypeBool AbortExecute;
+  std::atomic<vtkTypeBool> AbortExecute;
 
   /**
    * Keys used to specify input port requirements.
@@ -313,6 +349,12 @@ public:
    */
   static vtkInformationIntegerKey* CAN_HANDLE_PIECE_REQUEST();
 
+  /**
+   *
+   * \ingroup InformationKeys
+   */
+  static vtkInformationIntegerKey* ABORTED();
+
   ///@{
   /**
    * Set the input data arrays that this algorithm will
@@ -700,6 +742,13 @@ protected:
   vtkAlgorithm();
   ~vtkAlgorithm() override;
 
+  // Time stamp to store the last time any filter was aborted.
+  static vtkTimeStamp LastAbortTime;
+
+  // Time stamp to store the last time this filter checked for an
+  // abort.
+  vtkTimeStamp LastAbortCheckTime;
+
   // Keys used to indicate that input/output port information has been
   // filled.
   static vtkInformationIntegerKey* PORT_REQUIREMENTS_FILLED();
@@ -707,6 +756,12 @@ protected:
   // Arbitrary extra information associated with this algorithm
   vtkInformation* Information;
 
+  /**
+   * Checks to see if an upstream filter has been aborted. If an abort
+   * has occurred, return true.
+   */
+  bool CheckUpstreamAbort();
+
   /**
    * Fill the input port information objects for this algorithm.  This
    * is invoked by the first call to GetInputPortInformation for each
@@ -736,7 +791,7 @@ protected:
   int OutputPortIndexInRange(int index, const char* action);
 
   /**
-   * Get the assocition of the actual data array for the input array specified
+   * Get the association of the actual data array for the input array specified
    * by idx, this is only reasonable during the REQUEST_DATA pass.
    */
   int GetInputArrayAssociation(int idx, vtkInformationVector** inputVector);
@@ -895,6 +950,9 @@ private:
 
   double ProgressShift;
   double ProgressScale;
+  vtkAlgorithm* ContainerAlgorithm;
+  bool AbortOutput;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
