@@ -16,23 +16,24 @@
 
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAlgorithmOutput);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAlgorithmOutput::vtkAlgorithmOutput()
 {
   this->Producer = nullptr;
   this->Index = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAlgorithmOutput::~vtkAlgorithmOutput() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAlgorithmOutput::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  if(this->Producer)
+  if (this->Producer)
   {
     os << indent << "Producer: " << this->Producer << "\n";
   }
@@ -43,26 +44,27 @@ void vtkAlgorithmOutput::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Index: " << this->Index << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAlgorithmOutput::SetIndex(int index)
 {
   this->Index = index;
 }
 
-//----------------------------------------------------------------------------
-int vtkAlgorithmOutput::GetIndex()
+//------------------------------------------------------------------------------
+int vtkAlgorithmOutput::GetIndex() const
 {
   return this->Index;
 }
 
-//----------------------------------------------------------------------------
-vtkAlgorithm* vtkAlgorithmOutput::GetProducer()
+//------------------------------------------------------------------------------
+vtkAlgorithm* vtkAlgorithmOutput::GetProducer() const
 {
   return this->Producer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAlgorithmOutput::SetProducer(vtkAlgorithm* producer)
 {
   this->Producer = producer;
 }
+VTK_ABI_NAMESPACE_END
