@@ -25,6 +25,7 @@
 #include "vtkInformationVector.h"
 #include "vtkPointData.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCachedStreamingDemandDrivenPipeline);
 
 //------------------------------------------------------------------------------
@@ -105,6 +106,7 @@ int vtkCachedStreamingDemandDrivenPipeline ::NeedToExecuteData(
 
   // Does the superclass want to execute? We must skip our direct superclass
   // because it looks at update extents but does not know about the cache
+  // NOLINTNEXTLINE(bugprone-parent-virtual-call)
   if (this->vtkDemandDrivenPipeline::NeedToExecuteData(outputPort, inInfoVec, outInfoVec))
   {
     return 1;
@@ -272,3 +274,4 @@ int vtkCachedStreamingDemandDrivenPipeline ::ExecuteData(
 
   return result;
 }
+VTK_ABI_NAMESPACE_END
