@@ -19,7 +19,7 @@
  * vtkDemandDrivenPipeline is an executive that will execute an
  * algorithm only when its outputs are out-of-date with respect to its
  * inputs.
-*/
+ */
 
 #ifndef vtkDemandDrivenPipeline_h
 #define vtkDemandDrivenPipeline_h
@@ -27,6 +27,7 @@
 #include "vtkCommonExecutionModelModule.h" // For export macro
 #include "vtkExecutive.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkDataArray;
 class vtkDataSetAttributes;
@@ -38,53 +39,48 @@ class vtkInformationVector;
 class vtkInformationKeyVectorKey;
 class vtkInformationUnsignedLongKey;
 
-  ///\defgroup InformationKeys Information Keys
-  /// The VTK pipeline relies on algorithms providing information about their
-  /// input and output and responding to requests.  The information objects used
-  /// to perform these actions map known keys to values.  This is a list of keys
-  /// that information objects use and what each key should be used for.
-  ///
+///\defgroup InformationKeys Information Keys
+/// The VTK pipeline relies on algorithms providing information about their
+/// input and output and responding to requests.  The information objects used
+/// to perform these actions map known keys to values.  This is a list of keys
+/// that information objects use and what each key should be used for.
+///
 
 class VTKCOMMONEXECUTIONMODEL_EXPORT vtkDemandDrivenPipeline : public vtkExecutive
 {
 public:
   static vtkDemandDrivenPipeline* New();
-  vtkTypeMacro(vtkDemandDrivenPipeline,vtkExecutive);
+  vtkTypeMacro(vtkDemandDrivenPipeline, vtkExecutive);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Generalized interface for asking the executive to fulfill update
    * requests.
    */
-  vtkTypeBool ProcessRequest(vtkInformation* request,
-                             vtkInformationVector** inInfo,
-                             vtkInformationVector* outInfo) override;
+  vtkTypeBool ProcessRequest(
+    vtkInformation* request, vtkInformationVector** inInfo, vtkInformationVector* outInfo) override;
 
   /**
    * Implement the pipeline modified time request.
    */
-  int
-  ComputePipelineMTime(vtkInformation* request,
-                       vtkInformationVector** inInfoVec,
-                       vtkInformationVector* outInfoVec,
-                       int requestFromOutputPort,
-                       vtkMTimeType* mtime) override;
+  int ComputePipelineMTime(vtkInformation* request, vtkInformationVector** inInfoVec,
+    vtkInformationVector* outInfoVec, int requestFromOutputPort, vtkMTimeType* mtime) override;
 
-  //@{
+  ///@{
   /**
    * Bring the algorithm's outputs up-to-date.  Returns 1 for success
    * and 0 for failure.
    */
   vtkTypeBool Update() override;
   vtkTypeBool Update(int port) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the PipelineMTime for this exective.
    */
   vtkGetMacro(PipelineMTime, vtkMTimeType);
-  //@}
+  ///@}
 
   /**
    * Set whether the given output port releases data when it is
@@ -173,16 +169,12 @@ protected:
   ~vtkDemandDrivenPipeline() override;
 
   // Helper methods to send requests to the algorithm.
-  virtual int ExecuteDataObject(vtkInformation* request,
-                                vtkInformationVector** inInfo,
-                                vtkInformationVector* outInfo);
-  virtual int ExecuteInformation(vtkInformation* request,
-                                 vtkInformationVector** inInfo,
-                                 vtkInformationVector* outInfo);
-  virtual int ExecuteData(vtkInformation* request,
-                          vtkInformationVector** inInfo,
-                          vtkInformationVector* outInfo);
-
+  virtual int ExecuteDataObject(
+    vtkInformation* request, vtkInformationVector** inInfo, vtkInformationVector* outInfo);
+  virtual int ExecuteInformation(
+    vtkInformation* request, vtkInformationVector** inInfo, vtkInformationVector* outInfo);
+  virtual int ExecuteData(
+    vtkInformation* request, vtkInformationVector** inInfo, vtkInformationVector* outInfo);
 
   // Reset the pipeline update values in the given output information object.
   void ResetPipelineInformation(int, vtkInformation*) override;
@@ -191,16 +183,15 @@ protected:
   // output port exists and has a valid type.
   virtual int CheckDataObject(int port, vtkInformationVector* outInfo);
 
-
   // Input connection validity checkers.
-  int InputCountIsValid(vtkInformationVector **);
-  int InputCountIsValid(int port,vtkInformationVector **);
-  int InputTypeIsValid(vtkInformationVector **);
-  int InputTypeIsValid(int port,vtkInformationVector **);
-  virtual int InputTypeIsValid(int port, int index,vtkInformationVector **);
-  int InputFieldsAreValid(vtkInformationVector **);
-  int InputFieldsAreValid(int port,vtkInformationVector **);
-  virtual int InputFieldsAreValid(int port, int index,vtkInformationVector **);
+  int InputCountIsValid(vtkInformationVector**);
+  int InputCountIsValid(int port, vtkInformationVector**);
+  int InputTypeIsValid(vtkInformationVector**);
+  int InputTypeIsValid(int port, vtkInformationVector**);
+  virtual int InputTypeIsValid(int port, int index, vtkInformationVector**);
+  int InputFieldsAreValid(vtkInformationVector**);
+  int InputFieldsAreValid(int port, vtkInformationVector**);
+  virtual int InputFieldsAreValid(int port, int index, vtkInformationVector**);
 
   // Field existence checkers.
   int DataSetAttributeExists(vtkDataSetAttributes* dsa, vtkInformation* field);
@@ -212,20 +203,16 @@ protected:
   int InputIsRepeatable(int port);
 
   // Decide whether the output data need to be generated.
-  virtual int NeedToExecuteData(int outputPort,
-                                vtkInformationVector** inInfoVec,
-                                vtkInformationVector* outInfoVec);
+  virtual int NeedToExecuteData(
+    int outputPort, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec);
 
   // Handle before/after operations for ExecuteData method.
-  virtual void ExecuteDataStart(vtkInformation* request,
-                                vtkInformationVector** inInfoVec,
-                                vtkInformationVector* outInfoVec);
-  virtual void ExecuteDataEnd(vtkInformation* request,
-                              vtkInformationVector** inInfoVec,
-                              vtkInformationVector* outInfoVec);
-  virtual void MarkOutputsGenerated(vtkInformation* request,
-                                    vtkInformationVector** inInfoVec,
-                                    vtkInformationVector* outInfoVec);
+  virtual void ExecuteDataStart(
+    vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec);
+  virtual void ExecuteDataEnd(
+    vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec);
+  virtual void MarkOutputsGenerated(
+    vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec);
 
   // Largest MTime of any algorithm on this executive or preceding
   // executives.
@@ -238,13 +225,14 @@ protected:
 
   friend class vtkCompositeDataPipeline;
 
-  vtkInformation *InfoRequest;
-  vtkInformation *DataObjectRequest;
-  vtkInformation *DataRequest;
+  vtkInformation* InfoRequest;
+  vtkInformation* DataObjectRequest;
+  vtkInformation* DataRequest;
 
 private:
   vtkDemandDrivenPipeline(const vtkDemandDrivenPipeline&) = delete;
   void operator=(const vtkDemandDrivenPipeline&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
