@@ -22,14 +22,15 @@
  * as well as accept a pipeline request using the UPDATE_MEMBER key.
  * Note that it is expected that all ensemble members produce data of the
  * same type.
-*/
+ */
 
 #ifndef vtkEnsembleSource_h
 #define vtkEnsembleSource_h
 
-#include "vtkCommonExecutionModelModule.h" // For export macro
 #include "vtkAlgorithm.h"
+#include "vtkCommonExecutionModelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkEnsembleSourceInternal;
 class vtkTable;
 class vtkInformationDataObjectMetaDataKey;
@@ -39,8 +40,8 @@ class vtkInformationIntegerKey;
 class VTKCOMMONEXECUTIONMODEL_EXPORT vtkEnsembleSource : public vtkAlgorithm
 {
 public:
-  static vtkEnsembleSource *New();
-  vtkTypeMacro(vtkEnsembleSource,vtkAlgorithm);
+  static vtkEnsembleSource* New();
+  vtkTypeMacro(vtkEnsembleSource, vtkAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
@@ -60,7 +61,7 @@ public:
    */
   unsigned int GetNumberOfMembers();
 
-  //@{
+  ///@{
   /**
    * Set/Get the current ensemble member to process. Note that this data member
    * will not be used if the UPDATE_MEMBER key is present in the pipeline. Also,
@@ -69,7 +70,7 @@ public:
    */
   vtkSetMacro(CurrentMember, unsigned int);
   vtkGetMacro(CurrentMember, unsigned int);
-  //@}
+  ///@}
 
   /**
    * Set the meta-data that will be propagated downstream. Make sure that this table
@@ -96,9 +97,8 @@ protected:
 
   friend class vtkInformationEnsembleMemberRequestKey;
 
-  vtkTypeBool ProcessRequest(vtkInformation *request,
-                             vtkInformationVector **inputVector,
-                             vtkInformationVector *outputVector) override;
+  vtkTypeBool ProcessRequest(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
   int FillOutputPortInformation(int, vtkInformation*) override;
 
   vtkAlgorithm* GetCurrentReader(vtkInformation*);
@@ -113,4 +113,5 @@ private:
   void operator=(const vtkEnsembleSource&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
