@@ -33,6 +33,7 @@
 
 #include "vtkCompositeDataPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkInformationKeyMacro(vtkExecutive, ALGORITHM_AFTER_FORWARD, Integer);
 vtkInformationKeyMacro(vtkExecutive, ALGORITHM_BEFORE_FORWARD, Integer);
 vtkInformationKeyMacro(vtkExecutive, ALGORITHM_DIRECTION, Integer);
@@ -103,7 +104,7 @@ vtkInformationVector** vtkExecutiveInternals::GetInputInformation(int newNumberO
   // Return the array of information vector pointers.
   if (newNumberOfPorts > 0)
   {
-    return &this->InputInformation[0];
+    return this->InputInformation.data();
   }
   else
   {
@@ -147,18 +148,6 @@ void vtkExecutive::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-//------------------------------------------------------------------------------
-void vtkExecutive::Register(vtkObjectBase* o)
-{
-  this->RegisterInternal(o, 1);
-}
-
-//------------------------------------------------------------------------------
-void vtkExecutive::UnRegister(vtkObjectBase* o)
-{
-  this->UnRegisterInternal(o, 1);
-}
-
 //------------------------------------------------------------------------------
 void vtkExecutive::SetAlgorithm(vtkAlgorithm* newAlgorithm)
 {
@@ -271,9 +260,9 @@ vtkExecutive* vtkExecutive::GetInputExecutive(int port, int index)
   if (index < 0 || index >= this->GetNumberOfInputConnections(port))
   {
     vtkErrorMacro("Attempt to get executive for connection index "
-      << index << " on input port " << port << " of algorithm " << this->Algorithm->GetClassName()
-      << "(" << this->Algorithm << "), which has " << this->GetNumberOfInputConnections(port)
-      << " connections.");
+      << index << " on input port " << port << " of algorithm "
+      << this->Algorithm->GetObjectDescription() << ", which has "
+      << this->GetNumberOfInputConnections(port) << " connections.");
     return nullptr;
   }
   if (vtkAlgorithmOutput* input = this->Algorithm->GetInputConnection(port, index))
@@ -362,9 +351,9 @@ int vtkExecutive::InputPortIndexInRange(int port, const char* action)
   if (port < 0 || port >= this->Algorithm->GetNumberOfInputPorts())
   {
     vtkErrorMacro("Attempt to " << (action ? action : "access") << " input port index " << port
-                                << " for algorithm " << this->Algorithm->GetClassName() << "("
-                                << this->Algorithm << "), which has "
-                                << this->Algorithm->GetNumberOfInputPorts() << " input ports.");
+                                << " for algorithm " << this->Algorithm->GetObjectDescription()
+                                << ", which has " << this->Algorithm->GetNumberOfInputPorts()
+                                << " input ports.");
     return 0;
   }
   return 1;
@@ -385,9 +374,9 @@ int vtkExecutive::OutputPortIndexInRange(int port, const char* action)
   if (port < 0 || port >= this->Algorithm->GetNumberOfOutputPorts())
   {
     vtkErrorMacro("Attempt to " << (action ? action : "access") << " output port index " << port
-                                << " for algorithm " << this->Algorithm->GetClassName() << "("
-                                << this->Algorithm << "), which has "
-                                << this->Algorithm->GetNumberOfOutputPorts() << " output ports.");
+                                << " for algorithm " << this->Algorithm->GetObjectDescription()
+                                << ", which has " << this->Algorithm->GetNumberOfOutputPorts()
+                                << " output ports.");
     return 0;
   }
   return 1;
@@ -749,8 +738,8 @@ int vtkExecutive::CallAlgorithm(vtkInformation* request, int direction,
   // If the algorithm failed report it now.
   if (!result)
   {
-    vtkErrorMacro("Algorithm " << this->Algorithm->GetClassName() << "(" << this->Algorithm
-                               << ") returned failure for request: " << *request);
+    vtkErrorMacro("Algorithm " << this->Algorithm->GetObjectDescription()
+                               << " returned failure for request: " << *request);
   }
 
   return result;
@@ -768,16 +757,15 @@ int vtkExecutive::CheckAlgorithm(const char* method, vtkInformation* request)
       vtkErrorMacro(<< method
                     << " invoked during another request.  "
                        "Returning failure to algorithm "
-                    << this->Algorithm->GetClassName() << "(" << this->Algorithm
-                    << ") for the recursive request:\n"
-                    << rqmsg.str().c_str());
+                    << this->Algorithm->GetObjectDescription() << " for the recursive request:\n"
+                    << rqmsg.str());
     }
     else
     {
       vtkErrorMacro(<< method
                     << " invoked during another request.  "
                        "Returning failure to algorithm "
-                    << this->Algorithm->GetClassName() << "(" << this->Algorithm << ").");
+                    << this->Algorithm->GetObjectDescription() << ".");
     }
 
     // Tests should fail when this happens because there is a bug in
@@ -790,3 +778,22 @@ int vtkExecutive::CheckAlgorithm(const char* method, vtkInformation* request)
   }
   return 1;
 }
+
+//------------------------------------------------------------------------------
+// Look at all inputs and check ABORTED flag. If it is set, return true.
+// Otherwise return false.
+bool vtkExecutive::CheckAbortedInput(vtkInformationVector** inInfoVec)
+{
+  for (int i = 0; i < this->GetNumberOfInputPorts(); i++)
+  {
+    for (int j = 0; j < inInfoVec[i]->GetNumberOfInformationObjects(); j++)
+    {
+      if (inInfoVec[i]->GetInformationObject(j)->Get(vtkAlgorithm::ABORTED()))
+      {
+        return true;
+      }
+    }
+  }
+  return false;
+}
+VTK_ABI_NAMESPACE_END
