@@ -21,8 +21,15 @@
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExplicitStructuredGridAlgorithm);
 
+//------------------------------------------------------------------------------
+void vtkExplicitStructuredGridAlgorithm::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 vtkExplicitStructuredGridAlgorithm::vtkExplicitStructuredGridAlgorithm()
 {
@@ -172,3 +179,4 @@ int vtkExplicitStructuredGridAlgorithm::FillInputPortInformation(
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkExplicitStructuredGrid");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
