@@ -17,12 +17,12 @@
 #include "vtkInformation.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
-#include "vtkReaderExecutive.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
 #include <numeric>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkParallelReaderInternal
 {
   using FileNamesType = std::vector<std::string>;
@@ -42,12 +42,6 @@ vtkParallelReader::~vtkParallelReader()
   delete this->Internal;
 }
 
-//------------------------------------------------------------------------------
-vtkExecutive* vtkParallelReader::CreateDefaultExecutive()
-{
-  return vtkReaderExecutive::New();
-}
-
 //------------------------------------------------------------------------------
 void vtkParallelReader::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -131,7 +125,7 @@ int vtkParallelReader::ReadMetaData(vtkInformation* metadata)
   timeRange[0] = times[0];
   timeRange[1] = times[nTimes - 1];
 
-  metadata->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &times[0], (int)nTimes);
+  metadata->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), times.data(), (int)nTimes);
   metadata->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), timeRange, 2);
 
   return 1;
@@ -192,3 +186,4 @@ double vtkParallelReader::GetTimeValue(const std::string&)
 {
   return vtkMath::Nan();
 }
+VTK_ABI_NAMESPACE_END
