@@ -37,6 +37,7 @@
 #include "vtkCommonExecutionModelModule.h" // For export macro
 #include "vtkRectilinearGrid.h"            // makes things a bit easier
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkRectilinearGrid;
 
@@ -47,14 +48,14 @@ public:
   vtkTypeMacro(vtkRectilinearGridAlgorithm, vtkAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get the output data object for a port on this algorithm.
    */
   vtkRectilinearGrid* GetOutput();
   vtkRectilinearGrid* GetOutput(int);
   virtual void SetOutput(vtkDataObject* d);
-  //@}
+  ///@}
 
   /**
    * see vtkAlgorithm for details
@@ -68,7 +69,7 @@ public:
   vtkDataObject* GetInput(int port);
   vtkRectilinearGrid* GetRectilinearGridInput(int port);
 
-  //@{
+  ///@{
   /**
    * Assign a data object as input. Note that this method does not
    * establish a pipeline connection. Use SetInputConnection() to
@@ -76,9 +77,9 @@ public:
    */
   void SetInputData(vtkDataObject*);
   void SetInputData(int, vtkDataObject*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Assign a data object as input. Note that this method does not
    * establish a pipeline connection. Use AddInputConnection() to
@@ -86,7 +87,7 @@ public:
    */
   void AddInputData(vtkDataObject*);
   void AddInputData(int, vtkDataObject*);
-  //@}
+  ///@}
 
 protected:
   vtkRectilinearGridAlgorithm();
@@ -103,7 +104,7 @@ protected:
   virtual int RequestData(vtkInformation* request, vtkInformationVector** inputVector,
     vtkInformationVector* outputVector);
 
-  //@{
+  ///@{
   /**
    * This is called by the superclass.
    * This is the method you should override.
@@ -112,7 +113,7 @@ protected:
   {
     return 1;
   };
-  //@}
+  ///@}
 
   // see algorithm for more info
   int FillOutputPortInformation(int port, vtkInformation* info) override;
@@ -123,4 +124,5 @@ private:
   void operator=(const vtkRectilinearGridAlgorithm&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
