@@ -17,6 +17,7 @@
 #include "vtkCommand.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSMPProgressObserver);
 
 vtkSMPProgressObserver::vtkSMPProgressObserver() = default;
@@ -31,5 +32,6 @@ void vtkSMPProgressObserver::UpdateProgress(double progress)
 
 void vtkSMPProgressObserver::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
