@@ -17,12 +17,12 @@
 #include "vtkInformation.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
-#include "vtkReaderExecutive.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
 #include <numeric>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkSimpleReaderInternal
 {
   using FileNamesType = std::vector<std::string>;
@@ -43,12 +43,6 @@ vtkSimpleReader::~vtkSimpleReader()
   delete this->Internal;
 }
 
-//------------------------------------------------------------------------------
-vtkExecutive* vtkSimpleReader::CreateDefaultExecutive()
-{
-  return vtkReaderExecutive::New();
-}
-
 //------------------------------------------------------------------------------
 void vtkSimpleReader::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -166,7 +160,7 @@ int vtkSimpleReader::ReadMetaData(vtkInformation* metadata)
   timeRange[0] = times[0];
   timeRange[1] = times[nTimes - 1];
 
-  metadata->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &times[0], (int)nTimes);
+  metadata->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), times.data(), (int)nTimes);
   metadata->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), timeRange, 2);
 
   return 1;
@@ -245,3 +239,4 @@ double vtkSimpleReader::GetTimeValue(const std::string&)
 {
   return vtkMath::Nan();
 }
+VTK_ABI_NAMESPACE_END
