@@ -27,6 +27,7 @@
 #include "vtkUnstructuredGrid.h"
 
 // Methods and functors for processing in parallel
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 { // begin anonymous namespace
 
@@ -303,26 +304,29 @@ struct MapToSpanSpace
     cellPts->SetNumberOfIds(12);
     vtkDoubleArray*& cellScalars = this->CellScalars.Local();
     cellScalars->SetNumberOfTuples(12);
+    // required for multi thread
+    if (this->DataSet->GetNumberOfPoints() > 0)
+    {
+      this->DataSet->GetCellPoints(0, cellPts);
+    }
   }
 
   void operator()(vtkIdType cellId, vtkIdType endCellId)
   {
-    vtkIdType j, numScalars;
-    double *s, sMin, sMax;
     vtkIdList*& cellPts = this->CellPts.Local();
     vtkDoubleArray*& cellScalars = this->CellScalars.Local();
 
     for (; cellId < endCellId; ++cellId)
     {
       this->DataSet->GetCellPoints(cellId, cellPts);
-      numScalars = cellPts->GetNumberOfIds();
+      const vtkIdType numScalars = cellPts->GetNumberOfIds();
       cellScalars->SetNumberOfTuples(numScalars);
       this->Scalars->GetTuples(cellPts, cellScalars);
-      s = cellScalars->GetPointer(0);
+      const double* s = cellScalars->GetPointer(0);
 
-      sMin = VTK_DOUBLE_MAX;
-      sMax = VTK_DOUBLE_MIN;
-      for (j = 0; j < numScalars; j++)
+      double sMin = VTK_DOUBLE_MAX;
+      double sMax = VTK_DOUBLE_MIN;
+      for (vtkIdType j = 0; j < numScalars; j++)
       {
         if (s[j] < sMin)
         {
@@ -344,6 +348,12 @@ struct MapToSpanSpace
 
   static void Execute(vtkIdType numCells, vtkInternalSpanSpace* ss, vtkDataSet* ds, vtkDataArray* s)
   {
+    // required for multi thread
+    if (ds->GetNumberOfPoints() > 0)
+    {
+      vtkNew<vtkIdList> dummy;
+      ds->GetCellPoints(0, dummy);
+    }
     MapToSpanSpace map(ss, ds, s);
     vtkSMPTools::For(0, numCells, map);
   }
@@ -532,7 +542,7 @@ void vtkSpanSpace::BuildTree()
   }
   this->SpanSpace = new vtkInternalSpanSpace(this->Resolution, range[0], range[1], numCells);
 
-  // Acclerated span space construction (for unstructured grids).  Templated
+  // Accelerated span space construction (for unstructured grids).  Templated
   // over scalar type; direct access to vtkUnstructuredGrid innards.
   vtkUnstructuredGrid* ugrid = vtkUnstructuredGrid::SafeDownCast(this->DataSet);
   if (ugrid != nullptr)
@@ -627,7 +637,6 @@ vtkIdType vtkSpanSpace::GetNumberOfCellBatches(double scalarValue)
 
   // Find the rectangle in span space that spans the isovalue
   vtkInternalSpanSpace* sp = this->SpanSpace;
-  ;
   sp->GetSpanRectangle(scalarValue, this->RMin, this->RMax);
 
   // Loop over each span row to count total memory allocation required.
@@ -682,7 +691,6 @@ const vtkIdType* vtkSpanSpace::GetCellBatch(vtkIdType batchNum, vtkIdType& numCe
 {
   // Make sure that everything is hunky dory
   vtkInternalSpanSpace* sp = this->SpanSpace;
-  ;
   vtkIdType pos = batchNum * this->BatchSize;
   if (sp->NumCells < 1 || !sp->CandidateCells || pos >= sp->NumCandidates)
   {
@@ -715,3 +723,4 @@ void vtkSpanSpace::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Compute Resolution: " << (this->ComputeResolution ? "On\n" : "Off\n");
   os << indent << "Number of Cells Per Bucket: " << this->NumberOfCellsPerBucket << "\n";
 }
+VTK_ABI_NAMESPACE_END
