@@ -35,6 +35,7 @@
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSphereTree);
 vtkCxxSetObjectMacro(vtkSphereTree, DataSet, vtkDataSet);
 
@@ -358,7 +359,7 @@ struct UnstructuredSpheres : public DataSetSpheres
     vtkUnstructuredGrid* grid = static_cast<vtkUnstructuredGrid*>(this->DataSet);
     double cellPts[120], *p, r;
     vtkIdType ptNum;
-    const vtkIdType* cellIds;
+    vtkNew<vtkIdList> cellIds;
     vtkIdType numCellPts;
     double& radius = this->Radius.Local();
     vtkIdType& count = this->Count.Local();
@@ -371,12 +372,12 @@ struct UnstructuredSpheres : public DataSetSpheres
 
     for (; cellId < endCellId; ++cellId, sphere += 4)
     {
-      grid->GetCellPoints(cellId, numCellPts, cellIds);
-      numCellPts = (numCellPts < 40 ? numCellPts : 40);
+      grid->GetCellPoints(cellId, cellIds);
+      numCellPts = std::min(cellIds->GetNumberOfIds(), static_cast<vtkIdType>(40));
       p = cellPts;
       for (ptNum = 0; ptNum < numCellPts; ++ptNum, p += 3)
       {
-        grid->GetPoint(cellIds[ptNum], p);
+        grid->GetPoint(cellIds->GetId(ptNum), p);
       }
       vtkSphere::ComputeBoundingSphere(cellPts, numCellPts, sphere, nullptr);
 
@@ -1617,3 +1618,4 @@ void vtkSphereTree::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Maximum Number Of Levels: " << this->MaxLevel << "\n";
   os << indent << "Build Hierarchy: " << (this->BuildHierarchy ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
