@@ -44,12 +44,13 @@
 #include <vector>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkThreadedCompositeDataPipeline);
 
 //------------------------------------------------------------------------------
 namespace
 {
-static vtkInformationVector** Clone(vtkInformationVector** src, int n)
+vtkInformationVector** Clone(vtkInformationVector** src, int n)
 {
   vtkInformationVector** dst = new vtkInformationVector*[n];
   for (int i = 0; i < n; ++i)
@@ -59,7 +60,7 @@ static vtkInformationVector** Clone(vtkInformationVector** src, int n)
   }
   return dst;
 }
-static void DeleteAll(vtkInformationVector** dst, int n)
+void DeleteAll(vtkInformationVector** dst, int n)
 {
   for (int i = 0; i < n; ++i)
   {
@@ -124,7 +125,7 @@ public:
     , InObjs(inObjs)
   {
     int numInputPorts = this->Exec->GetNumberOfInputPorts();
-    this->OutObjs = &outObjs[0];
+    this->OutObjs = outObjs.data();
     this->InfoPrototype = vtkSmartPointer<ProcessBlockData>::New();
     this->InfoPrototype->Construct(this->InInfoVec, numInputPorts, this->OutInfoVec);
   }
@@ -281,9 +282,10 @@ int vtkThreadedCompositeDataPipeline::CallAlgorithm(vtkInformation* request, int
   // If the algorithm failed report it now.
   if (!result)
   {
-    vtkErrorMacro("Algorithm " << this->Algorithm->GetClassName() << "(" << this->Algorithm
-                               << ") returned failure for request: " << *request);
+    vtkErrorMacro("Algorithm " << this->Algorithm->GetObjectDescription()
+                               << " returned failure for request: " << *request);
   }
 
   return result;
 }
+VTK_ABI_NAMESPACE_END
