@@ -15,9 +15,12 @@
 #include "vtkAmoebaMinimizer.h"
 #include "vtkObjectFactory.h"
 
+#include <cmath>
+
 #define N_STEPS_NO_VALUE_IMPROVEMENT 2
 #define N_STEPS_NO_PARAM_IMPROVEMENT 18
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAmoebaMinimizer);
 
 //------------------------------------------------------------------------------
@@ -770,3 +773,4 @@ int vtkAmoebaMinimizer::PerformAmoeba()
 
   return (improvement_found);
 }
+VTK_ABI_NAMESPACE_END
