@@ -32,6 +32,7 @@
 #include "vtkCommonMathModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONMATH_EXPORT vtkMatrix4x4 : public vtkObject
 {
 public:
@@ -129,6 +130,22 @@ public:
   void Transpose() { vtkMatrix4x4::Transpose(this, this); }
   static void Transpose(const double inElements[16], double outElements[16]);
 
+  ///@{
+  /**
+   * Construct a matrix from a rotation
+   */
+  static void MatrixFromRotation(double angle, double x, double y, double z, vtkMatrix4x4* result);
+  static void MatrixFromRotation(double angle, double x, double y, double z, double matrix[16]);
+  ///@}
+
+  /**
+   * Given an orientation and position this function will fill in a matrix
+   * representing the transformation from the pose to whatever space the pose was
+   * defined in. For example if the position and orientation are in world
+   * coordinates then this method would set the matrix to be PoseToWorld
+   */
+  static void PoseToMatrix(double pos[3], double ori[4], vtkMatrix4x4* mat);
+
   /**
    * Multiply a homogeneous coordinate by this matrix, i.e. out = A*in.
    * The in[4] and out[4] can be the same array.
@@ -164,7 +181,7 @@ public:
     return this->DoublePoint;
   }
 
-  //@{
+  ///@{
   /**
    * Multiplies matrices a and b and stores the result in c.
    */
@@ -172,7 +189,7 @@ public:
   static void Multiply4x4(const double a[16], const double b[16], double c[16]);
   static void Multiply4x4(const double a[16], const double b[16], float c[16]);
   static void MultiplyAndTranspose4x4(const double a[16], const double b[16], float c[16]);
-  //@}
+  ///@}
 
   /**
    * Compute adjoint of the matrix and put it into out.
@@ -297,4 +314,5 @@ inline bool vtkMatrix4x4::IsIdentity()
     M[12] == 0.0 && M[13] == 0.0 && M[14] == 0.0 && M[15] == 1.0;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
