@@ -31,6 +31,7 @@
 
 #define VTK_SIGN(x) (((x) < 0) ? (-1) : (1))
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolynomialSolversUnivariate);
 
 static const double sqrt3 = sqrt(static_cast<double>(3.));
@@ -43,7 +44,8 @@ double vtkPolynomialSolversUnivariate::DivisionTolerance = 1e-8; // sqrt( VTK_DB
 void vtkPolynomialSolversUnivariate::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "(s) DivisionTolerance: " << this->GetDivisionTolerance() << "\n";
+  os << indent
+     << "(s) DivisionTolerance: " << vtkPolynomialSolversUnivariate::GetDivisionTolerance() << "\n";
 }
 
 //------------------------------------------------------------------------------
@@ -115,7 +117,7 @@ ostream& vtkPolynomialSolversUnivariate::PrintPolynomial(ostream& os, double* P,
 // Double precision comparison with 0
 inline bool IsZero(double x)
 {
-  return (fabs(x) < absolute0) ? true : false;
+  return fabs(x) < absolute0;
 }
 
 //------------------------------------------------------------------------------
@@ -136,11 +138,11 @@ inline bool AreEqual(double x, double y, double rTol)
   double absy = fabs(y);
   if (absx > absy)
   {
-    return delta > rTol * absx ? false : true;
+    return delta <= rTol * absx;
   }
   else
   {
-    return delta > rTol * absy ? false : true;
+    return delta <= rTol * absy;
   }
 }
 
@@ -1186,7 +1188,7 @@ static int vtkHabichtOrSturmBisectionSolve(double* P, int d, double* a, double*
       } // While ub[nloc] - lb[nloc] > tol
 
       bisection[nloc] = false;
-      if (bisect == false)
+      if (!bisect)
       {
         // Move on to next interval.
         continue;
@@ -2225,3 +2227,4 @@ double vtkPolynomialSolversUnivariate::GetDivisionTolerance()
 {
   return vtkPolynomialSolversUnivariate::DivisionTolerance;
 }
+VTK_ABI_NAMESPACE_END
