@@ -35,6 +35,7 @@
 
 #include "vtkTuple.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 template <typename T>
 class vtkQuaternion : public vtkTuple<T, 4>
 {
@@ -161,48 +162,48 @@ public:
    */
   vtkQuaternion<T> NormalizedWithAngleInDegrees() const;
 
-  //@{
+  ///@{
   /**
    * Set/Get the w, x, y and z components of the quaternion.
    */
   void Set(const T& w, const T& x, const T& y, const T& z);
   void Set(T quat[4]);
   void Get(T quat[4]) const;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the w component of the quaternion, i.e. element 0.
    */
   void SetW(const T& w);
   const T& GetW() const;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the x component of the quaternion, i.e. element 1.
    */
   void SetX(const T& x);
   const T& GetX() const;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the y component of the quaternion, i.e. element 2.
    */
   void SetY(const T& y);
   const T& GetY() const;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the y component of the quaternion, i.e. element 3.
    */
   void SetZ(const T& z);
   const T& GetZ() const;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the angle (in radians) and the axis corresponding to
    * the axis-angle rotation of this quaternion.
@@ -210,7 +211,7 @@ public:
   T GetRotationAngleAndAxis(T axis[3]) const;
   void SetRotationAngleAndAxis(T angle, T axis[3]);
   void SetRotationAngleAndAxis(const T& angle, const T& x, const T& y, const T& z);
-  //@}
+  ///@}
 
   /**
    * Cast the quaternion to the specified type and return the result.
@@ -283,12 +284,12 @@ public:
    */
   vtkQuaternion<T> operator/(const T& scalar) const;
 
-  //@{
+  ///@{
   /**
    * Performs in place division of the quaternions by a scalar value.
    */
   void operator/=(const T& scalar);
-  //@}
+  ///@}
 };
 
 /**
@@ -442,6 +443,7 @@ public:
   vtkQuaternionOperatorMacro(vtkQuaterniond, double);
 };
 
+VTK_ABI_NAMESPACE_END
 #include "vtkQuaternion.txx"
 
 #endif // vtkQuaternion_h
