@@ -32,10 +32,12 @@
 #include "vtkCommonMathModule.h" // For export macro
 #include "vtkInitialValueProblemSolver.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONMATH_EXPORT vtkRungeKutta2 : public vtkInitialValueProblemSolver
 {
 public:
   vtkTypeMacro(vtkRungeKutta2, vtkInitialValueProblemSolver);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Construct a vtkRungeKutta2 with no initial FunctionSet.
@@ -43,7 +45,7 @@ public:
   static vtkRungeKutta2* New();
 
   using Superclass::ComputeNextStep;
-  //@{
+  ///@{
   /**
    * Given initial values, xprev , initial time, t and a requested time
    * interval, delT calculate values of x at t+delT (xnext).
@@ -84,7 +86,7 @@ public:
   int ComputeNextStep(double* xprev, double* dxprev, double* xnext, double t, double& delT,
     double& delTActual, double minStep, double maxStep, double maxError, double& error,
     void* userData) override;
-  //@}
+  ///@}
 
 protected:
   vtkRungeKutta2();
@@ -95,6 +97,5 @@ private:
   void operator=(const vtkRungeKutta2&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkRungeKutta2.h
