@@ -38,6 +38,7 @@
 #include "vtkCommonMathModule.h" // For export macro
 #include "vtkInitialValueProblemSolver.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONMATH_EXPORT vtkRungeKutta45 : public vtkInitialValueProblemSolver
 {
 public:
@@ -50,7 +51,7 @@ public:
   static vtkRungeKutta45* New();
 
   using Superclass::ComputeNextStep;
-  //@{
+  ///@{
   /**
    * Given initial values, xprev , initial time, t and a requested time
    * interval, delT calculate values of x at t+delTActual (xnext).
@@ -100,7 +101,7 @@ public:
   int ComputeNextStep(double* xprev, double* dxprev, double* xnext, double t, double& delT,
     double& delTActual, double minStep, double maxStep, double maxError, double& estErr,
     void* userData) override;
-  //@}
+  ///@}
 
 protected:
   vtkRungeKutta45();
@@ -124,4 +125,5 @@ private:
   void operator=(const vtkRungeKutta45&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
