@@ -17,6 +17,7 @@
 #include "vtkLogger.h"
 #include "vtkObjectFactory.h"
 
+#include <vtksys/Encoding.hxx>
 #include <vtksys/SystemTools.hxx>
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
@@ -35,6 +36,7 @@
 #include <dlfcn.h>
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkResourceFileLocator);
 //------------------------------------------------------------------------------
 vtkResourceFileLocator::vtkResourceFileLocator()
@@ -66,17 +68,17 @@ std::string vtkResourceFileLocator::Locate(const std::string& anchor,
     std::string curanchor = vtksys::SystemTools::JoinPath(path_components);
     for (const std::string& curprefix : landmark_prefixes)
     {
-      const std::string landmarkdir =
+      std::string landmarkdir =
         curprefix.empty() ? curanchor : curanchor + VTK_PATH_SEPARATOR + curprefix;
       const std::string landmarktocheck = landmarkdir + VTK_PATH_SEPARATOR + landmark;
       if (vtksys::SystemTools::FileExists(landmarktocheck))
       {
-        VTK_FILE_LOCATOR_DEBUG_MESSAGE("trying file %s -- success!", landmarktocheck.c_str());
+        VTK_FILE_LOCATOR_DEBUG_MESSAGE("trying file %s -- found!", landmarktocheck.c_str());
         return landmarkdir;
       }
       else
       {
-        VTK_FILE_LOCATOR_DEBUG_MESSAGE("trying file %s -- failed!", landmarktocheck.c_str());
+        VTK_FILE_LOCATOR_DEBUG_MESSAGE("trying file %s -- not found!", landmarktocheck.c_str());
       }
     }
     path_components.pop_back();
@@ -114,13 +116,13 @@ std::string vtkResourceFileLocator::GetLibraryPathForSymbolWin32(const void* fpt
 #if defined(_WIN32) && !defined(__CYGWIN__)
   MEMORY_BASIC_INFORMATION mbi;
   VirtualQuery(fptr, &mbi, sizeof(mbi));
-  char pathBuf[16384];
-  if (!GetModuleFileName(static_cast<HMODULE>(mbi.AllocationBase), pathBuf, sizeof(pathBuf)))
+  wchar_t pathBuf[16384];
+  if (!GetModuleFileNameW(static_cast<HMODULE>(mbi.AllocationBase), pathBuf, sizeof(pathBuf)))
   {
     return std::string();
   }
 
-  return std::string(pathBuf);
+  return vtksys::Encoding::ToNarrow(pathBuf);
 #else
   (void)fptr;
   return std::string();
@@ -133,31 +135,4 @@ void vtkResourceFileLocator::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "LogVerbosity: " << this->LogVerbosity << endl;
 }
-
-void vtkResourceFileLocator::SetPrintDebugInformation(bool val)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkResourceFileLocator::SetPrintDebugInformation, "VTK 9.0",
-    vtkResourceFileLocator::SetLogVerbosity);
-  this->SetLogVerbosity(val ? vtkLogger::VERBOSITY_INFO : vtkLogger::VERBOSITY_TRACE);
-}
-
-bool vtkResourceFileLocator::GetPrintDebugInformation()
-{
-  VTK_LEGACY_REPLACED_BODY(vtkResourceFileLocator::GetPrintDebugInformation, "VTK 9.0",
-    vtkResourceFileLocator::GetLogVerbosity);
-  return (this->GetLogVerbosity() == vtkLogger::VERBOSITY_INFO);
-}
-
-void vtkResourceFileLocator::PrintDebugInformationOn()
-{
-  VTK_LEGACY_REPLACED_BODY(vtkResourceFileLocator::PrintDebugInformationOn, "VTK 9.0",
-    vtkResourceFileLocator::SetLogVerbosity);
-  this->SetLogVerbosity(vtkLogger::VERBOSITY_INFO);
-}
-
-void vtkResourceFileLocator::PrintDebugInformationOff()
-{
-  VTK_LEGACY_REPLACED_BODY(vtkResourceFileLocator::PrintDebugInformationOff, "VTK 9.0",
-    vtkResourceFileLocator::SetLogVerbosity);
-  this->SetLogVerbosity(vtkLogger::VERBOSITY_TRACE);
-}
+VTK_ABI_NAMESPACE_END
