@@ -29,17 +29,18 @@
 #include "vtkCommonSystemModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkStringArray;
 
 class VTKCOMMONSYSTEM_EXPORT vtkDirectory : public vtkObject
 {
 public:
-  //@{
+  ///@{
   /**
    * Return the class name as a string.
    */
   vtkTypeMacro(vtkDirectory, vtkObject);
-  //@}
+  ///@}
 
   /**
    * Create a new vtkDirectory object.
@@ -56,7 +57,7 @@ public:
    * in that directory. 0 is returned if the directory can not be
    * opened, 1 if it is opened.
    */
-  int Open(const char* dir);
+  int Open(VTK_FILEPATH const char* dir);
 
   /**
    * Return the number of files in the current directory.
@@ -66,7 +67,7 @@ public:
   /**
    * Return the file at the given index, the indexing is 0 based
    */
-  const char* GetFile(vtkIdType index);
+  VTK_FILEPATH const char* GetFile(vtkIdType index);
 
   /**
    * Return true if the file is a directory.  If the file is not an
@@ -74,34 +75,34 @@ public:
    * directory. If no directory has been opened, it is assumed to
    * be relative to the current working directory.
    */
-  int FileIsDirectory(const char* name);
+  int FileIsDirectory(VTK_FILEPATH const char* name);
 
-  //@{
+  ///@{
   /**
    * Get an array that contains all the file names.
    */
   vtkGetObjectMacro(Files, vtkStringArray);
-  //@}
+  ///@}
 
   /**
    * Get the current working directory.
    */
-  static const char* GetCurrentWorkingDirectory(char* buf, unsigned int len);
+  static VTK_FILEPATH const char* GetCurrentWorkingDirectory(char* buf, unsigned int len);
 
   /**
    * Create directory.
    */
-  static int MakeDirectory(const char* dir);
+  static int MakeDirectory(VTK_FILEPATH const char* dir);
 
   /**
    * Remove a directory.
    */
-  static int DeleteDirectory(const char* dir);
+  static int DeleteDirectory(VTK_FILEPATH const char* dir);
 
   /**
    * Rename a file or directory.
    */
-  static int Rename(const char* oldname, const char* newname);
+  static int Rename(VTK_FILEPATH const char* oldname, VTK_FILEPATH const char* newname);
 
 protected:
   // delete the Files and Path ivars and set
@@ -121,4 +122,5 @@ private:
   void operator=(const vtkDirectory&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
