@@ -17,6 +17,7 @@
 #include "vtkClientSocket.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkServerSocket);
 //------------------------------------------------------------------------------
 vtkServerSocket::vtkServerSocket() = default;
@@ -98,3 +99,4 @@ void vtkServerSocket::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
