@@ -28,6 +28,7 @@
 #if defined(_WIN32) && !defined(__CYGWIN__)
 #define VTK_WINDOWS_FULL
 #include "vtkWindows.h"
+#include "vtksys/Encoding.hxx"
 #else
 #include <arpa/inet.h>
 #include <cerrno>
@@ -71,8 +72,7 @@
   do                                                                                               \
   {                                                                                                \
     (_ret) = (_call);                                                                              \
-  } while (                                                                                        \
-    ((_ret) == vtkSocketErrorReturnMacro) && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)));
+  } while (((_ret) == vtkSocketErrorReturnMacro) && (vtkErrnoMacro == vtkSocketErrorIdMacro(EINTR)))
 
 // use when _str may be a null pointer but _fallback is not.
 #define vtkSafeStrMacro(_str, _fallback) ((_str) ? (_str) : (_fallback))
@@ -80,30 +80,45 @@
 // convert error number to string and report via vtkErrorMacro.
 #define vtkSocketErrorMacro(_eno, _message)                                                        \
   vtkErrorMacro(<< (_message) << " " << vtkSafeStrMacro(vtkStrerrorMacro(_eno), "unknown error")   \
-                << ".");
+                << ".")
 
 // convert error number to string and report via vtkGenericWarningMacro
 #define vtkSocketGenericErrorMacro(_message)                                                       \
   vtkGenericWarningMacro(<< (_message) << " "                                                      \
                          << vtkSafeStrMacro(vtkStrerrorMacro(vtkErrnoMacro), "unknown error")      \
-                         << ".");
+                         << ".")
 
 // on windows strerror doesn't handle socket error codes
 #if defined(_WIN32) && !defined(__CYGWIN__)
+VTK_ABI_NAMESPACE_BEGIN
 static const char* wsaStrerror(int wsaeid)
 {
-  static char buf[256] = { '\0' };
-  int ok;
-  ok = FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM, 0, wsaeid, 0, buf, 256, 0);
+  wchar_t wbuf[256];
+  int ok = FormatMessageW(FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, 0, wsaeid, 0,
+    wbuf, sizeof(wbuf), 0);
   if (!ok)
   {
-    return 0;
+    return nullptr;
   }
+
+  std::string result = vtksys::Encoding::ToNarrow(wbuf);
+  size_t count = result.length();
+
+  static char buf[256];
+  if (count >= sizeof(buf))
+  {
+    count = sizeof(buf) - 1;
+  }
+  strncpy(buf, result.c_str(), count);
+  buf[count + 1] = '\0';
+
   return buf;
 }
+VTK_ABI_NAMESPACE_END
 #endif
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkSocket::vtkSocket()
 {
   this->SocketDescriptor = -1;
@@ -604,3 +619,4 @@ void vtkSocket::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "SocketDescriptor: " << this->SocketDescriptor << endl;
 }
+VTK_ABI_NAMESPACE_END
