@@ -25,28 +25,59 @@
 #include "vtkTimerLog.h"
 
 #include "vtkMath.h"
+#include "vtksys/FStream.hxx"
 
 #include <algorithm>
 #include <cassert>
 #include <cmath>
+#include <cstdarg>
 #include <iomanip>
 #include <iterator>
-#include <cstdarg>
 #include <string>
 #include <vector>
 
 #ifndef _WIN32
-#include <climits>     // for CLK_TCK
+#include <climits> // for CLK_TCK
 #include <sys/time.h>
 #include <unistd.h>
 #endif
 
 #ifndef _WIN32_WCE
-#include <sys/types.h>
 #include <ctime>
+#include <sys/types.h>
 #endif
 #include "vtkObjectFactory.h"
 
+//==============================================================================
+VTK_ABI_NAMESPACE_BEGIN
+static unsigned int vtkTimerLogCleanupCounter = 0;
+std::vector<vtkTimerLogEntry>* vtkTimerLogEntryVectorPtr = nullptr;
+
+vtkTimerLogCleanup::vtkTimerLogCleanup()
+{
+  ++::vtkTimerLogCleanupCounter;
+}
+
+vtkTimerLogCleanup::~vtkTimerLogCleanup()
+{
+  if (--::vtkTimerLogCleanupCounter == 0)
+  {
+    delete ::vtkTimerLogEntryVectorPtr;
+    ::vtkTimerLogEntryVectorPtr = nullptr;
+  }
+}
+
+static std::vector<vtkTimerLogEntry>& vtkGetTimerLogEntryVector()
+{
+  if (!vtkTimerLogEntryVectorPtr)
+  {
+    vtkTimerLogEntryVectorPtr = new std::vector<vtkTimerLogEntry>();
+  }
+  return *vtkTimerLogEntryVectorPtr;
+}
+
+//==============================================================================
+
 vtkStandardNewMacro(vtkTimerLog);
 
 // initialize the class variables
@@ -55,7 +86,6 @@ int vtkTimerLog::Indent = 0;
 int vtkTimerLog::MaxEntries = 100;
 int vtkTimerLog::NextEntry = 0;
 int vtkTimerLog::WrapFlag = 0;
-std::vector<vtkTimerLogEntry> vtkTimerLog::TimerLog;
 
 #ifdef CLK_TCK
 int vtkTimerLog::TicksPerSecond = CLK_TCK;
@@ -67,7 +97,6 @@ int vtkTimerLog::TicksPerSecond = 60;
 #define CLOCKS_PER_SEC (vtkTimerLog::TicksPerSecond)
 #endif
 
-
 #ifdef _WIN32
 #ifndef _WIN32_WCE
 timeb vtkTimerLog::FirstWallTime;
@@ -79,40 +108,39 @@ FILETIME vtkTimerLog::CurrentWallTime;
 #else
 timeval vtkTimerLog::FirstWallTime;
 timeval vtkTimerLog::CurrentWallTime;
-tms     vtkTimerLog::FirstCpuTicks;
-tms     vtkTimerLog::CurrentCpuTicks;
+tms vtkTimerLog::FirstCpuTicks;
+tms vtkTimerLog::CurrentCpuTicks;
 #endif
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove timer log.
 void vtkTimerLog::CleanupLog()
 {
-  vtkTimerLog::TimerLog.clear();
+  vtkGetTimerLogEntryVector().clear();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Clear the timing table.  walltime and cputime will also be set
 // to zero when the first new event is recorded.
 void vtkTimerLog::ResetLog()
 {
   vtkTimerLog::WrapFlag = 0;
   vtkTimerLog::NextEntry = 0;
-  // may want to free TimerLog to force realloc so
+  // may want to free entry_vector to force realloc so
   // that user can resize the table by changing MaxEntries.
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event.  The event is represented by a formatted
 // string.
-void vtkTimerLog::FormatAndMarkEvent(const char *format, ...)
+void vtkTimerLog::FormatAndMarkEvent(const char* format, ...)
 {
-  if (! vtkTimerLog::Logging)
+  if (!vtkTimerLog::Logging)
   {
     return;
   }
 
-  static  char event[4096];
+  static char event[4096];
   va_list var_args;
   va_start(var_args, format);
   vsnprintf(event, sizeof(event), format, var_args);
@@ -121,19 +149,19 @@ void vtkTimerLog::FormatAndMarkEvent(const char *format, ...)
   vtkTimerLog::MarkEventInternal(event, vtkTimerLogEntry::STANDALONE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event and capture walltime and cputicks.
-void vtkTimerLog::MarkEvent(const char *event)
+void vtkTimerLog::MarkEvent(const char* event)
 {
   vtkTimerLog::MarkEventInternal(event, vtkTimerLogEntry::STANDALONE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event and capture walltime and cputicks.
 void vtkTimerLog::MarkEventInternal(
-  const char *event, vtkTimerLogEntry::LogEntryType type, vtkTimerLogEntry* entry)
+  const char* event, vtkTimerLogEntry::LogEntryType type, vtkTimerLogEntry* entry)
 {
-  if (! vtkTimerLog::Logging)
+  if (!vtkTimerLog::Logging)
   {
     return;
   }
@@ -141,14 +169,16 @@ void vtkTimerLog::MarkEventInternal(
   double time_diff;
   int ticks_diff;
 
+  auto& global_entries = vtkGetTimerLogEntryVector();
+
   // If this the first event we're recording, allocate the
   // internal timing table and initialize WallTime and CpuTicks
   // for this first event to zero.
-  if (vtkTimerLog::NextEntry == 0 && ! vtkTimerLog::WrapFlag)
+  if (vtkTimerLog::NextEntry == 0 && !vtkTimerLog::WrapFlag)
   {
-    if (vtkTimerLog::TimerLog.empty())
+    if (global_entries.empty())
     {
-      vtkTimerLog::TimerLog.resize(vtkTimerLog::MaxEntries);
+      global_entries.resize(vtkTimerLog::MaxEntries);
     }
 
 #ifdef _WIN32
@@ -157,27 +187,27 @@ void vtkTimerLog::MarkEventInternal(
     GetLocalTime(&st);
     SystemTimeToFileTime(&st, &(vtkTimerLog::FirstWallTime));
 #else
-    ::ftime( &(vtkTimerLog::FirstWallTime) );
+    ::ftime(&(vtkTimerLog::FirstWallTime));
 #endif
 #else
-    gettimeofday( &(vtkTimerLog::FirstWallTime), nullptr );
+    gettimeofday(&(vtkTimerLog::FirstWallTime), nullptr);
     times(&FirstCpuTicks);
 #endif
 
     if (entry)
     {
-      vtkTimerLog::TimerLog[0] = *entry;
+      global_entries[0] = *entry;
     }
     else
     {
-      vtkTimerLog::TimerLog[0].Indent = vtkTimerLog::Indent;
-      vtkTimerLog::TimerLog[0].WallTime = 0.0;
-      vtkTimerLog::TimerLog[0].CpuTicks = 0;
+      global_entries[0].Indent = vtkTimerLog::Indent;
+      global_entries[0].WallTime = 0.0;
+      global_entries[0].CpuTicks = 0;
       if (event)
       {
-        vtkTimerLog::TimerLog[0].Event = event;
+        global_entries[0].Event = event;
       }
-      vtkTimerLog::TimerLog[0].Type = type;
+      global_entries[0].Type = type;
       vtkTimerLog::NextEntry = 1;
     }
     return;
@@ -185,7 +215,7 @@ void vtkTimerLog::MarkEventInternal(
 
   if (entry)
   {
-    vtkTimerLog::TimerLog[vtkTimerLog::NextEntry] = *entry;
+    global_entries[vtkTimerLog::NextEntry] = *entry;
   }
   else
   {
@@ -194,44 +224,40 @@ void vtkTimerLog::MarkEventInternal(
     SYSTEMTIME st;
     GetLocalTime(&st);
     SystemTimeToFileTime(&st, &(vtkTimerLog::CurrentWallTime));
-    time_diff = (vtkTimerLog::CurrentWallTime.dwHighDateTime -
-      vtkTimerLog::FirstWallTime.dwHighDateTime);
-    time_diff = time_diff * 429.4967296;
-    time_diff = time_diff + ((vtkTimerLog::CurrentWallTime.dwLowDateTime -
-      vtkTimerLog::FirstWallTime.dwLowDateTime) / 10000000.0);
-#else
-    static double scale = 1.0/1000.0;
-    ::ftime( &(vtkTimerLog::CurrentWallTime) );
     time_diff =
-      vtkTimerLog::CurrentWallTime.time - vtkTimerLog::FirstWallTime.time;
+      (vtkTimerLog::CurrentWallTime.dwHighDateTime - vtkTimerLog::FirstWallTime.dwHighDateTime);
+    time_diff = time_diff * 429.4967296;
+    time_diff = time_diff +
+      ((vtkTimerLog::CurrentWallTime.dwLowDateTime - vtkTimerLog::FirstWallTime.dwLowDateTime) /
+        10000000.0);
+#else
+    static double scale = 1.0 / 1000.0;
+    ::ftime(&(vtkTimerLog::CurrentWallTime));
+    time_diff = vtkTimerLog::CurrentWallTime.time - vtkTimerLog::FirstWallTime.time;
     time_diff +=
-      (vtkTimerLog::CurrentWallTime.millitm
-       - vtkTimerLog::FirstWallTime.millitm) * scale;
+      (vtkTimerLog::CurrentWallTime.millitm - vtkTimerLog::FirstWallTime.millitm) * scale;
 #endif
     ticks_diff = 0;
 #else
-    static double scale = 1.0/1000000.0;
-    gettimeofday( &(vtkTimerLog::CurrentWallTime), nullptr );
-    time_diff  =  vtkTimerLog::CurrentWallTime.tv_sec
-      - vtkTimerLog::FirstWallTime.tv_sec;
+    static double scale = 1.0 / 1000000.0;
+    gettimeofday(&(vtkTimerLog::CurrentWallTime), nullptr);
+    time_diff = vtkTimerLog::CurrentWallTime.tv_sec - vtkTimerLog::FirstWallTime.tv_sec;
     time_diff +=
-      (vtkTimerLog::CurrentWallTime.tv_usec
-       - vtkTimerLog::FirstWallTime.tv_usec) * scale;
+      (vtkTimerLog::CurrentWallTime.tv_usec - vtkTimerLog::FirstWallTime.tv_usec) * scale;
 
     times(&CurrentCpuTicks);
     ticks_diff = (CurrentCpuTicks.tms_utime + CurrentCpuTicks.tms_stime) -
       (FirstCpuTicks.tms_utime + FirstCpuTicks.tms_stime);
 #endif
 
-    vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].Indent = vtkTimerLog::Indent;
-    vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].WallTime =
-      static_cast<double>(time_diff);
-    vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].CpuTicks = ticks_diff;
+    global_entries[vtkTimerLog::NextEntry].Indent = vtkTimerLog::Indent;
+    global_entries[vtkTimerLog::NextEntry].WallTime = static_cast<double>(time_diff);
+    global_entries[vtkTimerLog::NextEntry].CpuTicks = ticks_diff;
     if (event)
     {
-      vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].Event = event;
+      global_entries[vtkTimerLog::NextEntry].Event = event;
     }
-    vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].Type = type;
+    global_entries[vtkTimerLog::NextEntry].Type = type;
   }
 
   vtkTimerLog::NextEntry++;
@@ -242,12 +268,12 @@ void vtkTimerLog::MarkEventInternal(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event and capture walltime and cputicks.
 // Increments indent after mark.
-void vtkTimerLog::MarkStartEvent(const char *event)
+void vtkTimerLog::MarkStartEvent(const char* event)
 {
-  if (! vtkTimerLog::Logging)
+  if (!vtkTimerLog::Logging)
   { // Maybe we should still change the Indent ...
     return;
   }
@@ -256,12 +282,12 @@ void vtkTimerLog::MarkStartEvent(const char *event)
   ++vtkTimerLog::Indent;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event and capture walltime and cputicks.
 // Decrements indent after mark.
-void vtkTimerLog::MarkEndEvent(const char *event)
+void vtkTimerLog::MarkEndEvent(const char* event)
 {
-  if (! vtkTimerLog::Logging)
+  if (!vtkTimerLog::Logging)
   { // Maybe we should still change the Indent ...
     return;
   }
@@ -270,12 +296,11 @@ void vtkTimerLog::MarkEndEvent(const char *event)
   --vtkTimerLog::Indent;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event with known walltime and cputicks.
-void vtkTimerLog::InsertTimedEvent(
-  const char *event, double time, int cpuTicks)
+void vtkTimerLog::InsertTimedEvent(const char* event, double time, int cpuTicks)
 {
-  if (! vtkTimerLog::Logging)
+  if (!vtkTimerLog::Logging)
   {
     return;
   }
@@ -294,7 +319,7 @@ void vtkTimerLog::InsertTimedEvent(
   vtkTimerLog::MarkEventInternal(event, vtkTimerLogEntry::INSERTED, &entry);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Record a timing event and capture walltime and cputicks.
 int vtkTimerLog::GetNumberOfEvents()
 {
@@ -308,8 +333,8 @@ int vtkTimerLog::GetNumberOfEvents()
   }
 }
 
-//----------------------------------------------------------------------------
-vtkTimerLogEntry *vtkTimerLog::GetEvent(int idx)
+//------------------------------------------------------------------------------
+vtkTimerLogEntry* vtkTimerLog::GetEvent(int idx)
 {
   int num = vtkTimerLog::GetNumberOfEvents();
   int start = 0;
@@ -325,59 +350,59 @@ vtkTimerLogEntry *vtkTimerLog::GetEvent(int idx)
   }
   idx = (idx + start) % vtkTimerLog::MaxEntries;
 
-  return &(vtkTimerLog::TimerLog[idx]);
+  return &(vtkGetTimerLogEntryVector()[idx]);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTimerLog::GetEventIndent(int idx)
 {
-  if (vtkTimerLogEntry *tmp = vtkTimerLog::GetEvent(idx))
+  if (vtkTimerLogEntry* tmp = vtkTimerLog::GetEvent(idx))
   {
     return tmp->Indent;
   }
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkTimerLog::GetEventWallTime(int idx)
 {
-  if (vtkTimerLogEntry *tmp = vtkTimerLog::GetEvent(idx))
+  if (vtkTimerLogEntry* tmp = vtkTimerLog::GetEvent(idx))
   {
     return tmp->WallTime;
   }
   return 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkTimerLog::GetEventString(int idx)
 {
-  if (vtkTimerLogEntry *tmp = vtkTimerLog::GetEvent(idx))
+  if (vtkTimerLogEntry* tmp = vtkTimerLog::GetEvent(idx))
   {
     return tmp->Event.c_str();
   }
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTimerLogEntry::LogEntryType vtkTimerLog::GetEventType(int idx)
 {
-  if (vtkTimerLogEntry *tmp = vtkTimerLog::GetEvent(idx))
+  if (vtkTimerLogEntry* tmp = vtkTimerLog::GetEvent(idx))
   {
     return tmp->Type;
   }
   return vtkTimerLogEntry::INVALID;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Write the timing table out to a file.  Calculate some helpful
 // statistics (deltas and percentages) in the process.
-void vtkTimerLog::DumpLogWithIndents(ostream *os, double threshold)
+void vtkTimerLog::DumpLogWithIndents(ostream* os, double threshold)
 {
 #ifndef _WIN32_WCE
   int num = vtkTimerLog::GetNumberOfEvents();
   std::vector<bool> handledEvents(num, false);
 
-  for (int w=0; w < vtkTimerLog::WrapFlag+1; w++)
+  for (int w = 0; w < vtkTimerLog::WrapFlag + 1; w++)
   {
     int start = 0;
     int end = vtkTimerLog::NextEntry;
@@ -386,12 +411,12 @@ void vtkTimerLog::DumpLogWithIndents(ostream *os, double threshold)
       start = vtkTimerLog::NextEntry;
       end = vtkTimerLog::MaxEntries;
     }
-    for (int i1=start; i1 < end; i1++)
+    for (int i1 = start; i1 < end; i1++)
     {
       int indent1 = vtkTimerLog::GetEventIndent(i1);
       vtkTimerLogEntry::LogEntryType eventType = vtkTimerLog::GetEventType(i1);
       int endEvent = -1; // only modified if this is a START event
-      if (eventType == vtkTimerLogEntry::END && handledEvents[i1] == true)
+      if (eventType == vtkTimerLogEntry::END && handledEvents[i1])
       {
         continue; // this END event is handled by the corresponding START event
       }
@@ -399,14 +424,14 @@ void vtkTimerLog::DumpLogWithIndents(ostream *os, double threshold)
       {
         // Search for an END event. it may be before the START event if we've wrapped.
         int counter = 1;
-        while (counter < num && vtkTimerLog::GetEventIndent((i1+counter)%num) > indent1)
+        while (counter < num && vtkTimerLog::GetEventIndent((i1 + counter) % num) > indent1)
         {
           counter++;
         }
-        if (vtkTimerLog::GetEventIndent((i1+counter)%num) == indent1)
+        if (vtkTimerLog::GetEventIndent((i1 + counter) % num) == indent1)
         {
           counter--;
-          endEvent = (i1+counter)%num;
+          endEvent = (i1 + counter) % num;
           handledEvents[endEvent] = true;
         }
       }
@@ -442,8 +467,8 @@ void vtkTimerLog::DumpLogWithIndents(ostream *os, double threshold)
 #endif
 }
 
-//----------------------------------------------------------------------------
-void vtkTimerLog::DumpLogWithIndentsAndPercentages(std::ostream *os)
+//------------------------------------------------------------------------------
+void vtkTimerLog::DumpLogWithIndentsAndPercentages(std::ostream* os)
 {
   assert(os);
   // Use indents to pair start/end events. Indents work like this:
@@ -466,8 +491,8 @@ void vtkTimerLog::DumpLogWithIndentsAndPercentages(std::ostream *os)
   {
     *os << "Error: Event log has exceeded vtkTimerLog::MaxEntries.\n"
            "Call vtkTimerLog::SetMaxEntries to increase the log buffer size.\n"
-           "Current vtkTimerLog::MaxEntries: " << vtkTimerLog::MaxEntries
-        << ".\n";
+           "Current vtkTimerLog::MaxEntries: "
+        << vtkTimerLog::MaxEntries << ".\n";
     return;
   }
 
@@ -480,8 +505,8 @@ void vtkTimerLog::DumpLogWithIndentsAndPercentages(std::ostream *os)
   int longestString = 0;
   for (int i = 0; i < numEvents; ++i)
   {
-    longestString = std::max(longestString, static_cast<int>(
-                               strlen(vtkTimerLog::GetEventString(i))));
+    longestString =
+      std::max(longestString, static_cast<int>(strlen(vtkTimerLog::GetEventString(i))));
   }
 
   // Loop to numEvents - 1, since the last event must be an end event.
@@ -516,25 +541,21 @@ void vtkTimerLog::DumpLogWithIndentsAndPercentages(std::ostream *os)
     endIdx--;
 
     // Get the current event time:
-    double elapsedTime = logEntryType == vtkTimerLogEntry::START ?
-      vtkTimerLog::GetEventWallTime(endIdx) - vtkTimerLog::GetEventWallTime(startIdx) :
-      vtkTimerLog::GetEventWallTime(startIdx);
+    double elapsedTime = logEntryType == vtkTimerLogEntry::START
+      ? vtkTimerLog::GetEventWallTime(endIdx) - vtkTimerLog::GetEventWallTime(startIdx)
+      : vtkTimerLog::GetEventWallTime(startIdx);
 
     // The total time the parent took to execute. If empty, this is the first
     // event, and just set to 100%.
-    IndentTime parent = parentInfo.empty() ? IndentTime(-1, elapsedTime)
-                                           : parentInfo.back();
+    IndentTime parent = parentInfo.empty() ? IndentTime(-1, elapsedTime) : parentInfo.back();
 
     // Percentage of parent exec time, rounded to a single decimal:
     double percentage = std::round(elapsedTime / parent.second * 1000.) / 10.;
 
-    *os << std::setw(12) << std::setprecision(6) << std::fixed
-        << elapsedTime
-        << std::setw(0) << "s"
-        << std::setw(curIndent * 2) << " "
-        << std::setprecision(1) << std::setw(5) << std::right << percentage
-        << std::setw(0) << std::left << "% "
-        << std::setw(longestString) << vtkTimerLog::GetEventString(startIdx);
+    *os << std::setw(12) << std::setprecision(6) << std::fixed << elapsedTime << std::setw(0) << "s"
+        << std::setw(curIndent * 2) << " " << std::setprecision(1) << std::setw(5) << std::right
+        << percentage << std::setw(0) << std::left << "% " << std::setw(longestString)
+        << vtkTimerLog::GetEventString(startIdx);
     if (logEntryType == vtkTimerLogEntry::INSERTED)
     {
       *os << " (inserted time)";
@@ -544,81 +565,70 @@ void vtkTimerLog::DumpLogWithIndentsAndPercentages(std::ostream *os)
     // Add our parent info if this was time with a START and END event:
     if (logEntryType == vtkTimerLogEntry::START)
     {
-      parentInfo.push_back(IndentTime(curIndent, elapsedTime));
+      parentInfo.emplace_back(curIndent, elapsedTime);
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Write the timing table out to a file. This is meant for non-timed events,
 // i.e. event type = STANDALONE. All other event types besides the first
 // are ignored.
-void vtkTimerLog::DumpLog(const char *filename)
+void vtkTimerLog::DumpLog(const char* filename)
 {
 #ifndef _WIN32_WCE
-  ofstream os_with_warning_C4701(filename);
+  vtksys::ofstream os_with_warning_C4701(filename);
   int i;
 
-  if ( vtkTimerLog::WrapFlag )
+  auto& global_entries = vtkGetTimerLogEntryVector();
+  if (vtkTimerLog::WrapFlag)
   {
-    vtkTimerLog::DumpEntry(
-      os_with_warning_C4701, 0,
-      vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].WallTime, 0,
-      vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].CpuTicks, 0,
-      vtkTimerLog::TimerLog[vtkTimerLog::NextEntry].Event.c_str());
+    vtkTimerLog::DumpEntry(os_with_warning_C4701, 0,
+      global_entries[vtkTimerLog::NextEntry].WallTime, 0,
+      global_entries[vtkTimerLog::NextEntry].CpuTicks, 0,
+      global_entries[vtkTimerLog::NextEntry].Event.c_str());
     int previousEvent = vtkTimerLog::NextEntry;
-    for (i=vtkTimerLog::NextEntry+1; i<vtkTimerLog::MaxEntries; i++)
+    for (i = vtkTimerLog::NextEntry + 1; i < vtkTimerLog::MaxEntries; i++)
     {
-      if (vtkTimerLog::TimerLog[i].Type == vtkTimerLogEntry::STANDALONE)
+      if (global_entries[i].Type == vtkTimerLogEntry::STANDALONE)
       {
-        vtkTimerLog::DumpEntry(
-          os_with_warning_C4701, i-vtkTimerLog::NextEntry,
-          vtkTimerLog::TimerLog[i].WallTime,
-          vtkTimerLog::TimerLog[i].WallTime
-          - vtkTimerLog::TimerLog[previousEvent].WallTime,
-          vtkTimerLog::TimerLog[i].CpuTicks,
-          vtkTimerLog::TimerLog[i].CpuTicks
-          - vtkTimerLog::TimerLog[previousEvent].CpuTicks,
-          vtkTimerLog::TimerLog[i].Event.c_str());
+        vtkTimerLog::DumpEntry(os_with_warning_C4701, i - vtkTimerLog::NextEntry,
+          global_entries[i].WallTime,
+          global_entries[i].WallTime - global_entries[previousEvent].WallTime,
+          global_entries[i].CpuTicks,
+          global_entries[i].CpuTicks - global_entries[previousEvent].CpuTicks,
+          global_entries[i].Event.c_str());
         previousEvent = i;
       }
     }
-    for (i=0; i<vtkTimerLog::NextEntry; i++)
+    for (i = 0; i < vtkTimerLog::NextEntry; i++)
     {
-      if (vtkTimerLog::TimerLog[i].Type == vtkTimerLogEntry::STANDALONE)
+      if (global_entries[i].Type == vtkTimerLogEntry::STANDALONE)
       {
-        vtkTimerLog::DumpEntry(
-          os_with_warning_C4701, vtkTimerLog::MaxEntries-vtkTimerLog::NextEntry+i,
-          vtkTimerLog::TimerLog[i].WallTime,
-          vtkTimerLog::TimerLog[i].WallTime
-          - vtkTimerLog::TimerLog[previousEvent].WallTime,
-          vtkTimerLog::TimerLog[i].CpuTicks,
-          vtkTimerLog::TimerLog[i].CpuTicks
-          - vtkTimerLog::TimerLog[previousEvent].CpuTicks,
-          vtkTimerLog::TimerLog[i].Event.c_str());
+        vtkTimerLog::DumpEntry(os_with_warning_C4701,
+          vtkTimerLog::MaxEntries - vtkTimerLog::NextEntry + i, global_entries[i].WallTime,
+          global_entries[i].WallTime - global_entries[previousEvent].WallTime,
+          global_entries[i].CpuTicks,
+          global_entries[i].CpuTicks - global_entries[previousEvent].CpuTicks,
+          global_entries[i].Event.c_str());
         previousEvent = i;
       }
     }
   }
   else
   {
-    vtkTimerLog::DumpEntry(
-      os_with_warning_C4701, 0, vtkTimerLog::TimerLog[0].WallTime, 0,
-      vtkTimerLog::TimerLog[0].CpuTicks, 0,
-      vtkTimerLog::TimerLog[0].Event.c_str());
+    vtkTimerLog::DumpEntry(os_with_warning_C4701, 0, global_entries[0].WallTime, 0,
+      global_entries[0].CpuTicks, 0, global_entries[0].Event.c_str());
     int previousEvent = 0;
-    for (i=1; i<vtkTimerLog::NextEntry; i++)
+    for (i = 1; i < vtkTimerLog::NextEntry; i++)
     {
-      if (vtkTimerLog::TimerLog[i].Type == vtkTimerLogEntry::STANDALONE)
+      if (global_entries[i].Type == vtkTimerLogEntry::STANDALONE)
       {
-        vtkTimerLog::DumpEntry(
-          os_with_warning_C4701, i, vtkTimerLog::TimerLog[i].WallTime,
-          vtkTimerLog::TimerLog[i].WallTime
-          - vtkTimerLog::TimerLog[previousEvent].WallTime,
-          vtkTimerLog::TimerLog[i].CpuTicks,
-          vtkTimerLog::TimerLog[i].CpuTicks
-          - vtkTimerLog::TimerLog[previousEvent].CpuTicks,
-          vtkTimerLog::TimerLog[i].Event.c_str());
+        vtkTimerLog::DumpEntry(os_with_warning_C4701, i, global_entries[i].WallTime,
+          global_entries[i].WallTime - global_entries[previousEvent].WallTime,
+          global_entries[i].CpuTicks,
+          global_entries[i].CpuTicks - global_entries[previousEvent].CpuTicks,
+          global_entries[i].Event.c_str());
         previousEvent = i;
       }
     }
@@ -628,7 +638,7 @@ void vtkTimerLog::DumpLog(const char *filename)
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Print method for vtkTimerLog.
 void vtkTimerLog::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -643,29 +653,29 @@ void vtkTimerLog::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Entry \tWall Time\tCpuTicks\tEvent\n";
   os << indent << "----------------------------------------------\n";
 
-  if ( vtkTimerLog::WrapFlag )
+  auto& global_entries = vtkGetTimerLogEntryVector();
+  if (vtkTimerLog::WrapFlag)
   {
-    for (int i=vtkTimerLog::NextEntry; i<vtkTimerLog::MaxEntries; i++)
+    for (int i = vtkTimerLog::NextEntry; i < vtkTimerLog::MaxEntries; i++)
     {
-      os << indent << i << "\t\t" << TimerLog[i].WallTime << "\t\t" <<
-        TimerLog[i].CpuTicks << "\t\t" << TimerLog[i].Event << "\n";
+      os << indent << i << "\t\t" << global_entries[i].WallTime << "\t\t"
+         << global_entries[i].CpuTicks << "\t\t" << global_entries[i].Event << "\n";
     }
   }
 
-  for (int i=0; i<vtkTimerLog::NextEntry; i++)
+  for (int i = 0; i < vtkTimerLog::NextEntry; i++)
   {
-    os << indent << i << "\t\t" << TimerLog[i].WallTime << "\t\t" <<
-      TimerLog[i].CpuTicks << "\t\t" << TimerLog[i].Event << "\n";
+    os << indent << i << "\t\t" << global_entries[i].WallTime << "\t\t"
+       << global_entries[i].CpuTicks << "\t\t" << global_entries[i].Event << "\n";
   }
 
   os << "\n" << indent << "StartTime: " << this->StartTime << "\n";
 }
 
-
 // Methods to support simple timer functionality, separate from
 // timer table logging.
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the elapsed number of seconds since 00:00:00 Coordinated Universal
 // Time (UTC), Thursday, 1 January 1970. This is also called Unix Time.
 double vtkTimerLog::GetUniversalTime()
@@ -680,49 +690,48 @@ double vtkTimerLog::GetUniversalTime()
   SystemTimeToFileTime(&st, &CurrentTime);
   currentTimeInSeconds = CurrentTime.dwHighDateTime;
   currentTimeInSeconds *= 429.4967296;
-  currentTimeInSeconds = currentTimeInSeconds +
-        CurrentTime.dwLowDateTime / 10000000.0;
+  currentTimeInSeconds = currentTimeInSeconds + CurrentTime.dwLowDateTime / 10000000.0;
 #else
   timeb CurrentTime;
-  static double scale = 1.0/1000.0;
-  ::ftime( &CurrentTime );
+  static double scale = 1.0 / 1000.0;
+  ::ftime(&CurrentTime);
   currentTimeInSeconds = CurrentTime.time + scale * CurrentTime.millitm;
 #endif
 #else
   timeval CurrentTime;
-  static double scale = 1.0/1000000.0;
-  gettimeofday( &CurrentTime, nullptr );
+  static double scale = 1.0 / 1000000.0;
+  gettimeofday(&CurrentTime, nullptr);
   currentTimeInSeconds = CurrentTime.tv_sec + scale * CurrentTime.tv_usec;
 #endif
 
   return currentTimeInSeconds;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkTimerLog::GetCPUTime()
 {
 #ifndef _WIN32_WCE
-  return static_cast<double>(clock()) /static_cast<double>(CLOCKS_PER_SEC);
+  return static_cast<double>(clock()) / static_cast<double>(CLOCKS_PER_SEC);
 #else
   return 1.0;
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the StartTime to the current time. Used with GetElapsedTime().
 void vtkTimerLog::StartTimer()
 {
   this->StartTime = vtkTimerLog::GetUniversalTime();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Sets EndTime to the current time. Used with GetElapsedTime().
 void vtkTimerLog::StopTimer()
 {
   this->EndTime = vtkTimerLog::GetUniversalTime();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the difference between StartTime and EndTime as
 // a floating point value indicating the elapsed time in seconds.
 double vtkTimerLog::GetElapsedTime()
@@ -730,51 +739,47 @@ double vtkTimerLog::GetElapsedTime()
   return (this->EndTime - this->StartTime);
 }
 
-//----------------------------------------------------------------------------
-void vtkTimerLog::DumpEntry(ostream& os, int index, double ttime,
-                            double deltatime, int tick, int deltatick,
-                            const char *event)
+//------------------------------------------------------------------------------
+void vtkTimerLog::DumpEntry(ostream& os, int index, double ttime, double deltatime, int tick,
+  int deltatick, const char* event)
 {
-  os << index << "   "
-     << ttime << "  "
-     << deltatime << "   "
-     << static_cast<double>(tick)/vtkTimerLog::TicksPerSecond << "  "
-     << static_cast<double>(deltatick)/vtkTimerLog::TicksPerSecond << "  ";
+  os << index << "   " << ttime << "  " << deltatime << "   "
+     << static_cast<double>(tick) / vtkTimerLog::TicksPerSecond << "  "
+     << static_cast<double>(deltatick) / vtkTimerLog::TicksPerSecond << "  ";
   if (deltatime == 0.0)
   {
     os << "0.0   ";
   }
   else
   {
-    os << 100.0*deltatick/vtkTimerLog::TicksPerSecond/deltatime << "   ";
+    os << 100.0 * deltatick / vtkTimerLog::TicksPerSecond / deltatime << "   ";
   }
   os << event << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTimerLog::SetMaxEntries(int a)
 {
   if (a == vtkTimerLog::MaxEntries)
   {
     return;
   }
+  auto& global_entries = vtkGetTimerLogEntryVector();
   int numEntries = vtkTimerLog::GetNumberOfEvents();
   if (vtkTimerLog::WrapFlag)
   { // if we've wrapped events, reorder them
     std::vector<vtkTimerLogEntry> tmp;
     tmp.reserve(vtkTimerLog::MaxEntries);
-    std::copy(vtkTimerLog::TimerLog.begin() + vtkTimerLog::NextEntry,
-              vtkTimerLog::TimerLog.end(),
-              std::back_inserter(tmp));
-    std::copy(vtkTimerLog::TimerLog.begin(),
-              vtkTimerLog::TimerLog.begin() + vtkTimerLog::NextEntry,
-              std::back_inserter(tmp));
-    vtkTimerLog::TimerLog = tmp;
+    std::copy(global_entries.begin() + vtkTimerLog::NextEntry, global_entries.end(),
+      std::back_inserter(tmp));
+    std::copy(global_entries.begin(), global_entries.begin() + vtkTimerLog::NextEntry,
+      std::back_inserter(tmp));
+    global_entries = tmp;
     vtkTimerLog::WrapFlag = 0;
   }
   if (numEntries <= a)
   {
-    vtkTimerLog::TimerLog.resize(a);
+    global_entries.resize(a);
     vtkTimerLog::NextEntry = numEntries;
     vtkTimerLog::WrapFlag = 0;
     vtkTimerLog::MaxEntries = a;
@@ -783,15 +788,15 @@ void vtkTimerLog::SetMaxEntries(int a)
   // Reduction so we need to get rid of the first bunch of events
   int offset = numEntries - a;
   assert(offset >= 0);
-  vtkTimerLog::TimerLog.erase(vtkTimerLog::TimerLog.begin(),
-                              vtkTimerLog::TimerLog.begin()+offset);
+  global_entries.erase(global_entries.begin(), global_entries.begin() + offset);
   vtkTimerLog::MaxEntries = a;
   vtkTimerLog::NextEntry = 0;
   vtkTimerLog::WrapFlag = 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTimerLog::GetMaxEntries()
 {
   return vtkTimerLog::MaxEntries;
 }
+VTK_ABI_NAMESPACE_END
