@@ -27,7 +27,7 @@
  * on the vtkPoints object, or the transformation might not update.
  * @sa
  * vtkLinearTransform
-*/
+ */
 
 #ifndef vtkLandmarkTransform_h
 #define vtkLandmarkTransform_h
@@ -39,27 +39,28 @@
 #define VTK_LANDMARK_SIMILARITY 7
 #define VTK_LANDMARK_AFFINE 12
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONTRANSFORMS_EXPORT vtkLandmarkTransform : public vtkLinearTransform
 {
 public:
-  static vtkLandmarkTransform *New();
+  static vtkLandmarkTransform* New();
 
-  vtkTypeMacro(vtkLandmarkTransform,vtkLinearTransform);
+  vtkTypeMacro(vtkLandmarkTransform, vtkLinearTransform);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the source and target landmark sets. The two sets must have
    * the same number of points.  If you add or change points in these objects,
    * you must call Modified() on them or the transformation might not update.
    */
-  void SetSourceLandmarks(vtkPoints *points);
-  void SetTargetLandmarks(vtkPoints *points);
+  void SetSourceLandmarks(vtkPoints* source);
+  void SetTargetLandmarks(vtkPoints* target);
   vtkGetObjectMacro(SourceLandmarks, vtkPoints);
   vtkGetObjectMacro(TargetLandmarks, vtkPoints);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the number of degrees of freedom to constrain the solution to.
    * Rigidbody (VTK_LANDMARK_RIGIDBODY): rotation and translation only.
@@ -69,19 +70,19 @@ public:
    * Ratios of distances along a line are preserved.
    * The default is similarity.
    */
-  vtkSetMacro(Mode,int);
-  void SetModeToRigidBody() { this->SetMode(VTK_LANDMARK_RIGIDBODY); };
-  void SetModeToSimilarity() { this->SetMode(VTK_LANDMARK_SIMILARITY); };
-  void SetModeToAffine() { this->SetMode(VTK_LANDMARK_AFFINE); };
-  //@}
+  vtkSetMacro(Mode, int);
+  void SetModeToRigidBody() { this->SetMode(VTK_LANDMARK_RIGIDBODY); }
+  void SetModeToSimilarity() { this->SetMode(VTK_LANDMARK_SIMILARITY); }
+  void SetModeToAffine() { this->SetMode(VTK_LANDMARK_AFFINE); }
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the current transformation mode.
    */
-  vtkGetMacro(Mode,int);
-  const char *GetModeAsString();
-  //@}
+  vtkGetMacro(Mode, int);
+  const char* GetModeAsString();
+  ///@}
 
   /**
    * Invert the transformation.  This is done by switching the
@@ -97,7 +98,7 @@ public:
   /**
    * Make another transform of the same type.
    */
-  vtkAbstractTransform *MakeTransform() override;
+  vtkAbstractTransform* MakeTransform() override;
 
 protected:
   vtkLandmarkTransform();
@@ -109,18 +110,19 @@ protected:
   /**
    * This method does no type checking, use DeepCopy instead.
    */
-  void InternalDeepCopy(vtkAbstractTransform *transform) override;
+  void InternalDeepCopy(vtkAbstractTransform* transform) override;
 
   vtkPoints* SourceLandmarks;
   vtkPoints* TargetLandmarks;
 
   int Mode;
+
 private:
   vtkLandmarkTransform(const vtkLandmarkTransform&) = delete;
   void operator=(const vtkLandmarkTransform&) = delete;
 };
 
-inline const char *vtkLandmarkTransform::GetModeAsString()
+inline const char* vtkLandmarkTransform::GetModeAsString()
 {
   switch (this->Mode)
   {
@@ -135,4 +137,5 @@ inline const char *vtkLandmarkTransform::GetModeAsString()
   }
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
