@@ -36,6 +36,7 @@
 #include "vtkCommonTransformsModule.h" // For export macro
 #include "vtkHomogeneousTransform.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONTRANSFORMS_EXPORT vtkLinearTransform : public vtkHomogeneousTransform
 {
 public:
@@ -75,7 +76,7 @@ public:
     return this->TransformDoubleNormal(normal[0], normal[1], normal[2]);
   }
 
-  //@{
+  ///@{
   /**
    * Apply the transformation to an (x,y,z) normal.
    * Use this if you are programming in python or Java.
@@ -92,9 +93,9 @@ public:
   {
     return this->TransformFloatNormal(normal[0], normal[1], normal[2]);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Apply the transformation to a double-precision (x,y,z) normal.
    * Use this if you are programming in python or Java.
@@ -111,7 +112,7 @@ public:
   {
     return this->TransformDoubleNormal(normal[0], normal[1], normal[2]);
   }
-  //@}
+  ///@}
 
   /**
    * Synonymous with TransformDoubleVector(x,y,z).
@@ -146,7 +147,7 @@ public:
     this->InternalTransformVector(in, out);
   }
 
-  //@{
+  ///@{
   /**
    * Apply the transformation to an (x,y,z) vector.
    * Use this if you are programming in python or Java.
@@ -163,9 +164,9 @@ public:
   {
     return this->TransformFloatVector(vec[0], vec[1], vec[2]);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Apply the transformation to a double-precision (x,y,z) vector.
    * Use this if you are programming in python or Java.
@@ -182,7 +183,7 @@ public:
   {
     return this->TransformDoubleVector(vec[0], vec[1], vec[2]);
   }
-  //@}
+  ///@}
 
   /**
    * Apply the transformation to a series of points, and append the
@@ -219,34 +220,34 @@ public:
     return static_cast<vtkLinearTransform*>(this->GetInverse());
   }
 
-  //@{
+  ///@{
   /**
    * This will calculate the transformation without calling Update.
    * Meant for use only within other VTK classes.
    */
   void InternalTransformPoint(const float in[3], float out[3]) override;
   void InternalTransformPoint(const double in[3], double out[3]) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This will calculate the transformation without calling Update.
    * Meant for use only within other VTK classes.
    */
   virtual void InternalTransformNormal(const float in[3], float out[3]);
   virtual void InternalTransformNormal(const double in[3], double out[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This will calculate the transformation without calling Update.
    * Meant for use only within other VTK classes.
    */
   virtual void InternalTransformVector(const float in[3], float out[3]);
   virtual void InternalTransformVector(const double in[3], double out[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This will calculate the transformation as well as its derivative
    * without calling Update.  Meant for use only within other VTK
@@ -256,7 +257,7 @@ public:
     const float in[3], float out[3], float derivative[3][3]) override;
   void InternalTransformDerivative(
     const double in[3], double out[3], double derivative[3][3]) override;
-  //@}
+  ///@}
 
 protected:
   vtkLinearTransform() = default;
@@ -267,4 +268,5 @@ private:
   void operator=(const vtkLinearTransform&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
