@@ -32,11 +32,13 @@
 
 #include "vtkTransform.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONTRANSFORMS_EXPORT vtkTransformCollection : public vtkCollection
 {
 public:
   vtkTypeMacro(vtkTransformCollection, vtkCollection);
   static vtkTransformCollection* New();
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Add a Transform to the list.
@@ -83,5 +85,5 @@ inline vtkTransform* vtkTransformCollection::GetNextItem()
   return static_cast<vtkTransform*>(this->GetNextItemAsObject());
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
-// VTK-HeaderTest-Exclude: vtkTransformCollection.h
