@@ -12,8 +12,6 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// Hide VTK_DEPRECATED_IN_9_1_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
 
 #include "vtkBlueObeliskData.h"
 
@@ -21,10 +19,6 @@
 #include "vtkBlueObeliskDataInternal.h"
 #include "vtkBlueObeliskDataParser.h"
 #include "vtkFloatArray.h"
-#include "vtkLegacy.h" // For VTK_LEGACY_REMOVE
-#if !defined(VTK_LEGACY_REMOVE)
-#include "vtkMutexLock.h"
-#endif
 #include "vtkObjectFactory.h"
 #include "vtkStringArray.h"
 #include "vtkTypeTraits.h"
@@ -33,6 +27,7 @@
 #include <vector>
 
 // Hidden STL reference: std::vector<vtkAbstractArray*>
+VTK_ABI_NAMESPACE_BEGIN
 class MyStdVectorOfVtkAbstractArrays : public std::vector<vtkAbstractArray*>
 {
 };
@@ -41,13 +36,7 @@ vtkStandardNewMacro(vtkBlueObeliskData);
 
 //------------------------------------------------------------------------------
 vtkBlueObeliskData::vtkBlueObeliskData()
-  :
-#if !defined(VTK_LEGACY_REMOVE)
-  WriteMutex(vtkSimpleMutexLock::New())
-#else
-  NewWriteMutex()
-#endif
-  , Initialized(false)
+  : Initialized(false)
   , NumberOfElements(0)
   , Arrays(new MyStdVectorOfVtkAbstractArrays)
 {
@@ -116,9 +105,6 @@ vtkBlueObeliskData::vtkBlueObeliskData()
 vtkBlueObeliskData::~vtkBlueObeliskData()
 {
   delete Arrays;
-#if !defined(VTK_LEGACY_REMOVE)
-  this->WriteMutex->Delete();
-#endif
 }
 
 //------------------------------------------------------------------------------
@@ -169,6 +155,7 @@ void vtkBlueObeliskData::PrintSelfIfExists(
     os << indent << name << " is null.\n";
   }
 }
+VTK_ABI_NAMESPACE_END
 
 // Helpers for reading raw data from the private header into a VTK array.
 namespace
@@ -200,24 +187,17 @@ void LoadDataArray(
 
 } // End anon namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 void vtkBlueObeliskData::LockWriteMutex()
 {
-#if !defined(VTK_LEGACY_REMOVE)
-  this->WriteMutex->Lock();
-#else
   this->NewWriteMutex.lock();
-#endif
 }
 
 //------------------------------------------------------------------------------
 void vtkBlueObeliskData::UnlockWriteMutex()
 {
-#if !defined(VTK_LEGACY_REMOVE)
-  this->WriteMutex->Unlock();
-#else
   this->NewWriteMutex.unlock();
-#endif
 }
 
 //------------------------------------------------------------------------------
@@ -229,10 +209,10 @@ void vtkBlueObeliskData::Initialize()
     return;
   }
 
-  this->NumberOfElements = _vtkBlueObeliskData::numberOfElements;
+  this->NumberOfElements = vtkBlueObeliskData_::numberOfElements;
   vtkIdType arraySize = this->NumberOfElements + 1; // 0 is dummy element
 
-#define READARRAY(name) LoadStringArray(this->name.Get(), _vtkBlueObeliskData::name, arraySize)
+#define READARRAY(name) LoadStringArray(this->name.Get(), vtkBlueObeliskData_::name, arraySize)
 
   READARRAY(Symbols);
   READARRAY(LowerSymbols);
@@ -244,7 +224,7 @@ void vtkBlueObeliskData::Initialize()
 
 #undef READARRAY
 #define READARRAY(numComps, name)                                                                  \
-  LoadDataArray<numComps>(this->name.Get(), _vtkBlueObeliskData::name, arraySize)
+  LoadDataArray<numComps>(this->name.Get(), vtkBlueObeliskData_::name, arraySize)
 
   READARRAY(1, Masses);
   READARRAY(1, ExactMasses);
@@ -264,6 +244,7 @@ void vtkBlueObeliskData::Initialize()
   this->Initialized = true;
 }
 
+VTK_ABI_NAMESPACE_END
 // Helpers for GenerateHeaderFromXML:
 namespace
 {
@@ -338,6 +319,7 @@ void WriteDataArray(const std::string& name, ArrayT* data, std::ostream& out)
 
 } // end anon namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 bool vtkBlueObeliskData::GenerateHeaderFromXML(std::istream& xml, std::ostream& out)
 {
@@ -353,7 +335,7 @@ bool vtkBlueObeliskData::GenerateHeaderFromXML(std::istream& xml, std::ostream&
   out << "// Autogenerated by vtkBlueObeliskData::GenerateHeaderFromXML.\n"
          "// Do not edit. Any modifications may be lost.\n"
          "\n"
-         "namespace _vtkBlueObeliskData {\n"
+         "namespace vtkBlueObeliskData_ {\n"
          "\n"
          "static const unsigned int numberOfElements = "
       << data->GetNumberOfElements() << ";\n\n";
@@ -383,7 +365,7 @@ bool vtkBlueObeliskData::GenerateHeaderFromXML(std::istream& xml, std::ostream&
 
 #undef DUMPARRAY
 
-  out << "} // end namespace _vtkBlueObeliskData\n";
+  out << "} // end namespace vtkBlueObeliskData_\n";
 
   return true;
 }
@@ -424,3 +406,4 @@ void vtkBlueObeliskData::Reset()
     (*it)->Reset();
   }
 }
+VTK_ABI_NAMESPACE_END
