@@ -20,8 +20,15 @@
 #include "vtkMolecule.h"
 #include "vtkPointData.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMoleculeToLinesFilter);
 
+//------------------------------------------------------------------------------
+void vtkMoleculeToLinesFilter::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 int vtkMoleculeToLinesFilter::RequestData(
   vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -47,3 +54,4 @@ int vtkMoleculeToLinesFilter::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
