@@ -23,8 +23,16 @@
 #include "vtkPointData.h"
 #include "vtkPointSet.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPointSetToMoleculeFilter);
 
+//------------------------------------------------------------------------------
+void vtkPointSetToMoleculeFilter::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "ConvertLinesIntoBonds: " << this->ConvertLinesIntoBonds << endl;
+}
+
 //------------------------------------------------------------------------------
 vtkPointSetToMoleculeFilter::vtkPointSetToMoleculeFilter()
   : ConvertLinesIntoBonds(true)
@@ -95,3 +103,4 @@ int vtkPointSetToMoleculeFilter::RequestData(
 
   return res;
 }
+VTK_ABI_NAMESPACE_END
