@@ -38,6 +38,7 @@
 #include <map>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkProteinRibbonFilter);
 
 namespace
@@ -165,8 +166,8 @@ int vtkProteinRibbonFilter::RequestData(
 
   for (int i = 0; i < input->GetNumberOfPoints(); i++)
   {
-    vtkStdString type = atomTypes->GetValue(i);
-    unsigned short atomicNum = static_cast<unsigned short>(atomType->GetValue(i) + 1);
+    std::string type = atomTypes->GetValue(i);
+    unsigned short atomicNum = static_cast<unsigned short>(atomType->GetValue(i));
 
     if (ishetatm->GetValue(i) && this->DrawSmallMoleculesAsSpheres)
     {
@@ -425,3 +426,4 @@ void vtkProteinRibbonFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
