@@ -32,20 +32,21 @@
 
 #include <vector>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkSimpleBondPerceiver);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSimpleBondPerceiver::vtkSimpleBondPerceiver()
   : Tolerance(0.45)
   , IsToleranceAbsolute(true)
 {
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSimpleBondPerceiver::~vtkSimpleBondPerceiver() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSimpleBondPerceiver::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -54,11 +55,9 @@ void vtkSimpleBondPerceiver::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "IsToleranceAbsolute: " << this->IsToleranceAbsolute << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSimpleBondPerceiver::RequestData(
-  vtkInformation* ,
-  vtkInformationVector** inputVector,
-  vtkInformationVector* outputVector)
+  vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   vtkMolecule* input = vtkMolecule::SafeDownCast(vtkDataObject::GetData(inputVector[0]));
   if (!input)
@@ -84,7 +83,7 @@ int vtkSimpleBondPerceiver::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSimpleBondPerceiver::ComputeBonds(vtkMolecule* molecule)
 {
   if (!molecule)
@@ -188,10 +187,11 @@ void vtkSimpleBondPerceiver::ComputeBonds(vtkMolecule* molecule)
   }
 }
 
-//----------------------------------------------------------------------------
-double vtkSimpleBondPerceiver::GetCovalentRadiusWithTolerance(vtkPeriodicTable* table,
-  vtkIdType atomicNumber)
+//------------------------------------------------------------------------------
+double vtkSimpleBondPerceiver::GetCovalentRadiusWithTolerance(
+  vtkPeriodicTable* table, vtkIdType atomicNumber)
 {
   return this->IsToleranceAbsolute ? table->GetCovalentRadius(atomicNumber) + this->Tolerance / 2
                                    : table->GetCovalentRadius(atomicNumber) * this->Tolerance;
 }
+VTK_ABI_NAMESPACE_END
