@@ -25,8 +25,19 @@
 #include "vtkTrivialProducer.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenGLMoleculeMapper);
 
+//------------------------------------------------------------------------------
+void vtkOpenGLMoleculeMapper::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "FastAtomMapper:\n";
+  this->FastAtomMapper->PrintSelf(os, indent.GetNextIndent());
+  os << indent << "FastBondMapper:\n";
+  this->FastBondMapper->PrintSelf(os, indent.GetNextIndent());
+}
+
 //------------------------------------------------------------------------------
 vtkOpenGLMoleculeMapper::vtkOpenGLMoleculeMapper()
 {
@@ -145,3 +156,4 @@ void vtkOpenGLMoleculeMapper::SetMapScalars(bool map)
   this->FastBondMapper->SetColorMode(
     map ? VTK_COLOR_MODE_MAP_SCALARS : VTK_COLOR_MODE_DIRECT_SCALARS);
 }
+VTK_ABI_NAMESPACE_END
