@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkYoungsMaterialInterfaceCEA.h,v $
+  Module:    vtkPSimpleBondPerceiver.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -28,8 +28,15 @@
 #include "vtkPolyData.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPSimpleBondPerceiver);
 
+//------------------------------------------------------------------------------
+void vtkPSimpleBondPerceiver::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 static inline bool InBounds(const double* bounds, const double* p)
 {
@@ -124,3 +131,4 @@ void vtkPSimpleBondPerceiver::ComputeBonds(vtkMolecule* molecule)
 
   this->Superclass::ComputeBonds(molecule);
 }
+VTK_ABI_NAMESPACE_END
