@@ -25,6 +25,7 @@
 #include "vtkThreadedImageAlgorithm.h"
 #include "vtkmyImagingModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBar;
 
 class VTKMYIMAGING_EXPORT vtkImageFoo : public vtkThreadedImageAlgorithm
@@ -34,15 +35,15 @@ public:
   vtkTypeMacro(vtkImageFoo, vtkThreadedImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the foo value.
    */
   vtkSetMacro(Foo, float);
   vtkGetMacro(Foo, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the desired output scalar type.
    */
@@ -59,7 +60,7 @@ public:
   void SetOutputScalarTypeToChar() { this->SetOutputScalarType(VTK_CHAR); }
   void SetOutputScalarTypeToSignedChar() { this->SetOutputScalarType(VTK_SIGNED_CHAR); }
   void SetOutputScalarTypeToUnsignedChar() { this->SetOutputScalarType(VTK_UNSIGNED_CHAR); }
-  //@}
+  ///@}
 
 protected:
   vtkImageFoo();
@@ -80,4 +81,5 @@ private:
   void operator=(const vtkImageFoo&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
