@@ -15,6 +15,13 @@
 #include "vtkBar2.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
-
 vtkStandardNewMacro(vtkBar2);
+
+//------------------------------------------------------------------------------
+void vtkBar2::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+VTK_ABI_NAMESPACE_END
