@@ -25,11 +25,13 @@
 #include "vtkObject.h"
 #include "vtkmyUnsortedModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKMYUNSORTED_EXPORT vtkBar2 : public vtkObject
 {
 public:
   static vtkBar2* New();
   vtkTypeMacro(vtkBar2, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
 protected:
   vtkBar2() {}
@@ -39,5 +41,6 @@ private:
   vtkBar2(const vtkBar2&) = delete;
   void operator=(const vtkBar2&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 
 #endif
