@@ -20,23 +20,25 @@
  *
  * This is a vtkContextItem that can be placed into a vtkContextScene. It draws
  * a block of the given dimensions, and reacts to mouse events.
-*/
+ */
 
 #ifndef vtkGraphItem_h
 #define vtkGraphItem_h
 
 #include "vtkContextItem.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContext2D;
 class vtkGraph;
+VTK_ABI_NAMESPACE_END
 
 class vtkGraphItem : public vtkContextItem
 {
 public:
   vtkTypeMacro(vtkGraphItem, vtkContextItem);
-  void PrintSelf(ostream &os, vtkIndent indent) override;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  static vtkGraphItem *New();
+  static vtkGraphItem* New();
 
   vtkGetObjectMacro(Graph, vtkGraph);
   virtual void SetGraph(vtkGraph* g);
@@ -44,37 +46,37 @@ public:
   /**
    * Paint event for the item.
    */
-  bool Paint(vtkContext2D *painter) override;
+  bool Paint(vtkContext2D* painter) override;
 
   /**
    * Returns true if the supplied x, y coordinate is inside the item.
    */
-  bool Hit(const vtkContextMouseEvent &mouse) override;
+  bool Hit(const vtkContextMouseEvent& mouse) override;
 
   /**
    * Mouse enter event.
    */
-  bool MouseEnterEvent(const vtkContextMouseEvent &mouse) override;
+  bool MouseEnterEvent(const vtkContextMouseEvent& mouse) override;
 
   /**
    * Mouse move event.
    */
-  bool MouseMoveEvent(const vtkContextMouseEvent &mouse) override;
+  bool MouseMoveEvent(const vtkContextMouseEvent& mouse) override;
 
   /**
    * Mouse leave event.
    */
-  bool MouseLeaveEvent(const vtkContextMouseEvent &mouse) override;
+  bool MouseLeaveEvent(const vtkContextMouseEvent& mouse) override;
 
   /**
    * Mouse button down event.
    */
-  bool MouseButtonPressEvent(const vtkContextMouseEvent &mouse) override;
+  bool MouseButtonPressEvent(const vtkContextMouseEvent& mouse) override;
 
   /**
    * Mouse button release event.
    */
-  bool MouseButtonReleaseEvent(const vtkContextMouseEvent &mouse) override;
+  bool MouseButtonReleaseEvent(const vtkContextMouseEvent& mouse) override;
 
   void UpdatePositions();
 
@@ -94,9 +96,8 @@ protected:
   Implementation* Impl;
 
 private:
-  vtkGraphItem(const vtkGraphItem &) = delete;
-  void operator=(const vtkGraphItem &) = delete;
-
+  vtkGraphItem(const vtkGraphItem&) = delete;
+  void operator=(const vtkGraphItem&) = delete;
 };
 
-#endif //vtkGraphItem_h
+#endif // vtkGraphItem_h
