@@ -21,8 +21,10 @@
 // Forward Qt class declarations
 class Ui_SimpleView;
 
+VTK_ABI_NAMESPACE_BEGIN
 // Forward VTK class declarations
 class vtkQtTableView;
+VTK_ABI_NAMESPACE_END
 
 class SimpleView : public QMainWindow
 {
