@@ -29,13 +29,14 @@
 #ifndef CustomLinkView_H
 #define CustomLinkView_H
 
-#include "vtkSmartPointer.h"    // Required for smart pointer internal ivars.
+#include "vtkSmartPointer.h" // Required for smart pointer internal ivars.
 
 #include <QMainWindow>
 
 // Forward Qt class declarations
 class Ui_CustomLinkView;
 
+VTK_ABI_NAMESPACE_BEGIN
 // Forward VTK class declarations
 class vtkCommand;
 class vtkEventQtSlotConnect;
@@ -44,52 +45,49 @@ class vtkObject;
 class vtkQtTableView;
 class vtkQtTreeView;
 class vtkXMLTreeReader;
+VTK_ABI_NAMESPACE_END
 
 class CustomLinkView : public QMainWindow
 {
   Q_OBJECT
 
 public:
-
   // Constructor/Destructor
   CustomLinkView();
   ~CustomLinkView() override;
 
-public slots:
+public Q_SLOTS:
 
   virtual void slotOpenXMLFile();
   virtual void slotExit();
 
 protected:
+protected Q_SLOTS:
 
-protected slots:
-
-public slots:
+public Q_SLOTS:
   // Qt signal (produced by vtkEventQtSlotConnect) will be connected to
   // this slot.
   // Full signature of the slot could be:
   // MySlot(vtkObject* caller, unsigned long vtk_event,
- //         void* clientData, void* callData, vtkCommand*)
+  //         void* clientData, void* callData, vtkCommand*)
   void selectionChanged(vtkObject*, unsigned long, void*, void* callData);
 
 private:
-
   // Methods
   void SetupCustomLink();
 
-
   // Members
-  vtkSmartPointer<vtkXMLTreeReader>       XMLReader;
-  vtkSmartPointer<vtkGraphLayoutView>     GraphView;
-  vtkSmartPointer<vtkQtTreeView>          TreeView;
-  vtkSmartPointer<vtkQtTableView>         TableView;
-  vtkSmartPointer<vtkQtTreeView>          ColumnView;
+  vtkSmartPointer<vtkXMLTreeReader> XMLReader;
+  vtkSmartPointer<vtkGraphLayoutView> GraphView;
+  vtkSmartPointer<vtkQtTreeView> TreeView;
+  vtkSmartPointer<vtkQtTableView> TableView;
+  vtkSmartPointer<vtkQtTreeView> ColumnView;
 
   // This class converts a vtkEvent to QT signal.
-  vtkSmartPointer<vtkEventQtSlotConnect>  Connections;
+  vtkSmartPointer<vtkEventQtSlotConnect> Connections;
 
   // Designer form
-  Ui_CustomLinkView *ui;
+  Ui_CustomLinkView* ui;
 };
 
 #endif // CustomLinkView_H
