@@ -11,17 +11,17 @@
 #include <QSurfaceFormat>
 
 #include "EasyView.h"
-#include "QVTKOpenGLWidget.h"
+#include "QVTKRenderWidget.h"
 
 extern int qInitResources_icons();
 
-int main( int argc, char** argv )
+int main(int argc, char** argv)
 {
   // needed to ensure appropriate OpenGL context is created for VTK rendering.
-  QSurfaceFormat::setDefaultFormat(QVTKOpenGLWidget::defaultFormat());
+  QSurfaceFormat::setDefaultFormat(QVTKRenderWidget::defaultFormat());
 
   // QT Stuff
-  QApplication app( argc, argv );
+  QApplication app(argc, argv);
 
   QApplication::setStyle("fusion");
 
