@@ -43,6 +43,7 @@
 #include <cmath>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAMRResampleFilter);
 vtkCxxSetObjectMacro(vtkAMRResampleFilter, Controller, vtkMultiProcessController);
 
@@ -125,7 +126,7 @@ int vtkAMRResampleFilter::RequestUpdateExtent(vtkInformation*, vtkInformationVec
     info->Set(vtkCompositeDataPipeline::LOAD_REQUESTED_BLOCKS(), 1);
 
     // Tell reader which blocks this process requires
-    info->Set(vtkCompositeDataPipeline::UPDATE_COMPOSITE_INDICES(), &this->BlocksToLoad[0],
+    info->Set(vtkCompositeDataPipeline::UPDATE_COMPOSITE_INDICES(), this->BlocksToLoad.data(),
       static_cast<int>(this->BlocksToLoad.size()));
   }
   return 1;
@@ -830,6 +831,10 @@ void vtkAMRResampleFilter::ExtractRegion(
   mbds->SetNumberOfBlocks(this->ROI->GetNumberOfBlocks());
   for (unsigned int block = 0; block < this->ROI->GetNumberOfBlocks(); ++block)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     if (this->IsRegionMine(block))
     {
       vtkUniformGrid* grid = vtkUniformGrid::New();
@@ -1230,3 +1235,4 @@ vtkUniformGrid* vtkAMRResampleFilter::GetReferenceGrid(vtkOverlappingAMR* amrds)
   // This process has no grids
   return nullptr;
 }
+VTK_ABI_NAMESPACE_END
