@@ -42,56 +42,58 @@
 #include <cassert>
 #include <sstream>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAMRSliceFilter);
+vtkCxxSetObjectMacro(vtkAMRSliceFilter, Controller, vtkMultiProcessController);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAMRSliceFilter::vtkAMRSliceFilter()
 {
   this->SetNumberOfInputPorts(1);
   this->SetNumberOfOutputPorts(1);
   this->OffsetFromOrigin = 0.0;
   this->Normal = X_NORMAL;
-  this->Controller = vtkMultiProcessController::GetGlobalController();
+  this->Controller = nullptr;
+  this->SetController(vtkMultiProcessController::GetGlobalController());
   this->MaxResolution = 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+vtkAMRSliceFilter::~vtkAMRSliceFilter()
+{
+  this->SetController(nullptr);
+}
+
+//------------------------------------------------------------------------------
 void vtkAMRSliceFilter::PrintSelf(std::ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//-----------------------------------------------------------------------------
-int vtkAMRSliceFilter::FillInputPortInformation(int vtkNotUsed(port),
-                                                vtkInformation* info)
+//------------------------------------------------------------------------------
+int vtkAMRSliceFilter::FillInputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkOverlappingAMR");
   return 1;
 }
 
-//-----------------------------------------------------------------------------
-int vtkAMRSliceFilter::FillOutputPortInformation(int vtkNotUsed(port),
-                                                 vtkInformation* info)
+//------------------------------------------------------------------------------
+int vtkAMRSliceFilter::FillOutputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkOverlappingAMR");
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkAMRSliceFilter::IsAMRData2D(vtkOverlappingAMR* input)
 {
   assert("pre: Input AMR dataset is nullptr" && (input != nullptr));
 
-  if (input->GetGridDescription() != VTK_XYZ_GRID)
-  {
-    return true;
-  }
-
-  return false;
+  return input->GetGridDescription() != VTK_XYZ_GRID;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPlane* vtkAMRSliceFilter::GetCutPlane(vtkOverlappingAMR* inp)
 {
   assert("pre: AMR dataset should not be nullptr" && (inp != nullptr));
@@ -111,8 +113,7 @@ vtkPlane* vtkAMRSliceFilter::GetCutPlane(vtkOverlappingAMR* inp)
     porigin[i] = minBounds[i];
 
   auto offset = vtkMath::ClampValue(
-    this->OffsetFromOrigin, 0.0,
-    maxBounds[this->Normal / 2] - minBounds[this->Normal / 2]);
+    this->OffsetFromOrigin, 0.0, maxBounds[this->Normal / 2] - minBounds[this->Normal / 2]);
 
   switch (this->Normal)
   {
@@ -137,7 +138,7 @@ vtkPlane* vtkAMRSliceFilter::GetCutPlane(vtkOverlappingAMR* inp)
   return (pl);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUniformGrid* vtkAMRSliceFilter::GetSlice(
   double origin[3], int* dims, double* gorigin, double* spacing)
 {
@@ -202,9 +203,8 @@ vtkUniformGrid* vtkAMRSliceFilter::GetSlice(
   return (slice);
 }
 
-//-----------------------------------------------------------------------------
-bool vtkAMRSliceFilter::PlaneIntersectsAMRBox(double plane[4],
-                                              double bounds[6])
+//------------------------------------------------------------------------------
+bool vtkAMRSliceFilter::PlaneIntersectsAMRBox(double plane[4], double bounds[6])
 {
   bool lowPnt = false;
   bool highPnt = false;
@@ -240,9 +240,8 @@ bool vtkAMRSliceFilter::PlaneIntersectsAMRBox(double plane[4],
   return false;
 }
 
-//-----------------------------------------------------------------------------
-void vtkAMRSliceFilter::ComputeAMRBlocksToLoad(vtkPlane* p,
-                                               vtkOverlappingAMR* metadata)
+//------------------------------------------------------------------------------
+void vtkAMRSliceFilter::ComputeAMRBlocksToLoad(vtkPlane* p, vtkOverlappingAMR* metadata)
 {
   assert("pre: plane object is nullptr" && (p != nullptr));
   assert("pre: metadata object is nullptr" && (metadata != nullptr));
@@ -254,22 +253,17 @@ void vtkAMRSliceFilter::ComputeAMRBlocksToLoad(vtkPlane* p,
   plane[0] = p->GetNormal()[0];
   plane[1] = p->GetNormal()[1];
   plane[2] = p->GetNormal()[2];
-  plane[3] = p->GetNormal()[0] * p->GetOrigin()[0] +
-             p->GetNormal()[1] * p->GetOrigin()[1] +
-             p->GetNormal()[2] * p->GetOrigin()[2];
+  plane[3] = p->GetNormal()[0] * p->GetOrigin()[0] + p->GetNormal()[1] * p->GetOrigin()[1] +
+    p->GetNormal()[2] * p->GetOrigin()[2];
 
   vtkSmartPointer<vtkUniformGridAMRDataIterator> iter;
-  iter.TakeReference(
-    vtkUniformGridAMRDataIterator::SafeDownCast(metadata->NewIterator()));
+  iter.TakeReference(vtkUniformGridAMRDataIterator::SafeDownCast(metadata->NewIterator()));
   iter->SetSkipEmptyNodes(false);
-  for (iter->InitTraversal();
-       !iter->IsDoneWithTraversal();
-       iter->GoToNextItem())
+  for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
   {
     if (iter->GetCurrentLevel() <= this->MaxResolution)
     {
-      double* bounds =
-        iter->GetCurrentMetaData()->Get(vtkDataObject::BOUNDING_BOX());
+      double* bounds = iter->GetCurrentMetaData()->Get(vtkDataObject::BOUNDING_BOX());
       if (this->PlaneIntersectsAMRBox(plane, bounds))
       {
         unsigned int amrGridIdx = iter->GetCurrentFlatIndex();
@@ -279,7 +273,7 @@ void vtkAMRSliceFilter::ComputeAMRBlocksToLoad(vtkPlane* p,
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAMRSliceFilter::GetAMRSliceInPlane(
   vtkPlane* p, vtkOverlappingAMR* inp, vtkOverlappingAMR* out)
 {
@@ -308,8 +302,7 @@ void vtkAMRSliceFilter::GetAMRSliceInPlane(
     this->ComputeAMRBlocksToLoad(p, inp);
   }
 
-  auto numLevels =
-    vtkMath::Min(this->MaxResolution + 1, inp->GetNumberOfLevels());
+  auto numLevels = vtkMath::Min(this->MaxResolution + 1, inp->GetNumberOfLevels());
   std::vector<int> blocksPerLevel(numLevels, 0);
   for (unsigned int i = 0; i < this->BlocksToLoad.size(); i++)
   {
@@ -333,7 +326,7 @@ void vtkAMRSliceFilter::GetAMRSliceInPlane(
     }
   }
 
-  out->Initialize(static_cast<int>(blocksPerLevel.size()), &blocksPerLevel[0]);
+  out->Initialize(static_cast<int>(blocksPerLevel.size()), blocksPerLevel.data());
   out->SetGridDescription(description);
   out->SetOrigin(p->GetOrigin());
   vtkTimerLog::MarkStartEvent("AMRSlice::GetAMRSliceInPlane");
@@ -341,6 +334,10 @@ void vtkAMRSliceFilter::GetAMRSliceInPlane(
   std::vector<int> dataIndices(out->GetNumberOfLevels(), 0);
   for (unsigned int i = 0; i < this->BlocksToLoad.size(); i++)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     int flatIndex = this->BlocksToLoad[i];
     unsigned int level;
     unsigned int dataIdx;
@@ -353,12 +350,8 @@ void vtkAMRSliceFilter::GetAMRSliceInPlane(
       // Get the 3-D Grid dimensions
       int dims[3];
       grid->GetDimensions(dims);
-      slice = this->GetSlice(p->GetOrigin(),
-                             dims,
-                             grid->GetOrigin(),
-                             grid->GetSpacing());
-      assert("Dimension of slice must be 2-D"
-        && (slice->GetDataDimension() == 2));
+      slice = this->GetSlice(p->GetOrigin(), dims, grid->GetOrigin(), grid->GetSpacing());
+      assert("Dimension of slice must be 2-D" && (slice->GetDataDimension() == 2));
       assert("2-D slice is nullptr" && (slice != nullptr));
       this->GetSliceCellData(slice, grid);
       this->GetSlicePointData(slice, grid);
@@ -374,11 +367,8 @@ void vtkAMRSliceFilter::GetAMRSliceInPlane(
       slice = this->GetSlice(p->GetOrigin(), dims, origin, spacing);
     }
 
-    vtkAMRBox box(slice->GetOrigin(),
-                  slice->GetDimensions(),
-                  slice->GetSpacing(),
-                  out->GetOrigin(),
-                  out->GetGridDescription());
+    vtkAMRBox box(slice->GetOrigin(), slice->GetDimensions(), slice->GetSpacing(), out->GetOrigin(),
+      out->GetGridDescription());
     out->SetSpacing(level, slice->GetSpacing());
     out->SetAMRBox(level, dataIndices[level], box);
     if (grid)
@@ -392,18 +382,21 @@ void vtkAMRSliceFilter::GetAMRSliceInPlane(
   vtkTimerLog::MarkEndEvent("AMRSlice::GetAMRSliceInPlane");
 
   vtkTimerLog::MarkStartEvent("AMRSlice::Generate Blanking");
-  vtkParallelAMRUtilities::BlankCells(out, this->Controller);
+
+  // Skipping BlankCells incase out is empty
+  if (!this->CheckAbort())
+  {
+    vtkParallelAMRUtilities::BlankCells(out, this->Controller);
+  }
   vtkTimerLog::MarkEndEvent("AMRSlice::Generate Blanking");
 }
 
-//-----------------------------------------------------------------------------
-void vtkAMRSliceFilter::ComputeCellCenter(vtkUniformGrid* ug,
-                                          const int cellIdx,
-                                          double centroid[3])
+//------------------------------------------------------------------------------
+void vtkAMRSliceFilter::ComputeCellCenter(vtkUniformGrid* ug, const int cellIdx, double centroid[3])
 {
   assert("pre: Input grid is nullptr" && (ug != nullptr));
-  assert("pre: cell index out-of-bounds!"
-    && ((cellIdx >= 0) && (cellIdx < ug->GetNumberOfCells())));
+  assert(
+    "pre: cell index out-of-bounds!" && ((cellIdx >= 0) && (cellIdx < ug->GetNumberOfCells())));
 
   vtkCell* myCell = ug->GetCell(cellIdx);
   assert("post: cell is nullptr" && (myCell != nullptr));
@@ -414,7 +407,7 @@ void vtkAMRSliceFilter::ComputeCellCenter(vtkUniformGrid* ug,
   myCell->EvaluateLocation(subId, pCenter, centroid, weights);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAMRSliceFilter::GetDonorCellIdx(double x[3], vtkUniformGrid* ug)
 {
   const double* x0 = ug->GetOrigin();
@@ -431,7 +424,7 @@ int vtkAMRSliceFilter::GetDonorCellIdx(double x[3], vtkUniformGrid* ug)
   return (vtkStructuredData::ComputeCellId(dims, ijk));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAMRSliceFilter::GetDonorPointIdx(double x[3], vtkUniformGrid* ug)
 {
   const double* x0 = ug->GetOrigin();
@@ -448,9 +441,8 @@ int vtkAMRSliceFilter::GetDonorPointIdx(double x[3], vtkUniformGrid* ug)
   return vtkStructuredData::ComputePointId(dims, ijk);
 }
 
-//-----------------------------------------------------------------------------
-void vtkAMRSliceFilter::GetSliceCellData(vtkUniformGrid* slice,
-                                         vtkUniformGrid* grid3D)
+//------------------------------------------------------------------------------
+void vtkAMRSliceFilter::GetSliceCellData(vtkUniformGrid* slice, vtkUniformGrid* grid3D)
 {
   // STEP 1: Allocate data-structures
   vtkCellData* sourceCD = grid3D->GetCellData();
@@ -472,14 +464,13 @@ void vtkAMRSliceFilter::GetSliceCellData(vtkUniformGrid* slice,
     vtkDataArray* array = sourceCD->GetArray(arrayIdx)->NewInstance();
     array->Initialize();
     array->SetName(sourceCD->GetArray(arrayIdx)->GetName());
-    array->SetNumberOfComponents(
-      sourceCD->GetArray(arrayIdx)->GetNumberOfComponents());
+    array->SetNumberOfComponents(sourceCD->GetArray(arrayIdx)->GetNumberOfComponents());
     array->SetNumberOfTuples(numCells);
     targetCD->AddArray(array);
     vtkUnsignedCharArray* uca = vtkArrayDownCast<vtkUnsignedCharArray>(array);
     if (uca != nullptr && uca == slice->GetCellGhostArray())
     {
-      // initiallize the ghost array
+      // initialize the ghost array
       memset(uca->WritePointer(0, numCells), 0, numCells);
     }
     array->Delete();
@@ -505,9 +496,8 @@ void vtkAMRSliceFilter::GetSliceCellData(vtkUniformGrid* slice,
   }
 }
 
-//-----------------------------------------------------------------------------
-void vtkAMRSliceFilter::GetSlicePointData(vtkUniformGrid* slice,
-                                          vtkUniformGrid* grid3D)
+//------------------------------------------------------------------------------
+void vtkAMRSliceFilter::GetSlicePointData(vtkUniformGrid* slice, vtkUniformGrid* grid3D)
 {
   // STEP 1: Allocate data-structures
   vtkPointData* sourcePD = grid3D->GetPointData();
@@ -529,8 +519,7 @@ void vtkAMRSliceFilter::GetSlicePointData(vtkUniformGrid* slice,
     vtkDataArray* array = sourcePD->GetArray(arrayIdx)->NewInstance();
     array->Initialize();
     array->SetName(sourcePD->GetArray(arrayIdx)->GetName());
-    array->SetNumberOfComponents(
-      sourcePD->GetArray(arrayIdx)->GetNumberOfComponents());
+    array->SetNumberOfComponents(sourcePD->GetArray(arrayIdx)->GetNumberOfComponents());
     array->SetNumberOfTuples(numPoints);
     targetPD->AddArray(array);
     vtkUnsignedCharArray* uca = vtkArrayDownCast<vtkUnsignedCharArray>(array);
@@ -562,10 +551,9 @@ void vtkAMRSliceFilter::GetSlicePointData(vtkUniformGrid* slice,
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAMRSliceFilter::RequestInformation(vtkInformation* vtkNotUsed(rqst),
-  vtkInformationVector** inputVector,
-  vtkInformationVector* vtkNotUsed(outputVector))
+  vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector))
 {
   this->BlocksToLoad.clear();
 
@@ -588,25 +576,23 @@ int vtkAMRSliceFilter::RequestInformation(vtkInformation* vtkNotUsed(rqst),
   return 1;
 }
 
-//-----------------------------------------------------------------------------
-int vtkAMRSliceFilter::RequestUpdateExtent(vtkInformation*,
-  vtkInformationVector** inputVector,
+//------------------------------------------------------------------------------
+int vtkAMRSliceFilter::RequestUpdateExtent(vtkInformation*, vtkInformationVector** inputVector,
   vtkInformationVector* vtkNotUsed(outputVector))
 {
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   assert("pre: inInfo is nullptr" && (inInfo != nullptr));
 
   // Send upstream request for higher resolution
-  if (this->BlocksToLoad.size() > 0)
+  if (!this->BlocksToLoad.empty())
   {
-    inInfo->Set(vtkCompositeDataPipeline::UPDATE_COMPOSITE_INDICES(),
-                &this->BlocksToLoad[0],
-    static_cast<int>(this->BlocksToLoad.size()));
+    inInfo->Set(vtkCompositeDataPipeline::UPDATE_COMPOSITE_INDICES(), this->BlocksToLoad.data(),
+      static_cast<int>(this->BlocksToLoad.size()));
   }
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAMRSliceFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -632,7 +618,7 @@ int vtkAMRSliceFilter::RequestData(vtkInformation* vtkNotUsed(request),
 
   if (this->IsAMRData2D(inputAMR))
   {
-    outputAMR->ShallowCopy(inputAMR);
+    outputAMR->CompositeShallowCopy(inputAMR);
     return 1;
   }
 
@@ -647,3 +633,4 @@ int vtkAMRSliceFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkTimerLog::MarkEndEvent(eventName.c_str());
   return 1;
 }
+VTK_ABI_NAMESPACE_END
