@@ -128,8 +128,9 @@ int TestNamedComponents(int, char*[])
   thresh->SetInputData(poly);
   thresh->SetInputArrayToProcess(
     0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_CELLS, vtkDataSetAttributes::SCALARS);
-
-  thresh->ThresholdBetween(0, 10);
+  thresh->SetThresholdFunction(vtkThreshold::THRESHOLD_BETWEEN);
+  thresh->SetLowerThreshold(0.0);
+  thresh->SetUpperThreshold(10.0);
   thresh->Update();
 
   vtkSmartPointer<vtkUnstructuredGrid> out = thresh->GetOutput();
@@ -166,8 +167,8 @@ int TestNamedComponents(int, char*[])
   calc->SetAttributeTypeToPointData();
   // Add coordinate scalar and vector variables
   calc->AddCoordinateScalarVariable("coordsX", 0);
-  calc->AddScalarVariable("point coords_YLOC", "point coords", 1);
-  calc->SetFunction("coordsX + point coords_YLOC");
+  calc->AddScalarVariable("\"point coords_YLOC\"", "point coords", 1);
+  calc->SetFunction("coordsX + \"point coords_YLOC\"");
   calc->SetResultArrayName("Result");
   calc->Update();
 
