@@ -15,30 +15,30 @@
 #include "vtkDataSetTriangleFilter.h"
 #include "vtkImageDataToPointSet.h"
 #include "vtkMappedUnstructuredGridGenerator.h"
-#include "vtkPartitionedDataSet.h"
 #include "vtkPlane.h"
 #include "vtkPlaneCutter.h"
 #include "vtkPointDataToCellData.h"
-#include "vtkPoints.h"
-#include "vtkPolygonBuilder.h"
+#include "vtkPolyData.h"
 #include "vtkRTAnalyticSource.h"
 #include "vtkSmartPointer.h"
 #include "vtkUnstructuredGrid.h"
 #include "vtkUnstructuredGridBase.h"
-#include <cassert>
 
 #define Compare(output, expected)                                                                  \
-  if (output->GetNumberOfCells() != expected)                                                      \
+  do                                                                                               \
   {                                                                                                \
-    cerr << "Test " << __FUNCTION__ << " expected " << expected << " cells, got "                  \
-         << output->GetNumberOfCells() << endl;                                                    \
-    return false;                                                                                  \
-  }                                                                                                \
-  else                                                                                             \
-  {                                                                                                \
-    cout << "Test " << __FUNCTION__ << " succeeded with " << output->GetNumberOfCells()            \
-         << " cells." << endl;                                                                     \
-  }
+    if (output->GetNumberOfCells() != expected)                                                    \
+    {                                                                                              \
+      cerr << "Test " << __FUNCTION__ << " expected " << expected << " cells, got "                \
+           << output->GetNumberOfCells() << endl;                                                  \
+      return false;                                                                                \
+    }                                                                                              \
+    else                                                                                           \
+    {                                                                                              \
+      cout << "Test " << __FUNCTION__ << " succeeded with " << output->GetNumberOfCells()          \
+           << " cells." << endl;                                                                   \
+    }                                                                                              \
+  } while (false)
 
 bool TestPlaneCutterStructured(int type, int expected)
 {
@@ -66,13 +66,12 @@ bool TestPlaneCutterStructured(int type, int expected)
 
   cutter->SetGeneratePolygons(true);
   cutter->Update();
-  vtkPartitionedDataSet* output =
-    vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
 
   cutter->SetGeneratePolygons(false);
   cutter->Update();
-  output = vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, 7);
   return true;
 }
@@ -94,13 +93,12 @@ bool TestPlaneCutterUnmapped(int expected)
   cutter->Update();
   mg->Delete();
 
-  vtkPartitionedDataSet* output =
-    vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
 
   cutter->SetGeneratePolygons(false);
   cutter->Update();
-  output = vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
   return true;
 }
@@ -122,13 +120,12 @@ bool TestPlaneCutterMapped(int expected)
   cutter->Update();
   mg->Delete();
 
-  vtkPartitionedDataSet* output =
-    vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
 
   cutter->SetGeneratePolygons(false);
   cutter->Update();
-  output = vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
   return true;
 }
@@ -158,23 +155,21 @@ bool TestPlaneCutterUnstructured(int expected)
   // so the number of expected cells is always the number of triangles.
   cutter->SetGeneratePolygons(true);
   cutter->Update();
-  vtkPartitionedDataSet* output =
-    vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
 
   cutter->SetGeneratePolygons(false);
   cutter->Update();
-  output = vtkPartitionedDataSet::SafeDownCast(cutter->GetOutputDataObject(0));
+  output = vtkPolyData::SafeDownCast(cutter->GetOutputDataObject(0));
   Compare(output, expected);
   return true;
 }
 
 int TestPlaneCutter(int, char*[])
 {
-  int expected[] = { 7, 4 };
   for (int type = 0; type < 2; type++)
   {
-    if (!TestPlaneCutterStructured(type, expected[type]))
+    if (!TestPlaneCutterStructured(type, 4))
     {
       cerr << "Cutting Structured failed" << endl;
       return EXIT_FAILURE;
