@@ -33,7 +33,7 @@
  * there are global point ids. In the case of the presence of global point ids,
  * the filter exclusively relies on those ids, not checking if points are
  * coincident. It assumes that the global ids were properly set. In the case of
- * the absence of global ids, points withing Tolerance are merged.
+ * the absence of global ids, points within Tolerance are merged.
  *
  * @sa
  * vtkAppendFilter vtkAppendPolyData
@@ -45,6 +45,7 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPointSetAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkDataSetCollection;
 
@@ -55,7 +56,7 @@ public:
   vtkTypeMacro(vtkAppendDataSets, vtkPointSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set if the filter should merge coincidental points
    * Note: The filter will only merge points if the ghost cell array doesn't exist
@@ -64,9 +65,9 @@ public:
   vtkGetMacro(MergePoints, bool);
   vtkSetMacro(MergePoints, bool);
   vtkBooleanMacro(MergePoints, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the tolerance to use to find coincident points when `MergePoints`
    * is `true`. Default is 0.0.
@@ -76,9 +77,9 @@ public:
    */
   vtkSetClampMacro(Tolerance, double, 0.0, VTK_DOUBLE_MAX);
   vtkGetMacro(Tolerance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set whether Tolerance is treated as an absolute or relative tolerance.
    * The default is to treat it as an absolute tolerance. When off, the
@@ -87,9 +88,9 @@ public:
   vtkSetMacro(ToleranceIsAbsolute, bool);
   vtkGetMacro(ToleranceIsAbsolute, bool);
   vtkBooleanMacro(ToleranceIsAbsolute, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the output type produced by this filter. Only input datasets compatible with the
    * output type will be merged in the output. For example, if the output type is vtkPolyData, then
@@ -101,9 +102,9 @@ public:
    */
   vtkSetMacro(OutputDataSetType, int);
   vtkGetMacro(OutputDataSetType, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output types. See the documentation
    * for the vtkAlgorithm::Precision enum for an explanation of the available
@@ -111,7 +112,7 @@ public:
    */
   vtkSetClampMacro(OutputPointsPrecision, int, SINGLE_PRECISION, DEFAULT_PRECISION);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
   /**
    * see vtkAlgorithm for details
@@ -156,4 +157,5 @@ private:
   vtkDataSetCollection* GetNonEmptyInputs(vtkInformationVector** inputVector);
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
