@@ -14,12 +14,12 @@
 =========================================================================*/
 #include "vtkAppendPolyData.h"
 
-#include "vtkAssume.h"
-#include "vtkArrayDispatch.h"
 #include "vtkAlgorithmOutput.h"
+#include "vtkArrayDispatch.h"
+#include "vtkAssume.h"
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
-#include "vtkDataArrayAccessor.h"
+#include "vtkDataArrayRange.h"
 #include "vtkDataSetAttributes.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -32,9 +32,10 @@
 #include <cassert>
 #include <cstdlib>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAppendPolyData);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAppendPolyData::vtkAppendPolyData()
 {
   this->ParallelStreaming = 0;
@@ -42,30 +43,28 @@ vtkAppendPolyData::vtkAppendPolyData()
   this->OutputPointsPrecision = vtkAlgorithm::DEFAULT_PRECISION;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAppendPolyData::~vtkAppendPolyData() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a dataset to the list of data to append.
-void vtkAppendPolyData::AddInputData(vtkPolyData *ds)
+void vtkAppendPolyData::AddInputData(vtkPolyData* ds)
 {
   if (this->UserManagedInputs)
   {
-    vtkErrorMacro(<<
-      "AddInput is not supported if UserManagedInputs is true");
+    vtkErrorMacro(<< "AddInput is not supported if UserManagedInputs is true");
     return;
   }
   this->Superclass::AddInputData(ds);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove a dataset from the list of data to append.
-void vtkAppendPolyData::RemoveInputData(vtkPolyData *ds)
+void vtkAppendPolyData::RemoveInputData(vtkPolyData* ds)
 {
   if (this->UserManagedInputs)
   {
-    vtkErrorMacro(<<
-      "RemoveInput is not supported if UserManagedInputs is true");
+    vtkErrorMacro(<< "RemoveInput is not supported if UserManagedInputs is true");
     return;
   }
 
@@ -74,25 +73,23 @@ void vtkAppendPolyData::RemoveInputData(vtkPolyData *ds)
     return;
   }
   int numCons = this->GetNumberOfInputConnections(0);
-  for(int i=0; i<numCons; i++)
+  for (int i = 0; i < numCons; i++)
   {
     if (this->GetInput(i) == ds)
     {
-      this->RemoveInputConnection(0,
-        this->GetInputConnection(0, i));
+      this->RemoveInputConnection(0, this->GetInputConnection(0, i));
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // make ProcessObject function visible
 // should only be used when UserManagedInputs is true.
 void vtkAppendPolyData::SetNumberOfInputs(int num)
 {
   if (!this->UserManagedInputs)
   {
-    vtkErrorMacro(<<
-      "SetNumberOfInputs is not supported if UserManagedInputs is false");
+    vtkErrorMacro(<< "SetNumberOfInputs is not supported if UserManagedInputs is false");
     return;
   }
 
@@ -100,7 +97,7 @@ void vtkAppendPolyData::SetNumberOfInputs(int num)
   this->SetNumberOfInputConnections(0, num);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAppendPolyData::SetInputDataByNumber(int num, vtkPolyData* input)
 {
   vtkTrivialProducer* tp = vtkTrivialProducer::New();
@@ -109,15 +106,13 @@ void vtkAppendPolyData::SetInputDataByNumber(int num, vtkPolyData* input)
   tp->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set Nth input, should only be used when UserManagedInputs is true.
-void vtkAppendPolyData::SetInputConnectionByNumber(int num,
-                                                   vtkAlgorithmOutput *input)
+void vtkAppendPolyData::SetInputConnectionByNumber(int num, vtkAlgorithmOutput* input)
 {
   if (!this->UserManagedInputs)
   {
-    vtkErrorMacro(<<
-      "SetInputConnectionByNumber is not supported if UserManagedInputs is false");
+    vtkErrorMacro(<< "SetInputConnectionByNumber is not supported if UserManagedInputs is false");
     return;
   }
 
@@ -125,35 +120,33 @@ void vtkAppendPolyData::SetInputConnectionByNumber(int num,
   this->SetNthInputConnection(0, num, input);
 }
 
-//----------------------------------------------------------------------------
-int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
-    vtkPolyData* inputs[], int numInputs)
+//------------------------------------------------------------------------------
+int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output, vtkPolyData* inputs[], int numInputs)
 {
   int idx;
-  vtkPolyData *ds;
-  vtkPoints  *inPts;
-  vtkPoints *newPts;
+  vtkPolyData* ds;
+  vtkPoints* inPts;
+  vtkPoints* newPts;
   vtkCellArray *inVerts, *newVerts;
   vtkCellArray *inLines, *newLines;
   vtkCellArray *inPolys, *newPolys;
   vtkIdType sizePolys, numPolys;
   vtkCellArray *inStrips, *newStrips;
   vtkIdType numPts, numCells;
-  vtkPointData *inPD = nullptr;
-  vtkCellData *inCD = nullptr;
-  vtkPointData *outputPD = output->GetPointData();
-  vtkCellData *outputCD = output->GetCellData();
-  vtkIdType *pStrips, *pLines, *pPolys,*pVerts;
+  vtkPointData* inPD = nullptr;
+  vtkCellData* inCD = nullptr;
+  vtkPointData* outputPD = output->GetPointData();
+  vtkCellData* outputCD = output->GetCellData();
 
-  vtkDebugMacro(<<"Appending polydata");
+  vtkDebugMacro(<< "Appending polydata");
 
   // loop over all data sets, checking to see what point data is available.
   numPts = 0;
   numCells = 0;
   sizePolys = numPolys = 0;
 
-  int countPD=0;
-  int countCD=0;
+  int countPD = 0;
+  int countCD = 0;
 
   vtkIdType numVerts = 0, numLines = 0, numStrips = 0;
   vtkIdType sizeLines = 0, sizeStrips = 0, sizeVerts = 0;
@@ -173,8 +166,8 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
       {
         ++countCD;
       } // for a data set that has cells
-    } // for a non nullptr input
-  } // for each input
+    }   // for a non nullptr input
+  }     // for each input
 
   // These are used to determine which fields are available for appending
   vtkDataSetAttributes::FieldList ptList(countPD);
@@ -208,20 +201,20 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
       {
         if (ds->GetVerts())
         {
-          sizeVerts += ds->GetVerts()->GetNumberOfConnectivityEntries();
+          sizeVerts += ds->GetVerts()->GetNumberOfConnectivityIds();
         }
         if (ds->GetLines())
         {
-          sizeLines += ds->GetLines()->GetNumberOfConnectivityEntries();
+          sizeLines += ds->GetLines()->GetNumberOfConnectivityIds();
         }
         // keep track of the size of the poly cell array
         if (ds->GetPolys())
         {
-          sizePolys += ds->GetPolys()->GetNumberOfConnectivityEntries();
+          sizePolys += ds->GetPolys()->GetNumberOfConnectivityIds();
         }
         if (ds->GetStrips())
         {
-          sizeStrips += ds->GetStrips()->GetNumberOfConnectivityEntries();
+          sizeStrips += ds->GetStrips()->GetNumberOfConnectivityIds();
         }
 
         numCells += ds->GetNumberOfCells();
@@ -234,7 +227,7 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
         numStrips += ds->GetNumberOfStrips();
 
         inCD = ds->GetCellData();
-        if ( countCD == 0 )
+        if (countCD == 0)
         {
           cellList.InitializeFieldList(inCD);
         }
@@ -244,12 +237,12 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
         }
         ++countCD;
       } // for a data set that has cells
-    } // for a non nullptr input
-  } // for each input
+    }   // for a non nullptr input
+  }     // for each input
 
   if (numPts < 1 && numCells < 1)
   {
-    vtkDebugMacro(<<"No data to append!");
+    vtkDebugMacro(<< "No data to append!");
     return 1;
   }
   this->UpdateProgress(0.10);
@@ -257,16 +250,16 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
   // Examine the points and check if they're the same type. If not,
   // use highest (double probably), otherwise the type of the first
   // array (float no doubt). Depends on defs in vtkSetGet.h - Warning.
-  int ttype, firstType=1;
+  int ttype, firstType = 1;
   int pointtype = 0;
 
   // Keep track of types for fast point append
   for (idx = 0; idx < numInputs; ++idx)
   {
     ds = inputs[idx];
-    if (ds != nullptr && ds->GetNumberOfPoints()>0)
+    if (ds != nullptr && ds->GetNumberOfPoints() > 0)
     {
-      if ( firstType )
+      if (firstType)
       {
         firstType = 0;
         pointtype = ds->GetPoints()->GetData()->GetDataType();
@@ -280,15 +273,15 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
   newPts = vtkPoints::New();
 
   // Set the desired precision for the points in the output.
-  if(this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
+  if (this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
   {
     newPts->SetDataType(pointtype);
   }
-  else if(this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
+  else if (this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
   {
     newPts->SetDataType(VTK_FLOAT);
   }
-  else if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
+  else if (this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
   {
     newPts->SetDataType(VTK_DOUBLE);
   }
@@ -296,38 +289,38 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
   newPts->SetNumberOfPoints(numPts);
 
   newVerts = vtkCellArray::New();
-  pVerts = newVerts->WritePointer(numVerts, sizeVerts);
+  bool allocated = newVerts->AllocateExact(numVerts, sizeVerts);
 
-  if (sizeVerts > 0 && !pVerts)
+  if (sizeVerts > 0 && !allocated)
   {
-    vtkErrorMacro(<<"Memory allocation failed in append filter");
+    vtkErrorMacro(<< "Memory allocation failed in append filter");
     return 0;
   }
 
   newLines = vtkCellArray::New();
-  pLines = newLines->WritePointer(numLines, sizeLines);
+  allocated = newLines->AllocateExact(numLines, sizeLines);
 
-  if (sizeLines > 0 && !pLines)
+  if (sizeLines > 0 && !allocated)
   {
-    vtkErrorMacro(<<"Memory allocation failed in append filter");
+    vtkErrorMacro(<< "Memory allocation failed in append filter");
     return 0;
   }
 
   newPolys = vtkCellArray::New();
-  pPolys = newPolys->WritePointer(numPolys, sizePolys);
+  allocated = newPolys->AllocateExact(numPolys, sizePolys);
 
-  if (sizePolys > 0 && !pPolys)
+  if (sizePolys > 0 && !allocated)
   {
-    vtkErrorMacro(<<"Memory allocation failed in append filter");
+    vtkErrorMacro(<< "Memory allocation failed in append filter");
     return 0;
   }
 
   newStrips = vtkCellArray::New();
-  pStrips = newStrips->WritePointer(numStrips, sizeStrips);
+  allocated = newStrips->AllocateExact(numStrips, sizeStrips);
 
-  if (sizeStrips > 0 && !pStrips)
+  if (sizeStrips > 0 && !allocated)
   {
-    vtkErrorMacro(<<"Memory allocation failed in append filter");
+    vtkErrorMacro(<< "Memory allocation failed in append filter");
     return 0;
   }
 
@@ -337,28 +330,32 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
   outputCD->CopyAllOn(vtkDataSetAttributes::COPYTUPLE);
 
   // Allocate the point and cell data
-  outputPD->CopyAllocate(ptList,numPts);
-  outputCD->CopyAllocate(cellList,numCells);
+  outputPD->CopyAllocate(ptList, numPts);
+  outputCD->CopyAllocate(cellList, numCells);
 
   // loop over all input sets
   vtkIdType ptOffset = 0;
   vtkIdType vertOffset = 0;
   vtkIdType linesOffset = numVerts;
-  vtkIdType polysOffset = numVerts+numLines;
-  vtkIdType stripsOffset = numVerts+numLines+numPolys;
+  vtkIdType polysOffset = numVerts + numLines;
+  vtkIdType stripsOffset = numVerts + numLines + numPolys;
   countPD = countCD = 0;
   for (idx = 0; idx < numInputs; ++idx)
   {
-    this->UpdateProgress(0.2 + 0.8*idx/numInputs);
+    if (this->CheckAbort())
+    {
+      break;
+    }
+    this->UpdateProgress(0.2 + 0.8 * idx / numInputs);
     ds = inputs[idx];
     // this check is not necessary, but I'll put it in anyway
     if (ds != nullptr)
     {
       numPts = ds->GetNumberOfPoints();
       numCells = ds->GetNumberOfCells();
-      if ( numPts <= 0 && numCells <= 0 )
+      if (numPts <= 0 && numCells <= 0)
       {
-        continue; //no input, just skip
+        continue; // no input, just skip
       }
 
       inPD = ds->GetPointData();
@@ -387,19 +384,22 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
         vtkIdType stripsIndex = polysIndex + ds->GetNumberOfPolys();
 
         // copy the cells
-        pVerts = this->AppendCells(pVerts, inVerts, ptOffset);
-        pLines = this->AppendCells(pLines, inLines, ptOffset);
-        pPolys = this->AppendCells(pPolys, inPolys, ptOffset);
-        pStrips = this->AppendCells(pStrips, inStrips, ptOffset);
+        this->AppendCells(newVerts, inVerts, ptOffset);
+        this->AppendCells(newLines, inLines, ptOffset);
+        this->AppendCells(newPolys, inPolys, ptOffset);
+        this->AppendCells(newStrips, inStrips, ptOffset);
 
         // copy cell data
         outputCD->CopyData(cellList, inCD, countCD, vertOffset, ds->GetNumberOfVerts(), vertsIndex);
         vertOffset += ds->GetNumberOfVerts();
-        outputCD->CopyData(cellList, inCD, countCD, linesOffset, ds->GetNumberOfLines(), linesIndex);
+        outputCD->CopyData(
+          cellList, inCD, countCD, linesOffset, ds->GetNumberOfLines(), linesIndex);
         linesOffset += ds->GetNumberOfLines();
-        outputCD->CopyData(cellList, inCD, countCD, polysOffset, ds->GetNumberOfPolys(), polysIndex);
+        outputCD->CopyData(
+          cellList, inCD, countCD, polysOffset, ds->GetNumberOfPolys(), polysIndex);
         polysOffset += ds->GetNumberOfPolys();
-        outputCD->CopyData(cellList, inCD, countCD, stripsOffset, ds->GetNumberOfStrips(), stripsIndex);
+        outputCD->CopyData(
+          cellList, inCD, countCD, stripsOffset, ds->GetNumberOfStrips(), stripsIndex);
         stripsOffset += ds->GetNumberOfStrips();
         ++countCD;
       }
@@ -412,25 +412,25 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
   output->SetPoints(newPts);
   newPts->Delete();
 
-  if ( newVerts->GetNumberOfCells() > 0 )
+  if (newVerts->GetNumberOfCells() > 0)
   {
     output->SetVerts(newVerts);
   }
   newVerts->Delete();
 
-  if ( newLines->GetNumberOfCells() > 0 )
+  if (newLines->GetNumberOfCells() > 0)
   {
     output->SetLines(newLines);
   }
   newLines->Delete();
 
-  if ( newPolys->GetNumberOfCells() > 0 )
+  if (newPolys->GetNumberOfCells() > 0)
   {
     output->SetPolys(newPolys);
   }
   newPolys->Delete();
 
-  if ( newStrips->GetNumberOfCells() > 0 )
+  if (newStrips->GetNumberOfCells() > 0)
   {
     output->SetStrips(newStrips);
   }
@@ -443,16 +443,15 @@ int vtkAppendPolyData::ExecuteAppend(vtkPolyData* output,
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method is much too long, and has to be broken up!
 // Append data sets into single polygonal data set.
-int vtkAppendPolyData::RequestData(vtkInformation *vtkNotUsed(request),
-                                   vtkInformationVector **inputVector,
-                                   vtkInformationVector *outputVector)
+int vtkAppendPolyData::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info object
   // get the output
-  vtkPolyData *output = vtkPolyData::GetData(outputVector, 0);
+  vtkPolyData* output = vtkPolyData::GetData(outputVector, 0);
 
   int numInputs = inputVector[0]->GetNumberOfInformationObjects();
   if (numInputs == 1)
@@ -467,17 +466,16 @@ int vtkAppendPolyData::RequestData(vtkInformation *vtkNotUsed(request),
     inputs[idx] = vtkPolyData::GetData(inputVector[0], idx);
   }
   int retVal = this->ExecuteAppend(output, inputs, numInputs);
-  delete [] inputs;
+  delete[] inputs;
   return retVal;
 }
 
-//----------------------------------------------------------------------------
-int vtkAppendPolyData::RequestUpdateExtent(vtkInformation *vtkNotUsed(request),
-                                           vtkInformationVector **inputVector,
-                                           vtkInformationVector *outputVector)
+//------------------------------------------------------------------------------
+int vtkAppendPolyData::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the output info object
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   int piece, numPieces, ghostLevel;
   int idx;
@@ -499,7 +497,7 @@ int vtkAppendPolyData::RequestUpdateExtent(vtkInformation *vtkNotUsed(request),
     numPieces = numPieces * numInputs;
   }
 
-  vtkInformation *inInfo;
+  vtkInformation* inInfo;
   // just copy the Update extent as default behavior.
   for (idx = 0; idx < numInputs; ++idx)
   {
@@ -508,21 +506,15 @@ int vtkAppendPolyData::RequestUpdateExtent(vtkInformation *vtkNotUsed(request),
     {
       if (this->ParallelStreaming)
       {
-        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),
-                    piece + idx);
-        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
-                    numPieces);
-        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-                    ghostLevel);
+        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), piece + idx);
+        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), numPieces);
+        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), ghostLevel);
       }
       else
       {
-        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),
-                    piece);
-        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
-                    numPieces);
-        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-                    ghostLevel);
+        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), piece);
+        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), numPieces);
+        inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), ghostLevel);
       }
     }
   }
@@ -530,7 +522,7 @@ int vtkAppendPolyData::RequestUpdateExtent(vtkInformation *vtkNotUsed(request),
   // send their WHOLE_EXTENT as UPDATE_EXTENT.
   for (idx = 1; idx < numInputs; ++idx)
   {
-    vtkInformation * inputInfo = inputVector[0]->GetInformationObject(idx);
+    vtkInformation* inputInfo = inputVector[0]->GetInformationObject(idx);
     if (inputInfo->Has(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()))
     {
       int ext[6];
@@ -542,61 +534,55 @@ int vtkAppendPolyData::RequestUpdateExtent(vtkInformation *vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
-vtkPolyData *vtkAppendPolyData::GetInput(int idx)
+//------------------------------------------------------------------------------
+vtkPolyData* vtkAppendPolyData::GetInput(int idx)
 {
-  return vtkPolyData::SafeDownCast(
-    this->GetExecutive()->GetInputData(0, idx));
+  return vtkPolyData::SafeDownCast(this->GetExecutive()->GetInputData(0, idx));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAppendPolyData::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << "ParallelStreaming:" << (this->ParallelStreaming?"On":"Off") << endl;
-  os << "UserManagedInputs:" << (this->UserManagedInputs?"On":"Off") << endl;
-  os << indent << "Output Points Precision: " << this->OutputPointsPrecision
-     << endl;
+  os << "ParallelStreaming:" << (this->ParallelStreaming ? "On" : "Off") << endl;
+  os << "UserManagedInputs:" << (this->UserManagedInputs ? "On" : "Off") << endl;
+  os << indent << "Output Points Precision: " << this->OutputPointsPrecision << endl;
 }
 
-//----------------------------------------------------------------------------
-namespace {
+//------------------------------------------------------------------------------
+namespace
+{
 struct AppendDataWorker
 {
   vtkIdType Offset;
 
-  AppendDataWorker(vtkIdType offset) : Offset(offset) {}
+  AppendDataWorker(vtkIdType offset)
+    : Offset(offset)
+  {
+  }
 
   template <typename Array1T, typename Array2T>
-  void operator()(Array1T *dest, Array2T *src)
+  void operator()(Array1T* dest, Array2T* src)
   {
-    vtkDataArrayAccessor<Array1T> d(dest);
-    vtkDataArrayAccessor<Array2T> s(src);
     VTK_ASSUME(src->GetNumberOfComponents() == dest->GetNumberOfComponents());
+    const auto srcTuples = vtk::DataArrayTupleRange(src);
 
-    const vtkIdType numTuples = src->GetNumberOfTuples();
-    const int numComps = src->GetNumberOfComponents();
+    // Offset the dstTuple range to begin at this->Offset
+    auto dstTuples = vtk::DataArrayTupleRange(dest, this->Offset);
 
-    for (vtkIdType t = 0; t < numTuples; ++t)
-    {
-      for (int c = 0; c < numComps; ++c)
-      {
-        d.Set(t + this->Offset, c, s.Get(t, c));
-      }
-    }
+    std::copy(srcTuples.cbegin(), srcTuples.cend(), dstTuples.begin());
   }
 };
 } // end anon namespace
 
-//----------------------------------------------------------------------------
-void vtkAppendPolyData::AppendData(vtkDataArray *dest, vtkDataArray *src,
-                                   vtkIdType offset)
+//------------------------------------------------------------------------------
+void vtkAppendPolyData::AppendData(vtkDataArray* dest, vtkDataArray* src, vtkIdType offset)
 {
   assert("Arrays have same number of components." &&
-         src->GetNumberOfComponents() == dest->GetNumberOfComponents());
+    src->GetNumberOfComponents() == dest->GetNumberOfComponents());
   assert("Destination array has enough tuples." &&
-         src->GetNumberOfTuples() + offset <= dest->GetNumberOfTuples());
+    src->GetNumberOfTuples() + offset <= dest->GetNumberOfTuples());
 
   AppendDataWorker worker(offset);
   if (!vtkArrayDispatch::Dispatch2SameValueType::Execute(dest, src, worker))
@@ -606,43 +592,14 @@ void vtkAppendPolyData::AppendData(vtkDataArray *dest, vtkDataArray *src,
   }
 }
 
-//----------------------------------------------------------------------------
-// returns the next pointer in dest
-vtkIdType *vtkAppendPolyData::AppendCells(vtkIdType *pDest, vtkCellArray *src,
-                                          vtkIdType offset)
+//------------------------------------------------------------------------------
+void vtkAppendPolyData::AppendCells(vtkCellArray* dst, vtkCellArray* src, vtkIdType offset)
 {
-  vtkIdType *pSrc, *end, *pNum;
-
-  if (src == nullptr)
-  {
-    return pDest;
-  }
-
-  pSrc = src->GetPointer();
-  end = pSrc + src->GetNumberOfConnectivityEntries();
-  pNum = pSrc;
-
-  while (pSrc < end)
-  {
-    if (pSrc == pNum)
-    {
-      // move cell pointer to next cell
-      pNum += 1+*pSrc;
-      // copy the number of cells
-      *pDest++ = *pSrc++;
-    }
-    else
-    {
-      // offset the point index
-      *pDest++ = offset + *pSrc++;
-    }
-  }
-
-  return pDest;
+  dst->Append(src, offset);
 }
 
-//----------------------------------------------------------------------------
-int vtkAppendPolyData::FillInputPortInformation(int port, vtkInformation *info)
+//------------------------------------------------------------------------------
+int vtkAppendPolyData::FillInputPortInformation(int port, vtkInformation* info)
 {
   if (!this->Superclass::FillInputPortInformation(port, info))
   {
@@ -651,3 +608,4 @@ int vtkAppendPolyData::FillInputPortInformation(int port, vtkInformation *info)
   info->Set(vtkAlgorithm::INPUT_IS_REPEATABLE(), 1);
   return 1;
 }
+VTK_ABI_NAMESPACE_END
