@@ -39,6 +39,7 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkDataArray;
 class vtkPoints;
@@ -52,7 +53,7 @@ public:
   vtkTypeMacro(vtkAppendPolyData, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * UserManagedInputs allows the user to set inputs by number instead of
    * using the AddInput/RemoveInput functions. Calls to
@@ -62,7 +63,7 @@ public:
   vtkSetMacro(UserManagedInputs, vtkTypeBool);
   vtkGetMacro(UserManagedInputs, vtkTypeBool);
   vtkBooleanMacro(UserManagedInputs, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Add a dataset to the list of data to append. Should not be
@@ -76,13 +77,13 @@ public:
    */
   void RemoveInputData(vtkPolyData*);
 
-  //@{
+  ///@{
   /**
    * Get any input of this filter.
    */
   vtkPolyData* GetInput(int idx);
   vtkPolyData* GetInput() { return this->GetInput(0); }
-  //@}
+  ///@}
 
   /**
    * Directly set(allocate) number of inputs, should only be used
@@ -94,7 +95,7 @@ public:
   void SetInputConnectionByNumber(int num, vtkAlgorithmOutput* input);
   void SetInputDataByNumber(int num, vtkPolyData* ds);
 
-  //@{
+  ///@{
   /**
    * ParallelStreaming is for a particular application.
    * It causes this filter to ask for a different piece
@@ -108,9 +109,9 @@ public:
   vtkSetMacro(ParallelStreaming, vtkTypeBool);
   vtkGetMacro(ParallelStreaming, vtkTypeBool);
   vtkBooleanMacro(ParallelStreaming, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output types. See the documentation
    * for the vtkAlgorithm::DesiredOutputPrecision enum for an explanation of
@@ -118,7 +119,7 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
   int ExecuteAppend(vtkPolyData* output, vtkPolyData* inputs[], int numInputs)
     VTK_SIZEHINT(inputs, numInputs);
@@ -156,4 +157,5 @@ private:
   void operator=(const vtkAppendPolyData&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
