@@ -33,6 +33,7 @@
 #include <map>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBinCellDataFilter);
 
 //------------------------------------------------------------------------------
@@ -202,6 +203,10 @@ int vtkBinCellDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   // iterate over each cell in the source mesh
   for (srcIt->InitTraversal(); !srcIt->IsDoneWithTraversal(); srcIt->GoToNextCell())
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     if (this->CellOverlapMethod == vtkBinCellDataFilter::CELL_CENTROID)
     {
       // identify the centroid of the source cell
@@ -427,3 +432,4 @@ void vtkBinCellDataFilter::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Cell Locator: " << this->CellLocator << "\n";
 }
+VTK_ABI_NAMESPACE_END
