@@ -39,6 +39,7 @@
 #include <atomic>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBinnedDecimation);
 
 //----------------------------------------------------------------------------
@@ -71,11 +72,13 @@ struct BinPoints
   double hX, hY, hZ;
   double fX, fY, fZ, bX, bY, bZ;
   vtkIdType xD, yD, zD, xyD;
+  vtkBinnedDecimation* Filter;
 
-  BinPoints(
-    PointsT* pts, TIds* binIds, const int* dims, const double* bounds, const double* spacing)
+  BinPoints(PointsT* pts, TIds* binIds, const int* dims, const double* bounds,
+    const double* spacing, vtkBinnedDecimation* filter)
     : Points(pts)
     , BinIds(binIds)
+    , Filter(filter)
   {
     for (auto i = 0; i < 3; ++i)
     {
@@ -129,8 +132,18 @@ struct BinPoints
     const auto points = vtk::DataArrayTupleRange<3>(this->Points, ptId, endPtId);
     double x[3];
     TIds* bins = this->BinIds + ptId;
+    bool isFirst = vtkSMPTools::GetSingleThread();
+
     for (const auto tuple : points)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       x[0] = static_cast<double>(tuple[0]);
       x[1] = static_cast<double>(tuple[1]);
       x[2] = static_cast<double>(tuple[2]);
@@ -152,9 +165,10 @@ struct GenerateTriangles
   vtkIdType* OutTris;
   vtkIdType* OutTriOffsets;
   ArrayList* Arrays;
+  vtkBinnedDecimation* Filter;
 
   GenerateTriangles(TIds* bins, TPtMap* ptMap, vtkCellArray* tris, TIds* triMap, vtkIdType* outTris,
-    vtkIdType* outTriOffsets, ArrayList* arrays)
+    vtkIdType* outTriOffsets, ArrayList* arrays, vtkBinnedDecimation* filter)
     : BinIds(bins)
     , PointMap(ptMap)
     , Tris(tris)
@@ -162,6 +176,7 @@ struct GenerateTriangles
     , OutTris(outTris)
     , OutTriOffsets(outTriOffsets)
     , Arrays(arrays)
+    , Filter(filter)
   {
   }
 
@@ -177,9 +192,18 @@ struct GenerateTriangles
     const TIds* triMap = this->TriMap;
     vtkIdType *outTris = this->OutTris, *outTri;
     vtkIdType *outTriOffsets = this->OutTriOffsets, *outOffsets;
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; triId < endTriId; ++triId)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       if ((triMap[triId + 1] - triMap[triId]) > 0) // spit out triangle
       {
         cellIter->GetCellAtId(triId, npts, tri);
@@ -212,12 +236,15 @@ struct SelectOutput
   vtkCellArray* Tris;
   TIds* TriMap;
   vtkSMPThreadLocal<vtkSmartPointer<vtkCellArrayIterator>> CellIterator;
+  vtkBinnedDecimation* Filter;
 
-  SelectOutput(TIds* bins, unsigned char* ptUses, vtkCellArray* tris, TIds* triMap)
+  SelectOutput(TIds* bins, unsigned char* ptUses, vtkCellArray* tris, TIds* triMap,
+    vtkBinnedDecimation* filter)
     : BinIds(bins)
     , PointUses(ptUses)
     , Tris(tris)
     , TriMap(triMap)
+    , Filter(filter)
   {
   }
 
@@ -230,9 +257,18 @@ struct SelectOutput
     vtkCellArrayIterator* cellIter = this->CellIterator.Local();
     TIds* triMap = this->TriMap + triId;
     unsigned char* ptUses = this->PointUses;
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; triId < endTriId; ++triId, ++triMap)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       cellIter->GetCellAtId(triId, npts, tri);
       // All three points have to be in different bins
       if (this->BinIds[tri[0]] != this->BinIds[tri[1]] &&
@@ -262,11 +298,13 @@ struct InitializePointMap
   const TIds* BinIds;
   const unsigned char* PointUses;
   TIds* PointMap;
+  vtkBinnedDecimation* Filter;
 
-  InitializePointMap(TIds* binIds, unsigned char* ptUses, TIds* ptMap)
+  InitializePointMap(TIds* binIds, unsigned char* ptUses, TIds* ptMap, vtkBinnedDecimation* filter)
     : BinIds(binIds)
     , PointUses(ptUses)
     , PointMap(ptMap)
+    , Filter(filter)
   {
   }
 
@@ -275,9 +313,18 @@ struct InitializePointMap
     const TIds* binIds = this->BinIds;
     const unsigned char* ptUses = this->PointUses + ptId;
     TIds* ptMap = this->PointMap;
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; ptId < endPtId; ++ptId)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       if (*ptUses++ > 0)
       {
         ptMap[binIds[ptId]] = (-1); // mark unvisited
@@ -291,7 +338,7 @@ struct InitializePointMap
 template <typename PointsT, typename TIds>
 void ReuseDecimate(vtkIdType numPts, PointsT* pts, vtkIdType numTris, vtkCellArray* tris,
   vtkCellData* inCD, vtkCellData* outCD, vtkIdType numBins, const int* dims, const double* bounds,
-  const double* spacing, vtkPolyData* output)
+  const double* spacing, vtkPolyData* output, vtkBinnedDecimation* filter)
 {
   // Setup execution. Several arrays are used to transform the data.
   // The bin id of each point
@@ -306,15 +353,15 @@ void ReuseDecimate(vtkIdType numPts, PointsT* pts, vtkIdType numTris, vtkCellArr
   TIds* triMap = new TIds[numTris + 1];
 
   // Bin points to generate a bin index for each point
-  BinPoints<PointsT, TIds> binPoints(pts, binIds, dims, bounds, spacing);
+  BinPoints<PointsT, TIds> binPoints(pts, binIds, dims, bounds, spacing, filter);
   vtkSMPTools::For(0, numPts, binPoints);
 
   // Select which triangles and points are sent to the output.
-  SelectOutput<TIds> selectOutput(binIds, ptUses, tris, triMap);
+  SelectOutput<TIds> selectOutput(binIds, ptUses, tris, triMap, filter);
   vtkSMPTools::For(0, numTris, selectOutput);
 
   // Initialize the point map, only the bins that contain something
-  InitializePointMap<TIds> initPtMap(binIds, ptUses, ptMap);
+  InitializePointMap<TIds> initPtMap(binIds, ptUses, ptMap, filter);
   vtkSMPTools::For(0, numPts, initPtMap);
 
   // Prefix sums to roll up the points and cells, and setup offsets for
@@ -357,8 +404,8 @@ void ReuseDecimate(vtkIdType numPts, PointsT* pts, vtkIdType numTris, vtkCellArr
   }
 
   // Produce output triangles.
-  GenerateTriangles<TIds, TIds> genTris(
-    binIds, ptMap, tris, triMap, outTris, outTriOffsets, (outCD != nullptr ? (&arrays) : nullptr));
+  GenerateTriangles<TIds, TIds> genTris(binIds, ptMap, tris, triMap, outTris, outTriOffsets,
+    (outCD != nullptr ? (&arrays) : nullptr), filter);
   vtkSMPTools::For(0, numTris, genTris);
   outTrisArray->SetData(outOffsets, outConn);
 
@@ -375,7 +422,8 @@ struct PointReuseWorker
 {
   template <typename DataT>
   void operator()(DataT* pts, bool largeIds, vtkCellArray* tris, vtkCellData* inCD,
-    vtkCellData* outCD, int* divs, double bounds[6], double spacing[3], vtkPolyData* output)
+    vtkCellData* outCD, int* divs, double bounds[6], double spacing[3], vtkPolyData* output,
+    vtkBinnedDecimation* filter)
   {
     vtkIdType numPts = pts->GetNumberOfTuples();
     vtkIdType numTris = tris->GetNumberOfCells();
@@ -385,12 +433,12 @@ struct PointReuseWorker
     if (!largeIds)
     {
       ReuseDecimate<DataT, int>(
-        numPts, pts, numTris, tris, inCD, outCD, numBins, divs, bounds, spacing, output);
+        numPts, pts, numTris, tris, inCD, outCD, numBins, divs, bounds, spacing, output, filter);
     }
     else
     {
       ReuseDecimate<DataT, vtkIdType>(
-        numPts, pts, numTris, tris, inCD, outCD, numBins, divs, bounds, spacing, output);
+        numPts, pts, numTris, tris, inCD, outCD, numBins, divs, bounds, spacing, output, filter);
     }
   }
 };
@@ -409,12 +457,15 @@ struct MapOutput
   vtkCellArray* Tris;
   TIds* TriMap;
   vtkSMPThreadLocal<vtkSmartPointer<vtkCellArrayIterator>> CellIterator;
+  vtkBinnedDecimation* Filter;
 
-  MapOutput(TIds* bins, std::atomic<TIds>* ptMap, vtkCellArray* tris, TIds* triMap)
+  MapOutput(TIds* bins, std::atomic<TIds>* ptMap, vtkCellArray* tris, TIds* triMap,
+    vtkBinnedDecimation* filter)
     : BinIds(bins)
     , PointMap(ptMap)
     , Tris(tris)
     , TriMap(triMap)
+    , Filter(filter)
   {
   }
 
@@ -447,9 +498,18 @@ struct MapOutput
     TIds* triMap = this->TriMap + triId;
     std::atomic<TIds>* ptMap = this->PointMap;
     TIds binIds[3];
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; triId < endTriId; ++triId, ++triMap)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       cellIter->GetCellAtId(triId, npts, tri);
       binIds[0] = this->BinIds[tri[0]];
       binIds[1] = this->BinIds[tri[1]];
@@ -483,11 +543,14 @@ struct CountPoints
   const int* Dims;
   std::atomic<TIds>* PointMap;
   int* SliceOffsets;
+  vtkBinnedDecimation* Filter;
 
-  CountPoints(const int* dims, std::atomic<TIds>* ptMap, int* sliceOffsets)
+  CountPoints(
+    const int* dims, std::atomic<TIds>* ptMap, int* sliceOffsets, vtkBinnedDecimation* filter)
     : Dims(dims)
     , PointMap(ptMap)
     , SliceOffsets(sliceOffsets)
+    , Filter(filter)
   {
   }
 
@@ -496,9 +559,18 @@ struct CountPoints
   void operator()(vtkIdType slice, vtkIdType endSlice)
   {
     int binOffset = slice * this->Dims[0] * this->Dims[1];
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; slice < endSlice; ++slice)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       vtkIdType numSlicePts = 0;
       for (auto j = 0; j < this->Dims[1]; ++j)
       {
@@ -543,9 +615,11 @@ struct GenerateBinPoints
   PointsT* InPoints;
   ArrayList* Arrays;
   float* OutPoints;
+  vtkBinnedDecimation* Filter;
 
   GenerateBinPoints(int genMode, const double* bounds, const double* spacing, const int* dims,
-    int* sliceOffsets, std::atomic<TIds>* ptMap, PointsT* inPts, ArrayList* arrays, float* outPts)
+    int* sliceOffsets, std::atomic<TIds>* ptMap, PointsT* inPts, ArrayList* arrays, float* outPts,
+    vtkBinnedDecimation* filter)
     : PointGenerationMode(genMode)
     , Bounds(bounds)
     , Spacing(spacing)
@@ -555,6 +629,7 @@ struct GenerateBinPoints
     , InPoints(inPts)
     , Arrays(arrays)
     , OutPoints(outPts)
+    , Filter(filter)
   {
   }
 
@@ -566,9 +641,18 @@ struct GenerateBinPoints
     float* xOut;
     double xIn[3];
     const auto pts = vtk::DataArrayTupleRange<3>(this->InPoints);
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; slice < endSlice; ++slice)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       for (auto j = 0; j < this->Dims[1]; ++j)
       {
         for (auto i = 0; i < this->Dims[0]; ++i)
@@ -616,14 +700,14 @@ template <typename PointsT, typename TIds>
 void BinPointsDecimate(int genMode, vtkIdType numPts, PointsT* pts, vtkPointData* inPD,
   vtkPointData* outPD, vtkIdType numTris, vtkCellArray* tris, vtkCellData* inCD, vtkCellData* outCD,
   vtkIdType numBins, const int* dims, const double* bounds, const double* spacing,
-  vtkPolyData* output)
+  vtkPolyData* output, vtkBinnedDecimation* filter)
 {
   // Setup execution. Several arrays are used to transform the data.
   // The bin id of each point.
   TIds* binIds = new TIds[numPts];
 
   // Now bin points to generate a bin index for each point.
-  BinPoints<PointsT, TIds> binPoints(pts, binIds, dims, bounds, spacing);
+  BinPoints<PointsT, TIds> binPoints(pts, binIds, dims, bounds, spacing, filter);
   vtkSMPTools::For(0, numPts, binPoints);
 
   // The ptMap is the output point id assigned to each bin (if the bin
@@ -632,20 +716,20 @@ void BinPointsDecimate(int genMode, vtkIdType numPts, PointsT* pts, vtkPointData
   // is a problem because a ptId can == zero; as a workaround, we'll
   // initially use negative ids, and convert to positive ids in the
   // final composition.
-  std::atomic<TIds>* ptMap = new std::atomic<TIds>[numBins] {};
+  std::atomic<TIds>* ptMap = new std::atomic<TIds>[numBins]();
 
   // Is the triangle output? And eventually the offset into the output cell array.
   TIds* triMap = new TIds[numTris + 1];
 
   // Begin to construct mappings of input points and cells, to output points
   // and cells.
-  MapOutput<TIds> mapOutput(binIds, ptMap, tris, triMap);
+  MapOutput<TIds> mapOutput(binIds, ptMap, tris, triMap, filter);
   vtkSMPTools::For(0, numTris, mapOutput);
 
   // Now generate the new points. First generate new point ids, and then
   // produce the actual points.
   int* sliceOffsets = new int[dims[2] + 1];
-  CountPoints<TIds> countPts(dims, ptMap, sliceOffsets);
+  CountPoints<TIds> countPts(dims, ptMap, sliceOffsets, filter);
   vtkSMPTools::For(0, dims[2], countPts);
   int numNewPts = sliceOffsets[dims[2]];
 
@@ -661,7 +745,7 @@ void BinPointsDecimate(int genMode, vtkIdType numPts, PointsT* pts, vtkPointData
 
   GenerateBinPoints<PointsT, TIds> genPts(genMode, bounds, spacing, dims, sliceOffsets, ptMap, pts,
     (outPD != nullptr ? (&ptArrays) : nullptr),
-    vtkFloatArray::FastDownCast(newPts->GetData())->GetPointer(0));
+    vtkFloatArray::FastDownCast(newPts->GetData())->GetPointer(0), filter);
   vtkSMPTools::For(0, dims[2], genPts);
   output->SetPoints(newPts);
 
@@ -691,8 +775,8 @@ void BinPointsDecimate(int genMode, vtkIdType numPts, PointsT* pts, vtkPointData
     arrays.AddArrays(numOutTris, inCD, outCD);
   }
 
-  GenerateTriangles<TIds, std::atomic<TIds>> genTris(
-    binIds, ptMap, tris, triMap, outTris, outTriOffsets, (outCD != nullptr ? (&arrays) : nullptr));
+  GenerateTriangles<TIds, std::atomic<TIds>> genTris(binIds, ptMap, tris, triMap, outTris,
+    outTriOffsets, (outCD != nullptr ? (&arrays) : nullptr), filter);
   vtkSMPTools::For(0, numTris, genTris);
   outTrisArray->SetData(outOffsets, outConn);
 
@@ -712,7 +796,7 @@ struct BinPointsWorker
   template <typename DataT>
   void operator()(DataT* pts, vtkPointData* inPD, vtkPointData* outPD, bool largeIds, int genMode,
     vtkCellArray* tris, vtkCellData* inCD, vtkCellData* outCD, int* divs, double bounds[6],
-    double spacing[3], vtkPolyData* output)
+    double spacing[3], vtkPolyData* output, vtkBinnedDecimation* filter)
   {
     vtkIdType numPts = pts->GetNumberOfTuples();
     vtkIdType numTris = tris->GetNumberOfCells();
@@ -721,12 +805,12 @@ struct BinPointsWorker
     if (!largeIds)
     {
       BinPointsDecimate<DataT, int>(genMode, numPts, pts, inPD, outPD, numTris, tris, inCD, outCD,
-        numBins, divs, bounds, spacing, output);
+        numBins, divs, bounds, spacing, output, filter);
     }
     else
     {
       BinPointsDecimate<DataT, vtkIdType>(genMode, numPts, pts, inPD, outPD, numTris, tris, inCD,
-        outCD, numBins, divs, bounds, spacing, output);
+        outCD, numBins, divs, bounds, spacing, output, filter);
     }
   }
 };
@@ -747,7 +831,7 @@ struct BinTuple
 
   // Operator< used to support the sort operation. Just sort on bin
   // id; points within a bin can be in any order.
-  bool operator<(const BinTuple& tuple) const { return (Bin < tuple.Bin ? true : false); }
+  bool operator<(const BinTuple& tuple) const { return Bin < tuple.Bin; }
 };
 
 template <typename PointsT, typename TIds>
@@ -756,8 +840,8 @@ struct BinPointTuples : public BinPoints<PointsT, TIds>
   BinTuple<TIds>* BinTuples;
 
   BinPointTuples(PointsT* pts, BinTuple<TIds>* binTuples, const int* dims, const double* bounds,
-    const double* spacing)
-    : BinPoints<PointsT, TIds>(pts, nullptr, dims, bounds, spacing)
+    const double* spacing, vtkBinnedDecimation* filter)
+    : BinPoints<PointsT, TIds>(pts, nullptr, dims, bounds, spacing, filter)
     , BinTuples(binTuples)
   {
   }
@@ -767,8 +851,17 @@ struct BinPointTuples : public BinPoints<PointsT, TIds>
     const auto points = vtk::DataArrayTupleRange<3>(this->Points, ptId, endPtId);
     double x[3];
     BinTuple<TIds>* bins = this->BinTuples + ptId;
+    bool isFirst = vtkSMPTools::GetSingleThread();
     for (const auto tuple : points)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       (*bins).PtId = ptId++;
       x[0] = static_cast<double>(tuple[0]);
       x[1] = static_cast<double>(tuple[1]);
@@ -786,11 +879,13 @@ struct MarkBinnedTris
   vtkCellArray* Tris;
   TIds* TriMap;
   vtkSMPThreadLocal<vtkSmartPointer<vtkCellArrayIterator>> CellIterator;
+  vtkBinnedDecimation* Filter;
 
-  MarkBinnedTris(BinTuple<TIds>* bt, vtkCellArray* tris, TIds* triMap)
+  MarkBinnedTris(BinTuple<TIds>* bt, vtkCellArray* tris, TIds* triMap, vtkBinnedDecimation* filter)
     : BinTuples(bt)
     , Tris(tris)
     , TriMap(triMap)
+    , Filter(filter)
   {
   }
 
@@ -803,9 +898,18 @@ struct MarkBinnedTris
     vtkCellArrayIterator* cellIter = this->CellIterator.Local();
     TIds* triMap = this->TriMap + triId;
     TIds binIds[3];
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; triId < endTriId; ++triId, ++triMap)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       cellIter->GetCellAtId(triId, npts, tri);
       binIds[0] = this->BinTuples[tri[0]].Bin;
       binIds[1] = this->BinTuples[tri[1]].Bin;
@@ -837,15 +941,17 @@ struct BinAveTriangles
   vtkIdType* OutTris;
   vtkIdType* OutTriOffsets;
   ArrayList* Arrays;
+  vtkBinnedDecimation* Filter;
 
   BinAveTriangles(const BinTuple<TIds>* bt, vtkCellArray* tris, TIds* triMap, vtkIdType* outTris,
-    vtkIdType* outTriOffsets, ArrayList* arrays)
+    vtkIdType* outTriOffsets, ArrayList* arrays, vtkBinnedDecimation* filter)
     : BinTuples(bt)
     , Tris(tris)
     , TriMap(triMap)
     , OutTris(outTris)
     , OutTriOffsets(outTriOffsets)
     , Arrays(arrays)
+    , Filter(filter)
   {
   }
 
@@ -860,9 +966,18 @@ struct BinAveTriangles
     const TIds* triMap = this->TriMap;
     vtkIdType *outTris = this->OutTris, *outTri;
     vtkIdType *outTriOffsets = this->OutTriOffsets, *outOffsets;
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; triId < endTriId; ++triId)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       if ((triMap[triId + 1] - triMap[triId]) > 0) // spit out triangle
       {
         cellIter->GetCellAtId(triId, npts, tri);
@@ -892,11 +1007,14 @@ struct GenerateAveTriangles
   const BinTuple<TIds>* BinTuples;
   const TIds* Offsets;
   vtkIdType* OutTris;
+  vtkBinnedDecimation* Filter;
 
-  GenerateAveTriangles(const BinTuple<TIds>* bt, TIds* offsets, vtkIdType* outTris)
+  GenerateAveTriangles(
+    const BinTuple<TIds>* bt, TIds* offsets, vtkIdType* outTris, vtkBinnedDecimation* filter)
     : BinTuples(bt)
     , Offsets(offsets)
     , OutTris(outTris)
+    , Filter(filter)
   {
   }
 
@@ -905,9 +1023,18 @@ struct GenerateAveTriangles
     const BinTuple<TIds>* binTuples = this->BinTuples;
     const TIds* offsets = this->Offsets;
     vtkIdType* outTri = this->OutTris + 3 * triId;
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; triId < endTriId; ++triId, outTri += 3)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       outTri[0] = (*(binTuples + offsets[outTri[0]])).PtId;
       outTri[1] = (*(binTuples + offsets[outTri[1]])).PtId;
       outTri[2] = (*(binTuples + offsets[outTri[2]])).PtId;
@@ -925,12 +1052,15 @@ struct MapOffsets
   TIds NumPts;
   TIds NumBins;
   TIds BatchSize;
+  vtkBinnedDecimation* Filter;
 
-  MapOffsets(BinTuple<TIds>* bt, TIds* offsets, TIds numPts, TIds numBins, TIds numBatches)
+  MapOffsets(BinTuple<TIds>* bt, TIds* offsets, TIds numPts, TIds numBins, TIds numBatches,
+    vtkBinnedDecimation* filter)
     : BinTuples(bt)
     , Offsets(offsets)
     , NumPts(numPts)
     , NumBins(numBins)
+    , Filter(filter)
   {
     this->BatchSize = static_cast<int>(ceil(static_cast<double>(numPts) / numBatches));
   }
@@ -962,15 +1092,25 @@ struct MapOffsets
       prevPt = curPt;
     } // else in the middle of a batch
 
+    bool isFirst = vtkSMPTools::GetSingleThread();
+
     // Okay we have a starting point for a bin run. Now we can begin
     // filling in the offsets in this batch. A previous thread should
     // have/will have completed the previous and subsequent runs outside
     // of the [batch,batchEnd) range
     for (curPt = prevPt; curPt < endBatchPt;)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       for (; curPt->Bin == prevPt->Bin && curPt <= endBatchPt; ++curPt)
       {
-        ; // advance
+        // advance
       }
       // Fill in any gaps in the offset array
       if (curPt < endPt) // still within range of points
@@ -997,11 +1137,13 @@ struct CountAvePts
   const int* Dims;
   const TIds* Offsets;
   int* SliceOffsets;
+  vtkBinnedDecimation* Filter;
 
-  CountAvePts(const int* dims, const TIds* offsets, int* sliceOffsets)
+  CountAvePts(const int* dims, const TIds* offsets, int* sliceOffsets, vtkBinnedDecimation* filter)
     : Dims(dims)
     , Offsets(offsets)
     , SliceOffsets(sliceOffsets)
+    , Filter(filter)
   {
   }
 
@@ -1010,9 +1152,18 @@ struct CountAvePts
   void operator()(vtkIdType slice, vtkIdType endSlice)
   {
     int binNum = slice * this->Dims[0] * this->Dims[1];
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; slice < endSlice; ++slice)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       vtkIdType numSlicePts = 0;
       for (auto j = 0; j < this->Dims[1]; ++j)
       {
@@ -1056,9 +1207,11 @@ struct GenerateAveBinPoints
   ArrayList* Arrays;
   float* OutPoints;
   vtkSMPThreadLocal<std::vector<vtkIdType>> PtIds;
+  vtkBinnedDecimation* Filter;
 
   GenerateAveBinPoints(const int* dims, PointsT* inPts, const int* sliceOffsets,
-    BinTuple<TIds>* binTuples, const TIds* offsets, ArrayList* arrays, float* outPts)
+    BinTuple<TIds>* binTuples, const TIds* offsets, ArrayList* arrays, float* outPts,
+    vtkBinnedDecimation* filter)
     : Dims(dims)
     , InPoints(inPts)
     , SliceOffsets(sliceOffsets)
@@ -1066,6 +1219,7 @@ struct GenerateAveBinPoints
     , Offsets(offsets)
     , Arrays(arrays)
     , OutPoints(outPts)
+    , Filter(filter)
   {
   }
 
@@ -1081,9 +1235,18 @@ struct GenerateAveBinPoints
     BinTuple<TIds>* pIds;
     TIds pId;
     std::vector<vtkIdType> v = this->PtIds.Local();
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; slice < endSlice; ++slice)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       for (auto j = 0; j < this->Dims[1]; ++j)
       {
         for (auto i = 0; i < this->Dims[0]; ++i)
@@ -1135,14 +1298,15 @@ struct GenerateAveBinPoints
 template <typename PointsT, typename TIds>
 void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPointData* outPD,
   vtkIdType numTris, vtkCellArray* tris, vtkCellData* inCD, vtkCellData* outCD, vtkIdType numBins,
-  const int* dims, const double* bounds, const double* spacing, vtkPolyData* output)
+  const int* dims, const double* bounds, const double* spacing, vtkPolyData* output,
+  vtkBinnedDecimation* filter)
 {
   // Setup execution. Several arrays are used to transform the data.
   // Define the bin id and associated point id of each point.
   BinTuple<TIds>* binTuples = new BinTuple<TIds>[numPts];
 
   // Now bin points to generate a bin index for each point.
-  BinPointTuples<PointsT, TIds> binPoints(pts, binTuples, dims, bounds, spacing);
+  BinPointTuples<PointsT, TIds> binPoints(pts, binTuples, dims, bounds, spacing, filter);
   vtkSMPTools::For(0, numPts, binPoints);
 
   // Initially, triMap indicates which triangles are output. And then
@@ -1151,7 +1315,7 @@ void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPo
 
   // Begin to construct mappings of input points and cells, to output points
   // and cells. First identify the triangles to be sent to the output.
-  MarkBinnedTris<TIds> markBinnedTris(binTuples, tris, triMap);
+  MarkBinnedTris<TIds> markBinnedTris(binTuples, tris, triMap, filter);
   vtkSMPTools::For(0, numTris, markBinnedTris);
 
   // Create a mapping of the input triangles to the output triangles.
@@ -1166,7 +1330,7 @@ void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPo
 
   // Generate the cell output (decimated list of triangles), with the
   // triangle connectivity based on bin ids (not point ids). We'll directly
-  // create the offet and connectivity arrays for the output polydata.
+  // create the offset and connectivity arrays for the output polydata.
   vtkCellArray* outTrisArray = output->GetPolys();
   vtkNew<vtkIdTypeArray> outConn;
   vtkIdType* outTris = outConn->WritePointer(0, numOutTris * 3);
@@ -1181,8 +1345,8 @@ void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPo
     arrays.AddArrays(numOutTris, inCD, outCD);
   }
 
-  BinAveTriangles<TIds> binTris(
-    binTuples, tris, triMap, outTris, outTriOffsets, (outCD != nullptr ? (&arrays) : nullptr));
+  BinAveTriangles<TIds> binTris(binTuples, tris, triMap, outTris, outTriOffsets,
+    (outCD != nullptr ? (&arrays) : nullptr), filter);
   vtkSMPTools::For(0, numTris, binTris);
   outTrisArray->SetData(outOffsets, outConn);
 
@@ -1195,7 +1359,7 @@ void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPo
   // into the sorted bin tuples (i.e., runs of points in each bin).
   TIds* offsets = new TIds[numBins + 1];
   TIds numBatches = (numPts < 10000 ? 1 : 100); // totally arbitrary
-  MapOffsets<TIds> offMapper(binTuples, offsets, numPts, numBins, numBatches);
+  MapOffsets<TIds> offMapper(binTuples, offsets, numPts, numBins, numBatches, filter);
   vtkSMPTools::For(0, numBatches, offMapper);
   offsets[numBins] = numPts;
 
@@ -1204,7 +1368,7 @@ void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPo
   // have to count the new points, and then accumulate them with a prefix
   // sum. For convenience, this is done on a bin slice-by-slice manner.
   int* sliceOffsets = new int[dims[2] + 1];
-  CountAvePts<TIds> countPts(dims, offsets, sliceOffsets);
+  CountAvePts<TIds> countPts(dims, offsets, sliceOffsets, filter);
   vtkSMPTools::For(0, dims[2], countPts);
   int numNewPts = sliceOffsets[dims[2]];
 
@@ -1226,12 +1390,12 @@ void AvePointsDecimate(vtkIdType numPts, PointsT* pts, vtkPointData* inPD, vtkPo
   // Do the core work of averaging point coordinates and attributes.
   GenerateAveBinPoints<PointsT, TIds> genPts(dims, pts, sliceOffsets, binTuples, offsets,
     (outPD != nullptr ? (&ptArrays) : nullptr),
-    vtkFloatArray::FastDownCast(newPts->GetData())->GetPointer(0));
+    vtkFloatArray::FastDownCast(newPts->GetData())->GetPointer(0), filter);
   vtkSMPTools::For(0, dims[2], genPts);
   output->SetPoints(newPts);
 
   // Finally map the triangle connectivity list to the new point ids.
-  GenerateAveTriangles<TIds> genAveTris(binTuples, offsets, outTris);
+  GenerateAveTriangles<TIds> genAveTris(binTuples, offsets, outTris, filter);
   vtkSMPTools::For(0, numOutTris, genAveTris);
 
   // Clean up
@@ -1249,7 +1413,7 @@ struct AvePointsWorker
   template <typename DataT>
   void operator()(DataT* pts, vtkPointData* inPD, vtkPointData* outPD, bool largeIds,
     vtkCellArray* tris, vtkCellData* inCD, vtkCellData* outCD, int* divs, double bounds[6],
-    double spacing[3], vtkPolyData* output)
+    double spacing[3], vtkPolyData* output, vtkBinnedDecimation* filter)
   {
     vtkIdType numPts = pts->GetNumberOfTuples();
     vtkIdType numTris = tris->GetNumberOfCells();
@@ -1258,12 +1422,12 @@ struct AvePointsWorker
     if (!largeIds)
     {
       AvePointsDecimate<DataT, int>(numPts, pts, inPD, outPD, numTris, tris, inCD, outCD, numBins,
-        divs, bounds, spacing, output);
+        divs, bounds, spacing, output, filter);
     }
     else
     {
       AvePointsDecimate<DataT, vtkIdType>(numPts, pts, inPD, outPD, numTris, tris, inCD, outCD,
-        numBins, divs, bounds, spacing, output);
+        numBins, divs, bounds, spacing, output, filter);
     }
   }
 };
@@ -1299,7 +1463,7 @@ vtkBinnedDecimation::vtkBinnedDecimation()
 }
 
 //----------------------------------------------------------------------------
-vtkBinnedDecimation::~vtkBinnedDecimation() {}
+vtkBinnedDecimation::~vtkBinnedDecimation() = default;
 
 //----------------------------------------------------------------------------
 // Use the same approach as vtkQuadricClustering (which is a bit of a mess but
@@ -1430,8 +1594,7 @@ int vtkBinnedDecimation::RequestData(vtkInformation* vtkNotUsed(request),
 
   // Determine what type of ids are needed: smaller id types save a lot of
   // memory.
-  this->LargeIds =
-    ((numBins > VTK_INT_MAX || numPts > VTK_INT_MAX || numTris > VTK_INT_MAX) ? true : false);
+  this->LargeIds = numBins > VTK_INT_MAX || numPts > VTK_INT_MAX || numTris > VTK_INT_MAX;
 
   // Fast path: dispatch to real point types
   using vtkArrayDispatch::Reals;
@@ -1449,10 +1612,10 @@ int vtkBinnedDecimation::RequestData(vtkInformation* vtkNotUsed(request),
     using PointReuseDispatch = vtkArrayDispatch::DispatchByValueType<Reals>;
     PointReuseWorker deciWorker;
     if (!PointReuseDispatch::Execute(inPts->GetData(), deciWorker, this->LargeIds, inTris, inCD,
-          outCD, this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output))
+          outCD, this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output, this))
     { // Fallback to slowpath for other point types
       deciWorker(inPts->GetData(), this->LargeIds, inTris, inCD, outCD, this->NumberOfDivisions,
-        this->Bounds, this->DivisionSpacing, output);
+        this->Bounds, this->DivisionSpacing, output, this);
     }
   }
 
@@ -1464,10 +1627,10 @@ int vtkBinnedDecimation::RequestData(vtkInformation* vtkNotUsed(request),
     BinPointsWorker deciWorker;
     if (!BinPointsDispatch::Execute(inPts->GetData(), deciWorker, inPD, outPD, this->LargeIds,
           this->PointGenerationMode, inTris, inCD, outCD, this->NumberOfDivisions, this->Bounds,
-          this->DivisionSpacing, output))
+          this->DivisionSpacing, output, this))
     { // Fallback to slowpath for other point types
       deciWorker(inPts->GetData(), inPD, outPD, this->LargeIds, this->PointGenerationMode, inTris,
-        inCD, outCD, this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output);
+        inCD, outCD, this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output, this);
     }
   }
 
@@ -1477,11 +1640,11 @@ int vtkBinnedDecimation::RequestData(vtkInformation* vtkNotUsed(request),
     using AvePointsDispatch = vtkArrayDispatch::DispatchByValueType<Reals>;
     AvePointsWorker deciWorker;
     if (!AvePointsDispatch::Execute(inPts->GetData(), deciWorker, inPD, outPD, this->LargeIds,
-          inTris, inCD, outCD, this->NumberOfDivisions, this->Bounds, this->DivisionSpacing,
-          output))
+          inTris, inCD, outCD, this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output,
+          this))
     { // Fallback to slowpath for other point types
       deciWorker(inPts->GetData(), inPD, outPD, this->LargeIds, inTris, inCD, outCD,
-        this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output);
+        this->NumberOfDivisions, this->Bounds, this->DivisionSpacing, output, this);
     }
   }
 
@@ -1652,3 +1815,4 @@ void vtkBinnedDecimation::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Pass Point Data : " << this->ProducePointData << endl;
   os << indent << "Produce Cell Data : " << this->ProduceCellData << endl;
 }
+VTK_ABI_NAMESPACE_END
