@@ -61,12 +61,21 @@
  * points must lie inside modified bounds).
  *
  * @warning
- * If you wish to operate on a set of coordinates
- * that has no cells, you must add a vtkPolyVertex cell with all of the points to the PolyData
+ * If you wish to operate on a set of point coordinates that has no cells,
+ * you must add a vtkPolyVertex cell with all of the points to the PolyData
  * (or use a vtkVertexGlyphFilter) before using the vtkCleanPolyData filter.
  *
+ * @warning
+ * The vtkStaticCleanPolyData filter is similar in operation to
+ * vtkCleanPolyData. However, vtkStaticCleanPolyData is non-incremental and
+ * uses a much faster threading approach (especially for larger datasets, and
+ * when merging points with a non-zero tolerance). However because of the
+ * difference in the traversal order in the point merging process, the output
+ * of the filters may be different.
+ *
  * @sa
- * vtkQuantizePolyDataPoints
+ * vtkQuantizePolyDataPoints vtkStaticCleanPolyData
+ * vtkStaticCleanUnstructuredGrid
  */
 
 #ifndef vtkCleanPolyData_h
@@ -75,6 +84,7 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIncrementalPointLocator;
 
 class VTKFILTERSCORE_EXPORT vtkCleanPolyData : public vtkPolyDataAlgorithm
@@ -84,7 +94,7 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent) override;
   vtkTypeMacro(vtkCleanPolyData, vtkPolyDataAlgorithm);
 
-  //@{
+  ///@{
   /**
    * By default ToleranceIsAbsolute is false and Tolerance is
    * a fraction of Bounding box diagonal, if true, AbsoluteTolerance is
@@ -93,53 +103,53 @@ public:
   vtkSetMacro(ToleranceIsAbsolute, vtkTypeBool);
   vtkBooleanMacro(ToleranceIsAbsolute, vtkTypeBool);
   vtkGetMacro(ToleranceIsAbsolute, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify tolerance in terms of fraction of bounding box length.
    * Default is 0.0.
    */
   vtkSetClampMacro(Tolerance, double, 0.0, 1.0);
   vtkGetMacro(Tolerance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify tolerance in absolute terms. Default is 1.0.
    */
   vtkSetClampMacro(AbsoluteTolerance, double, 0.0, VTK_DOUBLE_MAX);
   vtkGetMacro(AbsoluteTolerance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off conversion of degenerate lines to points. Default is On.
    */
   vtkSetMacro(ConvertLinesToPoints, vtkTypeBool);
   vtkBooleanMacro(ConvertLinesToPoints, vtkTypeBool);
   vtkGetMacro(ConvertLinesToPoints, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off conversion of degenerate polys to lines. Default is On.
    */
   vtkSetMacro(ConvertPolysToLines, vtkTypeBool);
   vtkBooleanMacro(ConvertPolysToLines, vtkTypeBool);
   vtkGetMacro(ConvertPolysToLines, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off conversion of degenerate strips to polys. Default is On.
    */
   vtkSetMacro(ConvertStripsToPolys, vtkTypeBool);
   vtkBooleanMacro(ConvertStripsToPolys, vtkTypeBool);
   vtkGetMacro(ConvertStripsToPolys, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get a boolean value that controls whether point merging is
    * performed. If on, a locator will be used, and points laying within
@@ -149,16 +159,16 @@ public:
   vtkSetMacro(PointMerging, vtkTypeBool);
   vtkGetMacro(PointMerging, vtkTypeBool);
   vtkBooleanMacro(PointMerging, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get a spatial locator for speeding the search process. By
    * default an instance of vtkMergePoints is used.
    */
   virtual void SetLocator(vtkIncrementalPointLocator* locator);
   vtkGetObjectMacro(Locator, vtkIncrementalPointLocator);
-  //@}
+  ///@}
 
   /**
    * Create default locator. Used to create one when none is specified.
@@ -194,7 +204,7 @@ public:
   vtkGetMacro(PieceInvariant, vtkTypeBool);
   vtkBooleanMacro(PieceInvariant, vtkTypeBool);
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output types. See the documentation
    * for the vtkAlgorithm::DesiredOutputPrecision enum for an explanation of
@@ -202,7 +212,7 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
 protected:
   vtkCleanPolyData();
@@ -229,4 +239,5 @@ private:
   void operator=(const vtkCleanPolyData&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
