@@ -20,19 +20,19 @@
 #include "vtkDemandDrivenPipeline.h"
 #include "vtkFloatArray.h"
 #include "vtkIdList.h"
+#include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
-#include "vtkPointData.h"
 #include "vtkPoints.h"
 #include "vtkPolyData.h"
 #include "vtkUnstructuredGrid.h"
-#include "vtkIdTypeArray.h"
 
 #include <map>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkConnectivityFilter);
 
 // Construct with default extraction mode to extract largest regions.
@@ -79,7 +79,7 @@ int vtkConnectivityFilter::RequestDataObject(vtkInformation* vtkNotUsed(request)
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   if (!inInfo)
   {
-      return 0;
+    return 0;
   }
 
   vtkDataObject* input = inInfo->Get(vtkDataObject::DATA_OBJECT());
@@ -115,46 +115,42 @@ int vtkConnectivityFilter::RequestDataObject(vtkInformation* vtkNotUsed(request)
   return 0;
 }
 
-int vtkConnectivityFilter::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkDataSet *input = vtkDataSet::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkPointSet *output = vtkPointSet::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataSet* input = vtkDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPointSet* output = vtkPointSet::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   vtkPolyData* pdOutput = vtkPolyData::SafeDownCast(output);
   vtkUnstructuredGrid* ugOutput = vtkUnstructuredGrid::SafeDownCast(output);
 
   vtkIdType numPts, numCells, cellId, i, j, pt;
-  vtkPoints *newPts;
+  vtkPoints* newPts;
   vtkIdType id;
   vtkIdType maxCellsInRegion;
   vtkIdType largestRegionId = 0;
-  vtkPointData *pd=input->GetPointData(), *outputPD=output->GetPointData();
-  vtkCellData *cd=input->GetCellData(), *outputCD=output->GetCellData();
+  vtkPointData *pd = input->GetPointData(), *outputPD = output->GetPointData();
+  vtkCellData *cd = input->GetCellData(), *outputCD = output->GetCellData();
 
-  vtkDebugMacro(<<"Executing connectivity filter.");
+  vtkDebugMacro(<< "Executing connectivity filter.");
 
   //  Check input/allocate storage
   //
-  numCells=input->GetNumberOfCells();
-  if ( (numPts=input->GetNumberOfPoints()) < 1 || numCells < 1 )
+  numCells = input->GetNumberOfCells();
+  if ((numPts = input->GetNumberOfPoints()) < 1 || numCells < 1)
   {
-    vtkDebugMacro(<<"No data to connect!");
+    vtkDebugMacro(<< "No data to connect!");
     return 1;
   }
 
   if (pdOutput)
   {
-    pdOutput->Allocate(numCells, numCells);
+    pdOutput->AllocateExact(numCells, 3);
   }
   if (ugOutput)
   {
@@ -164,13 +160,13 @@ int vtkConnectivityFilter::RequestData(
   // See whether to consider scalar connectivity
   //
   this->InScalars = input->GetPointData()->GetScalars();
-  if ( !this->ScalarConnectivity )
+  if (!this->ScalarConnectivity)
   {
     this->InScalars = nullptr;
   }
   else
   {
-    if ( this->ScalarRange[1] < this->ScalarRange[0] )
+    if (this->ScalarRange[1] < this->ScalarRange[0])
     {
       this->ScalarRange[1] = this->ScalarRange[0];
     }
@@ -180,12 +176,12 @@ int vtkConnectivityFilter::RequestData(
   //
   this->RegionSizes->Reset();
   this->Visited = new vtkIdType[numCells];
-  for ( i=0; i < numCells; i++ )
+  for (i = 0; i < numCells; i++)
   {
     this->Visited[i] = -1;
   }
   this->PointMap = new vtkIdType[numPts];
-  for ( i=0; i < numPts; i++ )
+  for (i = 0; i < numPts; i++)
   {
     this->PointMap[i] = -1;
   }
@@ -201,10 +197,10 @@ int vtkConnectivityFilter::RequestData(
   newPts = vtkPoints::New();
 
   // Set the desired precision for the points in the output.
-  if(this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
+  if (this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
   {
-    vtkPointSet *inputPointSet = vtkPointSet::SafeDownCast(input);
-    if(inputPointSet)
+    vtkPointSet* inputPointSet = vtkPointSet::SafeDownCast(input);
+    if (inputPointSet)
     {
       newPts->SetDataType(inputPointSet->GetPoints()->GetDataType());
     }
@@ -213,11 +209,11 @@ int vtkConnectivityFilter::RequestData(
       newPts->SetDataType(VTK_FLOAT);
     }
   }
-  else if(this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
+  else if (this->OutputPointsPrecision == vtkAlgorithm::SINGLE_PRECISION)
   {
     newPts->SetDataType(VTK_FLOAT);
   }
-  else if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
+  else if (this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
   {
     newPts->SetDataType(VTK_DOUBLE);
   }
@@ -229,9 +225,9 @@ int vtkConnectivityFilter::RequestData(
   // using a connected wave propagation.
   //
   this->Wave = vtkIdList::New();
-  this->Wave->Allocate(numPts/4+1,numPts);
+  this->Wave->Allocate(numPts / 4 + 1, numPts);
   this->Wave2 = vtkIdList::New();
-  this->Wave2->Allocate(numPts/4+1,numPts);
+  this->Wave2->Allocate(numPts / 4 + 1, numPts);
 
   this->PointNumber = 0;
   this->RegionNumber = 0;
@@ -242,31 +238,34 @@ int vtkConnectivityFilter::RequestData(
   this->PointIds = vtkIdList::New();
   this->PointIds->Allocate(8, VTK_CELL_SIZE);
 
-  if ( this->ExtractionMode != VTK_EXTRACT_POINT_SEEDED_REGIONS &&
-  this->ExtractionMode != VTK_EXTRACT_CELL_SEEDED_REGIONS &&
-  this->ExtractionMode != VTK_EXTRACT_CLOSEST_POINT_REGION )
-  { //visit all cells marking with region number
-    for (cellId=0; cellId < numCells; cellId++)
+  if (this->ExtractionMode != VTK_EXTRACT_POINT_SEEDED_REGIONS &&
+    this->ExtractionMode != VTK_EXTRACT_CELL_SEEDED_REGIONS &&
+    this->ExtractionMode != VTK_EXTRACT_CLOSEST_POINT_REGION)
+  { // visit all cells marking with region number
+    for (cellId = 0; cellId < numCells; cellId++)
     {
-      if ( cellId && !(cellId % 5000) )
+      if (cellId && !(cellId % 5000))
       {
-        this->UpdateProgress (0.1 + 0.8*cellId/numCells);
+        if (this->CheckAbort())
+        {
+          break;
+        }
+        this->UpdateProgress(0.1 + 0.8 * cellId / numCells);
       }
 
-      if ( this->Visited[cellId] < 0 )
+      if (this->Visited[cellId] < 0)
       {
         this->NumCellsInRegion = 0;
         this->Wave->InsertNextId(cellId);
-        this->TraverseAndMark (input);
+        this->TraverseAndMark(input);
 
-        if ( this->NumCellsInRegion > maxCellsInRegion )
+        if (this->NumCellsInRegion > maxCellsInRegion)
         {
           maxCellsInRegion = this->NumCellsInRegion;
           largestRegionId = this->RegionNumber;
         }
 
-        this->RegionSizes->InsertValue(this->RegionNumber++,
-                                       this->NumCellsInRegion);
+        this->RegionSizes->InsertValue(this->RegionNumber++, this->NumCellsInRegion);
         this->Wave->Reset();
         this->Wave2->Reset();
       }
@@ -276,82 +275,98 @@ int vtkConnectivityFilter::RequestData(
   {
     this->NumCellsInRegion = 0;
 
-    if ( this->ExtractionMode == VTK_EXTRACT_POINT_SEEDED_REGIONS )
+    if (this->ExtractionMode == VTK_EXTRACT_POINT_SEEDED_REGIONS)
     {
-      for (i=0; i < this->Seeds->GetNumberOfIds(); i++)
+      for (i = 0; i < this->Seeds->GetNumberOfIds(); i++)
       {
-        pt = this->Seeds->GetId(i);
-        if ( pt >= 0 )
+        if (this->CheckAbort())
         {
-          input->GetPointCells(pt,this->CellIds);
-          for (j=0; j < this->CellIds->GetNumberOfIds(); j++)
+          break;
+        }
+        pt = this->Seeds->GetId(i);
+        if (pt >= 0)
+        {
+          input->GetPointCells(pt, this->CellIds);
+          for (j = 0; j < this->CellIds->GetNumberOfIds(); j++)
           {
             this->Wave->InsertNextId(this->CellIds->GetId(j));
           }
         }
       }
     }
-    else if ( this->ExtractionMode == VTK_EXTRACT_CELL_SEEDED_REGIONS )
+    else if (this->ExtractionMode == VTK_EXTRACT_CELL_SEEDED_REGIONS)
     {
-      for (i=0; i < this->Seeds->GetNumberOfIds(); i++)
+      for (i = 0; i < this->Seeds->GetNumberOfIds(); i++)
       {
+        if (this->CheckAbort())
+        {
+          break;
+        }
         cellId = this->Seeds->GetId(i);
-        if ( cellId >= 0 )
+        if (cellId >= 0)
         {
           this->Wave->InsertNextId(cellId);
         }
       }
     }
-    else if ( this->ExtractionMode == VTK_EXTRACT_CLOSEST_POINT_REGION )
-    {//loop over points, find closest one
+    else if (this->ExtractionMode == VTK_EXTRACT_CLOSEST_POINT_REGION)
+    { // loop over points, find closest one
       double minDist2, dist2, x[3];
       vtkIdType minId = 0;
-      for (minDist2=VTK_DOUBLE_MAX, i=0; i<numPts; i++)
+      for (minDist2 = VTK_DOUBLE_MAX, i = 0; i < numPts; i++)
       {
-        input->GetPoint(i,x);
-        dist2 = vtkMath::Distance2BetweenPoints(x,this->ClosestPoint);
-        if ( dist2 < minDist2 )
+        if (this->CheckAbort())
+        {
+          break;
+        }
+        input->GetPoint(i, x);
+        dist2 = vtkMath::Distance2BetweenPoints(x, this->ClosestPoint);
+        if (dist2 < minDist2)
         {
           minId = i;
           minDist2 = dist2;
         }
       }
-      input->GetPointCells(minId,this->CellIds);
-      for (j=0; j < this->CellIds->GetNumberOfIds(); j++)
+      input->GetPointCells(minId, this->CellIds);
+      for (j = 0; j < this->CellIds->GetNumberOfIds(); j++)
       {
+        if (this->CheckAbort())
+        {
+          break;
+        }
         this->Wave->InsertNextId(this->CellIds->GetId(j));
       }
     }
-    this->UpdateProgress (0.5);
+    this->UpdateProgress(0.5);
 
-    //mark all seeded regions
-    this->TraverseAndMark (input);
-    this->RegionSizes->InsertValue(this->RegionNumber,this->NumCellsInRegion);
-    this->UpdateProgress (0.9);
+    // mark all seeded regions
+    this->TraverseAndMark(input);
+    this->RegionSizes->InsertValue(this->RegionNumber, this->NumCellsInRegion);
+    this->UpdateProgress(0.9);
   }
 
-  vtkDebugMacro (<<"Extracted " << this->RegionNumber << " region(s)");
+  vtkDebugMacro(<< "Extracted " << this->RegionNumber << " region(s)");
   this->Wave->Delete();
   this->Wave2->Delete();
 
   // Now that points and cells have been marked, traverse these lists pulling
   // everything that has been visited.
   //
-  //Pass through point data that has been visited
+  // Pass through point data that has been visited
   outputPD->CopyAllocate(pd);
   outputCD->CopyAllocate(cd);
 
-  for (i=0; i < numPts; i++)
+  for (i = 0; i < numPts; i++)
   {
-    if ( this->PointMap[i] > -1 )
+    if (this->PointMap[i] > -1)
     {
-      newPts->InsertPoint(this->PointMap[i],input->GetPoint(i));
-      outputPD->CopyData(pd,i,this->PointMap[i]);
+      newPts->InsertPoint(this->PointMap[i], input->GetPoint(i));
+      outputPD->CopyData(pd, i, this->PointMap[i]);
     }
   }
 
   // if coloring regions; send down new scalar data
-  if ( this->ColorRegions )
+  if (this->ColorRegions)
   {
     this->OrderRegionIds(this->NewScalars, this->NewCellScalars);
 
@@ -368,43 +383,39 @@ int vtkConnectivityFilter::RequestData(
 
   // Create output cells
   //
-  if ( this->ExtractionMode == VTK_EXTRACT_POINT_SEEDED_REGIONS ||
-  this->ExtractionMode == VTK_EXTRACT_CELL_SEEDED_REGIONS ||
-  this->ExtractionMode == VTK_EXTRACT_CLOSEST_POINT_REGION ||
-  this->ExtractionMode == VTK_EXTRACT_ALL_REGIONS)
+  if (this->ExtractionMode == VTK_EXTRACT_POINT_SEEDED_REGIONS ||
+    this->ExtractionMode == VTK_EXTRACT_CELL_SEEDED_REGIONS ||
+    this->ExtractionMode == VTK_EXTRACT_CLOSEST_POINT_REGION ||
+    this->ExtractionMode == VTK_EXTRACT_ALL_REGIONS)
   { // extract any cell that's been visited
-    for (cellId=0; cellId < numCells; cellId++)
+    for (cellId = 0; cellId < numCells; cellId++)
     {
-      if ( this->Visited[cellId] >= 0 )
+      if (this->Visited[cellId] >= 0)
       {
         // special handling for polyhedron cells
         if (vtkUnstructuredGrid::SafeDownCast(input) &&
-            input->GetCellType(cellId) == VTK_POLYHEDRON)
+          input->GetCellType(cellId) == VTK_POLYHEDRON)
         {
-          vtkUnstructuredGrid::SafeDownCast(input)->
-            GetFaceStream(cellId, this->PointIds);
-          vtkUnstructuredGrid::ConvertFaceStreamPointIds(this->PointIds,
-                                                         this->PointMap);
+          vtkUnstructuredGrid::SafeDownCast(input)->GetFaceStream(cellId, this->PointIds);
+          vtkUnstructuredGrid::ConvertFaceStreamPointIds(this->PointIds, this->PointMap);
         }
         else
         {
           input->GetCellPoints(cellId, this->PointIds);
-          for (i=0; i < this->PointIds->GetNumberOfIds(); i++)
+          for (i = 0; i < this->PointIds->GetNumberOfIds(); i++)
           {
             id = this->PointMap[this->PointIds->GetId(i)];
-            this->PointIds->InsertId(i,id);
+            this->PointIds->InsertId(i, id);
           }
         }
         vtkIdType newCellId = -1;
         if (pdOutput)
         {
-          newCellId = pdOutput->InsertNextCell(input->GetCellType(cellId),
-                                               this->PointIds);
+          newCellId = pdOutput->InsertNextCell(input->GetCellType(cellId), this->PointIds);
         }
         else if (ugOutput)
         {
-          newCellId = ugOutput->InsertNextCell(input->GetCellType(cellId),
-                                               this->PointIds);
+          newCellId = ugOutput->InsertNextCell(input->GetCellType(cellId), this->PointIds);
         }
         if (newCellId >= 0)
         {
@@ -413,51 +424,47 @@ int vtkConnectivityFilter::RequestData(
       }
     }
   }
-  else if ( this->ExtractionMode == VTK_EXTRACT_SPECIFIED_REGIONS )
+  else if (this->ExtractionMode == VTK_EXTRACT_SPECIFIED_REGIONS)
   {
-    for (cellId=0; cellId < numCells; cellId++)
+    for (cellId = 0; cellId < numCells; cellId++)
     {
       int inReg, regionId;
-      if ( (regionId=this->Visited[cellId]) >= 0 )
+      if ((regionId = this->Visited[cellId]) >= 0)
       {
-        for (inReg=0,i=0; i<this->SpecifiedRegionIds->GetNumberOfIds(); i++)
+        for (inReg = 0, i = 0; i < this->SpecifiedRegionIds->GetNumberOfIds(); i++)
         {
-          if ( regionId == this->SpecifiedRegionIds->GetId(i) )
+          if (regionId == this->SpecifiedRegionIds->GetId(i))
           {
             inReg = 1;
             break;
           }
         }
-        if ( inReg )
+        if (inReg)
         {
           // special handling for polyhedron cells
           if (vtkUnstructuredGrid::SafeDownCast(input) &&
-              input->GetCellType(cellId) == VTK_POLYHEDRON)
+            input->GetCellType(cellId) == VTK_POLYHEDRON)
           {
-            vtkUnstructuredGrid::SafeDownCast(input)->
-              GetFaceStream(cellId, this->PointIds);
-            vtkUnstructuredGrid::ConvertFaceStreamPointIds(this->PointIds,
-                                                           this->PointMap);
+            vtkUnstructuredGrid::SafeDownCast(input)->GetFaceStream(cellId, this->PointIds);
+            vtkUnstructuredGrid::ConvertFaceStreamPointIds(this->PointIds, this->PointMap);
           }
           else
           {
             input->GetCellPoints(cellId, this->PointIds);
-            for (i=0; i < this->PointIds->GetNumberOfIds(); i++)
+            for (i = 0; i < this->PointIds->GetNumberOfIds(); i++)
             {
               id = this->PointMap[this->PointIds->GetId(i)];
-              this->PointIds->InsertId(i,id);
+              this->PointIds->InsertId(i, id);
             }
           }
           vtkIdType newCellId = -1;
           if (pdOutput)
           {
-            newCellId = pdOutput->InsertNextCell(input->GetCellType(cellId),
-                                                 this->PointIds);
+            newCellId = pdOutput->InsertNextCell(input->GetCellType(cellId), this->PointIds);
           }
           else if (ugOutput)
           {
-            newCellId = ugOutput->InsertNextCell(input->GetCellType(cellId),
-                                                 this->PointIds);
+            newCellId = ugOutput->InsertNextCell(input->GetCellType(cellId), this->PointIds);
           }
           if (newCellId >= 0)
           {
@@ -467,40 +474,36 @@ int vtkConnectivityFilter::RequestData(
       }
     }
   }
-  else //extract largest region
+  else // extract largest region
   {
-    for (cellId=0; cellId < numCells; cellId++)
+    for (cellId = 0; cellId < numCells; cellId++)
     {
-      if ( this->Visited[cellId] == largestRegionId )
+      if (this->Visited[cellId] == largestRegionId)
       {
         // special handling for polyhedron cells
         if (vtkUnstructuredGrid::SafeDownCast(input) &&
-            input->GetCellType(cellId) == VTK_POLYHEDRON)
+          input->GetCellType(cellId) == VTK_POLYHEDRON)
         {
-          vtkUnstructuredGrid::SafeDownCast(input)->
-            GetFaceStream(cellId, this->PointIds);
-          vtkUnstructuredGrid::ConvertFaceStreamPointIds(this->PointIds,
-                                                         this->PointMap);
+          vtkUnstructuredGrid::SafeDownCast(input)->GetFaceStream(cellId, this->PointIds);
+          vtkUnstructuredGrid::ConvertFaceStreamPointIds(this->PointIds, this->PointMap);
         }
         else
         {
           input->GetCellPoints(cellId, this->PointIds);
-          for (i=0; i < this->PointIds->GetNumberOfIds(); i++)
+          for (i = 0; i < this->PointIds->GetNumberOfIds(); i++)
           {
             id = this->PointMap[this->PointIds->GetId(i)];
-            this->PointIds->InsertId(i,id);
+            this->PointIds->InsertId(i, id);
           }
         }
         vtkIdType newCellId = -1;
         if (pdOutput)
         {
-          newCellId = pdOutput->InsertNextCell(input->GetCellType(cellId),
-                                               this->PointIds);
+          newCellId = pdOutput->InsertNextCell(input->GetCellType(cellId), this->PointIds);
         }
         else if (ugOutput)
         {
-          newCellId = ugOutput->InsertNextCell(input->GetCellType(cellId),
-                                               this->PointIds);
+          newCellId = ugOutput->InsertNextCell(input->GetCellType(cellId), this->PointIds);
         }
         if (newCellId >= 0)
         {
@@ -510,45 +513,50 @@ int vtkConnectivityFilter::RequestData(
     }
   }
 
-  delete [] this->Visited;
-  delete [] this->PointMap;
+  delete[] this->Visited;
+  delete[] this->PointMap;
   this->PointIds->Delete();
   this->CellIds->Delete();
   output->Squeeze();
   vtkDataArray* outScalars = nullptr;
-  if (this->ColorRegions && (outScalars=output->GetPointData()->GetScalars()))
+  if (this->ColorRegions && (outScalars = output->GetPointData()->GetScalars()))
   {
     outScalars->Resize(output->GetNumberOfPoints());
   }
 
+#ifndef NDEBUG
   int num = this->GetNumberOfExtractedRegions();
   int count = 0;
 
   for (int ii = 0; ii < num; ii++)
   {
-    count += this->RegionSizes->GetValue (ii);
+    count += this->RegionSizes->GetValue(ii);
   }
-  vtkDebugMacro (<< "Total # of cells accounted for: " << count);
-  vtkDebugMacro (<< "Extracted " << output->GetNumberOfCells() << " cells");
+#endif
+  vtkDebugMacro(<< "Total # of cells accounted for: " << count);
+  vtkDebugMacro(<< "Extracted " << output->GetNumberOfCells() << " cells");
 
   return 1;
 }
 
-
 // Mark current cell as visited and assign region number.  Note:
 // traversal occurs across shared vertices.
 //
-void vtkConnectivityFilter::TraverseAndMark (vtkDataSet *input)
+void vtkConnectivityFilter::TraverseAndMark(vtkDataSet* input)
 {
   vtkIdType i, j, k, cellId, numIds, ptId, numPts, numCells;
-  vtkIdList *tmpWave;
+  vtkIdList* tmpWave;
 
-  while ( (numIds=this->Wave->GetNumberOfIds()) > 0 )
+  while ((numIds = this->Wave->GetNumberOfIds()) > 0)
   {
-    for ( i=0; i < numIds; i++ )
+    if (this->CheckAbort())
+    {
+      break;
+    }
+    for (i = 0; i < numIds; i++)
     {
       cellId = this->Wave->GetId(i);
-      if ( this->Visited[cellId] < 0 )
+      if (this->Visited[cellId] < 0)
       {
         this->NewCellScalars->SetValue(cellId, this->RegionNumber);
         this->Visited[cellId] = this->RegionNumber;
@@ -556,23 +564,22 @@ void vtkConnectivityFilter::TraverseAndMark (vtkDataSet *input)
         input->GetCellPoints(cellId, this->PointIds);
 
         numPts = this->PointIds->GetNumberOfIds();
-        for (j=0; j < numPts; j++)
+        for (j = 0; j < numPts; j++)
         {
-          if ( this->PointMap[ptId=this->PointIds->GetId(j)] < 0 )
+          if (this->PointMap[ptId = this->PointIds->GetId(j)] < 0)
           {
             this->PointMap[ptId] = this->PointNumber++;
-            this->NewScalars->SetValue(this->PointMap[ptId],
-                                       this->RegionNumber);
+            this->NewScalars->SetValue(this->PointMap[ptId], this->RegionNumber);
           }
 
-          input->GetPointCells(ptId,this->CellIds);
+          input->GetPointCells(ptId, this->CellIds);
 
           // check connectivity criterion (geometric + scalar)
           numCells = this->CellIds->GetNumberOfIds();
-          for (k=0; k < numCells; k++)
+          for (k = 0; k < numCells; k++)
           {
             cellId = this->CellIds->GetId(k);
-            if ( this->InScalars )
+            if (this->InScalars)
             {
               int numScalars, ii;
               double s, range[2];
@@ -581,23 +588,22 @@ void vtkConnectivityFilter::TraverseAndMark (vtkDataSet *input)
               numScalars = this->NeighborCellPointIds->GetNumberOfIds();
               this->CellScalars->SetNumberOfComponents(this->InScalars->GetNumberOfComponents());
               this->CellScalars->SetNumberOfTuples(numScalars);
-              this->InScalars->GetTuples(this->NeighborCellPointIds,
-                                         this->CellScalars);
-              range[0] = VTK_DOUBLE_MAX; range[1] = -VTK_DOUBLE_MAX;
-              for (ii=0; ii < numScalars;  ii++)
+              this->InScalars->GetTuples(this->NeighborCellPointIds, this->CellScalars);
+              range[0] = VTK_DOUBLE_MAX;
+              range[1] = -VTK_DOUBLE_MAX;
+              for (ii = 0; ii < numScalars; ii++)
               {
-                s = this->CellScalars->GetComponent(ii,0);
-                if ( s < range[0] )
+                s = this->CellScalars->GetComponent(ii, 0);
+                if (s < range[0])
                 {
                   range[0] = s;
                 }
-                if ( s > range[1] )
+                if (s > range[1])
                 {
                   range[1] = s;
                 }
               }
-              if ( range[1] >= this->ScalarRange[0] &&
-                   range[0] <= this->ScalarRange[1] )
+              if (range[1] >= this->ScalarRange[0] && range[0] <= this->ScalarRange[1])
               {
                 this->Wave2->InsertNextId(cellId);
               }
@@ -606,24 +612,25 @@ void vtkConnectivityFilter::TraverseAndMark (vtkDataSet *input)
             {
               this->Wave2->InsertNextId(cellId);
             }
-          }//for all cells using this point
-        }//for all points of this cell
-      }//if cell not yet visited
-    }//for all cells in this wave
+          } // for all cells using this point
+        }   // for all points of this cell
+      }     // if cell not yet visited
+    }       // for all cells in this wave
 
     tmpWave = this->Wave;
     this->Wave = this->Wave2;
     this->Wave2 = tmpWave;
     tmpWave->Reset();
-  } //while wave is not empty
+  } // while wave is not empty
 }
 
-void vtkConnectivityFilter::OrderRegionIds(vtkIdTypeArray* pointRegionIds, vtkIdTypeArray* cellRegionIds)
+void vtkConnectivityFilter::OrderRegionIds(
+  vtkIdTypeArray* pointRegionIds, vtkIdTypeArray* cellRegionIds)
 {
   if (this->ColorRegions)
   {
     if (this->RegionIdAssignmentMode == CELL_COUNT_DESCENDING ||
-        this->RegionIdAssignmentMode == CELL_COUNT_ASCENDING)
+      this->RegionIdAssignmentMode == CELL_COUNT_ASCENDING)
     {
       // Use a multimap to handle cases where more than one region has the same number of cells.
       std::multimap<vtkIdType, vtkIdType> cellCountToRegionId;
@@ -693,8 +700,8 @@ int vtkConnectivityFilter::GetNumberOfExtractedRegions()
   return this->RegionSizes->GetMaxId() + 1;
 }
 
-vtkTypeBool vtkConnectivityFilter::ProcessRequest(vtkInformation* request,
-  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
+vtkTypeBool vtkConnectivityFilter::ProcessRequest(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   if (request->Has(vtkDemandDrivenPipeline::REQUEST_DATA_OBJECT()))
   {
@@ -704,7 +711,6 @@ vtkTypeBool vtkConnectivityFilter::ProcessRequest(vtkInformation* request,
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-
 // Initialize list of point ids/cell ids used to seed regions.
 void vtkConnectivityFilter::InitializeSeedList()
 {
@@ -747,7 +753,7 @@ void vtkConnectivityFilter::DeleteSpecifiedRegion(int id)
   this->SpecifiedRegionIds->DeleteId(id);
 }
 
-int vtkConnectivityFilter::FillInputPortInformation(int, vtkInformation *info)
+int vtkConnectivityFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet");
   return 1;
@@ -761,21 +767,20 @@ int vtkConnectivityFilter::FillOutputPortInformation(int vtkNotUsed(port), vtkIn
 
 void vtkConnectivityFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Extraction Mode: ";
   os << this->GetExtractionModeAsString() << "\n";
 
-  os << indent << "Closest Point: (" << this->ClosestPoint[0] << ", "
-     << this->ClosestPoint[1] << ", " << this->ClosestPoint[2] << ")\n";
+  os << indent << "Closest Point: (" << this->ClosestPoint[0] << ", " << this->ClosestPoint[1]
+     << ", " << this->ClosestPoint[2] << ")\n";
 
   os << indent << "Color Regions: " << (this->ColorRegions ? "On\n" : "Off\n");
 
-  os << indent << "Scalar Connectivity: "
-     << (this->ScalarConnectivity ? "On\n" : "Off\n");
+  os << indent << "Scalar Connectivity: " << (this->ScalarConnectivity ? "On\n" : "Off\n");
 
-  double *range = this->GetScalarRange();
+  double* range = this->GetScalarRange();
   os << indent << "Scalar Range: (" << range[0] << ", " << range[1] << ")\n";
-  os << indent << "Output Points Precision: " << this->OutputPointsPrecision
-     << "\n";
+  os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
