@@ -15,8 +15,6 @@
 #include "vtkCutter.h"
 
 #include "vtk3DLinearGridPlaneCutter.h"
-#include "vtkArrayDispatch.h"
-#include "vtkAssume.h"
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkCellIterator.h"
@@ -37,6 +35,7 @@
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPlane.h"
+#include "vtkPlaneCutter.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkRectilinearGrid.h"
@@ -46,13 +45,13 @@
 #include "vtkStructuredGrid.h"
 #include "vtkSynchronizedTemplates3D.h"
 #include "vtkSynchronizedTemplatesCutter3D.h"
-#include "vtkTimerLog.h"
 #include "vtkUnstructuredGridBase.h"
 
 #include <algorithm>
 #include <cmath>
 
-vtkStandardNewMacro(vtkCutter);
+VTK_ABI_NAMESPACE_BEGIN
+vtkObjectFactoryNewMacro(vtkCutter);
 vtkCxxSetObjectMacro(vtkCutter, CutFunction, vtkImplicitFunction);
 vtkCxxSetObjectMacro(vtkCutter, Locator, vtkIncrementalPointLocator);
 
@@ -70,9 +69,13 @@ vtkCutter::vtkCutter(vtkImplicitFunction* cf)
   this->OutputPointsPrecision = DEFAULT_PRECISION;
 
   this->SynchronizedTemplates3D = vtkSynchronizedTemplates3D::New();
+  this->SynchronizedTemplates3D->SetContainerAlgorithm(this);
   this->SynchronizedTemplatesCutter3D = vtkSynchronizedTemplatesCutter3D::New();
+  this->SynchronizedTemplatesCutter3D->SetContainerAlgorithm(this);
   this->GridSynchronizedTemplates = vtkGridSynchronizedTemplates3D::New();
+  this->GridSynchronizedTemplates->SetContainerAlgorithm(this);
   this->RectilinearSynchronizedTemplates = vtkRectilinearSynchronizedTemplates::New();
+  this->RectilinearSynchronizedTemplates->SetContainerAlgorithm(this);
 }
 
 //------------------------------------------------------------------------------
@@ -296,32 +299,6 @@ void vtkCutter::RectilinearGridCutter(vtkDataSet* dataSetInput, vtkPolyData* thi
   contourData->Delete();
 }
 
-namespace
-{
-//------------------------------------------------------------------------------
-// Find the first visible cell in a vtkStructuredGrid.
-//
-vtkIdType GetFirstVisibleCell(vtkDataSet* DataSetInput)
-{
-  vtkStructuredGrid* input = vtkStructuredGrid::SafeDownCast(DataSetInput);
-  if (input)
-  {
-    if (input->HasAnyBlankCells())
-    {
-      vtkIdType size = input->GetNumberOfElements(vtkDataSet::CELL);
-      for (vtkIdType i = 0; i < size; ++i)
-      {
-        if (input->IsCellVisible(i) != 0)
-        {
-          return i;
-        }
-      }
-    }
-  }
-  return 0;
-}
-}
-
 //------------------------------------------------------------------------------
 // Cut through data generating surface.
 //
@@ -354,81 +331,109 @@ int vtkCutter::RequestData(
     return 1;
   }
 
-#ifdef TIMEME
-  vtkSmartPointer<vtkTimerLog> timer = vtkSmartPointer<vtkTimerLog>::New();
-  timer->StartTimer();
-#endif
+  vtkPlane* plane = vtkPlane::SafeDownCast(this->CutFunction);
+  auto executePlaneCutter = [&]() {
+    if (this->Locator == nullptr)
+    {
+      this->CreateDefaultLocator();
+    }
+    // Create a copy of vtkPlane and nudge it by the single contour
+    vtkNew<vtkPlane> newPlane;
+    newPlane->SetNormal(plane->GetNormal());
+    newPlane->SetOrigin(plane->GetOrigin());
 
-  if ((input->GetDataObjectType() == VTK_STRUCTURED_POINTS ||
-        input->GetDataObjectType() == VTK_IMAGE_DATA) &&
-    input->GetCell(0) && input->GetCell(0)->GetCellDimension() >= 3)
+    // Evaluate the distance the origin is from the original plane. This accommodates
+    // subclasses of vtkPlane that may have an additional offset parameter not
+    // accessible through the vtkPlane interface. Use this distance to adjust the origin
+    // in newPlane.
+    double d = plane->EvaluateFunction(plane->GetOrigin());
+    // In addition. We'll need to shift by the contour value.
+    newPlane->Push(-d + this->GetValue(0));
+
+    this->PlaneCutter->SetInputData(input);
+    this->PlaneCutter->SetPlane(newPlane);
+    bool mergePoints = this->GetLocator() && !this->GetLocator()->IsA("vtkNonMergingPointLocator");
+    this->PlaneCutter->SetMergePoints(mergePoints);
+    this->PlaneCutter->SetOutputPointsPrecision(this->GetOutputPointsPrecision());
+    this->PlaneCutter->SetGeneratePolygons(!this->GetGenerateTriangles());
+    this->PlaneCutter->SetInputArrayToProcess(0, this->GetInputArrayInformation(0));
+    this->PlaneCutter->BuildTreeOff();
+    this->PlaneCutter->ComputeNormalsOff();
+    this->PlaneCutter->Update();
+    output->ShallowCopy(this->PlaneCutter->GetOutput());
+  };
+  if (vtkImageData::SafeDownCast(input) &&
+    static_cast<vtkImageData*>(input)->GetDataDimension() == 3)
   {
-    this->StructuredPointsCutter(input, output, request, inputVector, outputVector);
+    if (plane && this->GetNumberOfContours() == 1 && this->GetGenerateCutScalars() == 0)
+    {
+      executePlaneCutter();
+    }
+    else
+    {
+      if (input->GetDataObjectType() == VTK_UNIFORM_GRID)
+      {
+        this->DataSetCutter(input, output);
+      }
+      else
+      {
+        this->StructuredPointsCutter(input, output, request, inputVector, outputVector);
+      }
+    }
   }
-  else if (input->GetDataObjectType() == VTK_STRUCTURED_GRID && input->GetCell(0) &&
-    input->GetCell(GetFirstVisibleCell(input))->GetCellDimension() >= 3)
+  else if (vtkStructuredGrid::SafeDownCast(input) &&
+    static_cast<vtkStructuredGrid*>(input)->GetDataDimension() == 3)
   {
-    this->StructuredGridCutter(input, output);
+    if (plane && this->GetNumberOfContours() == 1 && this->GetGenerateCutScalars() == 0)
+    {
+      executePlaneCutter();
+    }
+    else
+    {
+      this->StructuredGridCutter(input, output);
+    }
   }
-  else if (input->GetDataObjectType() == VTK_RECTILINEAR_GRID &&
+  else if (vtkRectilinearGrid::SafeDownCast(input) &&
     static_cast<vtkRectilinearGrid*>(input)->GetDataDimension() == 3)
   {
-    this->RectilinearGridCutter(input, output);
-  }
-  else if (input->GetDataObjectType() == VTK_UNSTRUCTURED_GRID_BASE ||
-    input->GetDataObjectType() == VTK_UNSTRUCTURED_GRID)
-  {
-    // See if the input can be fully processed by the fast vtk3DLinearGridPlaneCutter.
-    // This algorithm can provide a substantial speed improvement over the more general
-    // algorithm for vtkUnstructuredGrids.
-    if (this->GetGenerateTriangles() && this->GetCutFunction() &&
-      this->GetCutFunction()->IsA("vtkPlane") && this->GetNumberOfContours() == 1 &&
-      this->GetGenerateCutScalars() == 0 &&
-      vtk3DLinearGridPlaneCutter::CanFullyProcessDataObject(input))
+    if (plane && this->GetNumberOfContours() == 1 && this->GetGenerateCutScalars() == 0)
     {
-      vtkNew<vtk3DLinearGridPlaneCutter> linear3DCutter;
-
-      // Create a copy of vtkPlane and nudge it by the single contour
-      vtkPlane* plane = vtkPlane::SafeDownCast(this->GetCutFunction());
-      vtkNew<vtkPlane> newPlane;
-      newPlane->SetNormal(plane->GetNormal());
-      newPlane->SetOrigin(plane->GetOrigin());
-
-      // Evaluate the distance the origin is from the original plane. This accomodates
-      // subclasses of vtkPlane that may have an additional offset parameter not
-      // accessible through the vtkPlane interface. Use this distance to adjust the origin
-      // in newPlane.
-      double d = plane->EvaluateFunction(plane->GetOrigin());
-
-      // In addition. We'll need to shift by the contour value.
-      newPlane->Push(-d + this->GetValue(0));
-
-      linear3DCutter->SetPlane(newPlane);
-      linear3DCutter->SetOutputPointsPrecision(this->GetOutputPointsPrecision());
-      linear3DCutter->SetInputArrayToProcess(0, this->GetInputArrayInformation(0));
-      vtkNew<vtkEventForwarderCommand> progressForwarder;
-      progressForwarder->SetTarget(this);
-      linear3DCutter->AddObserver(vtkCommand::ProgressEvent, progressForwarder);
-
-      int retval = linear3DCutter->ProcessRequest(request, inputVector, outputVector);
-
-      return retval;
+      executePlaneCutter();
+    }
+    else
+    {
+      this->RectilinearGridCutter(input, output);
+    }
+  }
+  else if (vtkUnstructuredGridBase::SafeDownCast(input))
+  {
+    if (plane && this->GetNumberOfContours() == 1 && this->GetGenerateCutScalars() == 0 &&
+      this->GetGenerateTriangles() == 1)
+    {
+      executePlaneCutter();
+    }
+    else
+    {
+      this->UnstructuredGridCutter(input, output);
+    }
+  }
+  else if (vtkPolyData::SafeDownCast(input))
+  {
+    if (plane && this->GetNumberOfContours() == 1 && this->GetGenerateCutScalars() == 0 &&
+      this->GetGenerateTriangles() == 1)
+    {
+      executePlaneCutter();
+    }
+    else
+    {
+      this->DataSetCutter(input, output);
     }
-
-    vtkDebugMacro(<< "Executing Unstructured Grid Cutter");
-    this->UnstructuredGridCutter(input, output);
   }
   else
   {
-    vtkDebugMacro(<< "Executing DataSet Cutter");
     this->DataSetCutter(input, output);
   }
 
-#ifdef TIMEME
-  timer->StopTimer();
-  cout << "Sliced " << output->GetNumberOfCells() << " cells in " << timer->GetElapsedTime()
-       << " secs " << endl;
-#endif
   return 1;
 }
 
@@ -488,7 +493,7 @@ void vtkCutter::DataSetCutter(vtkDataSet* input, vtkPolyData* output)
   vtkCellData *inCD = input->GetCellData(), *outCD = output->GetCellData();
   vtkIdList* cellIds;
   vtkIdType numContours = this->ContourValues->GetNumberOfContours();
-  int abortExecute = 0;
+  bool abortExecute = false;
 
   cellScalars = vtkDoubleArray::New();
 
@@ -593,7 +598,7 @@ void vtkCutter::DataSetCutter(vtkDataSet* input, vtkPolyData* output)
         {
           vtkDebugMacro(<< "Cutting #" << cut);
           this->UpdateProgress(static_cast<double>(cut) / numCuts);
-          abortExecute = this->GetAbortExecute();
+          abortExecute = this->CheckAbort();
         }
 
         input->GetCell(cellId, cell);
@@ -649,7 +654,7 @@ void vtkCutter::DataSetCutter(vtkDataSet* input, vtkPolyData* output)
         {
           vtkDebugMacro(<< "Cutting #" << cellId);
           this->UpdateProgress(static_cast<double>(cellId) / numCells);
-          abortExecute = this->GetAbortExecute();
+          abortExecute = this->CheckAbort();
         }
 
         // I assume that "GetCellType" is fast.
@@ -744,7 +749,7 @@ void vtkCutter::UnstructuredGridCutter(vtkDataSet* input, vtkPolyData* output)
   double* contourValuesEnd = contourValues + numContours;
   double* contourIter;
 
-  int abortExecute = 0;
+  bool abortExecute = false;
 
   double range[2];
 
@@ -817,6 +822,7 @@ void vtkCutter::UnstructuredGridCutter(vtkDataSet* input, vtkPolyData* output)
     vtkDataArray* dataArrayInput = inputPointSet->GetPoints()->GetData();
     this->CutFunction->FunctionValue(dataArrayInput, cutScalars);
   }
+
   vtkSmartPointer<vtkCellIterator> cellIter =
     vtkSmartPointer<vtkCellIterator>::Take(input->NewCellIterator());
   vtkNew<vtkGenericCell> cell;
@@ -825,7 +831,8 @@ void vtkCutter::UnstructuredGridCutter(vtkDataSet* input, vtkPolyData* output)
   double tempScalar;
   cellScalars = cutScalars->NewInstance();
   cellScalars->SetNumberOfComponents(cutScalars->GetNumberOfComponents());
-  cellScalars->Allocate(VTK_CELL_SIZE * cutScalars->GetNumberOfComponents());
+  int maxCellSize = input->GetMaxCellSize();
+  cellScalars->Allocate(maxCellSize * cutScalars->GetNumberOfComponents());
 
   vtkContourHelper helper(this->Locator, newVerts, newLines, newPolys, inPD, inCD, outPD, outCD,
     estimatedSize, this->GenerateTriangles != 0);
@@ -852,7 +859,7 @@ void vtkCutter::UnstructuredGridCutter(vtkDataSet* input, vtkPolyData* output)
         {
           vtkDebugMacro(<< "Cutting #" << cut);
           this->UpdateProgress(static_cast<double>(cut) / numCuts);
-          abortExecute = this->GetAbortExecute();
+          abortExecute = this->CheckAbort();
         }
 
         pointIdList = cellIter->GetPointIds();
@@ -933,7 +940,7 @@ void vtkCutter::UnstructuredGridCutter(vtkDataSet* input, vtkPolyData* output)
         {
           vtkDebugMacro(<< "Cutting #" << cellId);
           this->UpdateProgress(static_cast<double>(cellId) / numCuts);
-          abortExecute = this->GetAbortExecute();
+          abortExecute = this->CheckAbort();
         }
 
         // Just fetch the cell type -- least expensive.
@@ -1082,3 +1089,4 @@ void vtkCutter::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Precision of the output points: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
