@@ -12,6 +12,9 @@
 #include "vtkMatrix4x4.h"
 #include "vtkStreamingTessellator.h"
 
+#include <cmath>
+
+VTK_ABI_NAMESPACE_BEGIN
 void vtkEdgeSubdivisionCriterion::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -119,14 +122,17 @@ bool vtkEdgeSubdivisionCriterion::ViewDependentEval(const double* p0, double* p1
     Transform->MultiplyPoint(p2t, p2t);
     int p0Code = 0, p2Code = 0;
 #define ENDPOINT_CODE(code, pt)                                                                    \
-  if (pt[0] > pt[3])                                                                               \
-    code += 1;                                                                                     \
-  else if (pt[0] < -pt[3])                                                                         \
-    code += 2;                                                                                     \
-  if (pt[1] > pt[3])                                                                               \
-    code += 4;                                                                                     \
-  else if (pt[1] < -pt[3])                                                                         \
-    code += 8;
+  do                                                                                               \
+  {                                                                                                \
+    if (pt[0] > pt[3])                                                                             \
+      code += 1;                                                                                   \
+    else if (pt[0] < -pt[3])                                                                       \
+      code += 2;                                                                                   \
+    if (pt[1] > pt[3])                                                                             \
+      code += 4;                                                                                   \
+    else if (pt[1] < -pt[3])                                                                       \
+      code += 8;                                                                                   \
+  } while (false)
 
     ENDPOINT_CODE(p0Code, p0t);
     ENDPOINT_CODE(p2Code, p2t);
@@ -178,3 +184,4 @@ bool vtkEdgeSubdivisionCriterion::FixedFieldErrorEval(
 
   return false;
 }
+VTK_ABI_NAMESPACE_END
