@@ -33,6 +33,7 @@
 
 #include <map>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFeatureEdges);
 
 namespace
@@ -52,6 +53,7 @@ vtkFeatureEdges::vtkFeatureEdges()
   this->NonManifoldEdges = true;
   this->ManifoldEdges = false;
   this->PassLines = false;
+  this->RemoveGhostInterfaces = true;
   this->Coloring = true;
   this->Locator = nullptr;
   this->OutputPointsPrecision = vtkAlgorithm::DEFAULT_PRECISION;
@@ -67,10 +69,11 @@ vtkFeatureEdges::~vtkFeatureEdges()
   }
 }
 
-#include "vtkLogger.h"
+VTK_ABI_NAMESPACE_END
 
 //------------------------------------------------------------------------------
 // Generate feature edges for mesh
+VTK_ABI_NAMESPACE_BEGIN
 int vtkFeatureEdges::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -281,7 +284,7 @@ int vtkFeatureEdges::RequestData(vtkInformation* vtkNotUsed(request),
   neighbors = vtkIdList::New();
   neighbors->Allocate(VTK_CELL_SIZE);
 
-  int abort = 0;
+  bool abort = false;
   vtkIdType progressInterval = newPolys->GetNumberOfCells() / 20 + 1;
 
   numBEdges = numNonManifoldEdges = numFedges = numManifoldEdges = 0;
@@ -337,7 +340,7 @@ int vtkFeatureEdges::RequestData(vtkInformation* vtkNotUsed(request),
     if (!(newCellId % progressInterval)) // manage progress / early abort
     {
       this->UpdateProgress(static_cast<double>(newCellId) / numCells);
-      abort = this->GetAbortExecute();
+      abort = this->CheckAbort();
     }
 
     if (numPolys == numCells) // Input only has Polys
@@ -405,6 +408,11 @@ int vtkFeatureEdges::RequestData(vtkInformation* vtkNotUsed(request),
           }
         }
       }
+      // Ignoring edges that are not visible
+      if (numNeiWithoutGhosts != numNei && this->RemoveGhostInterfaces)
+      {
+        continue;
+      }
 
       if (this->BoundaryEdges && numNeiWithoutGhosts < 1)
       {
@@ -624,3 +632,4 @@ void vtkFeatureEdges::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
