@@ -16,6 +16,7 @@
 
 #include "vtkArrayListTemplate.h" // For processing attribute data
 #include "vtkCellArray.h"
+#include "vtkCellData.h"
 #include "vtkDataArrayRange.h"
 #include "vtkFloatArray.h"
 #include "vtkImageData.h"
@@ -34,6 +35,7 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFlyingEdgesPlaneCutter);
 vtkCxxSetObjectMacro(vtkFlyingEdgesPlaneCutter, Plane, vtkPlane);
 
@@ -50,9 +52,8 @@ namespace
 // transform the output points.
 //
 template <class T>
-class vtkFlyingEdgesPlaneCutterAlgorithm
+struct vtkFlyingEdgesPlaneCutterAlgorithm
 {
-public:
   // Edge case table values.
   enum EdgeClass
   {
@@ -160,6 +161,9 @@ public:
   void ProcessYZEdges(vtkIdType row, vtkIdType slice);                           // PASS 2
   void GenerateOutput(T* inPtr, vtkIdType row, vtkIdType slice);                 // PASS 4
 
+  // Optional copying of cell data
+  void InterpolateCellData(ArrayList* cellArrays, vtkIdType row, vtkIdType slice);
+
   // Place holder for now in case fancy bit fiddling is needed later.
   void SetXEdge(unsigned char* ePtr, unsigned char edgeCase) { *ePtr = edgeCase; }
 
@@ -205,9 +209,20 @@ public:
         *connIter++ = eIds[*edges++];
         *connIter++ = eIds[*edges++];
       }
-
-      // Write the last offset:
-      *offsetIter = static_cast<ValueType>(3 * triId);
+    }
+  };
+  // Finalize the triangle cell array: after all the tris are inserted,
+  // the last offset has to be added to complete the offsets array.
+  struct FinalizeTrisImpl
+  {
+    template <typename CellStateT>
+    void operator()(CellStateT& state, vtkIdType numTris)
+    {
+      using ValueType = typename CellStateT::ValueType;
+      auto* offsets = state.GetOffsets();
+      auto offsetRange = vtk::DataArrayValueRange<1>(offsets);
+      auto offsetIter = offsetRange.begin() + numTris;
+      *offsetIter = static_cast<ValueType>(3 * numTris);
     }
   };
   void GenerateTris(unsigned char eCase, unsigned char numTris, vtkIdType* eIds, vtkIdType& triId)
@@ -292,11 +307,15 @@ public:
 
   // Threading integration via SMPTools
   template <class TT>
-  class Pass1
+  struct Pass1
   {
-  public:
     vtkFlyingEdgesPlaneCutterAlgorithm<TT>* Algo;
-    Pass1(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo) { this->Algo = algo; }
+    vtkFlyingEdgesPlaneCutter* Filter;
+    Pass1(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo, vtkFlyingEdgesPlaneCutter* filter)
+      : Filter(filter)
+    {
+      this->Algo = algo;
+    }
     void operator()(vtkIdType slice, vtkIdType end)
     {
       vtkIdType row;
@@ -304,8 +323,17 @@ public:
       double xL[3], xR[3];
       xL[0] = this->Algo->XL;
       xR[0] = this->Algo->XR;
+      bool isFirst = vtkSMPTools::GetSingleThread();
       for (; slice < end; ++slice)
       {
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
         xL[2] = slice;
         xR[2] = xL[2];
         for (row = 0, rowPtr = slicePtr; row < this->Algo->Dims[1]; ++row)
@@ -320,15 +348,28 @@ public:
     }
   };
   template <class TT>
-  class Pass2
+  struct Pass2
   {
-  public:
-    Pass2(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo) { this->Algo = algo; }
+    Pass2(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo, vtkFlyingEdgesPlaneCutter* filter)
+      : Filter(filter)
+    {
+      this->Algo = algo;
+    }
     vtkFlyingEdgesPlaneCutterAlgorithm<TT>* Algo;
+    vtkFlyingEdgesPlaneCutter* Filter;
     void operator()(vtkIdType slice, vtkIdType end)
     {
+      bool isFirst = vtkSMPTools::GetSingleThread();
       for (; slice < end; ++slice)
       {
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
         for (vtkIdType row = 0; row < (this->Algo->Dims[1] - 1); ++row)
         {
           this->Algo->ProcessYZEdges(row, slice);
@@ -337,24 +378,38 @@ public:
     }
   };
   template <class TT>
-  class Pass4
+  struct Pass4
   {
-  public:
-    Pass4(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo) { this->Algo = algo; }
+    Pass4(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo, vtkFlyingEdgesPlaneCutter* filter)
+      : Filter(filter)
+    {
+      this->Algo = algo;
+    }
     vtkFlyingEdgesPlaneCutterAlgorithm<TT>* Algo;
+    vtkFlyingEdgesPlaneCutter* Filter;
     void operator()(vtkIdType slice, vtkIdType end)
     {
       vtkIdType row;
       vtkIdType* eMD0 = this->Algo->EdgeMetaData + slice * 6 * this->Algo->Dims[1];
       vtkIdType* eMD1 = eMD0 + 6 * this->Algo->Dims[1];
       TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
+      bool isFirst = vtkSMPTools::GetSingleThread();
       for (; slice < end; ++slice)
       {
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
         // It's possible to skip entire slices if there is nothing to generate
         if (eMD1[3] > eMD0[3]) // there are triangle primitives!
         {
           for (row = 0, rowPtr = slicePtr; row < this->Algo->Dims[1] - 1; ++row)
           {
+
             this->Algo->GenerateOutput(rowPtr, row, slice);
             rowPtr += this->Algo->Inc1;
           } // for all rows in this slice
@@ -366,6 +421,53 @@ public:
     }
   };
 
+  template <class TT>
+  struct ProcessCD
+  {
+    ArrayList CellArrays;
+    ProcessCD(vtkFlyingEdgesPlaneCutterAlgorithm<TT>* algo, vtkIdType numCells, vtkCellData* inCD,
+      vtkCellData* outCD, vtkFlyingEdgesPlaneCutter* filter)
+      : Filter(filter)
+    {
+      this->Algo = algo;
+      outCD->CopyAllocate(inCD, numCells);
+      this->CellArrays.AddArrays(numCells, inCD, outCD, /*nullValue*/ 0.0, /*promote*/ false);
+    }
+    vtkFlyingEdgesPlaneCutterAlgorithm<TT>* Algo;
+    vtkFlyingEdgesPlaneCutter* Filter;
+    void operator()(vtkIdType slice, vtkIdType end)
+    {
+      vtkIdType row;
+      vtkIdType* eMD0 = this->Algo->EdgeMetaData + slice * 6 * this->Algo->Dims[1];
+      vtkIdType* eMD1 = eMD0 + 6 * this->Algo->Dims[1];
+      TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
+      bool isFirst = vtkSMPTools::GetSingleThread();
+      for (; slice < end; ++slice)
+      {
+        // It's possible to skip entire slices if there is no data to copy
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
+        if (eMD1[3] > eMD0[3]) // there are triangle primitives!
+        {
+          for (row = 0, rowPtr = slicePtr; row < this->Algo->Dims[1] - 1; ++row)
+          {
+            this->Algo->InterpolateCellData(&this->CellArrays, row, slice);
+            rowPtr += this->Algo->Inc1;
+          } // for all rows in this slice
+        }   // if there are triangles (i.e., output cells)
+        slicePtr += this->Algo->Inc2;
+        eMD0 = eMD1;
+        eMD1 = eMD0 + 6 * this->Algo->Dims[1];
+      } // for all slices in this batch
+    }
+  };
+
   // Interface between VTK and templated functions
   static void Contour(vtkFlyingEdgesPlaneCutter* self, vtkImageData* input, vtkDataArray* inScalars,
     int extent[6], vtkIdType* incs, T* scalars, vtkPolyData* output, vtkPoints* newPts,
@@ -408,7 +510,7 @@ vtkFlyingEdgesPlaneCutterAlgorithm<T>::vtkFlyingEdgesPlaneCutterAlgorithm()
   int i, j, k, l, ii, eCase, index, numTris;
   static const int vertMap[8] = { 0, 1, 3, 2, 4, 5, 7, 6 };
   static const int CASE_MASK[8] = { 1, 2, 4, 8, 16, 32, 64, 128 };
-  EDGE_LIST* edge;
+  int* edge;
   vtkMarchingCubesTriangleCases* triCase;
   unsigned char* edgeCase;
 
@@ -1087,11 +1189,14 @@ void vtkFlyingEdgesPlaneCutterAlgorithm<T>::GenerateOutput(
     }
 
     // advance along voxel row
-    ePtr[0]++;
-    ePtr[1]++;
-    ePtr[2]++;
-    ePtr[3]++;
-    eCase = this->GetEdgeCase(ePtr);
+    if (i != xR - 1)
+    {
+      ePtr[0]++;
+      ePtr[1]++;
+      ePtr[2]++;
+      ePtr[3]++;
+      eCase = this->GetEdgeCase(ePtr);
+    }
 
     ++ijk[0];
     sPtr += incs[0];
@@ -1099,6 +1204,76 @@ void vtkFlyingEdgesPlaneCutterAlgorithm<T>::GenerateOutput(
   } // for all non-trimmed cells along this x-edge
 }
 
+//------------------------------------------------------------------------------
+// Copy cell data from input to output
+template <class T>
+void vtkFlyingEdgesPlaneCutterAlgorithm<T>::InterpolateCellData(
+  ArrayList* arrays, vtkIdType row, vtkIdType slice)
+{
+  // Grab the edge meta data surrounding the voxel row.
+  vtkIdType* eMD[4];
+  eMD[0] = this->EdgeMetaData + (slice * this->Dims[1] + row) * 6; // this x-edge
+  eMD[1] = eMD[0] + 6;                                             // x-edge in +y direction
+  eMD[2] = eMD[0] + this->Dims[1] * 6;                             // x-edge in +z direction
+  eMD[3] = eMD[2] + 6;                                             // x-edge in +y+z direction
+
+  // Return if there is nothing to do (i.e., no triangles to generate)
+  if (eMD[0][3] == eMD[1][3])
+  {
+    return;
+  }
+
+  // Get the voxel row trim edges and prepare to generate. Find the voxel row
+  // trim edges, need to check all four x-edges to compute row trim edges.
+  vtkIdType xL = eMD[0][4], xR = eMD[0][5];
+  vtkIdType i;
+  for (i = 1; i < 4; ++i)
+  {
+    xL = (eMD[i][4] < xL ? eMD[i][4] : xL);
+    xR = (eMD[i][5] > xR ? eMD[i][5] : xR);
+  }
+
+  // Grab the four edge cases bounding this voxel x-row. Begin at left trim edge.
+  unsigned char* ePtr[4];
+  ePtr[0] = this->XCases + slice * this->SliceOffset + row * (this->Dims[0] - 1) + xL;
+  ePtr[1] = ePtr[0] + this->Dims[0] - 1;
+  ePtr[2] = ePtr[0] + this->SliceOffset;
+  ePtr[3] = ePtr[2] + this->Dims[0] - 1;
+
+  // Traverse all voxels in this row, those containing the contour are
+  // further identified for copying cell data. Begin by getting the
+  // starting voxel case and cell id.
+  unsigned char eCase = this->GetEdgeCase(ePtr);
+
+  // Determine the input and output cell ids.
+  vtkIdType inCellId =
+    xL + row * (this->Dims[0] - 1) + slice * (this->Dims[0] - 1) * (this->Dims[1] - 1);
+  vtkIdType outCellId = eMD[0][3];
+
+  for (i = xL; i < xR; ++i)
+  {
+    const unsigned char numTris = this->GetNumberOfPrimitives(eCase);
+    if (numTris > 0)
+    {
+      for (auto j = 0; j < numTris; ++j)
+      {
+        arrays->Copy(inCellId, outCellId++);
+      }
+    }
+
+    // advance along voxel row
+    inCellId++;
+    if (i != xR - 1)
+    {
+      ePtr[0]++;
+      ePtr[1]++;
+      ePtr[2]++;
+      ePtr[3]++;
+      eCase = this->GetEdgeCase(ePtr);
+    }
+  } // for voxel cells along row
+}
+
 //------------------------------------------------------------------------------
 // Contouring filter specialized for 3D volumes. This templated function
 // interfaces the vtkFlyingEdgesPlaneCutter class with the templated algorithm
@@ -1162,13 +1337,13 @@ void vtkFlyingEdgesPlaneCutterAlgorithm<T>::Contour(vtkFlyingEdgesPlaneCutter* s
   // intersections (i.e., accumulate information necessary for later output
   // memory allocation, e.g., the number of output points along the x-rows
   // are counted).
-  Pass1<T> pass1(&algo);
+  Pass1<T> pass1(&algo, self);
   vtkSMPTools::For(0, algo.Dims[2], pass1);
 
   // PASS 2: Traverse all voxel x-rows and process voxel y&z edges.  The
   // result is a count of the number of y- and z-intersections, as well as
   // the number of triangles generated along these voxel rows.
-  Pass2<T> pass2(&algo);
+  Pass2<T> pass2(&algo, self);
   vtkSMPTools::For(0, algo.Dims[2] - 1, pass2);
 
   // PASS 3: Now allocate and generate output. First we have to update the
@@ -1214,6 +1389,7 @@ void vtkFlyingEdgesPlaneCutterAlgorithm<T>::Contour(vtkFlyingEdgesPlaneCutter* s
     newPts->GetData()->WriteVoidPointer(0, 3 * totalPts);
     algo.NewPoints = static_cast<float*>(newPts->GetVoidPointer(0));
     newTris->ResizeExact(numOutTris, 3 * numOutTris);
+    newTris->Visit(FinalizeTrisImpl{}, numOutTris);
     algo.NewTris = newTris;
 
     if (newScalars)
@@ -1233,15 +1409,25 @@ void vtkFlyingEdgesPlaneCutterAlgorithm<T>::Contour(vtkFlyingEdgesPlaneCutter* s
       // Make sure we don't interpolate the input scalars twice
       output->GetPointData()->InterpolateAllocate(input->GetPointData(), totalPts);
       algo.Arrays.ExcludeArray(inScalars);
-      algo.Arrays.AddArrays(totalPts, input->GetPointData(), output->GetPointData());
+      algo.Arrays.AddArrays(totalPts, input->GetPointData(), output->GetPointData(),
+        /*nullValue*/ 0.0, /*promote*/ false);
     }
 
     // PASS 4: Fourth and final pass: Process voxel rows and generate output.
     // Note that we are simultaneously generating triangles and interpolating
     // points. These could be split into separate, parallel operations for
     // maximum performance.
-    Pass4<T> pass4(&algo);
+    Pass4<T> pass4(&algo, self);
     vtkSMPTools::For(0, algo.Dims[2] - 1, pass4);
+
+    // Process Cell Data: Some applications require the production of cell
+    // data. Since this slows the filter, we only perform this operation if
+    // cell data is present, and attribute interpolation is enabled.
+    if (self->GetInterpolateAttributes() && input->GetCellData()->GetNumberOfArrays() > 0)
+    {
+      ProcessCD<T> processCD(&algo, numOutTris, input->GetCellData(), output->GetCellData(), self);
+      vtkSMPTools::For(0, algo.Dims[2] - 1, processCD);
+    }
   }
 
   // Clean up and return
@@ -1341,23 +1527,13 @@ int vtkFlyingEdgesPlaneCutter::RequestData(
     return 0;
   }
 
-  // Check data type and execute appropriate function
+  // Check data type and execute appropriate function.
   //
   if (inScalars == nullptr)
   {
     vtkDebugMacro("No scalars for cutting.");
     return 0;
   }
-  int numComps = inScalars->GetNumberOfComponents();
-
-  if (this->ArrayComponent >= numComps)
-  {
-    vtkErrorMacro("Scalars have " << numComps
-                                  << " components. "
-                                     "ArrayComponent must be smaller than "
-                                  << numComps);
-    return 0;
-  }
 
   // Create necessary objects to hold output. We will defer the
   // actual allocation to a later point.
@@ -1374,7 +1550,7 @@ int vtkFlyingEdgesPlaneCutter::RequestData(
   vtkSmartPointer<vtkFloatArray> newNormals;
   if (this->ComputeNormals)
   {
-    newNormals = vtkFloatArray::New();
+    newNormals = vtkSmartPointer<vtkFloatArray>::New();
     newNormals->SetNumberOfComponents(3);
     newNormals->SetName("Normals");
   }
@@ -1428,5 +1604,5 @@ void vtkFlyingEdgesPlaneCutter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Plane: " << this->Plane << "\n";
   os << indent << "Compute Normals: " << (this->ComputeNormals ? "On\n" : "Off\n");
   os << indent << "Interpolate Attributes: " << (this->InterpolateAttributes ? "On\n" : "Off\n");
-  os << indent << "ArrayComponent: " << this->ArrayComponent << endl;
 }
+VTK_ABI_NAMESPACE_END
