@@ -33,6 +33,10 @@
  * A High-Performance Scalable Isocontouring Algorithm" by Schroeder,
  * Maynard, Geveci. Proc. of LDAV 2015. Chicago, IL.
  *
+ * The filter interpolates the input scalar field across the vtkPlane provided.
+ * If additional point and cell attribute data is to be interpolated, enable
+ * InterpolateAttributes.
+ *
  * @warning
  * This filter is specialized to 3D volumes. This implementation can produce
  * degenerate triangles (i.e., zero-area triangles).
@@ -52,27 +56,28 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 class vtkPlane;
 
 class VTKFILTERSCORE_EXPORT vtkFlyingEdgesPlaneCutter : public vtkPolyDataAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard construction and print methods.
    */
   static vtkFlyingEdgesPlaneCutter* New();
   vtkTypeMacro(vtkFlyingEdgesPlaneCutter, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * The modified time depends on the delegated cut plane.
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Specify the plane (an implicit function) to perform the cutting. The
    * definition of the plane (its origin and normal) is controlled via this
@@ -80,9 +85,9 @@ public:
    */
   virtual void SetPlane(vtkPlane*);
   vtkGetObjectMacro(Plane, vtkPlane);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the computation of normals. The normal generated is simply the
    * cut plane normal. By default this is disabled.
@@ -90,26 +95,26 @@ public:
   vtkSetMacro(ComputeNormals, vtkTypeBool);
   vtkGetMacro(ComputeNormals, vtkTypeBool);
   vtkBooleanMacro(ComputeNormals, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Indicate whether to interpolate other attribute data besides the input
-   * scalars (which are required). That is, as the isosurface is generated,
-   * interpolate all other point attribute data across intersected edges.
+   * Indicate whether to interpolate additional point data (beyond the point
+   * scalars which are always interpolated) and cell attribute data. By
+   * default this is disabled (for reasons of performance).
    */
   vtkSetMacro(InterpolateAttributes, vtkTypeBool);
   vtkGetMacro(InterpolateAttributes, vtkTypeBool);
   vtkBooleanMacro(InterpolateAttributes, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Set/get which component of the scalar array to contour on; defaults to 0.
+   * Set/get which component of the point data scalar array to contour on; defaults to 0.
    */
   vtkSetMacro(ArrayComponent, int);
   vtkGetMacro(ArrayComponent, int);
-  //@}
+  ///@}
 
 protected:
   vtkFlyingEdgesPlaneCutter();
@@ -129,4 +134,5 @@ private:
   void operator=(const vtkFlyingEdgesPlaneCutter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
