@@ -33,6 +33,7 @@
 #include "vtkUniformGrid.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGlyph3D);
 vtkCxxSetObjectMacro(vtkGlyph3D, SourceTransform, vtkTransform);
 
@@ -413,7 +414,7 @@ bool vtkGlyph3D::Execute(vtkDataSet* input, vtkInformationVector* sourceVector,
     if (!(inPtId % 10000))
     {
       this->UpdateProgress(static_cast<double>(inPtId) / numPts);
-      if (this->GetAbortExecute())
+      if (this->CheckAbort())
       {
         break;
       }
@@ -519,9 +520,10 @@ bool vtkGlyph3D::Execute(vtkDataSet* input, vtkInformationVector* sourceVector,
     }
 
     // Check ghost points.
-    // If we are processing a piece, we do not want to duplicate
-    // glyphs on the borders.
-    if (inGhostLevels && inGhostLevels[inPtId] & vtkDataSetAttributes::DUPLICATEPOINT)
+    // If we are processing a piece, we do not want to duplicate glyphs on the borders.
+    if (inGhostLevels &&
+      inGhostLevels[inPtId] &
+        (vtkDataSetAttributes::DUPLICATEPOINT | vtkDataSetAttributes::HIDDENPOINT))
     {
       continue;
     }
@@ -969,3 +971,4 @@ int vtkGlyph3D::FillInputPortInformation(int port, vtkInformation* info)
   }
   return 0;
 }
+VTK_ABI_NAMESPACE_END
