@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkMaskPoints.h"
 
 #include "vtkBoundingBox.h"
@@ -36,6 +33,7 @@
 #include <cstdlib>
 #include <random>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
@@ -61,7 +59,7 @@ inline void SwapPoint(
 
   // temp -> b
   points->SetPoint(b, ta);
-  data->CopyData(temp, 0, b);
+  data->CopyData(temp, vtkIdType(0), b);
 }
 
 //------------------------------------------------------------------------------
@@ -69,7 +67,7 @@ inline void SwapPoint(
 // this is average case linear, worse case quadratic implementation
 // (i.e., just like quicksort) -- there is the median of 5 or
 // median of medians algorithm, but I'm too lazy to implement it
-static void QuickSelect(vtkPoints* points, vtkPointData* data, vtkPointData* temp, vtkIdType start,
+void QuickSelect(vtkPoints* points, vtkPointData* data, vtkPointData* temp, vtkIdType start,
   vtkIdType end, vtkIdType nth, int axis)
 {
   // base case
@@ -121,8 +119,8 @@ static void QuickSelect(vtkPoints* points, vtkPointData* data, vtkPointData* tem
 //------------------------------------------------------------------------------
 // divide the data into sampling strata and randomly sample it
 // (one sample per stratum)
-static void SortAndSample(vtkPoints* points, vtkPointData* data, vtkPointData* temp,
-  vtkIdType start, vtkIdType end, vtkIdType size, int depth)
+void SortAndSample(vtkPoints* points, vtkPointData* data, vtkPointData* temp, vtkIdType start,
+  vtkIdType end, vtkIdType size, int depth)
 {
   // if size >= end - start return them all
   if (size >= (end - start))
@@ -206,7 +204,7 @@ static void SortAndSample(vtkPoints* points, vtkPointData* data, vtkPointData* t
 //------------------------------------------------------------------------------
 // For UNIFORM_SPATIAL_BOUNDS only,
 // Compute the nearestPointRadius for the point locator
-static double GetNearestPointRadius(double bounds[3], vtkIdType maximumNumberOfPoints)
+double GetNearestPointRadius(double bounds[3], vtkIdType maximumNumberOfPoints)
 {
   vtkBoundingBox boundingBox;
   boundingBox.AddBounds(bounds);
@@ -373,7 +371,7 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
   vtkPointData* outputPD = output->GetPointData();
   vtkIdType numPts = input->GetNumberOfPoints();
 
-  int abort = 0;
+  bool abort = false;
 
   // figure out how many sample points per process
   vtkIdType localMaxPts;
@@ -465,7 +463,7 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
           if (!(id % progressInterval)) // abort/progress
           {
             this->UpdateProgress(0.5 * id / numPts);
-            abort = this->GetAbortExecute();
+            abort = this->CheckAbort();
           }
         }
         break;
@@ -484,10 +482,14 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
         {
           double q2 = (q1 - 1.0) / (size - 1.0);
           double q3 = log(q2);
-          vtkIdType s;
+          vtkIdType s = 0;
 
           while (true)
           {
+            if (this->CheckAbort())
+            {
+              break;
+            }
             while (true)
             {
               s = (vtkIdType)(vprime / q3);
@@ -608,6 +610,7 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
         tempData->Delete();
         dataCopy->Delete();
         pointCopy->Delete();
+        this->CheckAbort();
         break;
       }
       case UNIFORM_SPATIAL_BOUNDS:
@@ -639,6 +642,10 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
 
         for (vtkIdType i = 0; i < numAddedPts; i++)
         {
+          if (this->CheckAbort())
+          {
+            break;
+          }
           randomGenerator->Next();
           double randX = randomGenerator->GetRangeValue(bounds[0], bounds[1]);
           randomGenerator->Next();
@@ -670,6 +677,10 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
         double localArea = 0.0;
         for (vtkIdType cellId = 0; cellId < nbCells; ++cellId)
         {
+          if (this->CheckAbort())
+          {
+            break;
+          }
           vtkCell* currentCell = input->GetCell(cellId);
           if (currentCell->GetCellDimension() != dim)
           {
@@ -717,6 +728,10 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
           std::uniform_real_distribution<> dis(0.0, localArea);
           for (vtkIdType ptId = 0; ptId < numAddedPts; ptId++)
           {
+            if (this->CheckAbort())
+            {
+              break;
+            }
             // The sampling vector being sorted, just find the index of the sampled cell
             double sample = dis(gen);
             auto it = std::upper_bound(cellContribs.cbegin(), cellContribs.cend(), sample);
@@ -760,7 +775,7 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
       if (!(id % progressInterval)) // abort/progress
       {
         this->UpdateProgress(0.5 * id / numPts);
-        abort = this->GetAbortExecute();
+        abort = this->CheckAbort();
       }
     }
   }
@@ -783,7 +798,7 @@ int vtkMaskPoints::RequestData(vtkInformation* vtkNotUsed(request),
       if (!(ptId % progressInterval)) // abort/progress
       {
         this->UpdateProgress(0.5 + 0.5 * ptId / (id + 1));
-        abort = this->GetAbortExecute();
+        abort = this->CheckAbort();
       }
       if (this->SingleVertexPerCell)
       {
@@ -834,3 +849,4 @@ void vtkMaskPoints::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Output Points Precision: " << this->GetOutputPointsPrecision() << "\n";
 }
+VTK_ABI_NAMESPACE_END
