@@ -30,6 +30,7 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSCORE_EXPORT vtkMaskPolyData : public vtkPolyDataAlgorithm
 {
 public:
@@ -37,21 +38,21 @@ public:
   vtkTypeMacro(vtkMaskPolyData, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Turn on every nth entity (cell).
    */
   vtkSetClampMacro(OnRatio, int, 1, VTK_INT_MAX);
   vtkGetMacro(OnRatio, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Start with this entity (cell).
    */
   vtkSetClampMacro(Offset, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(Offset, vtkIdType);
-  //@}
+  ///@}
 
 protected:
   vtkMaskPolyData();
@@ -66,4 +67,5 @@ private:
   void operator=(const vtkMaskPolyData&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
