@@ -30,8 +30,16 @@
 #include <set>
 #include <utility>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMoleculeAppend);
 
+//------------------------------------------------------------------------------
+void vtkMoleculeAppend::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "MergeCoincidentAtoms: " << this->MergeCoincidentAtoms << endl;
+}
+
 //------------------------------------------------------------------------------
 vtkMoleculeAppend::vtkMoleculeAppend()
   : MergeCoincidentAtoms(true)
@@ -78,6 +86,10 @@ int vtkMoleculeAppend::RequestData(
   // Process each input
   for (int idx = 0; idx < this->GetNumberOfInputConnections(0); ++idx)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkMolecule* input = vtkMolecule::GetData(inputVector[0], idx);
 
     // --------------------
@@ -275,3 +287,4 @@ bool vtkMoleculeAppend::CheckArrays(vtkAbstractArray* array1, vtkAbstractArray*
 
   return true;
 }
+VTK_ABI_NAMESPACE_END
