@@ -33,13 +33,15 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkMoleculeAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSCORE_EXPORT vtkMoleculeAppend : public vtkMoleculeAlgorithm
 {
 public:
   static vtkMoleculeAppend* New();
   vtkTypeMacro(vtkMoleculeAppend, vtkMoleculeAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get one input to this filter. This method is only for support of
    * old-style pipeline connections.  When writing new code you should
@@ -47,9 +49,9 @@ public:
    */
   vtkDataObject* GetInput(int idx);
   vtkDataObject* GetInput() { return this->GetInput(0); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify if coincident atoms (atom with exactly the same position)
    * should be merged into one.
@@ -79,4 +81,5 @@ private:
   void operator=(const vtkMoleculeAppend&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
