@@ -34,10 +34,22 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 
 #include <algorithm> // for fill_n
-#include <memory>    //for unique_ptr
+#include <numeric>   //for iota
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolyDataEdgeConnectivityFilter);
 
+namespace
+{ // anonymous
+
+enum RegionType
+{
+  SmallRegion = 0,
+  LargeRegion = 1
+};
+
+}; // anonymous namespace
+
 //------------------------------------------------------------------------------
 // Construct with default extraction mode to extract largest regions.
 vtkPolyDataEdgeConnectivityFilter::vtkPolyDataEdgeConnectivityFilter()
@@ -59,10 +71,11 @@ vtkPolyDataEdgeConnectivityFilter::vtkPolyDataEdgeConnectivityFilter()
   this->CellNeighbors = vtkSmartPointer<vtkIdList>::New();
   this->CellEdgeNeighbors = vtkSmartPointer<vtkIdList>::New();
 
-  this->GrowLargeRegions = 0;
+  this->RegionGrowing = RegionGrowingOff;
   this->LargeRegionThreshold = 0.10;
 
   this->ColorRegions = 1;
+  this->CellRegionAreas = 0;
 
   this->OutputPointsPrecision = DEFAULT_PRECISION;
 
@@ -71,7 +84,7 @@ vtkPolyDataEdgeConnectivityFilter::vtkPolyDataEdgeConnectivityFilter()
 }
 
 //------------------------------------------------------------------------------
-vtkPolyDataEdgeConnectivityFilter::~vtkPolyDataEdgeConnectivityFilter() {}
+vtkPolyDataEdgeConnectivityFilter::~vtkPolyDataEdgeConnectivityFilter() = default;
 
 //------------------------------------------------------------------------------
 void vtkPolyDataEdgeConnectivityFilter::SetSourceData(vtkPolyData* input)
@@ -96,6 +109,79 @@ vtkPolyData* vtkPolyDataEdgeConnectivityFilter::GetSource()
   return vtkPolyData::SafeDownCast(this->GetExecutive()->GetInputData(1, 0));
 }
 
+//------------------------------------------------------------------------------
+// Sort regions by ascending area. Also update the largest region id.
+void vtkPolyDataEdgeConnectivityFilter::SortRegionsByArea()
+{
+  // Setup the initial map
+  std::vector<vtkIdType> areaSort(this->NumberOfRegions);
+  std::iota(areaSort.begin(), areaSort.end(), 0);
+
+  // Now sort by area to produce a sorted list of regions.
+  std::vector<double>& regAreas = this->RegionAreas;
+  sort(areaSort.begin(), areaSort.end(),
+    [&](const vtkIdType& a, const vtkIdType& b) -> bool { return (regAreas[a] > regAreas[b]); });
+
+  // Create a region map that maps old region ids into new region ids.
+  std::vector<vtkIdType> regMap(this->NumberOfRegions);
+  for (auto i = 0; i < this->NumberOfRegions; ++i)
+  {
+    vtkIdType regId = areaSort[i];
+    regMap[regId] = i;
+  }
+
+  // Need to update the related region arrays. Copy the new information into
+  // temporary arrays, and then swap them with the "global" arrays.
+  // Update region ids associated with cells.
+  std::vector<vtkIdType> regionIds(this->RegionIds.size());
+  for (std::size_t i = 0; i < regionIds.size(); ++i)
+  {
+    regionIds[i] = regMap[this->RegionIds[i]];
+  }
+
+  // Update region classification and areas
+  std::vector<char> regionClassification(this->NumberOfRegions);
+  for (auto i = 0; i < this->NumberOfRegions; ++i)
+  {
+    regionClassification[i] = this->RegionClassification[areaSort[i]];
+  }
+
+  // Update the area of each region
+  std::vector<double> regionAreas(this->NumberOfRegions);
+  for (auto i = 0; i < this->NumberOfRegions; ++i)
+  {
+    regionAreas[i] = this->RegionAreas[areaSort[i]];
+  }
+
+  // Update the size of each region.
+  vtkNew<vtkIdTypeArray> regionSizes;
+  regionSizes->SetNumberOfTuples(this->RegionSizes->GetNumberOfTuples());
+  for (auto i = 0; i < this->NumberOfRegions; ++i)
+  {
+    regionSizes->SetTuple1(i, this->RegionSizes->GetValue(areaSort[i]));
+  }
+
+  // Okay replace global arrays with the local, renumbered arrays.
+  this->RegionIds.swap(regionIds);
+  this->RegionClassification.swap(regionClassification);
+  this->RegionAreas.swap(regionAreas);
+  this->RegionSizes = regionSizes;
+}
+
+//------------------------------------------------------------------------------
+// Determine the number of non-zero-area regions. This is assumed to take place
+// after the region sort by area occurs. Whether an region is non-zero is determined
+// by a threshold against the total area.
+vtkIdType vtkPolyDataEdgeConnectivityFilter::FindNumberOfExtractedRegions()
+{
+  vtkIdType regionNum = 0, numSizes = this->RegionSizes->GetNumberOfTuples();
+  while (regionNum < numSizes && this->RegionSizes->GetValue(regionNum) > 0)
+  {
+    regionNum++;
+  }
+  return regionNum;
+}
+
 //------------------------------------------------------------------------------
 int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -192,7 +278,7 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
 
   // Initialize.  Keep track of points and cells visited, and the region ids
   // of the cells.
-  this->RegionIds.reserve(numCells);
+  this->RegionIds.resize(numCells);
   std::fill_n(this->RegionIds.begin(), numCells, (-1));
 
   this->PointMap.reserve(numPts);
@@ -225,6 +311,7 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
 
   this->NumberOfPoints = 0;
   this->NumberOfRegions = 0;
+  this->NumberOfExtractedRegions = 0;
   maxCellsInRegion = 0;
 
   this->CellIds = vtkSmartPointer<vtkIdList>::New();
@@ -241,6 +328,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
       if (cellId && !(cellId % 5000))
       {
         this->UpdateProgress(0.1 + 0.8 * cellId / numCells);
+        if (this->CheckAbort())
+        {
+          break;
+        }
       }
 
       if (this->RegionIds[cellId] < 0)
@@ -269,6 +360,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
     {
       for (i = 0; i < (vtkIdType)this->Seeds.size(); i++)
       {
+        if (this->CheckAbort())
+        {
+          break;
+        }
         pt = this->Seeds[i];
         if (pt >= 0)
         {
@@ -284,6 +379,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
     {
       for (i = 0; i < (vtkIdType)this->Seeds.size(); i++)
       {
+        if (this->CheckAbort())
+        {
+          break;
+        }
         cellId = this->Seeds[i];
         if (cellId >= 0)
         {
@@ -321,14 +420,15 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
 
   vtkDebugMacro(<< "Identified " << this->NumberOfRegions << " region(s)");
 
-  // Optionally, assimilate small regions into bigger regions.
-  if (this->ExtractionMode == VTK_EXTRACT_LARGE_REGIONS || this->GrowLargeRegions)
+  // Sort regions based on their area.
+  this->TotalArea = this->ComputeRegionAreas();
+  if (this->RegionGrowing == LargeRegions)
   {
-    this->ComputeRegionAreas();
-    if (this->GrowLargeRegions)
-    {
-      this->GrowRegions();
-    }
+    this->GrowLargeRegions();
+  }
+  else if (this->RegionGrowing == SmallRegions)
+  {
+    this->GrowSmallRegions();
   }
 
   // Now that points and cells have been marked, traverse these lists pulling
@@ -347,6 +447,25 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
     }
   }
 
+  // if producing region areas, create the appropriate cell data
+  vtkSmartPointer<vtkFloatArray> regionAreas;
+  if (this->CellRegionAreas)
+  {
+    regionAreas = vtkSmartPointer<vtkFloatArray>::New();
+    regionAreas->SetName("CellRegionArea");
+    regionAreas->Allocate(numCells);
+    outputCD->AddArray(regionAreas);
+  }
+
+  // Remap the region ids so that region 0 is the largest region
+  // (by area), and so on. This requires also updating additional information
+  // such as RegionAreas, RegionSizes, and RegionClassification.
+  this->SortRegionsByArea();
+  largestRegionId = 0; // due to sort
+
+  // After the sort, update the number of non-zero-area regions.
+  this->NumberOfExtractedRegions = this->FindNumberOfExtractedRegions();
+
   // if coloring regions; send down new scalar data
   vtkSmartPointer<vtkIdTypeArray> cellRegionIds;
   if (this->ColorRegions)
@@ -358,7 +477,7 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
     outputCD->SetActiveAttribute(idx, vtkDataSetAttributes::SCALARS);
   }
 
-  // Set up
+  // Prepare to produce output
   output->SetPoints(newPts);
   if ((n = input->GetPolys()->GetNumberOfCells()) > 0)
   {
@@ -389,6 +508,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
         {
           cellRegionIds->InsertValue(newCellId, this->RegionIds[cellId]);
         }
+        if (regionAreas != nullptr)
+        {
+          regionAreas->InsertValue(newCellId, this->RegionAreas[this->RegionIds[cellId]]);
+        }
       }
     }
   }
@@ -422,6 +545,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
           {
             cellRegionIds->InsertValue(newCellId, this->RegionIds[cellId]);
           }
+          if (regionAreas != nullptr)
+          {
+            regionAreas->InsertValue(newCellId, this->RegionAreas[this->RegionIds[cellId]]);
+          }
         }
       }
     }
@@ -445,6 +572,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
         {
           cellRegionIds->InsertValue(newCellId, this->RegionIds[cellId]);
         }
+        if (regionAreas != nullptr)
+        {
+          regionAreas->InsertValue(newCellId, this->RegionAreas[this->RegionIds[cellId]]);
+        }
       }
     }
   }
@@ -452,7 +583,8 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
   {
     for (cellId = 0; cellId < numCells; cellId++)
     {
-      if (this->RegionIds[cellId] >= 0 && this->RegionClassification[this->RegionIds[cellId]] == 1)
+      if (this->RegionIds[cellId] >= 0 &&
+        this->RegionClassification[this->RegionIds[cellId]] == LargeRegion)
       {
         this->Mesh->GetCellPoints(cellId, npts, pts);
         this->PointIds->Reset();
@@ -467,6 +599,10 @@ int vtkPolyDataEdgeConnectivityFilter::RequestData(vtkInformation* vtkNotUsed(re
         {
           cellRegionIds->InsertValue(newCellId, this->RegionIds[cellId]);
         }
+        if (regionAreas != nullptr)
+        {
+          regionAreas->InsertValue(newCellId, this->RegionAreas[this->RegionIds[cellId]]);
+        }
       }
     }
   }
@@ -608,13 +744,6 @@ void vtkPolyDataEdgeConnectivityFilter::TraverseAndMark()
   } // while wave is not empty
 }
 
-//------------------------------------------------------------------------------
-// Obtain the number of connected regions.
-int vtkPolyDataEdgeConnectivityFilter::GetNumberOfExtractedRegions()
-{
-  return this->RegionSizes->GetMaxId() + 1;
-}
-
 //------------------------------------------------------------------------------
 // Initialize list of point ids/cell ids used to seed regions.
 void vtkPolyDataEdgeConnectivityFilter::InitializeSeedList()
@@ -692,18 +821,14 @@ int vtkPolyDataEdgeConnectivityFilter::FillInputPortInformation(int port, vtkInf
 //------------------------------------------------------------------------------
 double vtkPolyDataEdgeConnectivityFilter::ComputeRegionAreas()
 {
-  // Computer the area of each cell, and the total mesh area.
+  // Compute the area of each cell, and the total mesh area.
   // Also accumulate the area of each region.
   double totalArea = 0.0;
   const vtkIdType numCells = this->Mesh->GetPolys()->GetNumberOfCells();
 
-  this->CellAreas.reserve(numCells);
-
-  this->RegionAreas.reserve(this->NumberOfRegions);
-  std::fill_n(this->RegionAreas.begin(), this->NumberOfRegions, 0.0);
-
-  this->RegionClassification.reserve(this->NumberOfRegions);
-  std::fill_n(this->RegionClassification.begin(), this->NumberOfRegions, 0);
+  this->CellAreas.resize(numCells, 0);
+  this->RegionAreas.resize(this->NumberOfRegions, 0.0);
+  this->RegionClassification.resize(this->NumberOfRegions, SmallRegion);
 
   // Traverse polygons and compute area
   double area, normal[3];
@@ -730,17 +855,40 @@ double vtkPolyDataEdgeConnectivityFilter::ComputeRegionAreas()
   {
     if (this->RegionAreas[regNum] >= areaThreshold)
     {
-      this->RegionClassification[regNum] = 1;
+      this->RegionClassification[regNum] = LargeRegion;
     }
   }
 
   return totalArea;
 }
 
+//------------------------------------------------------------------------------
+// This method supports region growing. Basically it takes a neighboring cell
+// that is initially assigned to one region, and assigns it to a new
+// region. This also updates the region counts (i.e., number of cells) and
+// the region areas.
+void vtkPolyDataEdgeConnectivityFilter::ExchangeRegions(
+  vtkIdType regionId, vtkIdType neiId, vtkIdType neiRegionId)
+{
+  // Exchange region counts
+  vtkIdType regionSize = this->RegionSizes->GetValue(regionId);
+  vtkIdType neiRegionSize = this->RegionSizes->GetValue(neiRegionId);
+  this->RegionSizes->SetValue(regionId, (regionSize + 1));
+  this->RegionSizes->SetValue(neiRegionId, (neiRegionSize - 1));
+
+  // Exchange area contributions
+  double neiArea = this->CellAreas[neiId];
+  this->RegionAreas[regionId] += neiArea;
+  this->RegionAreas[neiRegionId] -= neiArea;
+
+  // Finally exchange region assignments
+  this->RegionIds[neiId] = regionId;
+}
+
 //------------------------------------------------------------------------------
 // Loop over cells, those in small regions are assigned to larger regions if they
 // are "close" enough. This is iterative.
-void vtkPolyDataEdgeConnectivityFilter::GrowRegions()
+void vtkPolyDataEdgeConnectivityFilter::GrowLargeRegions()
 {
   // Reuse the Wave vector to load up cells in small regions. We want to eliminate
   // looping over all cells and just process the cells in small regions.
@@ -749,7 +897,7 @@ void vtkPolyDataEdgeConnectivityFilter::GrowRegions()
   for (auto cellId = 0; cellId < numCells; ++cellId)
   {
     vtkIdType regId = this->RegionIds[cellId];
-    if (regId >= 0 && this->RegionClassification[regId] == 0)
+    if (regId >= 0 && this->RegionClassification[regId] == SmallRegion)
     {
       this->Wave.push_back(cellId);
     }
@@ -779,14 +927,14 @@ void vtkPolyDataEdgeConnectivityFilter::GrowRegions()
       {
         vtkIdType cellId = this->Wave[candidate];
         vtkIdType regId = this->RegionIds[cellId];
-        if (regId >= 0 && this->RegionClassification[regId] == 0)
+        if (regId >= 0 && this->RegionClassification[regId] == SmallRegion)
         {
           iter->GetCellAtId(cellId, npts, pts);
           vtkIdType largeRegId = this->AssimilateCell(cellId, npts, pts);
           if (largeRegId >= 0)
           {
             somethingChanged = true;
-            this->RegionIds[cellId] = largeRegId;
+            this->ExchangeRegions(largeRegId, cellId, regId);
           }
         } // if in small region, or no region
       }   // for all candidates
@@ -794,6 +942,73 @@ void vtkPolyDataEdgeConnectivityFilter::GrowRegions()
   }       // for each region growing pass
 }
 
+//------------------------------------------------------------------------------
+// Loop over cells, those in small regions are combined with other small
+// regions to produce larger regions. This is iterative using a wave
+// propagation approach.
+void vtkPolyDataEdgeConnectivityFilter::GrowSmallRegions()
+{
+  // Iteratively combine small cells with other small cells to create larger
+  // regions. Note that these small regions are grown by combining with all
+  // unvisited, unassigned edge neighbors that are also part of small regions.
+  //
+  this->Wave.clear();
+  const vtkIdType numCells = this->Mesh->GetPolys()->GetNumberOfCells();
+  std::vector<char> smallVisited(numCells, 0);
+
+  for (auto cellId = 0; cellId < numCells; ++cellId)
+  {
+    vtkIdType regId = this->RegionIds[cellId];
+    if (regId >= 0 && this->RegionClassification[regId] == SmallRegion && smallVisited[cellId] == 0)
+    {
+      this->Wave.push_back(cellId);
+      smallVisited[cellId] = 1;
+    }
+
+    // Now start growing the small region. Note: small regions are potentially
+    // assigned to other small regions. The end result is the number of cells
+    // in a previously extracted region may actually reduce to zero.
+    vtkIdType numIds;
+    while ((numIds = static_cast<vtkIdType>(this->Wave.size())) > 0)
+    {
+      for (auto i = 0; i < numIds; i++)
+      {
+        vtkIdType currentCellId = this->Wave[i];
+        vtkIdType currentRegionId = this->RegionIds[currentCellId];
+
+        // Check all edge neighbors
+        const vtkIdType* pts;
+        vtkIdType npts;
+        this->Mesh->GetCellPoints(currentCellId, npts, pts);
+        for (auto j = 0; j < npts; ++j)
+        {
+          vtkIdType v0 = pts[j];
+          vtkIdType v1 = pts[(j + 1) % npts];
+          this->Mesh->GetCellEdgeNeighbors(currentCellId, v0, v1, this->CellNeighbors);
+          vtkIdType numNeis = this->CellNeighbors->GetNumberOfIds();
+
+          for (auto k = 0; k < numNeis; ++k)
+          {
+            vtkIdType neiId = this->CellNeighbors->GetId(k);
+            vtkIdType neiRegId = this->RegionIds[neiId];
+            if (neiRegId >= 0 && this->RegionClassification[neiRegId] == SmallRegion &&
+              smallVisited[neiId] == 0)
+            {
+              this->ExchangeRegions(currentRegionId, neiId, neiRegId);
+              this->Wave2.push_back(neiId);
+              smallVisited[neiId] = 1;
+            } // if cell not yet visited
+          }   // for all edge neighbors
+        }     // for all edges of this cell
+      }       // for all cells in this propagation wave
+
+      this->Wave = this->Wave2;
+      this->Wave2.clear();
+      this->Wave2.reserve(numCells);
+    } // while wave is not empty
+  }   // for all cells
+}
+
 //------------------------------------------------------------------------------
 // Return a non-negative region id if the cell specified can be assimilated
 // into a large region. Currently a two-pass algorithm is used. This certainly
@@ -831,7 +1046,7 @@ int vtkPolyDataEdgeConnectivityFilter::AssimilateCell(
       neiId = this->CellEdgeNeighbors->GetId(j);
       regId = this->RegionIds[neiId];
 
-      if (regId >= 0 && this->RegionClassification[regId] == 1)
+      if (regId >= 0 && this->RegionClassification[regId] == LargeRegion)
       {
         if (e2 > longestAdjacentEdge2)
         {
@@ -887,10 +1102,12 @@ void vtkPolyDataEdgeConnectivityFilter::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << indent << id << ": " << this->RegionSizes->GetValue(id) << std::endl;
   }
 
-  os << indent << "Grow Large Regions: " << (this->GrowLargeRegions ? "On\n" : "Off\n");
+  os << indent << "Region Growing: " << this->RegionGrowing << "\n";
   os << indent << "Large Region Threshold: " << this->LargeRegionThreshold << "\n";
 
   os << indent << "Color Regions: " << (this->ColorRegions ? "On\n" : "Off\n");
+  os << indent << "Cell Region Areas: " << (this->CellRegionAreas ? "On\n" : "Off\n");
 
   os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
