@@ -34,12 +34,18 @@
  * cap(s) will be generated.
  *
  * @warning
+ * The method CanFullyProcessDataObject() is available to see whether the
+ * input data can be successfully processed by this filter. Use this method
+ * sparingly because it can be slow.
+ *
+ * @warning
  * This class has been threaded with vtkSMPTools. Using TBB or other
  * non-sequential type (set in the CMake variable
  * VTK_SMP_IMPLEMENTATION_TYPE) may improve performance significantly.
  *
  * @sa
- * vtkClipPolyData vtkClipClosedSurface vtkPlaneCutter vtkTriangleFilter vtkCutter
+ * vtkClipPolyData vtkClipClosedSurface vtkPolyDataPlaneCutter vtkPlaneCutter
+ * vtkTriangleFilter vtkCutter
  */
 
 #ifndef vtkPolyDataPlaneClipper_h
@@ -48,26 +54,28 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPlane.h"             // For clipping plane
 #include "vtkPolyDataAlgorithm.h"
-#include "vtkSmartPointer.h" // For SmartPointer
+#include "vtkPolyDataPlaneCutter.h" // For CanFullyProcessDataObject() method
+#include "vtkSmartPointer.h"        // For SmartPointer
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSCORE_EXPORT vtkPolyDataPlaneClipper : public vtkPolyDataAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard construction, type, and print methods.
    */
   static vtkPolyDataPlaneClipper* New();
   vtkTypeMacro(vtkPolyDataPlaneClipper, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * The modified time depends on the delegated clipping plane.
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Specify the plane (an implicit function) to perform the clipping. The
    * definition of the plane used to perform the clipping (i.e., its origin
@@ -75,9 +83,9 @@ public:
    */
   void SetPlane(vtkPlane*);
   vtkGetObjectMacro(Plane, vtkPlane);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether to generate clipping loops, i.e., the intersection of
    * the plane with the input polydata. The generation of clipping loops will
@@ -89,9 +97,9 @@ public:
   vtkSetMacro(ClippingLoops, bool);
   vtkGetMacro(ClippingLoops, bool);
   vtkBooleanMacro(ClippingLoops, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether to cap the clipped output vtkPolyData. If enabled, a
    * second vtkPolyData output will be produced that contains the capping
@@ -104,7 +112,7 @@ public:
   vtkSetMacro(Capping, bool);
   vtkGetMacro(Capping, bool);
   vtkBooleanMacro(Capping, bool);
-  //@}
+  ///@}
 
   /**
    * Get the output dataset representing the clipping loops and capping
@@ -115,7 +123,18 @@ public:
    */
   vtkPolyData* GetCap();
 
-  //@{
+  ///@{
+  /**
+   * Specify whether to pass point data through to the second (Cap) output.
+   * By default this is disabled. This feature is useful in certain situations
+   * when trying to combine the cap with clipped polydata.
+   */
+  vtkSetMacro(PassCapPointData, bool);
+  vtkGetMacro(PassCapPointData, bool);
+  vtkBooleanMacro(PassCapPointData, bool);
+  ///@}
+
+  ///@{
   /**
    * Set/get the desired precision for the output points type. See the
    * documentation for the vtkAlgorithm::DesiredOutputPrecision enum for an
@@ -124,9 +143,9 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the number of input triangles in a batch, where a batch defines
    * a subset of the input triangles operated on during threaded
@@ -135,7 +154,21 @@ public:
    */
   vtkSetClampMacro(BatchSize, unsigned int, 1, VTK_INT_MAX);
   vtkGetMacro(BatchSize, unsigned int);
-  //@}
+  ///@}
+
+  /**
+   * This helper method can be used to determine the if the input vtkPolyData
+   * contains convex polygonal cells, and therefore is suitable for
+   * processing by this filter. (The name of the method is consistent with
+   * other filters that perform similar operations.) This method returns true
+   * when the input contains only polygons (i.e., no verts, lines, or
+   * triangle strips); and each polygon is convex. It returns false
+   * otherwise.
+   */
+  static bool CanFullyProcessDataObject(vtkDataObject* object)
+  {
+    return vtkPolyDataPlaneCutter::CanFullyProcessDataObject(object);
+  }
 
 protected:
   vtkPolyDataPlaneClipper();
@@ -144,6 +177,7 @@ protected:
   vtkSmartPointer<vtkPlane> Plane;
   bool ClippingLoops;
   bool Capping;
+  bool PassCapPointData;
   int OutputPointsPrecision;
   unsigned int BatchSize;
 
@@ -155,4 +189,5 @@ private:
   void operator=(const vtkPolyDataPlaneClipper&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
