@@ -20,6 +20,7 @@
 #include "vtkCellData.h"
 #include "vtkCellLocatorStrategy.h"
 #include "vtkCharArray.h"
+#include "vtkClosestPointStrategy.h"
 #include "vtkFindCellStrategy.h"
 #include "vtkGenericCell.h"
 #include "vtkIdTypeArray.h"
@@ -30,33 +31,39 @@
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPointSet.h"
+#include "vtkPolyData.h"
 #include "vtkSMPThreadLocal.h"
+#include "vtkSMPThreadLocalObject.h"
 #include "vtkSMPTools.h"
 #include "vtkSmartPointer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkUnstructuredGrid.h"
 
 #include <algorithm>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkProbeFilter);
 vtkCxxSetObjectMacro(vtkProbeFilter, CellLocatorPrototype, vtkAbstractCellLocator);
 vtkCxxSetObjectMacro(vtkProbeFilter, FindCellStrategy, vtkFindCellStrategy);
 
-#define CELL_TOLERANCE_FACTOR_SQR 1e-6
+namespace
+{
+constexpr double CELL_TOLERANCE_FACTOR_SQR = 1e-6;
 
-static inline bool IsBlankedCell(vtkUnsignedCharArray* gcells, vtkIdType cellId)
+constexpr unsigned char CELL_GHOST_MASK =
+  vtkDataSetAttributes::HIDDENCELL | vtkDataSetAttributes::DUPLICATECELL;
+
+inline bool IsBlankedCell(vtkUnsignedCharArray* gcells, vtkIdType cellId)
 {
   if (gcells)
   {
     const auto flag = gcells->GetTypedComponent(cellId, 0);
-    return (flag & (vtkDataSetAttributes::HIDDENCELL | vtkDataSetAttributes::DUPLICATECELL)) != 0;
+    return (flag & CELL_GHOST_MASK) != 0;
   }
   return false;
 }
-
-class vtkProbeFilter::vtkVectorOfArrays : public std::vector<vtkDataArray*>
-{
-};
+}
 
 //------------------------------------------------------------------------------
 vtkProbeFilter::vtkProbeFilter()
@@ -68,7 +75,6 @@ vtkProbeFilter::vtkProbeFilter()
   this->SetNumberOfInputPorts(2);
   this->ValidPointMaskArrayName = nullptr;
   this->SetValidPointMaskArrayName("vtkValidPointMask");
-  this->CellArrays = new vtkVectorOfArrays();
 
   this->CellLocatorPrototype = nullptr;
   this->FindCellStrategy = nullptr;
@@ -81,6 +87,7 @@ vtkProbeFilter::vtkProbeFilter()
   this->PassFieldArrays = 1;
   this->Tolerance = 1.0;
   this->ComputeTolerance = true;
+  this->SnapToCellWithClosestPoint = false;
 }
 
 //------------------------------------------------------------------------------
@@ -96,7 +103,6 @@ vtkProbeFilter::~vtkProbeFilter()
   this->SetCellLocatorPrototype(nullptr);
   this->SetFindCellStrategy(nullptr);
 
-  delete this->CellArrays;
   delete this->PointList;
   delete this->CellList;
 }
@@ -198,6 +204,9 @@ int vtkProbeFilter::RequestData(vtkInformation* vtkNotUsed(request),
 void vtkProbeFilter::PassAttributeData(
   vtkDataSet* input, vtkDataObject* vtkNotUsed(source), vtkDataSet* output)
 {
+  // Please see vtkHyperTreeGridProbeFilter implementation of this method for a condensed version
+  // using vtkFieldData::PassData
+
   // copy point data arrays
   if (this->PassPointArrays)
   {
@@ -301,15 +310,15 @@ void vtkProbeFilter::InitializeForProbing(vtkDataSet* input, vtkDataSet* output)
   // All input PD is passed to output as PD. Those arrays in input CD that are
   // not present in output PD will be passed as output PD.
   vtkPointData* outPD = output->GetPointData();
-  outPD->InterpolateAllocate((*this->PointList), numPts, numPts);
+  outPD->InterpolateAllocate(*this->PointList, numPts, numPts);
 
   vtkCellData* tempCellData = vtkCellData::New();
   // We're okay with copying global ids for cells. we just don't flag them as
   // such.
   tempCellData->CopyAllOn(vtkDataSetAttributes::COPYTUPLE);
-  tempCellData->CopyAllocate((*this->CellList), numPts, numPts);
+  tempCellData->CopyAllocate(*this->CellList, numPts, numPts);
 
-  this->CellArrays->clear();
+  this->CellArrays.clear();
   int numCellArrays = tempCellData->GetNumberOfArrays();
   for (int cc = 0; cc < numCellArrays; cc++)
   {
@@ -317,7 +326,7 @@ void vtkProbeFilter::InitializeForProbing(vtkDataSet* input, vtkDataSet* output)
     if (inArray && inArray->GetName() && !outPD->GetArray(inArray->GetName()))
     {
       outPD->AddArray(inArray);
-      this->CellArrays->push_back(inArray);
+      this->CellArrays.push_back(inArray);
     }
   }
   tempCellData->Delete();
@@ -351,16 +360,14 @@ void vtkProbeFilter::DoProbing(
     return;
   }
 
-  if (vtkImageData::SafeDownCast(source))
+  if (auto sourceImage = vtkImageData::SafeDownCast(source))
   {
-    vtkImageData* sourceImage = vtkImageData::SafeDownCast(source);
     this->ProbeImageDataPoints(input, srcIdx, sourceImage, output);
   }
-  else if (vtkImageData::SafeDownCast(input))
+  else if (auto inputImage = vtkImageData::SafeDownCast(input))
   {
-    vtkImageData* inImage = vtkImageData::SafeDownCast(input);
-    vtkImageData* outImage = vtkImageData::SafeDownCast(output);
-    this->ProbePointsImageData(inImage, srcIdx, source, outImage);
+    vtkImageData* outputImage = vtkImageData::SafeDownCast(output);
+    this->ProbePointsImageData(inputImage, srcIdx, source, outputImage);
   }
   else
   {
@@ -376,42 +383,293 @@ void vtkProbeFilter::Probe(vtkDataSet* input, vtkDataSet* source, vtkDataSet* ou
   this->DoProbing(input, 0, source, output);
 }
 
+//------------------------------------------------------------------------------
+class vtkProbeFilter::ProbeEmptyPointsWorklet
+{
+  vtkProbeFilter* ProbeFilter;
+  int SourceIdx;
+  vtkDataSet* Input;
+  vtkDataSet* Source;
+  vtkPointData* SourcePD;
+  vtkCellData* SourceCD;
+  vtkPointData* OutputPD;
+  vtkFindCellStrategy* Strategy;
+  vtkUnsignedCharArray* SourceGhostFlags;
+  vtkCharArray* MaskArray;
+  double Tol2;
+  int MaxCellSize;
+
+  struct LocalData
+  {
+    vtkSmartPointer<vtkFindCellStrategy> Strategy;
+    vtkCellLocatorStrategy* CellLocatorStrategy;
+    vtkClosestPointStrategy* ClosestPointStrategy;
+    vtkSmartPointer<vtkGenericCell> CurrentCell;
+    vtkSmartPointer<vtkGenericCell> LastCell;
+    std::vector<double> Weights;
+    double LastPCoords[3];
+    int LastSubId;
+    double LastClosestPoint[3];
+    double LastCellBounds[6];
+    double LastLength2;
+    vtkIdType LastCellId;
+  };
+  vtkSMPThreadLocal<LocalData> TLData;
+
+public:
+  ProbeEmptyPointsWorklet(vtkProbeFilter* probeFilter, int sourceIndex, vtkDataSet* input,
+    vtkDataSet* source, vtkPointData* outputPD, vtkFindCellStrategy* strategy,
+    vtkUnsignedCharArray* sourceGhostFlags, vtkCharArray* maskArray, double tol2, int maxCellSize)
+    : ProbeFilter(probeFilter)
+    , SourceIdx(sourceIndex)
+    , Input(input)
+    , Source(source)
+    , SourcePD(source->GetPointData())
+    , SourceCD(source->GetCellData())
+    , OutputPD(outputPD)
+    , Strategy(strategy)
+    , SourceGhostFlags(sourceGhostFlags)
+    , MaskArray(maskArray)
+    , Tol2(tol2)
+    , MaxCellSize(maxCellSize)
+  {
+    // instantiate the cell map for polydata
+    vtkNew<vtkGenericCell> cell;
+    this->Source->GetCell(0, cell);
+  }
+
+  void Initialize()
+  {
+    auto& tlData = this->TLData.Local();
+    if (this->Strategy)
+    {
+      tlData.Strategy = vtk::TakeSmartPointer(this->Strategy->NewInstance());
+      tlData.Strategy->CopyParameters(this->Strategy);
+      tlData.Strategy->Initialize(vtkPointSet::SafeDownCast(this->Source));
+      tlData.CellLocatorStrategy = vtkCellLocatorStrategy::SafeDownCast(tlData.Strategy);
+      tlData.ClosestPointStrategy = vtkClosestPointStrategy::SafeDownCast(tlData.Strategy);
+    }
+    else
+    {
+      tlData.Strategy = nullptr;
+      tlData.CellLocatorStrategy = nullptr;
+      tlData.ClosestPointStrategy = nullptr;
+    }
+    tlData.CurrentCell = vtkSmartPointer<vtkGenericCell>::New();
+    tlData.LastCell = vtkSmartPointer<vtkGenericCell>::New();
+    tlData.Weights.resize(static_cast<size_t>(this->MaxCellSize));
+    tlData.LastCellId = -1;
+  }
+
+  static double GetLength2(const double bounds[6])
+  {
+    double diff, l = 0.0;
+    int i;
+
+    for (i = 0; i < 3; i++)
+    {
+      diff = bounds[2 * i + 1] - bounds[2 * i];
+      l += diff * diff;
+    }
+    return l;
+  }
+
+  void operator()(vtkIdType beginPointId, vtkIdType endPointId)
+  {
+    // global data
+    auto maskArray = this->MaskArray->GetPointer(0);
+    // thread local data
+    auto& tlData = this->TLData.Local();
+    auto& strategy = tlData.Strategy;
+    auto& cellLocatorStrategy = tlData.CellLocatorStrategy;
+    auto& closestPointStrategy = tlData.ClosestPointStrategy;
+    auto& currentCell = tlData.CurrentCell;
+    auto& lastCell = tlData.LastCell;
+    auto weights = tlData.Weights.data();
+    auto& lastPCoords = tlData.LastPCoords;
+    auto& lastSubId = tlData.LastSubId;
+    auto& lastClosestPoint = tlData.LastClosestPoint;
+    auto& lastCellBounds = tlData.LastCellBounds;
+    auto& lastLength2 = tlData.LastLength2;
+    auto& lastCellId = tlData.LastCellId;
+    // local data
+    double x[3], dist2;
+    vtkIdType closestPointFound;
+    int inside;
+    bool foundInCache, insideCellBounds;
+    bool isFirst = vtkSMPTools::GetSingleThread();
+
+    for (vtkIdType pointId = beginPointId; pointId < endPointId; ++pointId)
+    {
+      if (isFirst)
+      {
+        this->ProbeFilter->CheckAbort();
+      }
+      if (this->ProbeFilter->GetAbortOutput())
+      {
+        break;
+      }
+      if (maskArray[pointId] == static_cast<char>(1))
+      {
+        // skip points which have already been probed with success.
+        // This is helpful for multiblock dataset probing.
+        continue;
+      }
+
+      // Get the xyz coordinate of the point in the input dataset
+      this->Input->GetPoint(pointId, x);
+
+      foundInCache = false;
+      if (lastCellId != -1)
+      {
+        // check if it's inside cell bounds
+        insideCellBounds = lastCellBounds[0] <= x[0] && x[0] <= lastCellBounds[1] &&
+          lastCellBounds[2] <= x[1] && x[1] <= lastCellBounds[3] && lastCellBounds[4] <= x[2] &&
+          x[2] <= lastCellBounds[5];
+        if (insideCellBounds)
+        {
+          // Use cache cell only if point is inside
+          inside = currentCell->EvaluatePosition(
+            x, lastClosestPoint, lastSubId, lastPCoords, dist2, weights);
+          if (inside == 1)
+          {
+            foundInCache = true;
+          }
+        }
+      }
+      if (!foundInCache)
+      {
+        // strategies are used for subclasses of vtkPointSet
+        if (strategy)
+        {
+          if (cellLocatorStrategy)
+          {
+            // this location strategy uses a cell locator
+            lastCellId = cellLocatorStrategy->FindCell(x, nullptr, currentCell, -1,
+              this->Tol2 /*not used*/, lastSubId, lastPCoords, weights);
+            // this strategy once it finds a cell where the given point is inside it stops
+            // immediately, so currentCell contains the cell we want
+          }
+          else // vtkClosestPointStrategy
+          {
+            // this location strategy will first look at the neighbor cells of the cached cell (if
+            // any) and if that fails it will use jump and walk technique
+            if (lastCellId != -1)
+            {
+              // Use cache cell only if point is inside
+              this->Source->GetCell(lastCellId, lastCell);
+              lastCellId = closestPointStrategy->FindCell(
+                x, lastCell, currentCell, lastCellId, this->Tol2, lastSubId, lastPCoords, weights);
+              foundInCache = lastCellId != -1;
+            }
+            else
+            {
+              lastCellId = closestPointStrategy->FindCell(
+                x, nullptr, currentCell, -1, this->Tol2, lastSubId, lastPCoords, weights);
+            }
+            // this strategy once it finds a cell where the given point is inside it stops
+            // immediately, so currentCell contains the cell we want
+          }
+        }
+        else
+        {
+          // the classes that do not use a strategy are vtkImageData, vtkRectilinearGrid
+          lastCellId = this->Source->FindCell(
+            x, nullptr, currentCell, -1, this->Tol2, lastSubId, lastPCoords, weights);
+          // these classes don't use currentCell, so we will need to extract it if we found anything
+        }
+        if (lastCellId != -1)
+        {
+          // extract the cell that we found if we didn't use a strategy
+          if (!strategy)
+          {
+            this->Source->GetCell(lastCellId, currentCell);
+          }
+          // pcoords, weights and subid are all valid, so we can compute the closest point
+          // using EvaluateLocation
+          currentCell->EvaluateLocation(lastSubId, lastPCoords, lastClosestPoint, weights);
+          // copy bounds
+          std::copy_n(currentCell->GetBounds(), 6, lastCellBounds);
+          // compute lastLength2
+          lastLength2 = ProbeEmptyPointsWorklet::GetLength2(lastCellBounds);
+        }
+        else
+        {
+          if (this->ProbeFilter->SnapToCellWithClosestPoint && strategy)
+          {
+            // Find the closest point and the cell that it belong to
+            constexpr double snappingRadius = std::numeric_limits<double>::infinity();
+            closestPointFound = strategy->FindClosestPointWithinRadius(x, snappingRadius,
+              lastClosestPoint, currentCell, lastCellId, lastSubId, dist2, inside);
+            if (closestPointFound)
+            {
+              // pcoords, weights and subid are all valid, so we can compute the closest point
+              // using EvaluateLocation
+              this->Source->GetCell(lastCellId, currentCell);
+              // we don't need to calculate the closest point, but we do need to calculate the
+              // weights
+              currentCell->EvaluateLocation(lastSubId, lastPCoords, lastClosestPoint, weights);
+              // copy bounds
+              std::copy_n(currentCell->GetBounds(), 6, lastCellBounds);
+              // compute lastLength2
+              lastLength2 = ProbeEmptyPointsWorklet::GetLength2(lastCellBounds);
+            }
+            else
+            {
+              lastCellId = -1;
+            }
+          }
+        }
+      }
+
+      if (lastCellId >= 0 && !::IsBlankedCell(this->SourceGhostFlags, lastCellId))
+      {
+        if (this->ProbeFilter->ComputeTolerance)
+        {
+          // If ComputeTolerance is set, compute a tolerance proportional to the
+          // cell length.
+          dist2 = vtkMath::Distance2BetweenPoints(x, lastClosestPoint);
+          if (dist2 > (lastLength2 * CELL_TOLERANCE_FACTOR_SQR))
+          {
+            continue;
+          }
+        }
+
+        // Interpolate the point data
+        this->OutputPD->InterpolatePoint(*this->ProbeFilter->PointList, this->SourcePD,
+          this->SourceIdx, pointId, currentCell->PointIds, weights);
+        for (auto& cellArray : this->ProbeFilter->CellArrays)
+        {
+          if (auto inArray = this->SourceCD->GetArray(cellArray->GetName()))
+          {
+            this->OutputPD->CopyTuple(inArray, cellArray, lastCellId, pointId);
+          }
+        }
+        maskArray[pointId] = static_cast<char>(1);
+      }
+    }
+  }
+
+  void Reduce() {}
+};
+
 //------------------------------------------------------------------------------
 void vtkProbeFilter::ProbeEmptyPoints(
   vtkDataSet* input, int srcIdx, vtkDataSet* source, vtkDataSet* output)
 {
-  vtkIdType ptId, numPts;
-  double x[3], tol2;
-  vtkPointData *pd, *outPD;
-  vtkCellData* cd;
-  int subId;
-  double pcoords[3], *weights;
-  double fastweights[256];
+  double tol2;
+  vtkPointData* outPD;
 
   vtkDebugMacro(<< "Probing data");
 
-  pd = source->GetPointData();
-  cd = source->GetCellData();
-
-  auto sourceGhostFlags =
-    vtkUnsignedCharArray::SafeDownCast(cd->GetArray(vtkDataSetAttributes::GhostArrayName()));
+  auto sourceGhostFlags = vtkUnsignedCharArray::SafeDownCast(
+    source->GetCellData()->GetArray(vtkDataSetAttributes::GhostArrayName()));
 
   // lets use a stack allocated array if possible for performance reasons
-  int mcs = source->GetMaxCellSize();
-  if (mcs <= 256)
-  {
-    weights = fastweights;
-  }
-  else
-  {
-    weights = new double[mcs];
-  }
+  int maxCellSize = source->GetMaxCellSize();
 
-  numPts = input->GetNumberOfPoints();
   outPD = output->GetPointData();
 
-  char* maskArray = this->MaskPoints->GetPointer(0);
-
   if (this->ComputeTolerance)
   {
     // to compute a reasonable starting tolerance we use
@@ -446,8 +704,8 @@ void vtkProbeFilter::ProbeEmptyPoints(
   // vtkDataSet::FindCell() is used to accelerate the search.
   vtkFindCellStrategy* strategy = nullptr;
   vtkNew<vtkCellLocatorStrategy> cellLocStrategy;
-  vtkPointSet* ps;
-  if ((ps = vtkPointSet::SafeDownCast(source)) != nullptr)
+  vtkNew<vtkClosestPointStrategy> closestPointStrategy;
+  if (auto ps = vtkPointSet::SafeDownCast(source))
   {
     if (this->FindCellStrategy != nullptr)
     {
@@ -456,91 +714,44 @@ void vtkProbeFilter::ProbeEmptyPoints(
     }
     else if (this->CellLocatorPrototype != nullptr)
     {
-      cellLocStrategy->SetCellLocator(this->CellLocatorPrototype->NewInstance());
-      cellLocStrategy->GetCellLocator()->SetDataSet(source);
-      cellLocStrategy->GetCellLocator()->Update();
-      strategy = static_cast<vtkFindCellStrategy*>(cellLocStrategy.GetPointer());
-      cellLocStrategy->GetCellLocator()->UnRegister(this); // strategy took ownership
-    }
-  }
-
-  // Find the cell that contains xyz and get it
-  if (strategy == nullptr)
-  {
-    vtkDebugMacro(<< "Using vtkDataSet::FindCell()");
-  }
-  else
-  {
-    vtkDebugMacro(<< "Using strategy: " << strategy->GetClassName());
-  }
-
-  // Loop over all input points, interpolating source data
-  //
-  vtkNew<vtkGenericCell> gcell;
-  int abort = 0;
-  vtkIdType progressInterval = numPts / 20 + 1;
-  for (ptId = 0; ptId < numPts && !abort; ptId++)
-  {
-    if (!(ptId % progressInterval))
-    {
-      this->UpdateProgress(static_cast<double>(ptId) / numPts);
-      abort = GetAbortExecute();
-    }
-
-    if (maskArray[ptId] == static_cast<char>(1))
-    {
-      // skip points which have already been probed with success.
-      // This is helpful for multiblock dataset probing.
-      continue;
-    }
-
-    // Get the xyz coordinate of the point in the input dataset
-    input->GetPoint(ptId, x);
-
-    vtkIdType cellId = (strategy != nullptr)
-      ? strategy->FindCell(x, nullptr, gcell.GetPointer(), -1, tol2, subId, pcoords, weights)
-      : source->FindCell(x, nullptr, -1, tol2, subId, pcoords, weights);
-
-    vtkCell* cell = nullptr;
-    if (cellId >= 0 && !::IsBlankedCell(sourceGhostFlags, cellId))
-    {
-      cell = source->GetCell(cellId);
-      if (this->ComputeTolerance)
+      // if the existing locator is not the same type, set the locator of dataset instead of the
+      // strategy to allow other filters to reuse the locator.
+      auto existingLocator = ps->GetCellLocator();
+      bool sameLocatorType =
+        existingLocator ? this->CellLocatorPrototype->IsA(existingLocator->GetClassName()) : false;
+      if (!sameLocatorType)
       {
-        // If ComputeTolerance is set, compute a tolerance proportional to the
-        // cell length.
-        double dist2;
-        double closestPoint[3];
-        cell->EvaluatePosition(x, closestPoint, subId, pcoords, dist2, weights);
-        if (dist2 > (cell->GetLength2() * CELL_TOLERANCE_FACTOR_SQR))
-        {
-          continue;
-        }
+        auto cellLocator = vtk::TakeSmartPointer(this->CellLocatorPrototype->NewInstance());
+        ps->SetCellLocator(cellLocator);
+        cellLocator->SetDataSet(ps);
+        cellLocator->BuildLocator();
+      }
+      cellLocStrategy->Initialize(ps);
+      strategy = cellLocStrategy;
+    }
+    else // if no strategy or cell locator is specified, use the default strategy
+    {
+      closestPointStrategy->Initialize(ps);
+      strategy = closestPointStrategy;
+    }
+    if (vtkClosestPointStrategy::SafeDownCast(strategy))
+    {
+      if (auto polyData = vtkPolyData::SafeDownCast(ps))
+      {
+        polyData->BuildLinks();
+      }
+      else if (auto unstructuredGrid = vtkUnstructuredGrid::SafeDownCast(ps))
+      {
+        unstructuredGrid->BuildLinks();
       }
     }
-
-    if (cell)
-    {
-      // Interpolate the point data
-      outPD->InterpolatePoint((*this->PointList), pd, srcIdx, ptId, cell->PointIds, weights);
-      vtkVectorOfArrays::iterator iter;
-      for (iter = this->CellArrays->begin(); iter != this->CellArrays->end(); ++iter)
-      {
-        vtkDataArray* inArray = cd->GetArray((*iter)->GetName());
-        if (inArray)
-        {
-          outPD->CopyTuple(inArray, *iter, cellId, ptId);
-        }
-      }
-      maskArray[ptId] = static_cast<char>(1);
-    }
   }
 
+  ProbeEmptyPointsWorklet worker(this, srcIdx, input, source, outPD, strategy, sourceGhostFlags,
+    this->MaskPoints, tol2, maxCellSize);
+  vtkSMPTools::For(0, input->GetNumberOfPoints(), worker);
+
   this->MaskPoints->Modified();
-  if (mcs > 256)
-  {
-    delete[] weights;
-  }
 }
 
 //------------------------------------------------------------------------------
@@ -628,17 +839,15 @@ void vtkProbeFilter::ProbeImagePointsInCell(vtkCell* cell, vtkIdType cellId, vtk
           vtkIdType ptId = ix + dim[0] * (iy + dim[1] * iz);
 
           // Interpolate the point data
-          outPD->InterpolatePoint(
-            (*this->PointList), pd, srcBlockId, ptId, cell->PointIds, wtsBuff);
+          outPD->InterpolatePoint(*this->PointList, pd, srcBlockId, ptId, cell->PointIds, wtsBuff);
 
           // Assign cell data
-          vtkVectorOfArrays::iterator iter;
-          for (iter = this->CellArrays->begin(); iter != this->CellArrays->end(); ++iter)
+          for (auto& cellArray : this->CellArrays)
           {
-            vtkDataArray* inArray = cd->GetArray((*iter)->GetName());
+            vtkDataArray* inArray = cd->GetArray(cellArray->GetName());
             if (inArray)
             {
-              outPD->CopyTuple(inArray, *iter, cellId, ptId);
+              outPD->CopyTuple(inArray, cellArray, cellId, ptId);
             }
           }
 
@@ -650,67 +859,6 @@ void vtkProbeFilter::ProbeImagePointsInCell(vtkCell* cell, vtkIdType cellId, vtk
 }
 
 //------------------------------------------------------------------------------
-namespace
-{
-
-class CellStorage
-{
-public:
-  CellStorage() { this->Initialize(); }
-
-  ~CellStorage() { this->Clear(); }
-
-  // Copying does not make sense for this class but vtkSMPThreadLocal needs
-  // these functions to compile. Just initialize the object.
-  CellStorage(const CellStorage&) { this->Initialize(); }
-
-  CellStorage& operator=(const CellStorage& other)
-  {
-    if (this == &other)
-    {
-      return *this;
-    }
-
-    this->Clear();
-    this->Initialize();
-    return *this;
-  }
-
-  vtkCell* GetCell(vtkDataSet* dataset, vtkIdType cellId)
-  {
-    int celltype = dataset->GetCellType(cellId);
-    vtkGenericCell*& gc = this->Cells[celltype];
-    if (!gc)
-    {
-      gc = vtkGenericCell::New();
-    }
-    dataset->GetCell(cellId, gc);
-    return gc->GetRepresentativeCell();
-  }
-
-private:
-  void Initialize()
-  {
-    vtkGenericCell* null = nullptr;
-    std::fill(this->Cells, this->Cells + VTK_NUMBER_OF_CELL_TYPES, null);
-  }
-
-  void Clear()
-  {
-    for (int i = 0; i < VTK_NUMBER_OF_CELL_TYPES; ++i)
-    {
-      if (this->Cells[i])
-      {
-        this->Cells[i]->Delete();
-      }
-    }
-  }
-
-  vtkGenericCell* Cells[VTK_NUMBER_OF_CELL_TYPES];
-};
-
-} // anonymous namespace
-
 class vtkProbeFilter::ProbeImageDataWorklet
 {
 public:
@@ -727,6 +875,9 @@ public:
     , MaskArray(maskArray)
     , MaxCellSize(maxCellSize)
   {
+    // make source API threadsafe by calling it once in a single thread.
+    source->GetCellType(0);
+    source->GetCell(0, this->GenericCell.Local());
   }
 
   void operator()(vtkIdType cellBegin, vtkIdType cellEnd)
@@ -741,21 +892,30 @@ public:
     {
       std::vector<double>& dynamicweights = this->WeightsBuffer.Local();
       dynamicweights.resize(this->MaxCellSize);
-      weights = &dynamicweights[0];
+      weights = dynamicweights.data();
     }
 
     auto sourceGhostFlags = vtkUnsignedCharArray::SafeDownCast(
       this->Source->GetCellData()->GetArray(vtkDataSetAttributes::GhostArrayName()));
 
-    CellStorage& cs = this->Cells.Local();
+    auto& cell = this->GenericCell.Local();
+    bool isFirst = vtkSMPTools::GetSingleThread();
     for (vtkIdType cellId = cellBegin; cellId < cellEnd; ++cellId)
     {
+      if (isFirst)
+      {
+        this->ProbeFilter->CheckAbort();
+      }
+      if (this->ProbeFilter->GetAbortOutput())
+      {
+        break;
+      }
       if (IsBlankedCell(sourceGhostFlags, cellId))
       {
         continue;
       }
 
-      vtkCell* cell = cs.GetCell(this->Source, cellId);
+      this->Source->GetCell(cellId, cell);
       this->ProbeFilter->ProbeImagePointsInCell(cell, cellId, this->Source, this->SrcBlockId,
         this->Start, this->Spacing, this->Dim, this->OutPointData, this->MaskArray, weights);
     }
@@ -773,7 +933,7 @@ private:
   int MaxCellSize;
 
   vtkSMPThreadLocal<std::vector<double>> WeightsBuffer;
-  vtkSMPThreadLocal<CellStorage> Cells;
+  vtkSMPThreadLocalObject<vtkGenericCell> GenericCell;
 };
 
 //------------------------------------------------------------------------------
@@ -800,8 +960,6 @@ void vtkProbeFilter::ProbePointsImageData(
 
   if (numSrcCells > 0)
   {
-    // dummy call required before multithreaded calls
-    static_cast<void>(source->GetCellType(0));
     ProbeImageDataWorklet worklet(
       this, source, srcIdx, start, spacing, dim, outPD, maskArray, source->GetMaxCellSize());
     vtkSMPTools::For(0, numSrcCells, worklet);
@@ -817,15 +975,7 @@ namespace
 // Thread local storage
 struct ProbeImageDataPointsThreadLocal
 {
-  ProbeImageDataPointsThreadLocal()
-  {
-    // BaseThread will be set 'true' for the thread that gets the first piece
-    this->BaseThread = false;
-    this->PointIds = vtkSmartPointer<vtkIdList>::New();
-    this->PointIds->SetNumberOfIds(8);
-  }
-
-  bool BaseThread;
+  bool BaseThread = false;
   vtkSmartPointer<vtkIdList> PointIds;
 };
 
@@ -846,6 +996,15 @@ public:
   {
   }
 
+  void Initialize()
+  {
+    // BaseThread will be set 'true' for the thread that gets the first piece
+    ProbeImageDataPointsThreadLocal& DataPoint = this->Thread.Local();
+    DataPoint.BaseThread = false;
+    DataPoint.PointIds = vtkSmartPointer<vtkIdList>::New();
+    DataPoint.PointIds->SetNumberOfIds(8);
+  }
+
   void operator()(vtkIdType startId, vtkIdType endId)
   {
     if (startId == 0)
@@ -857,6 +1016,8 @@ public:
       endId, this->Thread.Local().BaseThread);
   }
 
+  void Reduce() {}
+
 private:
   vtkProbeFilter* ProbeFilter;
   vtkDataSet* Input;
@@ -924,13 +1085,17 @@ void vtkProbeFilter::ProbeImageDataPointsSMP(vtkDataSet* input, vtkImageData* so
 
   // Loop over all input points, interpolating source data
   vtkIdType progressInterval = endId / 20 + 1;
-  for (vtkIdType ptId = startId; ptId < endId && !GetAbortExecute(); ptId++)
+  for (vtkIdType ptId = startId; ptId < endId; ptId++)
   {
     if (baseThread && !(ptId % progressInterval))
     {
       // This is not ideal, because if the base thread executes more than one piece,
       // then the progress will repeat its 0.0 to 1.0 progression for each piece.
       this->UpdateProgress(static_cast<double>(ptId) / endId);
+      if (this->CheckAbort())
+      {
+        break;
+      }
     }
 
     if (maskArray[ptId] == static_cast<char>(1))
@@ -953,14 +1118,13 @@ void vtkProbeFilter::ProbeImageDataPointsSMP(vtkDataSet* input, vtkImageData* so
       source->GetCellPoints(cellId, pointIds);
 
       // Interpolate the point data
-      outPD->InterpolatePoint((*this->PointList), pd, srcIdx, ptId, pointIds, weights);
-      vtkVectorOfArrays::iterator iter;
-      for (iter = this->CellArrays->begin(); iter != this->CellArrays->end(); ++iter)
+      outPD->InterpolatePoint(*this->PointList, pd, srcIdx, ptId, pointIds, weights);
+      for (auto& cellArray : this->CellArrays)
       {
-        vtkDataArray* inArray = cd->GetArray((*iter)->GetName());
+        vtkDataArray* inArray = cd->GetArray(cellArray->GetName());
         if (inArray)
         {
-          outPD->CopyTuple(inArray, *iter, cellId, ptId);
+          outPD->CopyTuple(inArray, cellArray, cellId, ptId);
         }
       }
       maskArray[ptId] = static_cast<char>(1);
@@ -1107,3 +1271,4 @@ void vtkProbeFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "CellLocatorPrototype: "
      << (this->CellLocatorPrototype ? this->CellLocatorPrototype->GetClassName() : "NULL") << "\n";
 }
+VTK_ABI_NAMESPACE_END
