@@ -69,6 +69,9 @@
 #include "vtkDataSetAttributes.h" // needed for vtkDataSetAttributes::FieldList
 #include "vtkFiltersCoreModule.h" // For export macro
 
+#include <vector> // For std::vector
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractCellLocator;
 class vtkCell;
 class vtkCharArray;
@@ -84,7 +87,7 @@ public:
   vtkTypeMacro(vtkProbeFilter, vtkDataSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the data set that will be probed at the input points.
    * The Input gives the geometry (the points and cells) for the output,
@@ -93,7 +96,7 @@ public:
    */
   void SetSourceData(vtkDataObject* source);
   vtkDataObject* GetSource();
-  //@}
+  ///@}
 
   /**
    * Specify the data set that will be probed at the input points.
@@ -103,7 +106,7 @@ public:
    */
   void SetSourceConnection(vtkAlgorithmOutput* algOutput);
 
-  //@{
+  ///@{
   /**
    * Control whether the source point data is to be treated as categorical. If
    * the data is categorical, then the resultant data will be determined by
@@ -112,9 +115,9 @@ public:
   vtkSetMacro(CategoricalData, vtkTypeBool);
   vtkGetMacro(CategoricalData, vtkTypeBool);
   vtkBooleanMacro(CategoricalData, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This flag is used only when a piece is requested to update.  By default
    * the flag is off.  Because no spatial correspondence between input pieces
@@ -128,17 +131,17 @@ public:
   vtkSetMacro(SpatialMatch, vtkTypeBool);
   vtkGetMacro(SpatialMatch, vtkTypeBool);
   vtkBooleanMacro(SpatialMatch, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the list of point ids in the output that contain attribute data
    * interpolated from the source.
    */
   vtkIdTypeArray* GetValidPoints();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Returns the name of the char array added to the output with values 1 for
    * valid points and 0 for invalid points.
@@ -146,9 +149,9 @@ public:
    */
   vtkSetStringMacro(ValidPointMaskArrayName);
   vtkGetStringMacro(ValidPointMaskArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Shallow copy the input cell data arrays to the output.
    * Off by default.
@@ -156,8 +159,8 @@ public:
   vtkSetMacro(PassCellArrays, vtkTypeBool);
   vtkBooleanMacro(PassCellArrays, vtkTypeBool);
   vtkGetMacro(PassCellArrays, vtkTypeBool);
-  //@}
-  //@{
+  ///@}
+  ///@{
   /**
    * Shallow copy the input point data arrays to the output
    * Off by default.
@@ -165,9 +168,9 @@ public:
   vtkSetMacro(PassPointArrays, vtkTypeBool);
   vtkBooleanMacro(PassPointArrays, vtkTypeBool);
   vtkGetMacro(PassPointArrays, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set whether to pass the field-data arrays from the Input i.e. the input
    * providing the geometry to the output. On by default.
@@ -175,9 +178,9 @@ public:
   vtkSetMacro(PassFieldArrays, vtkTypeBool);
   vtkBooleanMacro(PassFieldArrays, vtkTypeBool);
   vtkGetMacro(PassFieldArrays, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the tolerance used to compute whether a point in the
    * source is in a cell of the input.  This value is only used
@@ -185,9 +188,23 @@ public:
    */
   vtkSetMacro(Tolerance, double);
   vtkGetMacro(Tolerance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Set/Get whether to snap to the cell with the closest point, if no cell has been found while
+   * FindCell is executed.
+   *
+   * Default is off.
+   *
+   * Note: This is useful only when the source is a vtkPointSet.
+   */
+  vtkSetMacro(SnapToCellWithClosestPoint, bool);
+  vtkBooleanMacro(SnapToCellWithClosestPoint, bool);
+  vtkGetMacro(SnapToCellWithClosestPoint, bool);
+  ///@}
+
+  ///@{
   /**
    * Set whether to use the Tolerance field or precompute the tolerance.
    * When on, the tolerance will be computed and the field
@@ -196,9 +213,9 @@ public:
   vtkSetMacro(ComputeTolerance, bool);
   vtkBooleanMacro(ComputeTolerance, bool);
   vtkGetMacro(ComputeTolerance, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / get the strategy used to perform the FindCell() operation. When
    * specified, the strategy is used in preference to a cell locator
@@ -207,9 +224,9 @@ public:
    */
   virtual void SetFindCellStrategy(vtkFindCellStrategy*);
   vtkGetObjectMacro(FindCellStrategy, vtkFindCellStrategy);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the prototype cell locator to perform the FindCell() operation.
    * (A prototype is used as an object factory to instantiate an instance of
@@ -220,7 +237,7 @@ public:
    */
   virtual void SetCellLocatorPrototype(vtkAbstractCellLocator*);
   vtkGetObjectMacro(CellLocatorPrototype, vtkAbstractCellLocator);
-  //@}
+  ///@}
 
 protected:
   vtkProbeFilter();
@@ -269,6 +286,7 @@ protected:
 
   double Tolerance;
   bool ComputeTolerance;
+  bool SnapToCellWithClosestPoint;
 
   char* ValidPointMaskArrayName;
   vtkIdTypeArray* ValidPoints;
@@ -307,8 +325,10 @@ private:
 
   class ProbeImageDataPointsWorklet;
 
-  class vtkVectorOfArrays;
-  vtkVectorOfArrays* CellArrays;
+  class ProbeEmptyPointsWorklet;
+
+  std::vector<vtkDataArray*> CellArrays;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
