@@ -29,6 +29,7 @@
 
 #include <unordered_set> // keep track of inserted triangles
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQuadricClustering);
 
 //------------------------------------------------------------------------------
@@ -88,6 +89,7 @@ vtkQuadricClustering::vtkQuadricClustering()
   this->FeatureEdges = vtkFeatureEdges::New();
   this->FeatureEdges->FeatureEdgesOff();
   this->FeatureEdges->BoundaryEdgesOn();
+  this->FeatureEdges->SetContainerAlgorithm(this);
   this->FeaturePoints = vtkPoints::New();
 
   this->InCellCount = this->OutCellCount = 0;
@@ -389,6 +391,10 @@ void vtkQuadricClustering::AddPolygons(
     ++this->InCellCount;
     if (curr > cstep)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       this->UpdateProgress(.6 + .2 * curr / total);
       cstep += step;
     }
@@ -408,6 +414,10 @@ void vtkQuadricClustering::AddStrips(vtkCellArray* strips, vtkPoints* points, in
 
   for (strips->InitTraversal(); strips->GetNextCell(numPts, ptIds);)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     points->GetPoint(ptIds[0], pts[0]);
     binIds[0] = this->HashPoint(pts[0]);
     points->GetPoint(ptIds[1], pts[1]);
@@ -596,6 +606,10 @@ void vtkQuadricClustering::AddEdges(
   edges->InitTraversal();
   for (vtkIdType i = 0; i < numCells; ++i)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     edges->GetNextCell(numPts, ptIds);
     if (numPts != 0)
     {
@@ -660,7 +674,7 @@ void vtkQuadricClustering::AddEdge(vtkIdType* binIds, double* pt0, double* pt1,
   // Compute dot(m, d);
   md = m[0] * d[0] + m[1] * d[1] + m[2] * d[2];
 
-  // We save nine coefficients of the error function cooresponding to:
+  // We save nine coefficients of the error function corresponding to:
   // 0: Px^2
   // 1: PxPy
   // 2: PxPz
@@ -744,6 +758,10 @@ void vtkQuadricClustering::AddVertices(
   verts->InitTraversal();
   for (vtkIdType i = 0; i < numCells; ++i)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     verts->GetNextCell(numPts, ptIds);
     // Can there be poly vertices?
     for (vtkIdType j = 0; j < numPts; ++j)
@@ -775,7 +793,7 @@ void vtkQuadricClustering::AddVertex(
 
   // Compute quadric for the vertex.
 
-  // We save nine coefficients of the error function cooresponding to:
+  // We save nine coefficients of the error function corresponding to:
   // 0: Px^2
   // 1: PxPy
   // 2: PxPz
@@ -891,7 +909,7 @@ void vtkQuadricClustering::EndAppend()
   vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   vtkIdType numBuckets;
-  int abortExecute = 0;
+  bool abortExecute = false;
   vtkPoints* outputPoints;
   double newPt[3];
   numBuckets = this->NumberOfDivisions[0] * this->NumberOfDivisions[1] * this->NumberOfDivisions[2];
@@ -925,7 +943,7 @@ void vtkQuadricClustering::EndAppend()
       cstep = 0;
       vtkDebugMacro(<< "Finding point in bin #" << i);
       this->UpdateProgress(0.8 + 0.2 * i / numBuckets);
-      abortExecute = this->GetAbortExecute();
+      abortExecute = this->CheckAbort();
     }
     ++cstep;
 
@@ -1328,7 +1346,7 @@ void vtkQuadricClustering::EndAppendVertexGeometry(vtkPolyData* input, vtkPolyDa
       outPtId = this->QuadricArray[binId].VertexId;
       if (outPtId >= 0)
       {
-        // Do not use this point.  Destroy infomration in Quadric array.
+        // Do not use this point.  Destroy information in Quadric array.
         this->QuadricArray[binId].VertexId = -1;
         tmp[tmpIdx] = outPtId;
         ++tmpIdx;
@@ -1529,3 +1547,4 @@ void vtkQuadricClustering::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Prevent Duplicate Cells : " << (this->PreventDuplicateCells ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
