@@ -42,6 +42,7 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRectilinearSynchronizedTemplates);
 
 //------------------------------------------------------------------------------
@@ -212,37 +213,40 @@ void vtkRSTComputePointGradient(
 
 //------------------------------------------------------------------------------
 #define VTK_RECT_CSP3PA(i2, j2, k2, s)                                                             \
-  if (NeedGradients)                                                                               \
+  do                                                                                               \
   {                                                                                                \
-    if (!g0)                                                                                       \
+    if (NeedGradients)                                                                             \
     {                                                                                              \
-      self->ComputeSpacing(data, i, j, k, exExt, spacing);                                         \
-      vtkRSTComputePointGradient(i, j, k, s0, inExt, xInc, yInc, zInc, spacing, n0);               \
-      g0 = 1;                                                                                      \
+      if (!g0)                                                                                     \
+      {                                                                                            \
+        self->ComputeSpacing(data, i, j, k, exExt, spacing);                                       \
+        vtkRSTComputePointGradient(i, j, k, s0, inExt, xInc, yInc, zInc, spacing, n0);             \
+        g0 = 1;                                                                                    \
+      }                                                                                            \
+      self->ComputeSpacing(data, i2, j2, k2, exExt, spacing);                                      \
+      vtkRSTComputePointGradient(i2, j2, k2, s, inExt, xInc, yInc, zInc, spacing, n1);             \
+      for (jj = 0; jj < 3; jj++)                                                                   \
+      {                                                                                            \
+        n[jj] = n0[jj] + t * (n1[jj] - n0[jj]);                                                    \
+      }                                                                                            \
+      if (ComputeGradients)                                                                        \
+      {                                                                                            \
+        newGradients->InsertNextTuple(n);                                                          \
+      }                                                                                            \
+      if (ComputeNormals)                                                                          \
+      {                                                                                            \
+        vtkMath::Normalize(n);                                                                     \
+        n[0] = -n[0];                                                                              \
+        n[1] = -n[1];                                                                              \
+        n[2] = -n[2];                                                                              \
+        newNormals->InsertNextTuple(n);                                                            \
+      }                                                                                            \
     }                                                                                              \
-    self->ComputeSpacing(data, i2, j2, k2, exExt, spacing);                                        \
-    vtkRSTComputePointGradient(i2, j2, k2, s, inExt, xInc, yInc, zInc, spacing, n1);               \
-    for (jj = 0; jj < 3; jj++)                                                                     \
+    if (ComputeScalars)                                                                            \
     {                                                                                              \
-      n[jj] = n0[jj] + t * (n1[jj] - n0[jj]);                                                      \
+      newScalars->InsertNextTuple(&value);                                                         \
     }                                                                                              \
-    if (ComputeGradients)                                                                          \
-    {                                                                                              \
-      newGradients->InsertNextTuple(n);                                                            \
-    }                                                                                              \
-    if (ComputeNormals)                                                                            \
-    {                                                                                              \
-      vtkMath::Normalize(n);                                                                       \
-      n[0] = -n[0];                                                                                \
-      n[1] = -n[1];                                                                                \
-      n[2] = -n[2];                                                                                \
-      newNormals->InsertNextTuple(n);                                                              \
-    }                                                                                              \
-  }                                                                                                \
-  if (ComputeScalars)                                                                              \
-  {                                                                                                \
-    newScalars->InsertNextTuple(&value);                                                           \
-  }
+  } while (false)
 
 //------------------------------------------------------------------------------
 //
@@ -299,6 +303,7 @@ void ContourRectilinearGrid(vtkRectilinearSynchronizedTemplates* self, int* exEx
   double spacing[6];
   vtkPolygonBuilder polyBuilder;
   vtkSmartPointer<vtkIdListCollection> polys = vtkSmartPointer<vtkIdListCollection>::New();
+  bool abort = false;
 
   if (ComputeScalars)
   {
@@ -364,7 +369,7 @@ void ContourRectilinearGrid(vtkRectilinearSynchronizedTemplates* self, int* exEx
   }
 
   // for each contour
-  for (vidx = 0; vidx < numContours; vidx++)
+  for (vidx = 0; vidx < numContours && !abort; vidx++)
   {
     value = values[vidx];
     inPtrZ = ptr;
@@ -375,6 +380,11 @@ void ContourRectilinearGrid(vtkRectilinearSynchronizedTemplates* self, int* exEx
     {
       self->UpdateProgress(
         (double)vidx / numContours + (k - zMin) / ((zMax - zMin + 1.0) * numContours));
+      if (self->CheckAbort())
+      {
+        abort = true;
+        break;
+      }
 
       z = zCoords->GetComponent(k - inExt[4], 0);
       x[2] = z;
@@ -858,3 +868,4 @@ void vtkRectilinearSynchronizedTemplates::PrintSelf(ostream& os, vtkIndent inden
   os << indent << "Compute Scalars: " << (this->ComputeScalars ? "On\n" : "Off\n");
   os << indent << "ArrayComponent: " << this->ArrayComponent << endl;
 }
+VTK_ABI_NAMESPACE_END
