@@ -22,8 +22,15 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStructuredGridOutlineFilter);
 
+//------------------------------------------------------------------------------
+void vtkStructuredGridOutlineFilter::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 // ComputeDivisionExtents has done most of the work for us.
 // Now just connect the points.
@@ -82,6 +89,10 @@ int vtkStructuredGridOutlineFilter::RequestData(vtkInformation* vtkNotUsed(reque
 
   for (i = 0; i < 12; i++)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     // Find the start of this edge, the length of this edge, and increment.
     xInc = 1;
     yInc = ext[1] - ext[0] + 1;
@@ -252,3 +263,4 @@ int vtkStructuredGridOutlineFilter::FillInputPortInformation(int, vtkInformation
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkStructuredGrid");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
