@@ -49,20 +49,22 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSCORE_EXPORT vtkTubeBender : public vtkPolyDataAlgorithm
 {
 public:
   static vtkTubeBender* New();
   // Generating VTK hierarchical class relationship
   vtkTypeMacro(vtkTubeBender, vtkPolyDataAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set the minimum tube radius (minimum because the tube radius may vary).
    */
   vtkSetClampMacro(Radius, double, 0.0, VTK_DOUBLE_MAX);
   vtkGetMacro(Radius, double);
-  //@}
+  ///@}
 
 protected:
   vtkTubeBender();
@@ -70,14 +72,14 @@ protected:
 
   double Radius;
 
-private:
-  vtkTubeBender(const vtkTubeBender&);  // Not implemented.
-  void operator=(const vtkTubeBender&); // Not implemented.
+public:
+  vtkTubeBender(const vtkTubeBender&) = delete;  // Not implemented.
+  void operator=(const vtkTubeBender&) = delete; // Not implemented.
 
 protected:
   int RequestData(vtkInformation* request, vtkInformationVector** inputVector,
     vtkInformationVector* outputVector) override;
-  void PrintSelf(ostream& os, vtkIndent indent) override;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkTubeBender_h
