@@ -27,6 +27,7 @@
 
 #include <algorithm>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTubeFilter);
 
 // Construct object with radius 0.5, radius variation turned off, the number
@@ -118,7 +119,7 @@ int vtkTubeFilter::RequestData(vtkInformation* vtkNotUsed(request),
   const vtkIdType* ptsOrig = nullptr;
   vtkIdType offset = 0;
   vtkFloatArray* newTCoords = nullptr;
-  int abort = 0;
+  bool abort = false;
   vtkIdType inCellId;
   double oldRadius = 1.0;
 
@@ -200,7 +201,7 @@ int vtkTubeFilter::RequestData(vtkInformation* vtkNotUsed(request),
   //
   if (inScalars)
   {
-    inScalars->GetRange(range, 0);
+    pd->GetRange(inScalars->GetName(), range, 0);
     if ((range[1] - range[0]) == 0.0)
     {
       if (this->VaryRadius == VTK_VARY_RADIUS_BY_SCALAR)
@@ -241,9 +242,9 @@ int vtkTubeFilter::RequestData(vtkInformation* vtkNotUsed(request),
   for (inLines->InitTraversal(); inLines->GetNextCell(npts, ptsOrig) && !abort; inCellId++)
   {
     this->UpdateProgress((double)inCellId / numLines);
-    abort = this->GetAbortExecute();
+    abort = this->CheckAbort();
 
-    // Make a copy of point indices to avoid modfiying input polydata cells
+    // Make a copy of point indices to avoid modifying input polydata cells
     // while removing degenerate lines.
     if (npts < 2)
     {
@@ -265,7 +266,7 @@ int vtkTubeFilter::RequestData(vtkInformation* vtkNotUsed(request),
     {
       singlePolyline->Reset(); // avoid instantiation
       singlePolyline->InsertNextCell(npts, pts);
-      lineNormalGenerator->GenerateSlidingNormals(inPts, singlePolyline, inNormals);
+      vtkPolyLine::GenerateSlidingNormals(inPts, singlePolyline, inNormals);
     }
 
     // Generate the points around the polyline. The tube is not stripped
@@ -844,3 +845,4 @@ void vtkTubeFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Texture Length: " << this->TextureLength << endl;
   os << indent << "Output Points Precision: " << this->OutputPointsPrecision << endl;
 }
+VTK_ABI_NAMESPACE_END
