@@ -26,7 +26,9 @@
 #include "vtkPoints.h"
 #include "vtkUnstructuredGrid.h"
 #include <map>
+#include <utility>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkUnstructuredGridQuadricDecimationEdge;
 class vtkUnstructuredGridQuadricDecimationFace;
 class vtkUnstructuredGridQuadricDecimationFaceHash;
@@ -41,16 +43,6 @@ class vtkUnstructuredGridQuadricDecimationTetMesh;
 // floating point epsilons
 #define VTK_FEPS 1e-6
 #define VTK_TEPS 1e-6
-#define VTK_SWAP(a, b, type)                                                                       \
-  {                                                                                                \
-    type t = a;                                                                                    \
-    a = b;                                                                                         \
-    b = t;                                                                                         \
-  }
-#define VTK_PRECHECK(pointer)                                                                      \
-  if (pointer)                                                                                     \
-    delete[](pointer);                                                                             \
-  (pointer)
 
 // =============================================================================
 // Vector 4 class
@@ -173,7 +165,7 @@ public:
 // =============================================================================
 // Symmetric 4x4 Matrix class
 // Storing lower half
-#define SM4op(i, OP) result.values[i] = values[i] OP m.values[i];
+#define SM4op(i, OP) result.values[i] = values[i] OP m.values[i]
 
 class vtkUnstructuredGridQuadricDecimationSymMat4
 {
@@ -557,17 +549,17 @@ public:
   {
     if (Verts[1] < Verts[0] && Verts[1] < Verts[2])
     {
-      VTK_SWAP(Verts[0], Verts[1], vtkUnstructuredGridQuadricDecimationVertex*);
+      std::swap(Verts[0], Verts[1]);
     }
 
     if (Verts[2] < Verts[0] && Verts[2] < Verts[1])
     {
-      VTK_SWAP(Verts[0], Verts[2], vtkUnstructuredGridQuadricDecimationVertex*);
+      std::swap(Verts[0], Verts[2]);
     }
 
     if (Verts[2] < Verts[1])
     {
-      VTK_SWAP(Verts[1], Verts[2], vtkUnstructuredGridQuadricDecimationVertex*);
+      std::swap(Verts[1], Verts[2]);
     }
   }
 
@@ -895,7 +887,7 @@ public:
     return Verts[0] == v || Verts[1] == v || Verts[2] == v || Verts[3] == v;
   }
 
-  // check to see if we can change fromV to toV without changing the orietation
+  // check to see if we can change fromV to toV without changing the orientation
   bool Changeable(vtkUnstructuredGridQuadricDecimationVertex* fromV,
     const vtkUnstructuredGridQuadricDecimationVec4& v4)
   {
@@ -965,11 +957,11 @@ void vtkUnstructuredGridQuadricDecimationTetra::FixOrientation()
 {
   if (Orientation() < 0)
   {
-    VTK_SWAP(Verts[2], Verts[3], vtkUnstructuredGridQuadricDecimationVertex*);
+    std::swap(Verts[2], Verts[3]);
   }
   if (Orientation() < 0)
   {
-    VTK_SWAP(Verts[1], Verts[2], vtkUnstructuredGridQuadricDecimationVertex*);
+    std::swap(Verts[1], Verts[2]);
   }
 }
 
@@ -1085,6 +1077,7 @@ public:
   float doublingRatio;
   bool noDoubling;
   float boundaryWeight;
+  vtkUnstructuredGridQuadricDecimation* filter;
   void BuildFullMesh();
   int Simplify(int n, int desiredTets);
 
@@ -1157,10 +1150,14 @@ void vtkUnstructuredGridQuadricDecimationTetMesh::AddCorner(
 // Clean the mesh
 void vtkUnstructuredGridQuadricDecimationTetMesh::clear()
 {
-  VTK_PRECHECK(Verts) = nullptr;
-  VTK_PRECHECK(tets) = nullptr;
-  VTK_PRECHECK(PT) = nullptr;
-  VTK_PRECHECK(L) = nullptr;
+  delete this->Verts;
+  this->Verts = nullptr;
+  delete this->tets;
+  this->tets = nullptr;
+  delete this->PT;
+  this->PT = nullptr;
+  delete this->L;
+  this->L = nullptr;
   faces.clear();
   unusedTets = 0;
   unusedVerts = 0;
@@ -1176,6 +1173,10 @@ void vtkUnstructuredGridQuadricDecimationTetMesh::BuildFullMesh()
   vtkUnstructuredGridQuadricDecimationFaceHashMap::iterator fi = faces.begin();
   while (fi != faces.end())
   {
+    if (this->filter->CheckAbort())
+    {
+      break;
+    }
     vtkUnstructuredGridQuadricDecimationFace* f = (*fi).second;
     f->UpdateQuadric(boundaryWeight);
     ++fi;
@@ -1257,6 +1258,10 @@ int vtkUnstructuredGridQuadricDecimationTetMesh::Simplify(int n, int desiredTets
   int run = 0;
   while ((count < n || desiredTets < (tCount - unusedTets)) && (run < 1000))
   {
+    if (this->filter->CheckAbort())
+    {
+      break;
+    }
     // as long as we want to collapse
     vtkUnstructuredGridQuadricDecimationQEF Q;
     vtkUnstructuredGridQuadricDecimationEdge e;
@@ -1377,7 +1382,8 @@ int vtkUnstructuredGridQuadricDecimationTetMesh::LoadUnstructuredGrid(
   clear();
   // Read all the vertices first
   vCount = vgrid->GetNumberOfPoints();
-  VTK_PRECHECK(Verts) = new vtkUnstructuredGridQuadricDecimationVertex[vCount];
+  delete this->Verts;
+  this->Verts = new vtkUnstructuredGridQuadricDecimationVertex[vCount];
   vtkPoints* vp = vgrid->GetPoints();
   vtkDataArray* vs = nullptr;
   if (scalarsName)
@@ -1413,9 +1419,12 @@ int vtkUnstructuredGridQuadricDecimationTetMesh::LoadUnstructuredGrid(
     return vtkUnstructuredGridQuadricDecimation::NO_CELLS;
   }
   maxTet = tCount;
-  VTK_PRECHECK(tets) = new vtkUnstructuredGridQuadricDecimationTetra[tCount];
-  VTK_PRECHECK(PT) = new vtkUnstructuredGridQuadricDecimationTetra*[tCount];
-  VTK_PRECHECK(L) = new int[4 * tCount];
+  delete this->tets;
+  this->tets = new vtkUnstructuredGridQuadricDecimationTetra[tCount];
+  delete this->PT;
+  this->PT = new vtkUnstructuredGridQuadricDecimationTetra*[tCount];
+  delete this->L;
+  this->L = new int[4 * tCount];
   vtkCellArray* vt = vgrid->GetCells();
   vtkIdType npts;
   const vtkIdType* idx;
@@ -1500,10 +1509,8 @@ int vtkUnstructuredGridQuadricDecimationTetMesh::SaveUnstructuredGrid(vtkUnstruc
   return vtkUnstructuredGridQuadricDecimation::NON_ERROR;
 }
 
-#undef VTK_PRECHECK
 #undef VTK_FEPS
 #undef VTK_TEPS
-#undef VTK_SWAP
 
 ////////////////////////////////////////////////////////////////////////////////
 /* ========================================================================== */
@@ -1579,6 +1586,7 @@ int vtkUnstructuredGridQuadricDecimation::RequestData(vtkInformation* vtkNotUsed
   myMesh.doublingRatio = this->AutoAddCandidatesThreshold;
   myMesh.noDoubling = !this->AutoAddCandidates;
   myMesh.boundaryWeight = this->BoundaryWeight;
+  myMesh.filter = this;
   int err = myMesh.LoadUnstructuredGrid((vtkUnstructuredGrid*)(input), this->ScalarsName);
   if (err != vtkUnstructuredGridQuadricDecimation::NON_ERROR)
   {
@@ -1597,3 +1605,4 @@ int vtkUnstructuredGridQuadricDecimation::RequestData(vtkInformation* vtkNotUsed
   myMesh.SaveUnstructuredGrid(output);
   return 1;
 }
+VTK_ABI_NAMESPACE_END
