@@ -26,8 +26,18 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkUnstructuredGridToExplicitStructuredGrid);
 
+//------------------------------------------------------------------------------
+void vtkUnstructuredGridToExplicitStructuredGrid::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "WholeExtent: (" << this->WholeExtent[0] << ", " << this->WholeExtent[1] << ", "
+     << this->WholeExtent[2] << ", " << this->WholeExtent[3] << ", " << this->WholeExtent[4] << ", "
+     << this->WholeExtent[5] << ")\n";
+}
+
 //------------------------------------------------------------------------------
 vtkUnstructuredGridToExplicitStructuredGrid::vtkUnstructuredGridToExplicitStructuredGrid()
 {
@@ -115,14 +125,14 @@ int vtkUnstructuredGridToExplicitStructuredGrid::RequestData(
   {
     for (vtkIdType i = 0; i < expectedCells; i++)
     {
-      output->GetCellData()->CopyData(input->GetCellData(), 0, i);
+      output->GetCellData()->CopyData(input->GetCellData(), vtkIdType(0), i);
       // Blank after copying the cell data to ensure it is not overwritten
       output->BlankCell(i);
     }
   }
 
   int progressCount = 0;
-  int abort = 0;
+  bool abort = false;
   vtkIdType progressInterval = nbCells / 20 + 1;
 
   // Copy unstructured cells
@@ -133,7 +143,7 @@ int vtkUnstructuredGridToExplicitStructuredGrid::RequestData(
     {
       vtkDebugMacro("Process cell #" << i);
       this->UpdateProgress(static_cast<double>(i) / nbCells);
-      abort = this->GetAbortExecute();
+      abort = this->CheckAbort();
       progressCount = 0;
     }
     progressCount++;
@@ -204,3 +214,4 @@ int vtkUnstructuredGridToExplicitStructuredGrid::FillInputPortInformation(
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkUnstructuredGrid");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
