@@ -21,14 +21,13 @@
 #include "vtkCellData.h"
 #include "vtkCommand.h"
 #include "vtkCompositeDataSet.h"
+#include "vtkDataAssembly.h"
+#include "vtkDataAssemblyUtilities.h"
 #include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
-#include "vtkExtractSelectedThresholds.h"
 #include "vtkExtractSelection.h"
 #include "vtkFieldData.h"
 #include "vtkGraph.h"
-#include "vtkHierarchicalBoxDataIterator.h"
-#include "vtkHierarchicalBoxDataSet.h"
 #include "vtkIdList.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
@@ -41,7 +40,10 @@
 #include "vtkSmartPointer.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
+#include "vtkUniformGridAMR.h"
+#include "vtkUniformGridAMRDataIterator.h"
 #include "vtkUnsignedIntArray.h"
+#include "vtkValueSelector.h"
 #include "vtkVariantArray.h"
 
 #include <algorithm>
@@ -50,12 +52,13 @@
 #include <set>
 #include <vector>
 
-#define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkConvertSelection, ArrayNames, vtkStringArray);
 vtkCxxSetObjectMacro(vtkConvertSelection, SelectionExtractor, vtkExtractSelection);
 
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkConvertSelection);
+
 //------------------------------------------------------------------------------
 vtkConvertSelection::vtkConvertSelection()
 {
@@ -110,7 +113,7 @@ const char* vtkConvertSelection::GetArrayName()
 {
   if (this->ArrayNames && this->ArrayNames->GetNumberOfValues() > 0)
   {
-    return this->ArrayNames->GetValue(0);
+    return this->ArrayNames->GetValue(0).c_str();
   }
   return nullptr;
 }
@@ -120,7 +123,7 @@ int vtkConvertSelection::SelectTableFromTable(
   vtkTable* selTable, vtkTable* dataTable, vtkIdTypeArray* indices)
 {
   std::set<vtkIdType> matching;
-  VTK_CREATE(vtkIdList, list);
+  vtkNew<vtkIdList> list;
   for (vtkIdType row = 0; row < selTable->GetNumberOfRows(); row++)
   {
     matching.clear();
@@ -148,10 +151,9 @@ int vtkConvertSelection::SelectTableFromTable(
         }
       }
     }
-    std::set<vtkIdType>::iterator it, itEnd = matching.end();
-    for (it = matching.begin(); it != itEnd; ++it)
+    for (const auto& match : matching)
     {
-      indices->InsertNextValue(*it);
+      indices->InsertNextValue(match);
     }
     if (row % 100 == 0)
     {
@@ -166,7 +168,7 @@ int vtkConvertSelection::SelectTableFromTable(
 int vtkConvertSelection::ConvertToIndexSelection(
   vtkSelectionNode* input, vtkDataSet* data, vtkSelectionNode* output)
 {
-  vtkSmartPointer<vtkSelection> tempInput = vtkSmartPointer<vtkSelection>::New();
+  vtkNew<vtkSelection> tempInput;
   tempInput->AddNode(input);
 
   // Use the extraction filter to create an insidedness array.
@@ -204,7 +206,7 @@ int vtkConvertSelection::ConvertToIndexSelection(
   }
 
   // Convert the insidedness array into an index input.
-  vtkSmartPointer<vtkIdTypeArray> indexArray = vtkSmartPointer<vtkIdTypeArray>::New();
+  vtkNew<vtkIdTypeArray> indexArray;
   for (vtkIdType i = 0; i < insidedness->GetNumberOfTuples(); i++)
   {
     if (insidedness->GetValue(i) == 1)
@@ -221,20 +223,31 @@ int vtkConvertSelection::ConvertToBlockSelection(
   vtkSelection* input, vtkCompositeDataSet* data, vtkSelection* output)
 {
   std::set<unsigned int> indices;
+  int fieldType = -1;
   for (unsigned int n = 0; n < input->GetNumberOfNodes(); ++n)
   {
     vtkSmartPointer<vtkSelectionNode> inputNode = input->GetNode(n);
+
+    // if node has no items in the selection list, it's a clear indication that
+    // nothing is selected and the node should simply be ignored.
+    if (inputNode->GetSelectionList() == nullptr ||
+      inputNode->GetSelectionList()->GetNumberOfTuples() == 0)
+    {
+      continue;
+    }
+
     if (inputNode->GetContentType() == vtkSelectionNode::GLOBALIDS)
     {
       // global id selection does not have COMPOSITE_INDEX() key, so we convert
       // it to an index base selection, so that we can determine the composite
       // indices.
-      vtkSmartPointer<vtkSelection> tempSel = vtkSmartPointer<vtkSelection>::New();
+      vtkNew<vtkSelection> tempSel;
       tempSel->AddNode(inputNode);
       vtkSmartPointer<vtkSelection> tempOutput;
       tempOutput.TakeReference(vtkConvertSelection::ToIndexSelection(tempSel, data));
       inputNode = tempOutput->GetNode(0);
     }
+
     vtkInformation* properties = inputNode->GetProperties();
     if (properties->Has(vtkSelectionNode::CONTENT_TYPE()) &&
       properties->Has(vtkSelectionNode::COMPOSITE_INDEX()))
@@ -244,28 +257,63 @@ int vtkConvertSelection::ConvertToBlockSelection(
     }
     else if (properties->Has(vtkSelectionNode::CONTENT_TYPE()) &&
       properties->Has(vtkSelectionNode::HIERARCHICAL_INDEX()) &&
-      properties->Has(vtkSelectionNode::HIERARCHICAL_LEVEL()) &&
-      data->IsA("vtkHierarchicalBoxDataSet"))
+      properties->Has(vtkSelectionNode::HIERARCHICAL_LEVEL()) && data->IsA("vtkUniformGridAMR"))
     {
       // convert hierarchical index to composite index.
-      vtkHierarchicalBoxDataSet* hbox = static_cast<vtkHierarchicalBoxDataSet*>(data);
+      vtkUniformGridAMR* hbox = vtkUniformGridAMR::SafeDownCast(data);
       indices.insert(hbox->GetCompositeIndex(
         static_cast<unsigned int>(properties->Get(vtkSelectionNode::HIERARCHICAL_LEVEL())),
         static_cast<unsigned int>(properties->Get(vtkSelectionNode::HIERARCHICAL_INDEX()))));
     }
+
+    // save field type. I am just picking the first one for now.
+    fieldType = fieldType == -1 ? inputNode->GetFieldType() : fieldType;
   }
 
-  vtkSmartPointer<vtkUnsignedIntArray> selectionList = vtkSmartPointer<vtkUnsignedIntArray>::New();
-  selectionList->SetNumberOfTuples(static_cast<vtkIdType>(indices.size()));
-  std::set<unsigned int>::iterator siter;
-  vtkIdType index = 0;
-  for (siter = indices.begin(); siter != indices.end(); ++siter, ++index)
+  if (indices.empty())
   {
-    selectionList->SetValue(index, *siter);
+    // nothing to convert, or converted to empty selection.
+    return 1;
   }
-  vtkSmartPointer<vtkSelectionNode> outputNode = vtkSmartPointer<vtkSelectionNode>::New();
-  outputNode->SetContentType(vtkSelectionNode::BLOCKS);
-  outputNode->SetSelectionList(selectionList);
+
+  vtkNew<vtkSelectionNode> outputNode;
+  outputNode->SetFieldType(fieldType);
+  if (this->OutputType == vtkSelectionNode::BLOCKS)
+  {
+    vtkNew<vtkUnsignedIntArray> selectionList;
+    selectionList->SetNumberOfTuples(static_cast<vtkIdType>(indices.size()));
+    vtkIdType cc = 0;
+    for (const auto& id : indices)
+    {
+      selectionList->SetValue(cc++, id);
+    }
+    outputNode->SetContentType(vtkSelectionNode::BLOCKS);
+    outputNode->SetSelectionList(selectionList);
+  }
+  else if (this->OutputType == vtkSelectionNode::BLOCK_SELECTORS)
+  {
+    // convert ids to selectors.
+    std::vector<unsigned int> vIndices(indices.size());
+    std::copy(indices.begin(), indices.end(), vIndices.begin());
+
+    auto hierarchy =
+      vtkDataAssemblyUtilities::GetDataAssembly(vtkDataAssemblyUtilities::HierarchyName(), data);
+    const auto selectors =
+      vtkDataAssemblyUtilities::GetSelectorsForCompositeIds(vIndices, hierarchy);
+
+    vtkNew<vtkStringArray> selectionList;
+    selectionList->SetName(vtkDataAssemblyUtilities::HierarchyName());
+    selectionList->SetNumberOfTuples(selectors.size());
+    vtkIdType cc = 0;
+    for (const auto& name : selectors)
+    {
+      selectionList->SetValue(cc++, name);
+    }
+    outputNode->SetContentType(vtkSelectionNode::BLOCK_SELECTORS);
+    outputNode->SetSelectionList(selectionList);
+  }
+
+  outputNode->SetFieldType(fieldType);
   output->AddNode(outputNode);
   return 1;
 }
@@ -274,9 +322,10 @@ int vtkConvertSelection::ConvertToBlockSelection(
 int vtkConvertSelection::ConvertCompositeDataSet(
   vtkSelection* input, vtkCompositeDataSet* data, vtkSelection* output)
 {
-  // If this->OutputType == vtkSelectionNode::BLOCKS we just want to create a new
+  // If OutputType is BLOCKS or BLOCK_SELECTORS we just want to create a new
   // selection with the chosen block indices.
-  if (this->OutputType == vtkSelectionNode::BLOCKS)
+  if (this->OutputType == vtkSelectionNode::BLOCKS ||
+    this->OutputType == vtkSelectionNode::BLOCK_SELECTORS)
   {
     return this->ConvertToBlockSelection(input, data, output);
   }
@@ -313,23 +362,25 @@ int vtkConvertSelection::ConvertCompositeDataSet(
       : 0;
 
     if ((!has_composite_key && !has_hierarchical_key) &&
-      inputNode->GetContentType() == vtkSelectionNode::QUERY &&
+      (inputNode->GetContentType() == vtkSelectionNode::BLOCKS ||
+        inputNode->GetContentType() == vtkSelectionNode::BLOCK_SELECTORS ||
+        inputNode->GetContentType() == vtkSelectionNode::QUERY) &&
       this->OutputType == vtkSelectionNode::INDICES)
     {
-      this->ConvertFromQueryNodeCompositeDataSet(inputNode, data, output);
+      this->ConvertFromQueryAndBlockSelectionNodeCompositeDataSet(inputNode, data, output);
       continue;
     }
 
     vtkSmartPointer<vtkCompositeDataIterator> iter;
     iter.TakeReference(data->NewIterator());
 
-    vtkHierarchicalBoxDataIterator* hbIter = vtkHierarchicalBoxDataIterator::SafeDownCast(iter);
+    vtkUniformGridAMRDataIterator* hierIter = vtkUniformGridAMRDataIterator::SafeDownCast(iter);
 
     for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
     {
-      if (has_hierarchical_key && hbIter &&
-        (hbIter->GetCurrentLevel() != hierarchical_level ||
-          hbIter->GetCurrentIndex() != hierarchical_index))
+      if (has_hierarchical_key && hierIter &&
+        (hierIter->GetCurrentLevel() != hierarchical_level ||
+          hierIter->GetCurrentIndex() != hierarchical_index))
       {
         continue;
       }
@@ -339,8 +390,8 @@ int vtkConvertSelection::ConvertCompositeDataSet(
         continue;
       }
 
-      vtkSmartPointer<vtkSelection> outputNodes = vtkSmartPointer<vtkSelection>::New();
-      vtkSmartPointer<vtkSelection> tempSel = vtkSmartPointer<vtkSelection>::New();
+      vtkNew<vtkSelection> outputNodes;
+      vtkNew<vtkSelection> tempSel;
       tempSel->AddNode(inputNode);
       if (!this->Convert(tempSel, iter->GetCurrentDataObject(), outputNodes))
       {
@@ -359,7 +410,7 @@ int vtkConvertSelection::ConvertCompositeDataSet(
           outputNode->GetProperties()->Set(
             vtkSelectionNode::COMPOSITE_INDEX(), iter->GetCurrentFlatIndex());
 
-          if (has_hierarchical_key && hbIter)
+          if (has_hierarchical_key && hierIter)
           {
             outputNode->GetProperties()->Set(
               vtkSelectionNode::HIERARCHICAL_LEVEL(), hierarchical_level);
@@ -376,11 +427,11 @@ int vtkConvertSelection::ConvertCompositeDataSet(
 }
 
 //------------------------------------------------------------------------------
-int vtkConvertSelection::ConvertFromQueryNodeCompositeDataSet(
+int vtkConvertSelection::ConvertFromQueryAndBlockSelectionNodeCompositeDataSet(
   vtkSelectionNode* inputNode, vtkCompositeDataSet* data, vtkSelection* output)
 {
-  // QUERY selection types with composite data input need special handling.
-  // The query can apply to a composite dataset, so we extract the selection
+  // QUERY/block/block_selectors selection types with composite data input need special handling.
+  // The query/block/block_selectors can apply to a composite dataset, so we extract the selection
   // on the entire dataset here and convert it to an index selection.
   vtkNew<vtkSelection> tempSelection;
   tempSelection->AddNode(inputNode);
@@ -390,14 +441,12 @@ int vtkConvertSelection::ConvertFromQueryNodeCompositeDataSet(
   extract->SetInputData(1, tempSelection);
   extract->Update();
 
-  vtkDataObject* extracted = extract->GetOutput();
-  vtkCompositeDataSet* cds = vtkCompositeDataSet::SafeDownCast(extracted);
-  if (cds)
+  if (auto cds = vtkCompositeDataSet::SafeDownCast(extract->GetOutput()))
   {
     vtkSmartPointer<vtkCompositeDataIterator> iter;
     iter.TakeReference(cds->NewIterator());
 
-    vtkHierarchicalBoxDataIterator* hbIter = vtkHierarchicalBoxDataIterator::SafeDownCast(iter);
+    vtkUniformGridAMRDataIterator* hierIter = vtkUniformGridAMRDataIterator::SafeDownCast(iter);
 
     for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
     {
@@ -415,10 +464,10 @@ int vtkConvertSelection::ConvertFromQueryNodeCompositeDataSet(
       outputProperties->Set(vtkSelectionNode::INVERSE(), 0);
       outputProperties->Set(vtkSelectionNode::COMPOSITE_INDEX(), iter->GetCurrentFlatIndex());
 
-      if (hbIter)
+      if (hierIter)
       {
-        outputProperties->Set(vtkSelectionNode::HIERARCHICAL_LEVEL(), hbIter->GetCurrentLevel());
-        outputProperties->Set(vtkSelectionNode::HIERARCHICAL_INDEX(), hbIter->GetCurrentIndex());
+        outputProperties->Set(vtkSelectionNode::HIERARCHICAL_LEVEL(), hierIter->GetCurrentLevel());
+        outputProperties->Set(vtkSelectionNode::HIERARCHICAL_INDEX(), hierIter->GetCurrentIndex());
       }
 
       // Create a list of ids to select
@@ -466,8 +515,12 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
 {
   for (unsigned int n = 0; n < input->GetNumberOfNodes(); ++n)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkSelectionNode* inputNode = input->GetNode(n);
-    vtkSmartPointer<vtkSelectionNode> outputNode = vtkSmartPointer<vtkSelectionNode>::New();
+    vtkNew<vtkSelectionNode> outputNode;
 
     outputNode->ShallowCopy(inputNode);
     outputNode->SetContentType(this->OutputType);
@@ -524,7 +577,7 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
       vtkFieldData* selData = inputNode->GetSelectionData();
       for (int i = 0; i < selData->GetNumberOfArrays(); i++)
       {
-        if (strcmp(selData->GetAbstractArray(i)->GetName(), this->ArrayNames->GetValue(i)) != 0)
+        if (selData->GetAbstractArray(i)->GetName() != this->ArrayNames->GetValue(i))
         {
           same = false;
           break;
@@ -618,11 +671,9 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
       }
     }
 
-    //
     // First, convert the selection to a list of indices
-    //
 
-    vtkSmartPointer<vtkIdTypeArray> indices = vtkSmartPointer<vtkIdTypeArray>::New();
+    vtkNew<vtkIdTypeArray> indices;
 
     if (inputNode->GetContentType() == vtkSelectionNode::FRUSTUM ||
       inputNode->GetContentType() == vtkSelectionNode::LOCATIONS ||
@@ -635,7 +686,7 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
         return 0;
       }
       // Use the extract selection filter to create an index selection
-      vtkSmartPointer<vtkSelectionNode> indexNode = vtkSmartPointer<vtkSelectionNode>::New();
+      vtkNew<vtkSelectionNode> indexNode;
       this->ConvertToIndexSelection(inputNode, vtkDataSet::SafeDownCast(data), indexNode);
       // TODO: We should shallow copy this, but the method is not defined.
       indices->DeepCopy(indexNode->GetSelectionList());
@@ -669,10 +720,20 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
           return 1;
         }
       }
+      // create insidenessArray
+      vtkNew<vtkSignedCharArray> insidednessArray;
+      insidednessArray->SetName(lims->GetName());
+      insidednessArray->SetNumberOfComponents(1);
+      insidednessArray->SetNumberOfTuples(dataArr->GetNumberOfTuples());
+      // create selector
+      vtkNew<vtkValueSelector> valueSelector;
+      valueSelector->SetInsidednessArrayName(lims->GetName());
+      valueSelector->Initialize(inputNode);
+      valueSelector->ComputeSelectedElements(data, insidednessArray);
+      valueSelector->Finalize();
       for (vtkIdType id = 0; id < dataArr->GetNumberOfTuples(); id++)
       {
-        int keepPoint = vtkExtractSelectedThresholds::EvaluateValue(dataArr, id, lims);
-        if (keepPoint)
+        if (insidednessArray->GetValue(id) == 1)
         {
           indices->InsertNextValue(id);
         }
@@ -686,9 +747,9 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
     else if (inputNode->GetContentType() == vtkSelectionNode::VALUES)
     {
       vtkFieldData* selData = inputNode->GetSelectionData();
-      vtkSmartPointer<vtkTable> selTable = vtkSmartPointer<vtkTable>::New();
+      vtkNew<vtkTable> selTable;
       selTable->GetRowData()->ShallowCopy(selData);
-      vtkSmartPointer<vtkTable> dataTable = vtkSmartPointer<vtkTable>::New();
+      vtkNew<vtkTable> dataTable;
       for (vtkIdType col = 0; col < selTable->GetNumberOfColumns(); col++)
       {
         vtkAbstractArray* dataArr = nullptr;
@@ -757,9 +818,9 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
         selArr->GetName())
       {
         // Perform the lookup, keeping only those items in the correct domain.
-        vtkStdString domain = selArr->GetName();
+        std::string domain = selArr->GetName();
         vtkIdType numTuples = selArr->GetNumberOfTuples();
-        vtkSmartPointer<vtkIdList> list = vtkSmartPointer<vtkIdList>::New();
+        vtkNew<vtkIdList> list;
         for (vtkIdType i = 0; i < numTuples; i++)
         {
           dataArr->LookupValue(selArr->GetVariantValue(i), list);
@@ -780,7 +841,7 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
       {
         // Perform the lookup
         vtkIdType numTuples = selArr->GetNumberOfTuples();
-        vtkSmartPointer<vtkIdList> list = vtkSmartPointer<vtkIdList>::New();
+        vtkNew<vtkIdList> list;
         for (vtkIdType i = 0; i < numTuples; i++)
         {
           dataArr->LookupValue(selArr->GetVariantValue(i), list);
@@ -796,10 +857,8 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
     double progress = 0.8;
     this->InvokeEvent(vtkCommand::ProgressEvent, &progress);
 
-    //
     // Now that we have the list of indices, convert the selection by indexing
     // values in another array.
-    //
 
     // If it is an index selection, we are done.
     if (this->OutputType == vtkSelectionNode::INDICES)
@@ -835,7 +894,7 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
         }
       }
 
-      std::map<vtkStdString, vtkSmartPointer<vtkAbstractArray>> domainArrays;
+      std::map<std::string, vtkSmartPointer<vtkAbstractArray>> domainArrays;
       vtkIdType numTuples = outputDataArr->GetNumberOfTuples();
       vtkIdType numIndices = indices->GetNumberOfTuples();
       for (vtkIdType i = 0; i < numIndices; ++i)
@@ -845,12 +904,12 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
         {
           continue;
         }
-        vtkStdString domain = outputDomainArr->GetValue(index);
+        std::string domain = outputDomainArr->GetValue(index);
         if (domainArrays.count(domain) == 0)
         {
           domainArrays[domain].TakeReference(
             vtkAbstractArray::CreateArray(outputDataArr->GetDataType()));
-          domainArrays[domain]->SetName(domain);
+          domainArrays[domain]->SetName(domain.c_str());
         }
         vtkAbstractArray* domainArr = domainArrays[domain];
         domainArr->InsertNextTuple(index, outputDataArr);
@@ -860,32 +919,29 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
           this->InvokeEvent(vtkCommand::ProgressEvent, &progress);
         }
       }
-      std::map<vtkStdString, vtkSmartPointer<vtkAbstractArray>>::iterator it, itEnd;
-      it = domainArrays.begin();
-      itEnd = domainArrays.end();
-      for (; it != itEnd; ++it)
+      for (auto& domainArray : domainArrays)
       {
-        vtkSmartPointer<vtkSelectionNode> node = vtkSmartPointer<vtkSelectionNode>::New();
+        vtkNew<vtkSelectionNode> node;
         node->SetContentType(vtkSelectionNode::PEDIGREEIDS);
         node->SetFieldType(inputNode->GetFieldType());
-        node->SetSelectionList(it->second);
+        node->SetSelectionList(domainArray.second);
         output->Union(node);
       }
       continue;
     }
 
-    vtkSmartPointer<vtkDataSetAttributes> outputData = vtkSmartPointer<vtkDataSetAttributes>::New();
+    vtkNew<vtkDataSetAttributes> outputData;
     for (vtkIdType ind = 0; ind < numOutputArrays; ind++)
     {
       // Find the output array where to get the output selection values.
       vtkAbstractArray* outputDataArr = nullptr;
       if (dsa && this->OutputType == vtkSelectionNode::VALUES)
       {
-        outputDataArr = dsa->GetAbstractArray(this->ArrayNames->GetValue(ind));
+        outputDataArr = dsa->GetAbstractArray(this->ArrayNames->GetValue(ind).c_str());
       }
       else if (fd && this->OutputType == vtkSelectionNode::VALUES)
       {
-        outputDataArr = fd->GetAbstractArray(this->ArrayNames->GetValue(ind));
+        outputDataArr = fd->GetAbstractArray(this->ArrayNames->GetValue(ind).c_str());
       }
       else if (dsa && this->OutputType == vtkSelectionNode::PEDIGREEIDS)
       {
@@ -927,7 +983,7 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
 
         if (this->MatchAnyValues)
         {
-          vtkSmartPointer<vtkSelectionNode> outNode = vtkSmartPointer<vtkSelectionNode>::New();
+          vtkNew<vtkSelectionNode> outNode;
           outNode->ShallowCopy(inputNode);
           outNode->SetContentType(this->OutputType);
           outNode->SetSelectionList(outputArr);
@@ -946,7 +1002,7 @@ int vtkConvertSelection::Convert(vtkSelection* input, vtkDataObject* data, vtkSe
     // that the selection list is not null.
     if (outputData->GetNumberOfArrays() == 0)
     {
-      vtkSmartPointer<vtkIdTypeArray> arr = vtkSmartPointer<vtkIdTypeArray>::New();
+      vtkNew<vtkIdTypeArray> arr;
       arr->SetName("Empty");
       outputData->AddArray(arr);
     }
@@ -970,7 +1026,7 @@ int vtkConvertSelection::RequestData(vtkInformation* vtkNotUsed(request),
     this->SetSelectionExtractor(se);
   }
 
-  vtkSmartPointer<vtkSelection> input = vtkSmartPointer<vtkSelection>::New();
+  vtkNew<vtkSelection> input;
   input->ShallowCopy(origInput);
   if (this->InputFieldType != -1)
   {
@@ -987,7 +1043,7 @@ int vtkConvertSelection::RequestData(vtkInformation* vtkNotUsed(request),
   vtkSelection* output = vtkSelection::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
   if (data && data->IsA("vtkCompositeDataSet"))
   {
-    return this->ConvertCompositeDataSet(input, static_cast<vtkCompositeDataSet*>(data), output);
+    return this->ConvertCompositeDataSet(input, vtkCompositeDataSet::SafeDownCast(data), output);
   }
 
   return this->Convert(input, data, output);
@@ -1009,7 +1065,7 @@ int vtkConvertSelection::FillInputPortInformation(int port, vtkInformation* info
   }
   else if (port == 1)
   {
-    // Can convert from a vtkDataSet, vtkGraph, or vtkTable
+    // Can convert from a vtkCompositeDataSet, vtkDataSet, vtkGraph, or vtkTable
     info->Remove(vtkConvertSelection::INPUT_REQUIRED_DATA_TYPE());
     info->Append(vtkConvertSelection::INPUT_REQUIRED_DATA_TYPE(), "vtkCompositeDataSet");
     info->Append(vtkConvertSelection::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet");
@@ -1102,7 +1158,7 @@ vtkSelection* vtkConvertSelection::ToPedigreeIdSelection(vtkSelection* input, vt
 vtkSelection* vtkConvertSelection::ToValueSelection(
   vtkSelection* input, vtkDataObject* data, const char* arrayName)
 {
-  VTK_CREATE(vtkStringArray, names);
+  vtkNew<vtkStringArray> names;
   names->InsertNextValue(arrayName);
   return vtkConvertSelection::ToSelectionType(input, data, vtkSelectionNode::VALUES, names);
 }
@@ -1118,10 +1174,10 @@ vtkSelection* vtkConvertSelection::ToValueSelection(
 vtkSelection* vtkConvertSelection::ToSelectionType(vtkSelection* input, vtkDataObject* data,
   int type, vtkStringArray* arrayNames, int inputFieldType, bool allowMissingArray)
 {
-  VTK_CREATE(vtkConvertSelection, convert);
+  vtkNew<vtkConvertSelection> convert;
   vtkDataObject* dataCopy = data->NewInstance();
   dataCopy->ShallowCopy(data);
-  VTK_CREATE(vtkSelection, inputCopy);
+  vtkNew<vtkSelection> inputCopy;
   inputCopy->ShallowCopy(input);
   convert->SetInputData(0, inputCopy);
   convert->SetInputData(1, dataCopy);
@@ -1151,3 +1207,4 @@ void vtkConvertSelection::PrintSelf(ostream& os, vtkIndent indent)
     this->ArrayNames->PrintSelf(os, indent.GetNextIndent());
   }
 }
+VTK_ABI_NAMESPACE_END
