@@ -36,6 +36,7 @@
 #include "vtkFiltersExtractionModule.h" // For export macro
 #include "vtkSelectionAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataSet;
 class vtkGraph;
 class vtkIdTypeArray;
@@ -57,7 +58,7 @@ public:
    */
   void SetDataObjectConnection(vtkAlgorithmOutput* in);
 
-  //@{
+  ///@{
   /**
    * The input field type.
    * If this is set to a number other than -1, ignores the input selection
@@ -68,42 +69,42 @@ public:
    */
   vtkSetMacro(InputFieldType, int);
   vtkGetMacro(InputFieldType, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The output selection content type.
    * This should be one of the constants defined in vtkSelectionNode.h.
    */
   vtkSetMacro(OutputType, int);
   vtkGetMacro(OutputType, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The output array name for value or threshold selections.
    */
   virtual void SetArrayName(const char*);
   virtual const char* GetArrayName();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The output array names for value selection.
    */
   virtual void SetArrayNames(vtkStringArray*);
   vtkGetObjectMacro(ArrayNames, vtkStringArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convenience methods used by UI
    */
   void AddArrayName(const char*);
   void ClearArrayNames();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When on, creates a separate selection node for each array.
    * Defaults to OFF.
@@ -111,9 +112,9 @@ public:
   vtkSetMacro(MatchAnyValues, bool);
   vtkGetMacro(MatchAnyValues, bool);
   vtkBooleanMacro(MatchAnyValues, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When enabled, not finding expected array will not return an error.
    * Defaults to OFF.
@@ -121,18 +122,18 @@ public:
   vtkSetMacro(AllowMissingArray, bool);
   vtkGetMacro(AllowMissingArray, bool);
   vtkBooleanMacro(AllowMissingArray, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get a selection extractor used in some conversions to
    * obtain IDs.
    */
   virtual void SetSelectionExtractor(vtkExtractSelection*);
   vtkGetObjectMacro(SelectionExtractor, vtkExtractSelection);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Static methods for easily converting between selection types.
    * NOTE: The returned selection pointer IS reference counted,
@@ -145,7 +146,7 @@ public:
     vtkSelection* input, vtkDataObject* data, const char* arrayName);
   static vtkSelection* ToValueSelection(
     vtkSelection* input, vtkDataObject* data, vtkStringArray* arrayNames);
-  //@}
+  ///@}
 
   /**
    * Static generic method for obtaining selected items from a data object.
@@ -154,7 +155,7 @@ public:
   static void GetSelectedItems(
     vtkSelection* input, vtkDataObject* data, int fieldType, vtkIdTypeArray* indices);
 
-  //@{
+  ///@{
   /**
    * Static methods for easily obtaining selected items from a data object.
    * The array argument will be filled with the selected items.
@@ -164,7 +165,7 @@ public:
   static void GetSelectedPoints(vtkSelection* input, vtkDataSet* data, vtkIdTypeArray* indices);
   static void GetSelectedCells(vtkSelection* input, vtkDataSet* data, vtkIdTypeArray* indices);
   static void GetSelectedRows(vtkSelection* input, vtkTable* data, vtkIdTypeArray* indices);
-  //@}
+  ///@}
 
   /**
    * A generic static method for converting selection types.
@@ -183,7 +184,7 @@ protected:
 
   int ConvertCompositeDataSet(vtkSelection* input, vtkCompositeDataSet* data, vtkSelection* output);
 
-  int ConvertFromQueryNodeCompositeDataSet(
+  int ConvertFromQueryAndBlockSelectionNodeCompositeDataSet(
     vtkSelectionNode* input, vtkCompositeDataSet* data, vtkSelection* output);
 
   int ConvertToIndexSelection(vtkSelectionNode* input, vtkDataSet* data, vtkSelectionNode* output);
@@ -206,4 +207,5 @@ private:
   void operator=(const vtkConvertSelection&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
