@@ -37,6 +37,7 @@
 #include "vtkFiltersExtractionModule.h" // For export macro
 #include "vtkPassInputTypeAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController;
 
 class VTKFILTERSEXTRACTION_EXPORT vtkExpandMarkedElements : public vtkPassInputTypeAlgorithm
@@ -46,22 +47,44 @@ public:
   vtkTypeMacro(vtkExpandMarkedElements, vtkPassInputTypeAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the controller to use. By default, is initialized to
    * `vtkMultiProcessController::GetGlobalController` in the constructor.
    */
   void SetController(vtkMultiProcessController*);
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the number of layers to expand by.
+   * Default is 2.
    */
   vtkSetClampMacro(NumberOfLayers, int, 1, VTK_INT_MAX);
   vtkGetMacro(NumberOfLayers, int);
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * Get/Set the flag to remove seed of marked elements.
+   * Default is false.
+   */
+  vtkSetMacro(RemoveSeed, bool);
+  vtkGetMacro(RemoveSeed, bool);
+  vtkBooleanMacro(RemoveSeed, bool);
+  ///@}
+
+  ///@{
+  /**
+   * Get/Set the flag to remove intermediate layers
+   * Default is false.
+   */
+  vtkSetMacro(RemoveIntermediateLayers, bool);
+  vtkGetMacro(RemoveIntermediateLayers, bool);
+  vtkBooleanMacro(RemoveIntermediateLayers, bool);
+  ///@}
+
 protected:
   vtkExpandMarkedElements();
   ~vtkExpandMarkedElements() override;
@@ -74,6 +97,9 @@ private:
 
   vtkMultiProcessController* Controller = nullptr;
   int NumberOfLayers = 2;
+  bool RemoveSeed = false;
+  bool RemoveIntermediateLayers = false;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
