@@ -20,6 +20,7 @@
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPointSet.h"
@@ -30,13 +31,16 @@
 #include "vtkUniformGrid.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExtractCellsByType);
 
+VTK_ABI_NAMESPACE_END
 #include <set>
 
 // Special token marks any cell type
 #define VTK_ANY_CELL_TYPE 1000000
 
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkCellTypeSet : public std::set<unsigned int>
 {
 };
@@ -103,15 +107,8 @@ void vtkExtractCellsByType::AddAllCellTypes()
 //------------------------------------------------------------------------------
 bool vtkExtractCellsByType::ExtractCellType(unsigned int cellType)
 {
-  if (this->CellTypes->find(cellType) != this->CellTypes->end() ||
-    this->CellTypes->find(VTK_ANY_CELL_TYPE) != this->CellTypes->end())
-  {
-    return true;
-  }
-  else
-  {
-    return false;
-  }
+  return this->CellTypes->find(cellType) != this->CellTypes->end() ||
+    this->CellTypes->find(VTK_ANY_CELL_TYPE) != this->CellTypes->end();
 }
 
 //------------------------------------------------------------------------------
@@ -140,25 +137,28 @@ void vtkExtractCellsByType::ExtractUnstructuredData(vtkDataSet* inDS, vtkDataSet
     this->ExtractUnstructuredGridCells(inDS, outDS, ptMap, numNewPts);
   }
 
-  // Copy referenced input points to new points array
-  outPD->CopyAllocate(inPD);
-  vtkPointSet* inPtSet = vtkPointSet::SafeDownCast(inDS);
-  vtkPointSet* outPtSet = vtkPointSet::SafeDownCast(outDS);
-  vtkPoints* inPts = inPtSet->GetPoints();
-  vtkPoints* outPts = vtkPoints::New();
-  outPts->SetNumberOfPoints(numNewPts);
-  for (vtkIdType ptId = 0; ptId < numPts; ++ptId)
+  // Define points using point mapping for extracted cells
+  if (numNewPts > 0)
   {
-    if (ptMap[ptId] >= 0)
+    // Copy referenced input points to new points array
+    outPD->CopyAllocate(inPD);
+    vtkPointSet* inPtSet = vtkPointSet::SafeDownCast(inDS);
+    vtkPointSet* outPtSet = vtkPointSet::SafeDownCast(outDS);
+    vtkPoints* inPts = inPtSet->GetPoints();
+    vtkNew<vtkPoints> outPts;
+    outPts->SetNumberOfPoints(numNewPts);
+    for (vtkIdType ptId = 0; ptId < numPts; ++ptId)
     {
-      outPts->SetPoint(ptMap[ptId], inPts->GetPoint(ptId));
-      outPD->CopyData(inPD, ptId, ptMap[ptId]);
+      if (ptMap[ptId] >= 0)
+      {
+        outPts->SetPoint(ptMap[ptId], inPts->GetPoint(ptId));
+        outPD->CopyData(inPD, ptId, ptMap[ptId]);
+      }
     }
+    outPtSet->SetPoints(outPts);
   }
-  outPtSet->SetPoints(outPts);
 
   // Clean up
-  outPts->Delete();
   delete[] ptMap;
 }
 
@@ -192,6 +192,10 @@ void vtkExtractCellsByType::ExtractPolyDataCells(
     vtkCellArray* verts = vtkCellArray::New();
     for (inVerts->InitTraversal(); inVerts->GetNextCell(npts, pts); ++currentCellId)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       if (this->ExtractCellType(input->GetCellType(currentCellId)))
       {
         ptIds->Reset();
@@ -222,6 +226,10 @@ void vtkExtractCellsByType::ExtractPolyDataCells(
     vtkCellArray* lines = vtkCellArray::New();
     for (inLines->InitTraversal(); inLines->GetNextCell(npts, pts); ++currentCellId)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       if (this->ExtractCellType(input->GetCellType(currentCellId)))
       {
         ptIds->Reset();
@@ -253,6 +261,10 @@ void vtkExtractCellsByType::ExtractPolyDataCells(
     vtkCellArray* polys = vtkCellArray::New();
     for (inPolys->InitTraversal(); inPolys->GetNextCell(npts, pts); ++currentCellId)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       if (this->ExtractCellType(input->GetCellType(currentCellId)))
       {
         ptIds->Reset();
@@ -284,6 +296,10 @@ void vtkExtractCellsByType::ExtractPolyDataCells(
     // All cells are of type VTK_TRIANGLE_STRIP
     for (inStrips->InitTraversal(); inStrips->GetNextCell(npts, pts); ++currentCellId)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       ptIds->Reset();
       for (i = 0; i < npts; ++i)
       {
@@ -336,8 +352,14 @@ void vtkExtractCellsByType::ExtractUnstructuredGridCells(
   vtkIdList* ptIds = vtkIdList::New();
   int cellType;
   output->Allocate(numCells);
+  outCD->CopyAllocate(inCD);
+
   for (cellId = 0; cellId < numCells; ++cellId)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     cellType = input->GetCellType(cellId);
     if (this->ExtractCellType(cellType))
     {
@@ -414,6 +436,8 @@ int vtkExtractCellsByType::RequestData(vtkInformation* vtkNotUsed(request),
     output->Initialize(); // output is empty
   }
 
+  this->CheckAbort();
+
   return 1;
 }
 
@@ -432,3 +456,4 @@ void vtkExtractCellsByType::PrintSelf(ostream& os, vtkIndent indent)
   // Output the number of types specified
   os << indent << "Number of types specified: " << this->CellTypes->size() << "\n";
 }
+VTK_ABI_NAMESPACE_END
