@@ -14,8 +14,8 @@
 =========================================================================*/
 /**
  * @class   vtkExtractGeometry
- * @brief   extract cells that lie either entirely inside or outside of a specified implicit function
- *
+ * @brief   extract cells that lie either entirely inside or outside of a specified
+ *          implicit function
  *
  * vtkExtractGeometry extracts from its input dataset all cells that are either
  * completely inside or outside of a specified implicit function. Any type of
@@ -23,7 +23,7 @@
  * unstructured grid.
  *
  * To use this filter you must specify an implicit function. You must also
- * specify whethter to extract cells laying inside or outside of the implicit
+ * specify whether to extract cells laying inside or outside of the implicit
  * function. (The inside of an implicit function is the negative values
  * region.) An option exists to extract cells that are neither inside or
  * outside (i.e., boundary).
@@ -31,9 +31,14 @@
  * A more efficient version of this filter is available for vtkPolyData input.
  * See vtkExtractPolyDataGeometry.
  *
+ * @warning
+ * This class has been threaded with vtkSMPTools. Using TBB or other
+ * non-sequential type (set in the CMake variable
+ * VTK_SMP_IMPLEMENTATION_TYPE) may improve performance significantly.
+ *
  * @sa
  * vtkExtractPolyDataGeometry vtkGeometryFilter vtkExtractVOI
-*/
+ */
 
 #ifndef vtkExtractGeometry_h
 #define vtkExtractGeometry_h
@@ -41,75 +46,75 @@
 #include "vtkFiltersExtractionModule.h" // For export macro
 #include "vtkUnstructuredGridAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImplicitFunction;
 
 class VTKFILTERSEXTRACTION_EXPORT vtkExtractGeometry : public vtkUnstructuredGridAlgorithm
 {
 public:
-  vtkTypeMacro(vtkExtractGeometry,vtkUnstructuredGridAlgorithm);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  vtkTypeMacro(vtkExtractGeometry, vtkUnstructuredGridAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Construct object with ExtractInside turned on.
    */
-  static vtkExtractGeometry *New();
+  static vtkExtractGeometry* New();
 
   /**
    * Return the MTime taking into account changes to the implicit function
    */
-  vtkMTimeType GetMTime() VTK_OVERRIDE;
+  vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Specify the implicit function for inside/outside checks.
    */
   virtual void SetImplicitFunction(vtkImplicitFunction*);
-  vtkGetObjectMacro(ImplicitFunction,vtkImplicitFunction);
-  //@}
+  vtkGetObjectMacro(ImplicitFunction, vtkImplicitFunction);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Boolean controls whether to extract cells that are inside of implicit
    * function (ExtractInside == 1) or outside of implicit function
    * (ExtractInside == 0).
    */
-  vtkSetMacro(ExtractInside,int);
-  vtkGetMacro(ExtractInside,int);
-  vtkBooleanMacro(ExtractInside,int);
-  //@}
+  vtkSetMacro(ExtractInside, vtkTypeBool);
+  vtkGetMacro(ExtractInside, vtkTypeBool);
+  vtkBooleanMacro(ExtractInside, vtkTypeBool);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Boolean controls whether to extract cells that are partially inside.
    * By default, ExtractBoundaryCells is off.
    */
-  vtkSetMacro(ExtractBoundaryCells,int);
-  vtkGetMacro(ExtractBoundaryCells,int);
-  vtkBooleanMacro(ExtractBoundaryCells,int);
-  vtkSetMacro(ExtractOnlyBoundaryCells,int);
-  vtkGetMacro(ExtractOnlyBoundaryCells,int);
-  vtkBooleanMacro(ExtractOnlyBoundaryCells,int);
-  //@}
+  vtkSetMacro(ExtractBoundaryCells, vtkTypeBool);
+  vtkGetMacro(ExtractBoundaryCells, vtkTypeBool);
+  vtkBooleanMacro(ExtractBoundaryCells, vtkTypeBool);
+  vtkSetMacro(ExtractOnlyBoundaryCells, vtkTypeBool);
+  vtkGetMacro(ExtractOnlyBoundaryCells, vtkTypeBool);
+  vtkBooleanMacro(ExtractOnlyBoundaryCells, vtkTypeBool);
+  ///@}
 
 protected:
-  vtkExtractGeometry(vtkImplicitFunction *f=NULL);
-  ~vtkExtractGeometry() VTK_OVERRIDE;
+  vtkExtractGeometry(vtkImplicitFunction* f = nullptr);
+  ~vtkExtractGeometry() override;
 
   // Usual data generation method
-  int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *) VTK_OVERRIDE;
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
-  int FillInputPortInformation(int port, vtkInformation *info) VTK_OVERRIDE;
+  int FillInputPortInformation(int port, vtkInformation* info) override;
 
-  vtkImplicitFunction *ImplicitFunction;
-  int ExtractInside;
-  int ExtractBoundaryCells;
-  int ExtractOnlyBoundaryCells;
+  vtkImplicitFunction* ImplicitFunction;
+  vtkTypeBool ExtractInside;
+  vtkTypeBool ExtractBoundaryCells;
+  vtkTypeBool ExtractOnlyBoundaryCells;
 
 private:
-  vtkExtractGeometry(const vtkExtractGeometry&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkExtractGeometry&) VTK_DELETE_FUNCTION;
+  vtkExtractGeometry(const vtkExtractGeometry&) = delete;
+  void operator=(const vtkExtractGeometry&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-
