@@ -47,6 +47,7 @@
 #include "vtkFiltersExtractionModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImplicitFunction;
 
 class VTKFILTERSEXTRACTION_EXPORT vtkExtractPolyDataGeometry : public vtkPolyDataAlgorithm
@@ -65,15 +66,15 @@ public:
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Specify the implicit function for inside/outside checks.
    */
   virtual void SetImplicitFunction(vtkImplicitFunction*);
   vtkGetObjectMacro(ImplicitFunction, vtkImplicitFunction);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Boolean controls whether to extract cells that are inside of implicit
    * function (ExtractInside == 1) or outside of implicit function
@@ -82,9 +83,9 @@ public:
   vtkSetMacro(ExtractInside, vtkTypeBool);
   vtkGetMacro(ExtractInside, vtkTypeBool);
   vtkBooleanMacro(ExtractInside, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Boolean controls whether to extract cells that are partially inside.
    * By default, ExtractBoundaryCells is off.
@@ -92,9 +93,9 @@ public:
   vtkSetMacro(ExtractBoundaryCells, vtkTypeBool);
   vtkGetMacro(ExtractBoundaryCells, vtkTypeBool);
   vtkBooleanMacro(ExtractBoundaryCells, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Boolean controls whether points are culled or simply passed through
    * to the output.
@@ -102,7 +103,7 @@ public:
   vtkSetMacro(PassPoints, vtkTypeBool);
   vtkGetMacro(PassPoints, vtkTypeBool);
   vtkBooleanMacro(PassPoints, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkExtractPolyDataGeometry(vtkImplicitFunction* f = nullptr);
@@ -123,7 +124,7 @@ private:
   void operator=(const vtkExtractPolyDataGeometry&) = delete;
 };
 
-//@{
+///@{
 /**
  * When not passing points, have to use a point map to keep track of things.
  */
@@ -135,6 +136,7 @@ inline vtkIdType vtkExtractPolyDataGeometry::InsertPointInMap(
   pointMap[i] = newPts->InsertNextPoint(x);
   return pointMap[i];
 }
-//@}
+///@}
 
+VTK_ABI_NAMESPACE_END
 #endif
