@@ -12,10 +12,14 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+// VTK_DEPRECATED_IN_9_2_0() warnings for this class.
+#define VTK_DEPRECATION_LEVEL 0
+
 #include "vtkExtractSelectedLocations.h"
 
 #include "vtkCell.h"
 #include "vtkCellData.h"
+#include "vtkCellIterator.h"
 #include "vtkDoubleArray.h"
 #include "vtkGenericCell.h"
 #include "vtkIdList.h"
@@ -33,6 +37,7 @@
 #include "vtkSmartPointer.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExtractSelectedLocations);
 
 //------------------------------------------------------------------------------
@@ -159,29 +164,43 @@ void vtkExtractSelectedLocationsCopyCells(
   originalIds->SetNumberOfComponents(1);
   originalIds->SetName("vtkOriginalCellIds");
 
+  int cellType;
+  vtkIdType numCellPts;
+  vtkIdList* pointIdList;
   vtkIdType i, j, newId = 0;
   vtkIdList* ptIds = vtkIdList::New();
-  for (i = 0; i < numCells; i++)
+  vtkIdList* faces;
+
+  vtkSmartPointer<vtkCellIterator> cellIter =
+    vtkSmartPointer<vtkCellIterator>::Take(input->NewCellIterator());
+  for (i = 0, cellIter->InitTraversal(); !cellIter->IsDoneWithTraversal();
+       cellIter->GoToNextCell(), ++i)
   {
     if (inArray[i] > 0)
     {
+      cellType = cellIter->GetCellType();
+      numCellPts = cellIter->GetNumberOfPoints();
+      pointIdList = cellIter->GetPointIds();
+
+      ptIds->Reset();
       // special handling for polyhedron cells
-      if (vtkUnstructuredGrid::SafeDownCast(input) && vtkUnstructuredGrid::SafeDownCast(output) &&
-        input->GetCellType(i) == VTK_POLYHEDRON)
+      if (cellType == VTK_POLYHEDRON)
       {
-        ptIds->Reset();
-        vtkUnstructuredGrid::SafeDownCast(input)->GetFaceStream(i, ptIds);
+        faces = cellIter->GetFaces();
+        for (j = 0; j < faces->GetNumberOfIds(); ++j)
+        {
+          ptIds->InsertNextId(faces->GetId(j));
+        }
         vtkUnstructuredGrid::ConvertFaceStreamPointIds(ptIds, pointMap);
       }
       else
       {
-        input->GetCellPoints(i, ptIds);
-        for (j = 0; j < ptIds->GetNumberOfIds(); j++)
+        for (j = 0; j < numCellPts; j++)
         {
-          ptIds->SetId(j, pointMap[ptIds->GetId(j)]);
+          ptIds->InsertId(j, pointMap[pointIdList->GetId(j)]);
         }
       }
-      output->InsertNextCell(input->GetCellType(i), ptIds);
+      output->InsertNextCell(cellType, ptIds);
       outCD->CopyData(inCD, i, newId++);
       originalIds->InsertNextValue(i);
     }
@@ -274,6 +293,10 @@ int vtkExtractSelectedLocations::ExtractCells(
   vtkIdType ptId, cellId, locArrayIndex;
   for (locArrayIndex = 0; locArrayIndex < numLocs; locArrayIndex++)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     cellId = input->FindCell(
       locArray->GetTuple(locArrayIndex), nullptr, cell, 0, 0.0, subId, pcoords, weights);
     if ((cellId >= 0) && (cellInArray->GetValue(cellId) != flag))
@@ -319,7 +342,7 @@ int vtkExtractSelectedLocations::ExtractCells(
 
   idList->Delete();
 
-  if (!passThrough)
+  if (!this->CheckAbort() && !passThrough)
   {
     vtkIdType* pointMap = new vtkIdType[numPts]; // maps old point ids into new
     vtkExtractSelectedLocationsCopyPoints(input, output, pointInArray->GetPointer(0), pointMap);
@@ -437,6 +460,10 @@ int vtkExtractSelectedLocations::ExtractPoints(
   {
     for (locArrayIndex = 0; locArrayIndex < numLocs; locArrayIndex++)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       if (locator != nullptr)
       {
         ptId =
@@ -488,6 +515,7 @@ int vtkExtractSelectedLocations::ExtractPoints(
   else
   {
     ptId = -1;
+    this->CheckAbort();
   }
 
   ptCells->Delete();
@@ -498,7 +526,7 @@ int vtkExtractSelectedLocations::ExtractPoints(
     locator->Delete();
   }
 
-  if (!passThrough)
+  if (!this->CheckAbort() && !passThrough)
   {
     vtkIdType* pointMap = new vtkIdType[numPts]; // maps old point ids into new
     vtkExtractSelectedLocationsCopyPoints(input, output, pointInArray->GetPointer(0), pointMap);
@@ -540,3 +568,4 @@ void vtkExtractSelectedLocations::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
