@@ -12,6 +12,9 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+// VTK_DEPRECATED_IN_9_2_0() warnings for this class.
+#define VTK_DEPRECATION_LEVEL 0
+
 #include "vtkExtractSelectedThresholds.h"
 
 #include "vtkArrayDispatch.h"
@@ -36,6 +39,7 @@
 
 #include <algorithm>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExtractSelectedThresholds);
 
 //------------------------------------------------------------------------------
@@ -303,6 +307,10 @@ int vtkExtractSelectedThresholds::ExtractCells(
   // Check that the scalars of each cell satisfy the threshold criterion
   for (cellId = 0; cellId < input->GetNumberOfCells(); cellId++)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     cell = input->GetCell(cellId);
     cellPts = cell->GetPointIds();
     numCellPts = cell->GetNumberOfPoints();
@@ -321,7 +329,8 @@ int vtkExtractSelectedThresholds::ExtractCells(
         int above = 0;
         int below = 0;
         ptId = cellPts->GetId(i);
-        int inside = this->EvaluateValue(inScalars, comp_no, ptId, lims, &above, &below, nullptr);
+        int inside = vtkExtractSelectedThresholds::EvaluateValue(
+          inScalars, comp_no, ptId, lims, &above, &below, nullptr);
         totalAbove += above;
         totalBelow += below;
         // Have we detected a cell that straddles the threshold?
@@ -339,7 +348,7 @@ int vtkExtractSelectedThresholds::ExtractCells(
     }
     else // use cell scalars
     {
-      keepCell = this->EvaluateValue(inScalars, comp_no, cellId, lims);
+      keepCell = vtkExtractSelectedThresholds::EvaluateValue(inScalars, comp_no, cellId, lims);
       if (passThrough && (keepCell ^ inverse))
       {
         cellInArray->SetValue(cellId, flag);
@@ -500,7 +509,11 @@ int vtkExtractSelectedThresholds::ExtractPoints(
   vtkIdType outPtCnt = 0;
   for (vtkIdType ptId = 0; ptId < numPts; ptId++)
   {
-    int keepPoint = this->EvaluateValue(inScalars, comp_no, ptId, lims);
+    if (this->CheckAbort())
+    {
+      break;
+    }
+    int keepPoint = vtkExtractSelectedThresholds::EvaluateValue(inScalars, comp_no, ptId, lims);
     if (keepPoint ^ inverse)
     {
       if (passThrough)
@@ -620,7 +633,11 @@ int vtkExtractSelectedThresholds::ExtractRows(
   vtkIdType outRCnt = 0;
   for (vtkIdType rowId = 0; rowId < numRows; rowId++)
   {
-    int keepRow = this->EvaluateValue(inScalars, comp_no, rowId, lims);
+    if (this->CheckAbort())
+    {
+      break;
+    }
+    int keepRow = vtkExtractSelectedThresholds::EvaluateValue(inScalars, comp_no, rowId, lims);
     if (keepRow ^ inverse)
     {
       if (passThrough)
@@ -768,3 +785,4 @@ int vtkExtractSelectedThresholds::EvaluateValue(vtkDataArray* scalars, int comp_
     *InsideCount = inside;
   return keepCell;
 }
+VTK_ABI_NAMESPACE_END
