@@ -24,6 +24,7 @@
 #include <cmath>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExtractTimeSteps);
 
 vtkExtractTimeSteps::vtkExtractTimeSteps()
@@ -166,7 +167,7 @@ int vtkExtractTimeSteps::RequestInformation(
 
     if (!outTimes.empty())
     {
-      outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &outTimes[0],
+      outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), outTimes.data(),
         static_cast<int>(outTimes.size()));
 
       double range[2] = { outTimes.front(), outTimes.back() };
@@ -254,5 +255,8 @@ int vtkExtractTimeSteps::RequestData(
   {
     outData->ShallowCopy(inData);
   }
+
+  this->CheckAbort();
   return 1;
 }
+VTK_ABI_NAMESPACE_END
