@@ -25,7 +25,9 @@
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
+#include "vtkSMPTools.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExtractVectorComponents);
 
 //------------------------------------------------------------------------------
@@ -122,30 +124,63 @@ void vtkExtractVectorComponents::SetInputData(vtkDataSet* input)
 //------------------------------------------------------------------------------
 namespace
 {
-
-struct vtkExtractComponents
+template <typename ArrayT>
+class ExtractVectorComponentsFunctor
 {
-  template <class T>
-  void operator()(T* vectors, vtkDataArray* vx, vtkDataArray* vy, vtkDataArray* vz)
+  ArrayT* ArrayX;
+  ArrayT* ArrayY;
+  ArrayT* ArrayZ;
+  ArrayT* Vector;
+  vtkExtractVectorComponents* Filter;
+
+public:
+  ExtractVectorComponentsFunctor(vtkDataArray* arrayX, vtkDataArray* arrayY, vtkDataArray* arrayZ,
+    ArrayT* vector, vtkExtractVectorComponents* filter)
+    : Vector(vector)
+    , Filter(filter)
   {
-    T* x = T::FastDownCast(vx);
-    T* y = T::FastDownCast(vy);
-    T* z = T::FastDownCast(vz);
+    this->ArrayX = ArrayT::FastDownCast(arrayX);
+    this->ArrayY = ArrayT::FastDownCast(arrayY);
+    this->ArrayZ = ArrayT::FastDownCast(arrayZ);
+  }
+
+  void operator()(vtkIdType begin, vtkIdType end)
+  {
+    const auto inVector = vtk::DataArrayTupleRange<3>(this->Vector, begin, end);
 
-    const auto inRange = vtk::DataArrayTupleRange<3>(vectors);
     // mark out ranges as single component for better perf
-    auto outX = vtk::DataArrayValueRange<1>(x).begin();
-    auto outY = vtk::DataArrayValueRange<1>(y).begin();
-    auto outZ = vtk::DataArrayValueRange<1>(z).begin();
+    auto outX = vtk::DataArrayValueRange<1>(this->ArrayX, begin, end).begin();
+    auto outY = vtk::DataArrayValueRange<1>(this->ArrayY, begin, end).begin();
+    auto outZ = vtk::DataArrayValueRange<1>(this->ArrayZ, begin, end).begin();
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
-    for (auto value : inRange)
+    for (auto tuple : inVector)
     {
-      *outX++ = value[0];
-      *outY++ = value[1];
-      *outZ++ = value[2];
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
+      *outX++ = tuple[0];
+      *outY++ = tuple[1];
+      *outZ++ = tuple[2];
     }
   }
 };
+
+struct ExtractVectorComponentsWorker
+{
+  template <class ArrayT>
+  void operator()(ArrayT* vectors, vtkDataArray* vx, vtkDataArray* vy, vtkDataArray* vz,
+    vtkExtractVectorComponents* filter)
+  {
+    ExtractVectorComponentsFunctor<ArrayT> functor(vx, vy, vz, vectors, filter);
+    vtkSMPTools::For(0, vectors->GetNumberOfTuples(), functor);
+  }
+};
 } // namespace
 
 //------------------------------------------------------------------------------
@@ -239,9 +274,10 @@ int vtkExtractVectorComponents::RequestData(vtkInformation* vtkNotUsed(request),
     snprintf(newName, newNameSize, "%s-z", name);
     vz->SetName(newName);
 
-    if (!vtkArrayDispatch::Dispatch::Execute(vectors, vtkExtractComponents{}, vx, vy, vz))
+    if (!vtkArrayDispatch::Dispatch::Execute(
+          vectors, ExtractVectorComponentsWorker{}, vx, vy, vz, this))
     {
-      vtkExtractComponents{}(vectors, vx, vy, vz);
+      ExtractVectorComponentsWorker{}(vectors, vx, vy, vz, this);
     }
 
     outVx->PassData(pd);
@@ -283,9 +319,10 @@ int vtkExtractVectorComponents::RequestData(vtkInformation* vtkNotUsed(request),
     snprintf(newName, newNameSize, "%s-z", name);
     vzc->SetName(newName);
 
-    if (!vtkArrayDispatch::Dispatch::Execute(vectorsc, vtkExtractComponents{}, vxc, vyc, vzc))
+    if (!vtkArrayDispatch::Dispatch::Execute(
+          vectorsc, ExtractVectorComponentsWorker{}, vxc, vyc, vzc, this))
     {
-      vtkExtractComponents{}(vectorsc, vxc, vyc, vzc);
+      ExtractVectorComponentsWorker{}(vectorsc, vxc, vyc, vzc, this);
     }
 
     outVxc->PassData(cd);
@@ -313,6 +350,8 @@ int vtkExtractVectorComponents::RequestData(vtkInformation* vtkNotUsed(request),
   }
   delete[] newName;
 
+  this->CheckAbort();
+
   return 1;
 }
 
@@ -323,3 +362,4 @@ void vtkExtractVectorComponents::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "ExtractToFieldData: " << this->ExtractToFieldData << endl;
 }
+VTK_ABI_NAMESPACE_END
