@@ -13,32 +13,28 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkFrustumSelector.h"
 
-#include "vtkCell.h"
 #include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
 #include "vtkGenericCell.h"
-#include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkNew.h"
 #include "vtkPlane.h"
 #include "vtkPlanes.h"
 #include "vtkPoints.h"
+#include "vtkSMPThreadLocalObject.h"
 #include "vtkSMPTools.h"
 #include "vtkSelectionNode.h"
 #include "vtkSignedCharArray.h"
-#include "vtkVoxel.h"
+#include "vtkVectorOperators.h"
 
 #include <vector>
 
-#define MAXPLANE 6
-
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
+constexpr int MAX_PLANES = 6;
 //------------------------------------------------------------------------------
 void ComputePlane(
   int idx, double v0[3], double v1[3], double v2[3], vtkPoints* points, vtkDoubleArray* norms)
@@ -63,60 +59,101 @@ void ComputePlane(
 }
 
 //------------------------------------------------------------------------------
+struct FrustumPlanesType : public std::array<vtkSmartPointer<vtkPlane>, MAX_PLANES>
+{
+  FrustumPlanesType()
+  {
+    for (int i = 0; i < MAX_PLANES; ++i)
+    {
+      this->operator[](i) = vtkSmartPointer<vtkPlane>::New();
+    }
+  }
+  void Initialize(vtkPlanes* frustum)
+  {
+    for (int i = 0; i < MAX_PLANES; ++i)
+    {
+      frustum->GetPlane(i, this->operator[](i));
+    }
+  }
+};
+
 //------------------------------------------------------------------------------
 class ComputeCellsInFrustumFunctor
 {
+private:
+  vtkPlanes* Frustum;
+  vtkDataSet* Input;
+  vtkSignedCharArray* Array;
+  int NPVertexIds[6][2];
+
+  vtkSMPThreadLocalObject<vtkGenericCell> TLCell;
+  vtkSMPThreadLocal<FrustumPlanesType> TLFrustumPlanes;
+  vtkSMPThreadLocal<std::vector<double>> TLVertexBuffer;
+
 public:
   ComputeCellsInFrustumFunctor(vtkPlanes* f, vtkDataSet* in, vtkSignedCharArray* array)
     : Frustum(f)
     , Input(in)
     , Array(array)
   {
-    vtkIdType i;
+    // Hacky PrepareForMultithreadedAccess()
+    // call everything we will call on the data object on the main thread first
+    // so that it can build its caching structures
+    vtkNew<vtkGenericCell> cell;
+    this->Input->GetCell(0, cell);
+
     double x[3];
 
     // find the near and far vertices to each plane for quick in/out tests
-    for (i = 0; i < MAXPLANE; i++)
+    for (int i = 0; i < MAX_PLANES; i++)
     {
       this->Frustum->GetNormals()->GetTuple(i, x);
       int xside = (x[0] > 0) ? 1 : 0;
       int yside = (x[1] > 0) ? 1 : 0;
       int zside = (x[2] > 0) ? 1 : 0;
-      this->np_vertids[i][0] = (1 - xside) * 4 + (1 - yside) * 2 + (1 - zside);
-      this->np_vertids[i][1] = xside * 4 + yside * 2 + zside;
+      this->NPVertexIds[i][0] = (1 - xside) * 4 + (1 - yside) * 2 + (1 - zside);
+      this->NPVertexIds[i][1] = xside * 4 + yside * 2 + zside;
     }
   }
 
+  //--------------------------------------------------------------------------
+  void Initialize() { this->TLFrustumPlanes.Local().Initialize(this->Frustum); }
+
   //--------------------------------------------------------------------------
   void operator()(vtkIdType begin, vtkIdType end)
   {
     double bounds[6];
-    vtkNew<vtkGenericCell> cell;
+    auto& cell = this->TLCell.Local();
+    auto& frustumPlanes = this->TLFrustumPlanes.Local();
+    auto& vertexBuffer = this->TLVertexBuffer.Local();
 
     for (vtkIdType cellId = begin; cellId < end; ++cellId)
     {
-      Input->GetCellBounds(cellId, bounds);
-      Input->GetCell(cellId, cell);
-      int isect = this->ABoxFrustumIsect(bounds, cell);
-      if (isect == 1)
-      {
-        Array->SetValue(cellId, 1);
-      }
-      else
-      {
-        Array->SetValue(cellId, 0);
-      }
+      this->Input->GetCellBounds(cellId, bounds);
+      int isect = this->ABoxFrustumIsect(cellId, bounds, cell, frustumPlanes, vertexBuffer, false);
+      this->Array->SetValue(cellId, static_cast<signed char>(isect == 1));
     }
   }
 
+  //--------------------------------------------------------------------------
+  void Reduce()
+  {
+    // nothing to do here.
+  }
+
   //--------------------------------------------------------------------------
   // Intersect the cell (with its associated bounds) with the clipping frustum.
   // Return 1 if at least partially inside, 0 otherwise.
   // Also return a distance to the near plane.
-  int ABoxFrustumIsect(double* bounds, vtkCell* cell)
+  int ABoxFrustumIsect(vtkIdType cellId, double* bounds, vtkGenericCell* cell,
+    FrustumPlanesType& frustumPlanes, std::vector<double>& vertexBuffer, bool cellExtracted)
   {
     if (bounds[0] > bounds[1] || bounds[2] > bounds[3] || bounds[4] > bounds[5])
     {
+      if (!cellExtracted)
+      {
+        this->Input->GetCell(cellId, cell);
+      }
       return this->IsectDegenerateCell(cell);
     }
 
@@ -150,23 +187,19 @@ public:
     int intersect = 0;
 
     // reject if any plane rejects the entire bbox
-    vtkNew<vtkPlane> plane;
-    for (int pid = 0; pid < MAXPLANE; pid++)
+    for (int pid = 0; pid < MAX_PLANES; pid++)
     {
-      this->Frustum->GetPlane(pid, plane);
+      auto& plane = frustumPlanes[pid];
       double dist;
       int nvid;
       int pvid;
-      nvid = this->np_vertids[pid][0];
+      nvid = this->NPVertexIds[pid][0];
       dist = plane->EvaluateFunction(verts[nvid]);
       if (dist > 0.0)
       {
-        /*
-        this->NumRejects++;
-        */
         return 0;
       }
-      pvid = this->np_vertids[pid][1];
+      pvid = this->NPVertexIds[pid][1];
       dist = plane->EvaluateFunction(verts[pvid]);
       if (dist > 0.0)
       {
@@ -178,26 +211,25 @@ public:
     // accept if entire bbox is inside all planes
     if (!intersect)
     {
-      /*
-      this->NumAccepts++;
-      */
       return 1;
     }
 
-    // otherwise we have to do clipping tests to decide if actually insects
-    /*
-    this->NumIsects++;
-    */
+    // otherwise, we have to do clipping tests to decide if actually insects
     vtkCell* face;
     vtkCell* edge;
     vtkPoints* pts = nullptr;
-    std::vector<double> vertbuffer;
+    vertexBuffer.clear();
     int maxedges = 16;
     // be ready to resize if we hit a polygon with many vertices
-    vertbuffer.resize(3 * maxedges * 3);
-    double* vlist = &vertbuffer[0 * maxedges * 3];
-    double* wvlist = &vertbuffer[1 * maxedges * 3];
-    double* ovlist = &vertbuffer[2 * maxedges * 3];
+    vertexBuffer.resize(3 * maxedges * 3);
+    double* vlist = &vertexBuffer[0 * maxedges * 3];
+    double* wvlist = &vertexBuffer[1 * maxedges * 3];
+    double* ovlist = &vertexBuffer[2 * maxedges * 3];
+
+    if (!cellExtracted)
+    {
+      this->Input->GetCell(cellId, cell);
+    }
 
     int nfaces = cell->GetNumberOfFaces();
     if (nfaces < 1)
@@ -225,10 +257,10 @@ public:
           if (nedges + 4 > maxedges)
           {
             maxedges = (nedges + 4) * 2;
-            vertbuffer.resize(3 * maxedges * 3);
-            vlist = &vertbuffer[0 * maxedges * 3];
-            wvlist = &vertbuffer[1 * maxedges * 3];
-            ovlist = &vertbuffer[2 * maxedges * 3];
+            vertexBuffer.resize(3 * maxedges * 3);
+            vlist = &vertexBuffer[0 * maxedges * 3];
+            wvlist = &vertexBuffer[1 * maxedges * 3];
+            ovlist = &vertexBuffer[2 * maxedges * 3];
           }
           for (vtkIdType i = 0; i < cell->GetNumberOfPoints(); ++i)
           {
@@ -243,10 +275,10 @@ public:
       if (nedges + 4 > maxedges)
       {
         maxedges = (nedges + 4) * 2;
-        vertbuffer.resize(3 * maxedges * 3);
-        vlist = &vertbuffer[0 * maxedges * 3];
-        wvlist = &vertbuffer[1 * maxedges * 3];
-        ovlist = &vertbuffer[2 * maxedges * 3];
+        vertexBuffer.resize(3 * maxedges * 3);
+        vlist = &vertexBuffer[0 * maxedges * 3];
+        wvlist = &vertexBuffer[1 * maxedges * 3];
+        ovlist = &vertexBuffer[2 * maxedges * 3];
       }
       edge = cell->GetEdge(0);
       if (edge)
@@ -283,7 +315,7 @@ public:
         case VTK_LINE:
         case VTK_POLY_LINE:
         {
-          break;
+          return this->FrustumClipPolyline(nedges, vlist, bounds);
         }
         default:
         {
@@ -296,14 +328,13 @@ public:
           break;
         }
       }
-      if (this->FrustumClipPolygon(nedges, vlist, wvlist, ovlist))
+      if (this->FrustumClipPolygon(nedges, vlist, wvlist, ovlist, frustumPlanes))
       {
         return 1;
       }
     }
     else
     {
-
       // go around edges of each face and clip to planes
       // if nothing remains at the end, then we do not intersect and reject
       for (int f = 0; f < nfaces; f++)
@@ -322,10 +353,10 @@ public:
         if (nedges + 4 > maxedges)
         {
           maxedges = (nedges + 4) * 2;
-          vertbuffer.resize(3 * maxedges * 3);
-          vlist = &vertbuffer[0 * maxedges * 3];
-          wvlist = &vertbuffer[1 * maxedges * 3];
-          ovlist = &vertbuffer[2 * maxedges * 3];
+          vertexBuffer.resize(3 * maxedges * 3);
+          vlist = &vertexBuffer[0 * maxedges * 3];
+          wvlist = &vertexBuffer[1 * maxedges * 3];
+          ovlist = &vertexBuffer[2 * maxedges * 3];
         }
         edge = face->GetEdge(0);
         pts = edge->GetPoints();
@@ -369,7 +400,7 @@ public:
             break;
           }
         }
-        if (this->FrustumClipPolygon(nedges, vlist, wvlist, ovlist))
+        if (this->FrustumClipPolygon(nedges, vlist, wvlist, ovlist, frustumPlanes))
         {
           return 1;
         }
@@ -383,10 +414,9 @@ public:
   // handle degenerate cells by testing each point, if any in, then in
   int IsectDegenerateCell(vtkCell* cell)
   {
-    vtkIdType npts = cell->GetNumberOfPoints();
     vtkPoints* pts = cell->GetPoints();
     double x[3];
-    for (vtkIdType i = 0; i < npts; i++)
+    for (vtkIdType i = 0, npts = cell->GetNumberOfPoints(); i < npts; i++)
     {
       pts->GetPoint(i, x);
       if (this->Frustum->EvaluateFunction(x) < 0.0)
@@ -402,17 +432,18 @@ public:
   // if there is no intersection, returns 0
   // if there is an intersection, returns 1
   // update ovlist to contain the resulting clipped vertices
-  int FrustumClipPolygon(int nverts, double* ivlist, double* wvlist, double* ovlist)
+  int FrustumClipPolygon(
+    int nverts, double* ivlist, double* wvlist, double* ovlist, FrustumPlanesType& frustumPlanes)
   {
     int nwverts = nverts;
     memcpy(wvlist, ivlist, nverts * sizeof(double) * 3);
 
     int noverts = 0;
     int pid;
-    for (pid = 0; pid < MAXPLANE; pid++)
+    for (pid = 0; pid < MAX_PLANES; pid++)
     {
       noverts = 0;
-      this->PlaneClipPolygon(nwverts, wvlist, pid, noverts, ovlist);
+      this->PlaneClipPolygon(nwverts, wvlist, pid, noverts, ovlist, frustumPlanes);
       if (noverts == 0)
       {
         return 0;
@@ -427,21 +458,25 @@ public:
   //--------------------------------------------------------------------------
   // clips a polygon against the numbered plane, resulting vertices are stored
   // in ovlist, noverts
-  void PlaneClipPolygon(int nverts, double* ivlist, int pid, int& noverts, double* ovlist)
+  void PlaneClipPolygon(int nverts, double* ivlist, int pid, int& noverts, double* ovlist,
+    FrustumPlanesType& frustumPlanes)
   {
     int vid;
     // run around the polygon and clip to this edge
     for (vid = 0; vid < nverts - 1; vid++)
     {
-      this->PlaneClipEdge(&ivlist[vid * 3], &ivlist[(vid + 1) * 3], pid, noverts, ovlist);
+      this->PlaneClipEdge(
+        &ivlist[vid * 3], &ivlist[(vid + 1) * 3], pid, noverts, ovlist, frustumPlanes);
     }
-    this->PlaneClipEdge(&ivlist[(nverts - 1) * 3], &ivlist[0 * 3], pid, noverts, ovlist);
+    this->PlaneClipEdge(
+      &ivlist[(nverts - 1) * 3], &ivlist[0 * 3], pid, noverts, ovlist, frustumPlanes);
   }
 
   //--------------------------------------------------------------------------
   // clips a line segment against the numbered plane.
   // intersection point and the second vertex are added to overts if on or inside
-  void PlaneClipEdge(double* V0, double* V1, int pid, int& noverts, double* overts)
+  void PlaneClipEdge(
+    double* V0, double* V1, int pid, int& noverts, double* overts, FrustumPlanesType& frustumPlanes)
   {
     double t = 0.0;
     double ISECT[3];
@@ -458,9 +493,7 @@ public:
       noverts++;
     }
 
-    vtkNew<vtkPlane> plane;
-    this->Frustum->GetPlane(pid, plane);
-
+    auto& plane = frustumPlanes[pid];
     if (plane->EvaluateFunction(V1) < 0.0)
     {
       overts[noverts * 3 + 0] = V1[0];
@@ -470,14 +503,97 @@ public:
     }
   }
 
-  vtkPlanes* Frustum;
-  vtkDataSet* Input;
-  vtkSignedCharArray* Array;
-  int np_vertids[6][2];
+  //--------------------------------------------------------------------------
+  // Tests edge segments against the frustum.
+  // If there is no intersection, returns 0
+  // If there is an intersection, returns 1
+  // This is accomplished using Cyrus-Beck clipping.
+  int FrustumClipPolyline(int nverts, double* ivlist, double* bounds)
+  {
+    if (nverts < 1)
+    {
+      return 0;
+    }
+    vtkVector3d p0(ivlist[0], ivlist[1], ivlist[2]);
+    if (nverts < 2)
+    {
+      return this->ComputePlaneEndpointCode(p0) == 0;
+    }
+    // Compute the L1 "diameter" of the bounding box (used to test for degeneracy)
+    // We know bounds is valid at this point, so diam >= 0
+    const double diam = bounds[1] - bounds[0] + bounds[3] - bounds[2] + bounds[5] - bounds[4];
+    const double epsilon = 1e-6 * diam;
+    const double epsilon2 = 1e-10 * diam * diam;
+    vtkVector3d normal, basePoint;
+    vtkVector3d p1;
+    bool in = false;
+    for (int ii = 1; ii < nverts; ++ii, p0 = p1)
+    {
+      p1 = vtkVector3d(ivlist[3 * ii], ivlist[3 * ii + 1], ivlist[3 * ii + 2]);
+      vtkVector3d lineVec = p1 - p0;
+      if (lineVec.SquaredNorm() < epsilon2)
+      {
+        // Skip short edges; they would make denom == 0.0 and thus have no effect.
+        continue;
+      }
+      double tmin = 0.0;
+      double tmax = 1.0;
+      bool mayOverlap = true;
+      for (int pp = 0; mayOverlap && (pp < MAX_PLANES); ++pp)
+      {
+        this->Frustum->GetNormals()->GetTuple(pp, normal.GetData());
+        this->Frustum->GetPoints()->GetPoint(pp, basePoint.GetData());
+        vtkVector3d db = p0 - basePoint; // Vector from the plane's base point to p0 on the line.
+        double numer = db.Dot(normal);
+        double denom = lineVec.Dot(normal);
+        double t;
+        if (std::abs(denom) <= epsilon)
+        {
+          if (numer > 0)
+          {
+            mayOverlap = false;
+          }
+        }
+        else
+        {
+          t = -numer / denom;
+          if (denom < 0.0 && t > tmin)
+          {
+            tmin = t;
+          }
+          else if (denom > 0.0 && t < tmax)
+          {
+            tmax = t;
+          }
+        }
+      }
+      if (mayOverlap)
+      {
+        in |= (tmin <= tmax);
+        if (in)
+        {
+          break;
+        }
+      }
+    }
+    return in ? 1 : 0;
+  }
+
+  int ComputePlaneEndpointCode(const vtkVector3d& vertex)
+  {
+    int code = 0;
+    vtkVector3d normal, basePoint;
+    for (int pp = 0; pp < MAX_PLANES; ++pp)
+    {
+      this->Frustum->GetNormals()->GetTuple(pp, normal.GetData());
+      this->Frustum->GetPoints()->GetPoint(pp, basePoint.GetData());
+      code |= ((vertex - basePoint).Dot(normal) >= 0.0) ? (1 << pp) : 0;
+    }
+    return code;
+  }
 };
 }
 
-//------------------------------------------------------------------------------
 //------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkFrustumSelector);
 
@@ -643,27 +759,22 @@ void vtkFrustumSelector::ComputeSelectedPoints(vtkDataSet* input, vtkSignedCharA
     }
   });
 }
+
 //------------------------------------------------------------------------------
 void vtkFrustumSelector::ComputeSelectedCells(vtkDataSet* input, vtkSignedCharArray* cellSelected)
 {
   vtkIdType numCells = input->GetNumberOfCells();
 
-  // Hacky PrepareForMultithreadedAccess()
-  // call everything we will call on the data object on the main thread first
-  // so that it can build its caching structures
   if (numCells == 0)
   {
     return;
   }
-  double bounds[6];
-  vtkNew<vtkGenericCell> cell;
-  input->GetCellBounds(0, bounds);
-  input->GetCell(0, cell);
 
   ComputeCellsInFrustumFunctor functor(this->Frustum, input, cellSelected);
   vtkSMPTools::For(0, numCells, functor);
 }
 
+//------------------------------------------------------------------------------
 void vtkFrustumSelector::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -671,11 +782,13 @@ void vtkFrustumSelector::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Frustum: " << static_cast<void*>(this->Frustum) << "\n";
 }
 
+//------------------------------------------------------------------------------
 int vtkFrustumSelector::OverallBoundsTest(double bounds[6])
 {
   ComputeCellsInFrustumFunctor functor(this->Frustum, nullptr, nullptr);
 
-  vtkNew<vtkVoxel> vox;
+  vtkNew<vtkGenericCell> vox;
+  vox->SetCellType(VTK_VOXEL);
   vtkPoints* p = vox->GetPoints();
   p->SetPoint(0, bounds[0], bounds[2], bounds[4]);
   p->SetPoint(1, bounds[1], bounds[2], bounds[4]);
@@ -686,7 +799,9 @@ int vtkFrustumSelector::OverallBoundsTest(double bounds[6])
   p->SetPoint(6, bounds[0], bounds[3], bounds[5]);
   p->SetPoint(7, bounds[1], bounds[3], bounds[5]);
 
-  int rc;
-  rc = functor.ABoxFrustumIsect(bounds, vox);
-  return (rc > 0);
+  FrustumPlanesType frustumPlanes;
+  frustumPlanes.Initialize(this->Frustum);
+  std::vector<double> vertexBuffer;
+  return functor.ABoxFrustumIsect(-1, bounds, vox, frustumPlanes, vertexBuffer, true) > 0 ? 1 : 0;
 }
+VTK_ABI_NAMESPACE_END
