@@ -26,6 +26,7 @@
 #include "vtkTrivialProducer.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkProbeSelectedLocations);
 //------------------------------------------------------------------------------
 vtkProbeSelectedLocations::vtkProbeSelectedLocations() = default;
@@ -115,12 +116,14 @@ int vtkProbeSelectedLocations::RequestData(vtkInformation* vtkNotUsed(request),
 
   vtkProbeFilter* subFilter = vtkProbeFilter::New();
   vtkTrivialProducer* tp = vtkTrivialProducer::New();
+  tp->SetContainerAlgorithm(this);
   tp->SetOutput(inputClone);
   subFilter->SetInputConnection(1, tp->GetOutputPort());
   inputClone->Delete();
   tp->Delete();
 
   tp = vtkTrivialProducer::New();
+  tp->SetContainerAlgorithm(this);
   tp->SetOutput(tempInput);
   subFilter->SetInputConnection(0, tp->GetOutputPort());
   tempInput->Delete();
@@ -142,6 +145,7 @@ int vtkProbeSelectedLocations::RequestData(vtkInformation* vtkNotUsed(request),
     uExtent = outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
   }
 
+  subFilter->SetContainerAlgorithm(this);
   subFilter->UpdatePiece(piece, npieces, 0, uExtent);
   output->ShallowCopy(subFilter->GetOutput());
   subFilter->Delete();
@@ -154,3 +158,4 @@ void vtkProbeSelectedLocations::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
