@@ -27,6 +27,9 @@
 #include "vtkObject.h"
 #include "vtkSmartPointer.h" // For vtkSmartPointer
 
+#include <set> // for std::set
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataSet;
 class vtkDataObject;
 class vtkSelectionNode;
@@ -68,14 +71,14 @@ public:
    */
   virtual void Execute(vtkDataObject* input, vtkDataObject* output);
 
-  //@{
+  ///@{
   /**
    * Get/Set the name of the array to use for the insidedness array to add to
    * the output in `Execute` call.
    */
   vtkSetMacro(InsidednessArrayName, std::string);
   vtkGetMacro(InsidednessArrayName, std::string);
-  //@}
+  ///@}
 protected:
   vtkSelector();
   ~vtkSelector() override;
@@ -127,9 +130,12 @@ protected:
    * processed. If the selector cannot make an exact determination for the given
    * level and index, it should return `INHERIT`. Note, returning `INCLUDE` or
    * `EXCLUDE` has impact on all nodes in the subtree unless any of the node
-   * explicitly overrides the block selection mode.
+   * explicitly overrides the block selection mode. isDataObjectTree is true for vtkDataObjectTree
+   * and false for vtkUniformGridAMR. When isDataObjectTree == true, we treat compositeIndex == 0
+   * differently.
    */
-  virtual SelectionMode GetBlockSelection(unsigned int compositeIndex);
+  virtual SelectionMode GetBlockSelection(
+    unsigned int compositeIndex, bool isDataObjectTree = true);
 
   /**
    * Creates an array suitable for storing insideness. The array is named using
@@ -161,6 +167,10 @@ private:
   void ProcessAMR(vtkUniformGridAMR* input, vtkCompositeDataSet* output);
   void ProcessDataObjectTree(vtkDataObjectTree* input, vtkDataObjectTree* output,
     SelectionMode inheritedSelectionMode, unsigned int compositeIndex = 0);
+  void ProcessSelectors(vtkCompositeDataSet* input);
+
+  std::set<unsigned int> SubsetCompositeIds;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
