@@ -44,12 +44,14 @@
 #ifndef vtkCachingInterpolatedVelocityField_h
 #define vtkCachingInterpolatedVelocityField_h
 
+#include "vtkDeprecation.h"            // for VTK_DEPRECATED_IN_9_2_0
 #include "vtkFiltersFlowPathsModule.h" // For export macro
 #include "vtkFunctionSet.h"
 #include "vtkSmartPointer.h" // this is allowed
 
 #include <vector> // we need them
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkDataArray;
 class vtkPointData;
@@ -64,7 +66,10 @@ class IVFCacheList : public std::vector<IVFDataSetInfo>
 };
 //---------------------------------------------------------------------------
 
-class VTKFILTERSFLOWPATHS_EXPORT vtkCachingInterpolatedVelocityField : public vtkFunctionSet
+class VTK_DEPRECATED_IN_9_2_0(
+  "Use vtkCompositeInterpolatedVelocityField instead of vtkCachingInterpolatedVelocityField "
+  "and set the desired strategy.") VTKFILTERSFLOWPATHS_EXPORT vtkCachingInterpolatedVelocityField
+  : public vtkFunctionSet
 {
 public:
   vtkTypeMacro(vtkCachingInterpolatedVelocityField, vtkFunctionSet);
@@ -77,14 +82,14 @@ public:
   static vtkCachingInterpolatedVelocityField* New();
 
   using Superclass::FunctionValues;
-  //@{
+  ///@{
   /**
    * Evaluate the velocity field, f={u,v,w}, at {x, y, z}.
    * returns 1 if valid, 0 if test failed
    */
   int FunctionValues(double* x, double* f) override;
   virtual int InsideTest(double* x);
-  //@}
+  ///@}
 
   /**
    * Add a dataset used by the interpolation function evaluation.
@@ -92,7 +97,7 @@ public:
   virtual void SetDataSet(
     int I, vtkDataSet* dataset, bool staticdataset, vtkAbstractCellLocator* locator);
 
-  //@{
+  ///@{
   /**
    * If you want to work with an arbitrary vector array, then set its name
    * here. By default this in nullptr and the filter will use the active vector
@@ -100,7 +105,7 @@ public:
    */
   vtkGetStringMacro(VectorsSelection);
   void SelectVectors(const char* fieldName) { this->SetVectorsSelection(fieldName); }
-  //@}
+  ///@}
 
   /**
    * Set LastCellId to c and LastCacheIndex datasetindex, cached from last evaluation.
@@ -115,7 +120,7 @@ public:
    */
   void ClearLastCellInfo();
 
-  //@{
+  ///@{
   /**
    * Returns the interpolation weights/pcoords cached from last evaluation
    * if the cached cell is valid (returns 1). Otherwise, it does not
@@ -123,16 +128,16 @@ public:
    */
   int GetLastWeights(double* w);
   int GetLastLocalCoordinates(double pcoords[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Caching statistics.
    */
   vtkGetMacro(CellCacheHit, int);
   vtkGetMacro(DataSetCacheHit, int);
   vtkGetMacro(CacheMiss, int);
-  //@}
+  ///@}
 
 protected:
   vtkCachingInterpolatedVelocityField();
@@ -158,7 +163,7 @@ protected:
   int InsideTest(IVFDataSetInfo* cache, double* x);
 
   friend class vtkTemporalInterpolatedVelocityField;
-  //@{
+  ///@{
   /**
    * If all weights have been computed (parametric coords etc all valid)
    * then we can quickly interpolate a scalar/vector using the known weights
@@ -171,7 +176,7 @@ protected:
   bool InterpolatePoint(
     vtkCachingInterpolatedVelocityField* inCIVF, vtkPointData* outPD, vtkIdType outIndex);
   vtkGenericCell* GetLastCell();
-  //@}
+  ///@}
 
 private:
   vtkCachingInterpolatedVelocityField(const vtkCachingInterpolatedVelocityField&) = delete;
@@ -213,4 +218,7 @@ public:
 
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
+VTK_ABI_NAMESPACE_END
 #endif
+
+// VTK-HeaderTest-Exclude: vtkCachingInterpolatedVelocityField.h
