@@ -82,9 +82,8 @@
  * vtkStreamTracer vtkRibbonFilter vtkRuledSurfaceFilter vtkInitialValueProblemSolver
  * vtkRungeKutta2 vtkRungeKutta4 vtkRungeKutta45 vtkParticleTracerBase
  * vtkParticleTracer vtkParticlePathFilter vtkStreaklineFilter
- * vtkAbstractInterpolatedVelocityField vtkInterpolatedVelocityField
- * vtkCellLocatorInterpolatedVelocityField
- *
+ * vtkAbstractInterpolatedVelocityField vtkCompositeInterpolatedVelocityField
+ * vtkAMRInterpolatedVelocityField
  */
 
 #ifndef vtkEvenlySpacedStreamlines2D_h
@@ -93,9 +92,10 @@
 #include "vtkFiltersFlowPathsModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
-#include <array>
-#include <vector>
+#include <array>  // for std::array
+#include <vector> // for std::vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractInterpolatedVelocityField;
 class vtkCompositeDataSet;
 class vtkDataArray;
@@ -125,7 +125,7 @@ public:
    */
   static vtkEvenlySpacedStreamlines2D* New();
 
-  //@{
+  ///@{
   /**
    * Specify the starting point (seed) of the first streamline in the global
    * coordinate system. Search must be performed to find the initial cell
@@ -134,9 +134,9 @@ public:
    */
   vtkSetVector3Macro(StartPosition, double);
   vtkGetVector3Macro(StartPosition, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the integrator type to be used for streamline generation.
    * The object passed is not actually used but is cloned with
@@ -152,7 +152,7 @@ public:
   int GetIntegratorType();
   void SetIntegratorTypeToRungeKutta2();
   void SetIntegratorTypeToRungeKutta4();
-  //@}
+  ///@}
 
   /**
    * Set the velocity field interpolator type to the one involving
@@ -175,24 +175,24 @@ public:
   void SetIntegrationStepUnit(int unit);
   int GetIntegrationStepUnit() { return this->IntegrationStepUnit; }
 
-  //@{
+  ///@{
   /**
    * Specify the maximum number of steps for integrating a streamline.
    */
   vtkSetMacro(MaximumNumberOfSteps, vtkIdType);
   vtkGetMacro(MaximumNumberOfSteps, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * We don't try to eliminate loops with fewer points than this. Default value
    * is 4.
    */
   vtkSetMacro(MinimumNumberOfLoopPoints, vtkIdType);
   vtkGetMacro(MinimumNumberOfLoopPoints, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the Initial step size used for line integration, expressed in
    * IntegrationStepUnit
@@ -202,36 +202,36 @@ public:
    */
   vtkSetMacro(InitialIntegrationStep, double);
   vtkGetMacro(InitialIntegrationStep, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the separation distance between streamlines expressed in
    * IntegrationStepUnit.
    */
   vtkSetMacro(SeparatingDistance, double);
   vtkGetMacro(SeparatingDistance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Streamline integration is stopped if streamlines are closer than
    * SeparatingDistance*SeparatingDistanceRatio to other streamlines.
    */
   vtkSetMacro(SeparatingDistanceRatio, double);
   vtkGetMacro(SeparatingDistanceRatio, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Loops are considered closed if the have two points at distance less than this.
    * This is expressed in IntegrationStepUnit.
    */
   vtkSetMacro(ClosedLoopMaximumDistance, double);
   vtkGetMacro(ClosedLoopMaximumDistance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The angle (in radians) between the vector created by p0p1 and the
    * velocity in the point closing the loop. p0 is the current point
@@ -239,17 +239,17 @@ public:
    */
   vtkSetMacro(LoopAngle, double);
   vtkGetMacro(LoopAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the terminal speed value, below which integration is terminated.
    */
   vtkSetMacro(TerminalSpeed, double);
   vtkGetMacro(TerminalSpeed, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off vorticity computation at streamline points
    * (necessary for generating proper stream-ribbons using the
@@ -257,7 +257,7 @@ public:
    */
   vtkSetMacro(ComputeVorticity, bool);
   vtkGetMacro(ComputeVorticity, bool);
-  //@}
+  ///@}
 
   /**
    * The object used to interpolate the velocity field during
@@ -267,8 +267,7 @@ public:
 
   /**
    * Set the type of the velocity field interpolator to determine whether
-   * vtkInterpolatedVelocityField (INTERPOLATOR_WITH_DATASET_POINT_LOCATOR) or
-   * vtkCellLocatorInterpolatedVelocityField (INTERPOLATOR_WITH_CELL_LOCATOR)
+   * INTERPOLATOR_WITH_DATASET_POINT_LOCATOR or INTERPOLATOR_WITH_CELL_LOCATOR
    * is employed for locating cells during streamline integration. The latter
    * (adopting vtkAbstractCellLocator sub-classes such as vtkCellLocator and
    * vtkModifiedBSPTree) is more robust then the former (through vtkDataSet /
@@ -385,6 +384,5 @@ private:
   void operator=(const vtkEvenlySpacedStreamlines2D&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkEvenlySpacedStreamlines2D.h
