@@ -31,9 +31,6 @@
  *    double * x, double * f);
  * to define how the integration works.
  *
- * Inherited classes could reimplement InitializeVariablesParticleData and
- * InsertVariablesParticleData to add new UserVariables to integrate with.
- *
  * Inherited classes could reimplement InteractWithSurface or other surface interaction methods
  * to change the way particles interact with surfaces.
  *
@@ -63,6 +60,7 @@
 #include <mutex> // for mutexes
 #include <queue> // for new particles
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkAbstractCellLocator;
 class vtkCell;
@@ -122,7 +120,7 @@ public:
    */
   int FunctionValues(double* x, double* f, void* userData) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the locator used to locate cells in the datasets.
    * Only the locator class matter here, as it is used only to
@@ -131,22 +129,22 @@ public:
    */
   virtual void SetLocator(vtkAbstractCellLocator* locator);
   vtkGetObjectMacro(Locator, vtkAbstractCellLocator);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the state of the current locators
    */
   vtkGetMacro(LocatorsBuilt, bool);
   vtkSetMacro(LocatorsBuilt, bool);
-  //@}
+  ///@}
 
   /**
    * Set the parent tracker.
    */
   virtual void SetTracker(vtkLagrangianParticleTracker* Tracker);
 
-  //@{
+  ///@{
   /**
    * Add a dataset to locate cells in
    * This create a specific locator for the provided dataset
@@ -159,30 +157,30 @@ public:
   virtual void AddDataSet(
     vtkDataSet* dataset, bool surface = false, unsigned int surfaceFlatIndex = 0);
   virtual void ClearDataSets(bool surface = false);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the Use of initial integration input array to process
    */
   vtkSetMacro(UseInitialIntegrationTime, bool);
   vtkGetMacro(UseInitialIntegrationTime, bool);
   vtkBooleanMacro(UseInitialIntegrationTime, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the tolerance to use with this model.
    */
   vtkGetMacro(Tolerance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the specific tolerance to use with the locators.
    */
   vtkGetMacro(LocatorTolerance, double);
-  //@}
+  ///@}
 
   /**
    * Interact the current particle with a surfaces
@@ -225,15 +223,15 @@ public:
   virtual bool FindInLocators(double* x, vtkLagrangianParticle* particle, vtkDataSet*& dataset,
     vtkIdType& cellId, vtkAbstractCellLocator*& loc, double*& weights);
 
-  //@{
+  ///@{
   /**
-   * Convienience methods to call FindInLocators with less arguments
+   * Convenience methods to call FindInLocators with less arguments
    * THESE METHODS ARE NOT THREAD-SAFE
    */
   virtual bool FindInLocators(
     double* x, vtkLagrangianParticle* particle, vtkDataSet*& dataset, vtkIdType& cellId);
   virtual bool FindInLocators(double* x, vtkLagrangianParticle* particle);
-  //@}
+  ///@}
 
   /**
    * Initialize a particle by setting user variables and perform any user
@@ -267,14 +265,14 @@ public:
     return false;
   }
 
-  //@{
+  ///@{
   /**
    * Set/Get Non Planar Quad Support
    */
   vtkSetMacro(NonPlanarQuadSupport, bool);
   vtkGetMacro(NonPlanarQuadSupport, bool);
   vtkBooleanMacro(NonPlanarQuadSupport, bool);
-  //@}
+  ///@}
 
   /**
    * Get the seed arrays expected name
@@ -324,13 +322,13 @@ public:
    */
   virtual vtkIntArray* GetSurfaceArrayComps();
 
-  //@{
+  ///@{
   /**
    * Get the maximum weights size necessary for calling
    * FindInLocators with weights
    */
   virtual int GetWeightsSize();
-  //@}
+  ///@}
 
   /**
    * Let the model define it's own way to integrate
@@ -419,49 +417,49 @@ public:
   /**
    * Method used by the LPT to initialize data insertion in the provided
    * vtkFieldData. It initializes Id, ParentID, SeedID and Termination.
-   * Reimplement as needed in acccordance with InsertPathData.
+   * Reimplement as needed in accordance with InsertPathData.
    */
   virtual void InitializePathData(vtkFieldData* data);
 
   /**
    * Method used by the LPT to initialize data insertion in the provided
    * vtkFieldData. It initializes Interaction.
-   * Reimplement as needed in acccordance with InsertInteractionData.
+   * Reimplement as needed in accordance with InsertInteractionData.
    */
   virtual void InitializeInteractionData(vtkFieldData* data);
 
   /**
    * Method used by the LPT to initialize data insertion in the provided
    * vtkFieldData. It initializes StepNumber, ParticleVelocity, IntegrationTime.
-   * Reimplement as needed in acccordance with InsertParticleData.
+   * Reimplement as needed in accordance with InsertParticleData.
    */
   virtual void InitializeParticleData(vtkFieldData* particleData, int maxTuples = 0);
 
   /**
-   * Method used by the LPT to insert data from the partice into
+   * Method used by the LPT to insert data from the particle into
    * the provided vtkFieldData. It inserts Id, ParentID, SeedID and Termination.
-   * Reimplement as needed in acccordance with InitializePathData.
+   * Reimplement as needed in accordance with InitializePathData.
    */
   virtual void InsertPathData(vtkLagrangianParticle* particle, vtkFieldData* data);
 
   /**
-   * Method used by the LPT to insert data from the partice into
+   * Method used by the LPT to insert data from the particle into
    * the provided vtkFieldData. It inserts Interaction.
-   * Reimplement as needed in acccordance with InitializeInteractionData.
+   * Reimplement as needed in accordance with InitializeInteractionData.
    */
   virtual void InsertInteractionData(vtkLagrangianParticle* particle, vtkFieldData* data);
 
   /**
-   * Method used by the LPT to insert data from the partice into
+   * Method used by the LPT to insert data from the particle into
    * the provided vtkFieldData. It inserts StepNumber, ParticleVelocity, IntegrationTime.
    * stepEnum enables to select which data to insert, Prev, Current or Next.
-   * Reimplement as needed in acccordance with InitializeParticleData.
+   * Reimplement as needed in accordance with InitializeParticleData.
    */
   virtual void InsertParticleData(
     vtkLagrangianParticle* particle, vtkFieldData* data, int stepEnum);
 
   /**
-   * Method used by the LPT to insert data from the partice into
+   * Method used by the LPT to insert data from the particle into
    * the provided vtkFieldData. It inserts all arrays from the original SeedData.
    * Reimplement as needed.
    */
@@ -475,6 +473,15 @@ public:
    */
   virtual void ParticleAboutToBeDeleted(vtkLagrangianParticle* vtkNotUsed(particle)) {}
 
+  /**
+   * Method to be reimplemented if needed in inherited classes.
+   * Allows a inherited class to add surface interaction data from the model
+   */
+  virtual void InsertSurfaceInteractionData(
+    vtkLagrangianParticle* vtkNotUsed(particle), vtkPointData* vtkNotUsed(particleData))
+  {
+  }
+
 protected:
   vtkLagrangianBasicIntegrationModel();
   ~vtkLagrangianBasicIntegrationModel() override;
@@ -595,7 +602,7 @@ protected:
    * Method used by ParaView surface helper to get default
    * values for each leaf of each dataset of surface
    * nComponents could be retrieved with arrayName but is
-   * given for simplication purposes.
+   * given for simplification purposes.
    * it is your responsibility to initialize all components of
    * defaultValues[nComponent]
    */
@@ -649,4 +656,5 @@ private:
   void operator=(const vtkLagrangianBasicIntegrationModel&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
