@@ -50,9 +50,8 @@
 #include <limits>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkLagrangianParticleTracker);
-vtkCxxSetObjectMacro(
-  vtkLagrangianParticleTracker, IntegrationModel, vtkLagrangianBasicIntegrationModel);
 vtkCxxSetObjectMacro(vtkLagrangianParticleTracker, Integrator, vtkInitialValueProblemSolver);
 
 struct IntegratingFunctor
@@ -110,8 +109,17 @@ struct IntegratingFunctor
 
   void operator()(vtkIdType partId, vtkIdType endPartId)
   {
+    bool isFirst = vtkSMPTools::GetSingleThread();
     for (vtkIdType id = partId; id < endPartId; id++)
     {
+      if (isFirst)
+      {
+        this->Tracker->CheckAbort();
+      }
+      if (this->Tracker->GetAbortOutput())
+      {
+        break;
+      }
       vtkLagrangianParticle* particle = this->ParticlesVec[id];
       vtkLagrangianThreadedData* localData = this->LocalData.Local();
 
@@ -219,9 +227,11 @@ struct IntegratingFunctor
   }
 };
 
+static constexpr double MAX_REINTEGRATION_FACTOR = 1.0e10;
+
 //------------------------------------------------------------------------------
 vtkLagrangianParticleTracker::vtkLagrangianParticleTracker()
-  : IntegrationModel(vtkLagrangianMatidaIntegrationModel::New())
+  : IntegrationModel(vtkSmartPointer<vtkLagrangianMatidaIntegrationModel>::New())
   , Integrator(vtkRungeKutta2::New())
   , CellLengthComputationMode(STEP_CUR_CELL_LENGTH)
   , StepFactor(1.0)
@@ -250,7 +260,6 @@ vtkLagrangianParticleTracker::vtkLagrangianParticleTracker()
 vtkLagrangianParticleTracker::~vtkLagrangianParticleTracker()
 {
   this->SetIntegrator(nullptr);
-  this->SetIntegrationModel(nullptr);
 }
 
 //------------------------------------------------------------------------------
@@ -323,6 +332,18 @@ void vtkLagrangianParticleTracker::SetSurfaceData(vtkDataObject* surface)
   this->SetInputData(2, surface);
 }
 
+//------------------------------------------------------------------------------
+void vtkLagrangianParticleTracker::SetIntegrationModel(vtkLagrangianBasicIntegrationModel* model)
+{
+  if (this->IntegrationModel != model)
+  {
+    this->IntegrationModel = model;
+    this->SurfaceCacheInvalid = true;
+    this->FlowCacheInvalid = true;
+    this->Modified();
+  }
+}
+
 //------------------------------------------------------------------------------
 vtkDataObject* vtkLagrangianParticleTracker::GetSurface()
 {
@@ -514,7 +535,7 @@ int vtkLagrangianParticleTracker::RequestData(vtkInformation* vtkNotUsed(request
   this->IntegrationModel->PreIntegrate(particlesQueue);
 
   std::vector<vtkLagrangianParticle*> particlesVec;
-  while (!this->GetAbortExecute())
+  while (!this->CheckAbort())
   {
     // Check for particle feed
     this->GetParticleFeed(particlesQueue);
@@ -544,7 +565,7 @@ int vtkLagrangianParticleTracker::RequestData(vtkInformation* vtkNotUsed(request
   this->IntegrationModel->FinalizeThreadedData(this->SerialThreadedData);
 
   // Abort if necessary
-  if (this->GetAbortExecute())
+  if (this->CheckAbort())
   {
     // delete all remaining particle
     while (!particlesQueue.empty())
@@ -686,11 +707,11 @@ bool vtkLagrangianParticleTracker::FinalizeOutputs(
         }
         if (this->GeneratePolyVertexInteractionOutput)
         {
-          this->InsertPolyVertexCell(pdBlock);
+          vtkLagrangianParticleTracker::InsertPolyVertexCell(pdBlock);
         }
         else
         {
-          this->InsertVertexCells(pdBlock);
+          vtkLagrangianParticleTracker::InsertVertexCells(pdBlock);
         }
       }
     }
@@ -698,11 +719,11 @@ bool vtkLagrangianParticleTracker::FinalizeOutputs(
     {
       if (this->GeneratePolyVertexInteractionOutput)
       {
-        this->InsertPolyVertexCell(pdInteractionOutput);
+        vtkLagrangianParticleTracker::InsertPolyVertexCell(pdInteractionOutput);
       }
       else
       {
-        this->InsertVertexCells(pdInteractionOutput);
+        vtkLagrangianParticleTracker::InsertVertexCells(pdInteractionOutput);
       }
     }
   }
@@ -752,7 +773,7 @@ void vtkLagrangianParticleTracker::InsertVertexCells(vtkPolyData* polydata)
 bool vtkLagrangianParticleTracker::InitializeFlow(vtkDataObject* input, vtkBoundingBox* bounds)
 {
   // Check for updated cache
-  if (input == this->FlowCache && input->GetMTime() <= this->FlowTime &&
+  if (!this->FlowCacheInvalid && input == this->FlowCache && input->GetMTime() <= this->FlowTime &&
     this->IntegrationModel->GetLocatorsBuilt())
   {
     bounds->Reset();
@@ -802,16 +823,19 @@ bool vtkLagrangianParticleTracker::InitializeFlow(vtkDataObject* input, vtkBound
   this->FlowTime = input->GetMTime();
   this->FlowBoundsCache.Reset();
   this->FlowBoundsCache.AddBox(*bounds);
+  this->FlowCacheInvalid = false;
   return true;
 }
 
 //------------------------------------------------------------------------------
 bool vtkLagrangianParticleTracker::UpdateSurfaceCacheIfNeeded(vtkDataObject*& surfaces)
 {
-  if (surfaces != this->SurfacesCache || surfaces->GetMTime() > this->SurfacesTime)
+  if (this->SurfaceCacheInvalid || surfaces != this->SurfacesCache ||
+    surfaces->GetMTime() > this->SurfacesTime)
   {
     this->SurfacesCache = surfaces;
     this->SurfacesTime = surfaces->GetMTime();
+    this->SurfaceCacheInvalid = false;
     return true;
   }
   return false;
@@ -1044,6 +1068,12 @@ int vtkLagrangianParticleTracker::Integrate(vtkInitialValueProblemSolver* integr
       if (stepLengthCurr2 > stepLengthMax2)
       {
         reintegrationFactor *= 2;
+        if (reintegrationFactor > MAX_REINTEGRATION_FACTOR)
+        {
+          vtkErrorMacro(<< "ReintegrationFactor is too high. Dropping particle.");
+          particle->SetTermination(vtkLagrangianParticle::PARTICLE_TERMINATION_ABORTED);
+          break;
+        }
         continue;
       }
       reintegrationFactor = 1;
@@ -1229,6 +1259,9 @@ void vtkLagrangianParticleTracker::InsertInteractionOutputPoint(vtkLagrangianPar
   this->IntegrationModel->InsertParticleData(
     particle, pointData, vtkLagrangianBasicIntegrationModel::VARIABLE_STEP_NEXT);
 
+  // Let models add surface interaction data from the model
+  this->IntegrationModel->InsertSurfaceInteractionData(particle, pointData);
+
   // Finally, Insert data from seed data only on not yet written arrays
   this->IntegrationModel->InsertParticleSeedData(particle, pointData);
 }
@@ -1352,3 +1385,4 @@ void vtkLagrangianParticleTracker::DeleteParticle(vtkLagrangianParticle* particl
   this->IntegrationModel->ParticleAboutToBeDeleted(particle);
   delete particle;
 }
+VTK_ABI_NAMESPACE_END
