@@ -21,31 +21,29 @@
  *
  * @sa
  * vtkParticlePathFilterBase has the details of the algorithms
-*/
+ */
 
 #ifndef vtkParticlePathFilter_h
 #define vtkParticlePathFilter_h
 
 #include "vtkFiltersFlowPathsModule.h" // For export macro
-#include "vtkSmartPointer.h" // For protected ivars.
 #include "vtkParticleTracerBase.h"
-#include <vector> // For protected ivars
+#include "vtkSmartPointer.h" // For protected ivars.
+#include <vector>            // For protected ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSFLOWPATHS_EXPORT ParticlePathFilterInternal
 {
 public:
-  ParticlePathFilterInternal():Filter(nullptr){}
+  ParticlePathFilterInternal()
+    : Filter(nullptr)
+  {
+  }
   void Initialize(vtkParticleTracerBase* filter);
-  virtual ~ParticlePathFilterInternal(){}
-  virtual int OutputParticles(vtkPolyData* poly);
-  void SetClearCache(bool clearCache)
-  {
-    this->ClearCache = clearCache;
-  }
-  bool GetClearCache()
-  {
-    return this->ClearCache;
-  }
+  virtual ~ParticlePathFilterInternal() = default;
+  virtual int OutputParticles(vtkPolyData* particles);
+  void SetClearCache(bool clearCache) { this->ClearCache = clearCache; }
+  bool GetClearCache() { return this->ClearCache; }
   void Finalize();
   void Reset();
 
@@ -53,17 +51,17 @@ private:
   vtkParticleTracerBase* Filter;
   // Paths doesn't seem to work properly. it is meant to make connecting lines
   // for the particles
-  std::vector<vtkSmartPointer<vtkIdList> > Paths;
+  std::vector<vtkSmartPointer<vtkIdList>> Paths;
   bool ClearCache; // false by default
 };
 
-class VTKFILTERSFLOWPATHS_EXPORT vtkParticlePathFilter: public vtkParticleTracerBase
+class VTKFILTERSFLOWPATHS_EXPORT vtkParticlePathFilter : public vtkParticleTracerBase
 {
 public:
-  vtkTypeMacro(vtkParticlePathFilter,vtkParticleTracerBase)
+  vtkTypeMacro(vtkParticlePathFilter, vtkParticleTracerBase);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  static vtkParticlePathFilter *New();
+  static vtkParticlePathFilter* New();
 
 protected:
   vtkParticlePathFilter();
@@ -72,9 +70,10 @@ protected:
   void operator=(const vtkParticlePathFilter&) = delete;
 
   void ResetCache() override;
-  int OutputParticles(vtkPolyData* poly) override;
+  int OutputParticles(vtkPolyData* particles) override;
   void InitializeExtraPointDataArrays(vtkPointData* outputPD) override;
-  void AppendToExtraPointDataArrays(vtkParticleTracerBaseNamespace::ParticleInformation &) override;
+  void SetToExtraPointDataArrays(
+    vtkIdType particleId, vtkParticleTracerBaseNamespace::ParticleInformation&) override;
 
   void Finalize() override;
 
@@ -82,9 +81,8 @@ protected:
   // Store any information we need in the output and fetch what we can
   // from the input
   //
-  int RequestInformation(vtkInformation* request,
-                         vtkInformationVector** inputVector,
-                         vtkInformationVector* outputVector) override;
+  int RequestInformation(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
 
   ParticlePathFilterInternal It;
 
@@ -93,4 +91,5 @@ private:
   vtkIntArray* SimulationTimeStep;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
