@@ -28,17 +28,18 @@
 #ifndef vtkParticleTracerBase_h
 #define vtkParticleTracerBase_h
 
+#include "vtkDeprecation.h"            // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkFiltersFlowPathsModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
-#include "vtkSmartPointer.h" // For protected ivars.
+#include "vtkSmartPointer.h" // For vtkSmartPointer
 
 #include <list>   // STL Header
+#include <mutex>  // STL Header
 #include <vector> // STL Header
 
-class vtkAbstractInterpolatedVelocityField;
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractParticleWriter;
 class vtkCellArray;
-class vtkCharArray;
 class vtkCompositeDataSet;
 class vtkDataArray;
 class vtkDataSet;
@@ -52,10 +53,13 @@ class vtkMultiProcessController;
 class vtkPointData;
 class vtkPoints;
 class vtkPolyData;
+class vtkSignedCharArray;
 class vtkTemporalInterpolatedVelocityField;
+VTK_ABI_NAMESPACE_END
 
 namespace vtkParticleTracerBaseNamespace
 {
+VTK_ABI_NAMESPACE_BEGIN
 struct Position_t
 {
   double x[4];
@@ -84,7 +88,7 @@ struct ParticleInformation_t
   float angularVel;
   float time;
   float speed;
-  // once the partice is added, PointId is valid and is the tuple location
+  // once the particle is added, PointId is valid and is the tuple location
   // in ProtoPD.
   vtkIdType PointId;
   // if PointId is negative then in parallel this particle was just
@@ -97,11 +101,15 @@ typedef std::vector<ParticleInformation> ParticleVector;
 typedef ParticleVector::iterator ParticleIterator;
 typedef std::list<ParticleInformation> ParticleDataList;
 typedef ParticleDataList::iterator ParticleListIterator;
+struct ParticleTracerFunctor;
+VTK_ABI_NAMESPACE_END
 };
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSFLOWPATHS_EXPORT vtkParticleTracerBase : public vtkPolyDataAlgorithm
 {
 public:
+  friend struct vtkParticleTracerBaseNamespace::ParticleTracerFunctor;
   enum Solvers
   {
     RUNGE_KUTTA2,
@@ -115,7 +123,7 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent) override;
   void PrintParticleHistories();
 
-  //@{
+  ///@{
   /**
    * Turn on/off vorticity computation at streamline points
    * (necessary for generating proper stream-ribbons using the
@@ -123,26 +131,26 @@ public:
    */
   vtkGetMacro(ComputeVorticity, bool);
   void SetComputeVorticity(bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the terminal speed value, below which integration is terminated.
    */
   vtkGetMacro(TerminalSpeed, double);
   void SetTerminalSpeed(double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This can be used to scale the rate with which the streamribbons
    * twist. The default is 1.
    */
   vtkGetMacro(RotationScale, double);
   void SetRotationScale(double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * To get around problems with the Paraview Animation controls
    * we can just animate the time step and ignore the TIME_ requests
@@ -150,9 +158,9 @@ public:
   vtkSetMacro(IgnorePipelineTime, vtkTypeBool);
   vtkGetMacro(IgnorePipelineTime, vtkTypeBool);
   vtkBooleanMacro(IgnorePipelineTime, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When animating particles, it is nice to inject new ones every Nth step
    * to produce a continuous flow. Setting ForceReinjectionEveryNSteps to a
@@ -162,11 +170,11 @@ public:
    * redundant as the particles will be reinjected whenever the source changes
    * anyway
    */
-  vtkGetMacro(ForceReinjectionEveryNSteps, int);
-  void SetForceReinjectionEveryNSteps(int);
-  //@}
+  vtkGetMacro(ForceReinjectionEveryNSteps, vtkTypeBool);
+  void SetForceReinjectionEveryNSteps(vtkTypeBool);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Setting TerminationTime to a positive value will cause particles
    * to terminate when the time is reached. Use a vlue of zero to
@@ -175,7 +183,7 @@ public:
    */
   void SetTerminationTime(double t);
   vtkGetMacro(TerminationTime, double);
-  //@}
+  ///@}
 
   void SetIntegrator(vtkInitialValueProblemSolver*);
   vtkGetObjectMacro(Integrator, vtkInitialValueProblemSolver);
@@ -183,16 +191,16 @@ public:
   void SetIntegratorType(int type);
   int GetIntegratorType();
 
-  //@{
+  ///@{
   /**
    * Set the time value for particle tracing to begin. The units of time should
    * be consistent with the primary time variable.
    */
   vtkGetMacro(StartTime, double);
   void SetStartTime(double t);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * if StaticSeeds is set and the mesh is static,
    * then every time particles are injected we can re-use the same
@@ -202,11 +210,41 @@ public:
    * the motion will be ignored and results will not be as expected.
    * The default is that StaticSeeds is 0.
    */
-  vtkSetMacro(StaticSeeds, int);
-  vtkGetMacro(StaticSeeds, int);
-  //@}
+  vtkSetMacro(StaticSeeds, vtkTypeBool);
+  vtkGetMacro(StaticSeeds, vtkTypeBool);
+  ///@}
 
-  //@{
+  /**
+   * Types of Variance of Mesh over time
+   */
+  enum MeshOverTimeTypes
+  {
+    DIFFERENT = 0,
+    STATIC = 1,
+    LINEAR_TRANSFORMATION = 2,
+    SAME_TOPOLOGY = 3
+  };
+
+  ///@{
+  /*
+   * Set/Get the type of variance of the mesh over time.
+   *
+   * DIFFERENT = 0,
+   * STATIC = 1,
+   * LINEAR_TRANSFORMATION = 2
+   * SAME_TOPOLOGY = 3
+   */
+  virtual void SetMeshOverTime(int meshOverTime);
+  virtual int GetMeshOverTimeMinValue() { return DIFFERENT; }
+  virtual int GetMeshOverTimeMaxValue() { return SAME_TOPOLOGY; }
+  void SetMeshOverTimeToDifferent() { this->SetMeshOverTime(DIFFERENT); }
+  void SetMeshOverTimeToStatic() { this->SetMeshOverTime(STATIC); }
+  void SetMeshOverTimeToLinearTransformation() { this->SetMeshOverTime(LINEAR_TRANSFORMATION); }
+  void SetMeshOverTimeToSameTopology() { this->SetMeshOverTime(SAME_TOPOLOGY); }
+  vtkGetMacro(MeshOverTime, int);
+  ///@}
+
+  ///@{
   /**
    * if StaticMesh is set, many optimizations for cell caching
    * can be assumed. if StaticMesh is not set, the algorithm
@@ -216,11 +254,52 @@ public:
    * as this will invalidate all results.
    * The default is that StaticMesh is 0.
    */
-  vtkSetMacro(StaticMesh, int);
-  vtkGetMacro(StaticMesh, int);
-  //@}
+  VTK_DEPRECATED_IN_9_2_0("Use SetMeshOverTime instead")
+  virtual void SetStaticMesh(vtkTypeBool staticMesh)
+  {
+    this->SetMeshOverTime(staticMesh ? STATIC : DIFFERENT);
+  }
+  VTK_DEPRECATED_IN_9_2_0("Use GetMeshOverTime instead")
+  virtual vtkTypeBool GetStaticMesh() { return this->MeshOverTime == STATIC; }
+  ///@}
 
-  //@{
+  enum
+  {
+    INTERPOLATOR_WITH_DATASET_POINT_LOCATOR,
+    INTERPOLATOR_WITH_CELL_LOCATOR
+  };
+
+  /**
+   * Set the type of the velocity field interpolator to determine whether
+   * INTERPOLATOR_WITH_DATASET_POINT_LOCATOR or INTERPOLATOR_WITH_CELL_LOCATOR
+   * is employed for locating cells during streamline integration. The latter
+   * (adopting vtkAbstractCellLocator sub-classes such as vtkCellLocator and
+   * vtkModifiedBSPTree) is more robust than the former (through vtkDataSet /
+   * vtkPointSet::FindCell() coupled with vtkPointLocator). However the former
+   * can be much faster and produce adequate results.
+   *
+   * Default is INTERPOLATOR_WITH_CELL_LOCATOR (to maintain backwards compatibility).
+   */
+  void SetInterpolatorType(int interpolatorType);
+
+  /**
+   * Set the velocity field interpolator type to one that uses a point
+   * locator to perform local spatial searching. Typically a point locator is
+   * faster than searches with a cell locator, but it may not always find the
+   * correct cells enclosing a point. This is particularly true with meshes
+   * that are disjoint at seams, or abut meshes in an incompatible manner.
+   */
+  void SetInterpolatorTypeToDataSetPointLocator();
+
+  /**
+   * Set the velocity field interpolator type to one that uses a cell locator
+   * to perform spatial searching. Using a cell locator should always return
+   * the correct results, but it can be much slower that point locator-based
+   * searches. * By default a cell locator is used.
+   */
+  void SetInterpolatorTypeToCellLocator();
+
+  ///@{
   /**
    * Set/Get the Writer associated with this Particle Tracer
    * Ideally a parallel IO capable vtkH5PartWriter should be used
@@ -229,18 +308,18 @@ public:
    */
   virtual void SetParticleWriter(vtkAbstractParticleWriter* pw);
   vtkGetObjectMacro(ParticleWriter, vtkAbstractParticleWriter);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the filename to be used with the particle writer when
    * dumping particles to disk
    */
-  vtkSetStringMacro(ParticleFileName);
-  vtkGetStringMacro(ParticleFileName);
-  //@}
+  vtkSetFilePathMacro(ParticleFileName);
+  vtkGetFilePathMacro(ParticleFileName);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the filename to be used with the particle writer when
    * dumping particles to disk
@@ -248,9 +327,9 @@ public:
   vtkSetMacro(EnableParticleWriting, vtkTypeBool);
   vtkGetMacro(EnableParticleWriting, vtkTypeBool);
   vtkBooleanMacro(EnableParticleWriting, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the flag to disable cache
    * This is off by default and turned on in special circumstances
@@ -259,19 +338,28 @@ public:
   vtkSetMacro(DisableResetCache, vtkTypeBool);
   vtkGetMacro(DisableResetCache, vtkTypeBool);
   vtkBooleanMacro(DisableResetCache, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Provide support for multiple seed sources
    */
   void AddSourceConnection(vtkAlgorithmOutput* input);
   void RemoveAllSources();
-  //@}
+  ///@}
 
+  ///@{
+  /**
+   * Force the filter to run particle tracer in serial. This affects
+   * the filter only if more than 100 particles is to be generated.
+   */
+  vtkGetMacro(ForceSerialExecution, bool);
+  vtkSetMacro(ForceSerialExecution, bool);
+  vtkBooleanMacro(ForceSerialExecution, bool);
+  ///@}
 protected:
   vtkSmartPointer<vtkPolyData> Output; // managed by child classes
-  //@{
+  ///@{
   /**
    * ProtoPD is used just to keep track of the input array names and number of components
    * for copy allocating from other vtkPointDatas where the data is really stored
@@ -284,7 +372,10 @@ protected:
   // Everything related to time
   vtkTypeBool IgnorePipelineTime; // whether to use the pipeline time for termination
   vtkTypeBool DisableResetCache;  // whether to enable ResetCache() method
-  //@}
+  ///@}
+
+  // Control execution as serial or threaded
+  bool ForceSerialExecution;
 
   vtkParticleTracerBase();
   ~vtkParticleTracerBase() override;
@@ -344,9 +435,7 @@ protected:
    */
   virtual std::vector<vtkDataSet*> GetSeedSources(vtkInformationVector* inputVector, int timeStep);
 
-  //
   // Initialization of input (vector-field) geometry
-  //
   int InitializeInterpolator();
   int UpdateDataCache(vtkDataObject* td);
 
@@ -392,7 +481,9 @@ protected:
    * particle between the two times supplied.
    */
   void IntegrateParticle(vtkParticleTracerBaseNamespace::ParticleListIterator& it,
-    double currenttime, double terminationtime, vtkInitialValueProblemSolver* integrator);
+    double currentTime, double targetTime, vtkInitialValueProblemSolver* integrator,
+    vtkTemporalInterpolatedVelocityField* interpolator, vtkDoubleArray* cellVectors,
+    std::atomic<vtkIdType>& particleCount, std::mutex& eraseMutex, bool sequential);
 
   // if the particle is added to send list, then returns value is 1,
   // if it is kept on this process after a retry return value is 0
@@ -418,7 +509,7 @@ protected:
 
   vtkFloatArray* GetParticleAge(vtkPointData*);
   vtkIntArray* GetParticleIds(vtkPointData*);
-  vtkCharArray* GetParticleSourceIds(vtkPointData*);
+  vtkSignedCharArray* GetParticleSourceIds(vtkPointData*);
   vtkIntArray* GetInjectedPointIds(vtkPointData*);
   vtkIntArray* GetInjectedStepIds(vtkPointData*);
   vtkIntArray* GetErrorCodeArr(vtkPointData*);
@@ -438,9 +529,11 @@ protected:
   double GetCacheDataTime();
 
   virtual void ResetCache();
-  void AddParticle(vtkParticleTracerBaseNamespace::ParticleInformation& info, double* velocity);
+  void SetParticle(vtkParticleTracerBaseNamespace::ParticleInformation& info, double* velocity,
+    vtkTemporalInterpolatedVelocityField* interpolator, vtkIdType particleId,
+    vtkDoubleArray* cellVectors);
 
-  //@{
+  ///@{
   /**
    * Methods that check that the input arrays are ordered the
    * same on all data sets. This needs to be true for all
@@ -449,18 +542,23 @@ protected:
   virtual bool IsPointDataValid(vtkDataObject* input);
   bool IsPointDataValid(vtkCompositeDataSet* input, std::vector<std::string>& arrayNames);
   void GetPointDataArrayNames(vtkDataSet* input, std::vector<std::string>& names);
-  //@}
+  ///@}
 
   vtkGetMacro(ReinjectionCounter, int);
   vtkGetMacro(CurrentTimeValue, double);
 
+  void ResizeArrays(vtkIdType numTuples);
+
   /**
    * Methods to append values to existing point data arrays that may
    * only be desired on specific concrete derived classes.
    */
   virtual void InitializeExtraPointDataArrays(vtkPointData* vtkNotUsed(outputPD)) {}
 
-  virtual void AppendToExtraPointDataArrays(vtkParticleTracerBaseNamespace::ParticleInformation&) {}
+  virtual void SetToExtraPointDataArrays(
+    vtkIdType, vtkParticleTracerBaseNamespace::ParticleInformation&)
+  {
+  }
 
   vtkTemporalInterpolatedVelocityField* GetInterpolator();
 
@@ -470,12 +568,13 @@ protected:
    */
   virtual void AddRestartSeeds(vtkInformationVector** /*inputVector*/) {}
 
-private:
   /**
-   * Hide this because we require a new interpolator type
+   * Recover the ghost array in provided point data
+   * and rename it by adding "Original_" in front of it, if available.
    */
-  void SetInterpolatorPrototype(vtkAbstractInterpolatedVelocityField*) {}
+  virtual void RenameGhostArray(vtkPointData* pd);
 
+private:
   /**
    * When particles leave the domain, they must be collected
    * and sent to the other processes for possible continuation.
@@ -486,7 +585,7 @@ private:
    * to the integrator that is used.
    */
   bool RetryWithPush(vtkParticleTracerBaseNamespace::ParticleInformation& info, double* point1,
-    double delT, int subSteps);
+    double delT, int subSteps, vtkTemporalInterpolatedVelocityField* interpolator);
 
   bool SetTerminationTimeNoModify(double t);
 
@@ -502,9 +601,9 @@ private:
   int ReinjectionCounter;
 
   // Important for Caching of Cells/Ids/Weights etc
-  int AllFixedGeometry;
-  int StaticMesh;
-  int StaticSeeds;
+  vtkTypeBool AllFixedGeometry;
+  int MeshOverTime;
+  vtkTypeBool StaticSeeds;
 
   std::vector<double> InputTimeValues;
   double StartTime;
@@ -518,7 +617,7 @@ private:
   bool FirstIteration;
 
   // Innjection parameters
-  int ForceReinjectionEveryNSteps;
+  vtkTypeBool ForceReinjectionEveryNSteps;
   vtkTimeStamp ParticleInjectionTime;
   bool HasCache;
 
@@ -532,7 +631,6 @@ private:
 
   // The velocity interpolator
   vtkSmartPointer<vtkTemporalInterpolatedVelocityField> Interpolator;
-  vtkAbstractInterpolatedVelocityField* InterpolatorPrototype;
 
   // Data for time step CurrentTimeStep-1 and CurrentTimeStep
   vtkSmartPointer<vtkMultiBlockDataSet> CachedData[2];
@@ -545,22 +643,28 @@ private:
   using bounds = struct bounds_t;
   std::vector<bounds> CachedBounds[2];
 
-  // temporary variables used by Exeucte(), for convenience only
+  // variables used by Execute() to produce output
+
+  vtkSmartPointer<vtkDataSet> DataReferenceT[2];
 
   vtkSmartPointer<vtkPoints> OutputCoordinates;
+  vtkSmartPointer<vtkIdTypeArray> ParticleCellsConnectivity;
+  vtkSmartPointer<vtkIdTypeArray> ParticleCellsOffsets;
+  vtkSmartPointer<vtkCellArray> ParticleCells;
+
   vtkSmartPointer<vtkFloatArray> ParticleAge;
   vtkSmartPointer<vtkIntArray> ParticleIds;
-  vtkSmartPointer<vtkCharArray> ParticleSourceIds;
+  vtkSmartPointer<vtkSignedCharArray> ParticleSourceIds;
   vtkSmartPointer<vtkIntArray> InjectedPointIds;
   vtkSmartPointer<vtkIntArray> InjectedStepIds;
   vtkSmartPointer<vtkIntArray> ErrorCodeArray;
   vtkSmartPointer<vtkFloatArray> ParticleVorticity;
   vtkSmartPointer<vtkFloatArray> ParticleRotation;
   vtkSmartPointer<vtkFloatArray> ParticleAngularVel;
-  vtkSmartPointer<vtkDoubleArray> CellVectors;
   vtkSmartPointer<vtkPointData> OutputPointData;
-  vtkSmartPointer<vtkDataSet> DataReferenceT[2];
-  vtkSmartPointer<vtkCellArray> ParticleCells;
+
+  // temp array
+  vtkSmartPointer<vtkDoubleArray> CellVectors;
 
   vtkParticleTracerBase(const vtkParticleTracerBase&) = delete;
   void operator=(const vtkParticleTracerBase&) = delete;
@@ -574,4 +678,5 @@ private:
   static const double Epsilon;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
