@@ -84,10 +84,8 @@
  * vtkRibbonFilter vtkRuledSurfaceFilter vtkInitialValueProblemSolver
  * vtkRungeKutta2 vtkRungeKutta4 vtkRungeKutta45 vtkParticleTracerBase
  * vtkParticleTracer vtkParticlePathFilter vtkStreaklineFilter
- * vtkAbstractInterpolatedVelocityField vtkInterpolatedVelocityField
- * vtkCellLocatorInterpolatedVelocityField vtkSMPTools
- * vtkPStreamTracer
- *
+ * vtkAbstractInterpolatedVelocityField vtkCompositeInterpolatedVelocityField
+ * vtkAMRInterpolatedVelocityField vtkSMPTools vtkPStreamTracer
  */
 
 #ifndef vtkStreamTracer_h
@@ -99,6 +97,7 @@
 #include "vtkDataSetAttributesFieldList.h" // Needed to identify common data arrays
 #include "vtkInitialValueProblemSolver.h"  // Needed for constants
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractInterpolatedVelocityField;
 class vtkCompositeDataSet;
 class vtkDataArray;
@@ -110,9 +109,11 @@ class vtkIdList;
 class vtkIntArray;
 class vtkPoints;
 
+VTK_ABI_NAMESPACE_END
 #include <vector> // for std::vector
 
 // Helper struct to convert between different length scales.
+VTK_ABI_NAMESPACE_BEGIN
 struct VTKFILTERSFLOWPATHS_EXPORT vtkIntervalInformation
 {
   double Interval;
@@ -399,13 +400,15 @@ public:
    * of the same class as this prototype. The performance of streamline
    * generations can be significantly affected by the choice of the
    * interpolator, particularly its use of the locator to use.
+   *
+   * For non AMR datasets, initialize a vtkCompositeInterpolatedVelocityField
+   * and set the FindCellStrategyType.
    */
   void SetInterpolatorPrototype(vtkAbstractInterpolatedVelocityField* ivf);
 
   /**
    * Set the type of the velocity field interpolator to determine whether
-   * vtkInterpolatedVelocityField (INTERPOLATOR_WITH_DATASET_POINT_LOCATOR) or
-   * vtkCellLocatorInterpolatedVelocityField (INTERPOLATOR_WITH_CELL_LOCATOR)
+   * INTERPOLATOR_WITH_DATASET_POINT_LOCATOR or INTERPOLATOR_WITH_CELL_LOCATOR
    * is employed for locating cells during streamline integration. The latter
    * (adopting vtkAbstractCellLocator sub-classes such as vtkCellLocator and
    * vtkModifiedBSPTree) is more robust than the former (through vtkDataSet /
@@ -555,7 +558,7 @@ protected:
 
   // Only relevant for this derived parallel version of vtkStreamTracer,
   // but needs to be defined in this class to have a uniform interface
-  // betwen this class and the parallel override vtkPStreamTracer
+  // between this class and the parallel override vtkPStreamTracer
   bool UseLocalSeedSource;
 
   friend class PStreamTracerUtils;
@@ -565,4 +568,5 @@ private:
   void operator=(const vtkStreamTracer&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
