@@ -2,8 +2,18 @@
 import sys
 import vtk
 from vtk.util.misc import vtkGetDataRoot
+
 VTK_DATA_ROOT = vtkGetDataRoot()
 
+try:
+    import numpy as np
+    from vtk.util.numpy_support import numpy_to_vtk as ntov
+except ImportError:
+    print("WARNING: This test requires Numeric Python: http://numpy.sf.net")
+    from vtk.test import Testing
+
+    Testing.skip()
+
 # Prevent .pyc files being created.
 # Stops the vtk source being polluted
 # by .pyc files.
@@ -13,21 +23,23 @@ import backdrop
 
 # clip every quadratic cell type
 # Create a scene with one of each cell type.
+
 # QuadraticEdge
 edgePoints = vtk.vtkPoints()
 edgePoints.SetNumberOfPoints(3)
-edgePoints.InsertPoint(0, 0, 0, 0)
-edgePoints.InsertPoint(1, 1.0, 0, 0)
-edgePoints.InsertPoint(2, 0.5, 0.25, 0)
+edgePointsCoords = np.array([
+    [0, 0, 0],
+    [1.0, 0, 0],
+    [0.5, 0.25, 0]])
+edgePoints.SetData(ntov(edgePointsCoords))
 edgeScalars = vtk.vtkFloatArray()
 edgeScalars.SetNumberOfTuples(3)
 edgeScalars.InsertValue(0, 0.0)
 edgeScalars.InsertValue(1, 0.0)
 edgeScalars.InsertValue(2, 0.9)
 aEdge = vtk.vtkQuadraticEdge()
-aEdge.GetPointIds().SetId(0, 0)
-aEdge.GetPointIds().SetId(1, 1)
-aEdge.GetPointIds().SetId(2, 2)
+for i in range(aEdge.GetNumberOfPoints()):
+    aEdge.GetPointIds().SetId(i, i)
 aEdgeGrid = vtk.vtkUnstructuredGrid()
 aEdgeGrid.Allocate(1, 1)
 aEdgeGrid.InsertNextCell(aEdge.GetCellType(), aEdge.GetPointIds())
@@ -54,12 +66,14 @@ aEdgeclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic triangle
 triPoints = vtk.vtkPoints()
 triPoints.SetNumberOfPoints(6)
-triPoints.InsertPoint(0, 0.0, 0.0, 0.0)
-triPoints.InsertPoint(1, 1.0, 0.0, 0.0)
-triPoints.InsertPoint(2, 0.5, 0.8, 0.0)
-triPoints.InsertPoint(3, 0.5, 0.0, 0.0)
-triPoints.InsertPoint(4, 0.75, 0.4, 0.0)
-triPoints.InsertPoint(5, 0.25, 0.4, 0.0)
+triPointsCoords = np.array([
+    [0.0, 0.0, 0.0],
+    [1.0, 0.0, 0.0],
+    [0.5, 0.8, 0.0],
+    [0.5, 0.0, 0.0],
+    [0.75, 0.4, 0.0],
+    [0.25, 0.4, 0.0]])
+triPoints.SetData(ntov(triPointsCoords))
 triScalars = vtk.vtkFloatArray()
 triScalars.SetNumberOfTuples(6)
 triScalars.InsertValue(0, 0.0)
@@ -69,12 +83,8 @@ triScalars.InsertValue(3, 1.0)
 triScalars.InsertValue(4, 0.0)
 triScalars.InsertValue(5, 0.0)
 aTri = vtk.vtkQuadraticTriangle()
-aTri.GetPointIds().SetId(0, 0)
-aTri.GetPointIds().SetId(1, 1)
-aTri.GetPointIds().SetId(2, 2)
-aTri.GetPointIds().SetId(3, 3)
-aTri.GetPointIds().SetId(4, 4)
-aTri.GetPointIds().SetId(5, 5)
+for i in range(aTri.GetNumberOfPoints()):
+    aTri.GetPointIds().SetId(i, i)
 aTriGrid = vtk.vtkUnstructuredGrid()
 aTriGrid.Allocate(1, 1)
 aTriGrid.InsertNextCell(aTri.GetCellType(), aTri.GetPointIds())
@@ -101,14 +111,16 @@ aTriclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic quadrilateral
 quadPoints = vtk.vtkPoints()
 quadPoints.SetNumberOfPoints(8)
-quadPoints.InsertPoint(0, 0.0, 0.0, 0.0)
-quadPoints.InsertPoint(1, 1.0, 0.0, 0.0)
-quadPoints.InsertPoint(2, 1.0, 1.0, 0.0)
-quadPoints.InsertPoint(3, 0.0, 1.0, 0.0)
-quadPoints.InsertPoint(4, 0.5, 0.0, 0.0)
-quadPoints.InsertPoint(5, 1.0, 0.5, 0.0)
-quadPoints.InsertPoint(6, 0.5, 1.0, 0.0)
-quadPoints.InsertPoint(7, 0.0, 0.5, 0.0)
+quadPointsCoords = np.array([
+    [0.0, 0.0, 0.0],
+    [1.0, 0.0, 0.0],
+    [1.0, 1.0, 0.0],
+    [0.0, 1.0, 0.0],
+    [0.5, 0.0, 0.0],
+    [1.0, 0.5, 0.0],
+    [0.5, 1.0, 0.0],
+    [0.0, 0.5, 0.0]])
+quadPoints.SetData(ntov(quadPointsCoords))
 quadScalars = vtk.vtkFloatArray()
 quadScalars.SetNumberOfTuples(8)
 quadScalars.InsertValue(0, 0.0)
@@ -120,14 +132,8 @@ quadScalars.InsertValue(5, 0.0)
 quadScalars.InsertValue(6, 0.0)
 quadScalars.InsertValue(7, 0.0)
 aQuad = vtk.vtkQuadraticQuad()
-aQuad.GetPointIds().SetId(0, 0)
-aQuad.GetPointIds().SetId(1, 1)
-aQuad.GetPointIds().SetId(2, 2)
-aQuad.GetPointIds().SetId(3, 3)
-aQuad.GetPointIds().SetId(4, 4)
-aQuad.GetPointIds().SetId(5, 5)
-aQuad.GetPointIds().SetId(6, 6)
-aQuad.GetPointIds().SetId(7, 7)
+for i in range(aQuad.GetNumberOfPoints()):
+    aQuad.GetPointIds().SetId(i, i)
 aQuadGrid = vtk.vtkUnstructuredGrid()
 aQuadGrid.Allocate(1, 1)
 aQuadGrid.InsertNextCell(aQuad.GetCellType(), aQuad.GetPointIds())
@@ -154,15 +160,17 @@ aQuadclipActor.GetProperty().SetAmbient(1.0)
 # BiQuadratic quadrilateral
 BquadPoints = vtk.vtkPoints()
 BquadPoints.SetNumberOfPoints(9)
-BquadPoints.InsertPoint(0, 0.0, 0.0, 0.0)
-BquadPoints.InsertPoint(1, 1.0, 0.0, 0.0)
-BquadPoints.InsertPoint(2, 1.0, 1.0, 0.0)
-BquadPoints.InsertPoint(3, 0.0, 1.0, 0.0)
-BquadPoints.InsertPoint(4, 0.5, 0.0, 0.0)
-BquadPoints.InsertPoint(5, 1.0, 0.5, 0.0)
-BquadPoints.InsertPoint(6, 0.5, 1.0, 0.0)
-BquadPoints.InsertPoint(7, 0.0, 0.5, 0.0)
-BquadPoints.InsertPoint(8, 0.5, 0.5, 0.0)
+BquadPointsCoords = np.array([
+    [0.0, 0.0, 0.0],
+    [1.0, 0.0, 0.0],
+    [1.0, 1.0, 0.0],
+    [0.0, 1.0, 0.0],
+    [0.5, 0.0, 0.0],
+    [1.0, 0.5, 0.0],
+    [0.5, 1.0, 0.0],
+    [0.0, 0.5, 0.0],
+    [0.5, 0.5, 0.0]])
+BquadPoints.SetData(ntov(BquadPointsCoords))
 BquadScalars = vtk.vtkFloatArray()
 BquadScalars.SetNumberOfTuples(9)
 BquadScalars.InsertValue(0, 1.0)
@@ -175,15 +183,8 @@ BquadScalars.InsertValue(6, 0.0)
 BquadScalars.InsertValue(7, 0.0)
 BquadScalars.InsertValue(8, 1.0)
 BQuad = vtk.vtkBiQuadraticQuad()
-BQuad.GetPointIds().SetId(0, 0)
-BQuad.GetPointIds().SetId(1, 1)
-BQuad.GetPointIds().SetId(2, 2)
-BQuad.GetPointIds().SetId(3, 3)
-BQuad.GetPointIds().SetId(4, 4)
-BQuad.GetPointIds().SetId(5, 5)
-BQuad.GetPointIds().SetId(6, 6)
-BQuad.GetPointIds().SetId(7, 7)
-BQuad.GetPointIds().SetId(8, 8)
+for i in range(BQuad.GetNumberOfPoints()):
+    BQuad.GetPointIds().SetId(i, i)
 BQuadGrid = vtk.vtkUnstructuredGrid()
 BQuadGrid.Allocate(1, 1)
 BQuadGrid.InsertNextCell(BQuad.GetCellType(), BQuad.GetPointIds())
@@ -210,12 +211,14 @@ BQuadclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic linear quadrilateral
 QLquadPoints = vtk.vtkPoints()
 QLquadPoints.SetNumberOfPoints(6)
-QLquadPoints.InsertPoint(0, 0.0, 0.0, 0.0)
-QLquadPoints.InsertPoint(1, 1.0, 0.0, 0.0)
-QLquadPoints.InsertPoint(2, 1.0, 1.0, 0.0)
-QLquadPoints.InsertPoint(3, 0.0, 1.0, 0.0)
-QLquadPoints.InsertPoint(4, 0.5, 0.0, 0.0)
-QLquadPoints.InsertPoint(5, 0.5, 1.0, 0.0)
+QLquadPointsCoords = np.array([
+    [0.0, 0.0, 0.0],
+    [1.0, 0.0, 0.0],
+    [1.0, 1.0, 0.0],
+    [0.0, 1.0, 0.0],
+    [0.5, 0.0, 0.0],
+    [0.5, 1.0, 0.0]])
+QLquadPoints.SetData(ntov(QLquadPointsCoords))
 QLquadScalars = vtk.vtkFloatArray()
 QLquadScalars.SetNumberOfTuples(6)
 QLquadScalars.InsertValue(0, 1.0)
@@ -225,12 +228,8 @@ QLquadScalars.InsertValue(3, 0.0)
 QLquadScalars.InsertValue(4, 0.0)
 QLquadScalars.InsertValue(5, 1.0)
 QLQuad = vtk.vtkQuadraticLinearQuad()
-QLQuad.GetPointIds().SetId(0, 0)
-QLQuad.GetPointIds().SetId(1, 1)
-QLQuad.GetPointIds().SetId(2, 2)
-QLQuad.GetPointIds().SetId(3, 3)
-QLQuad.GetPointIds().SetId(4, 4)
-QLQuad.GetPointIds().SetId(5, 5)
+for i in range(QLQuad.GetNumberOfPoints()):
+    QLQuad.GetPointIds().SetId(i, i)
 QLQuadGrid = vtk.vtkUnstructuredGrid()
 QLQuadGrid.Allocate(1, 1)
 QLQuadGrid.InsertNextCell(QLQuad.GetCellType(), QLQuad.GetPointIds())
@@ -257,16 +256,18 @@ QLQuadclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic tetrahedron
 tetPoints = vtk.vtkPoints()
 tetPoints.SetNumberOfPoints(10)
-tetPoints.InsertPoint(0, 0.0, 0.0, 0.0)
-tetPoints.InsertPoint(1, 1.0, 0.0, 0.0)
-tetPoints.InsertPoint(2, 0.5, 0.8, 0.0)
-tetPoints.InsertPoint(3, 0.5, 0.4, 1.0)
-tetPoints.InsertPoint(4, 0.5, 0.0, 0.0)
-tetPoints.InsertPoint(5, 0.75, 0.4, 0.0)
-tetPoints.InsertPoint(6, 0.25, 0.4, 0.0)
-tetPoints.InsertPoint(7, 0.25, 0.2, 0.5)
-tetPoints.InsertPoint(8, 0.75, 0.2, 0.5)
-tetPoints.InsertPoint(9, 0.50, 0.6, 0.5)
+tetPointsCoords = np.array([
+    [0.0, 0.0, 0.0],
+    [1.0, 0.0, 0.0],
+    [0.5, 0.8, 0.0],
+    [0.5, 0.4, 1.0],
+    [0.5, 0.0, 0.0],
+    [0.75, 0.4, 0.0],
+    [0.25, 0.4, 0.0],
+    [0.25, 0.2, 0.5],
+    [0.75, 0.2, 0.5],
+    [0.50, 0.6, 0.5]])
+tetPoints.SetData(ntov(tetPointsCoords))
 tetScalars = vtk.vtkFloatArray()
 tetScalars.SetNumberOfTuples(10)
 tetScalars.InsertValue(0, 1.0)
@@ -280,16 +281,8 @@ tetScalars.InsertValue(7, 0.0)
 tetScalars.InsertValue(8, 0.0)
 tetScalars.InsertValue(9, 0.0)
 aTet = vtk.vtkQuadraticTetra()
-aTet.GetPointIds().SetId(0, 0)
-aTet.GetPointIds().SetId(1, 1)
-aTet.GetPointIds().SetId(2, 2)
-aTet.GetPointIds().SetId(3, 3)
-aTet.GetPointIds().SetId(4, 4)
-aTet.GetPointIds().SetId(5, 5)
-aTet.GetPointIds().SetId(6, 6)
-aTet.GetPointIds().SetId(7, 7)
-aTet.GetPointIds().SetId(8, 8)
-aTet.GetPointIds().SetId(9, 9)
+for i in range(aTet.GetNumberOfPoints()):
+    aTet.GetPointIds().SetId(i, i)
 aTetGrid = vtk.vtkUnstructuredGrid()
 aTetGrid.Allocate(1, 1)
 aTetGrid.InsertNextCell(aTet.GetCellType(), aTet.GetPointIds())
@@ -315,26 +308,28 @@ aTetclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic hexahedron
 hexPoints = vtk.vtkPoints()
 hexPoints.SetNumberOfPoints(20)
-hexPoints.InsertPoint(0, 0, 0, 0)
-hexPoints.InsertPoint(1, 1, 0, 0)
-hexPoints.InsertPoint(2, 1, 1, 0)
-hexPoints.InsertPoint(3, 0, 1, 0)
-hexPoints.InsertPoint(4, 0, 0, 1)
-hexPoints.InsertPoint(5, 1, 0, 1)
-hexPoints.InsertPoint(6, 1, 1, 1)
-hexPoints.InsertPoint(7, 0, 1, 1)
-hexPoints.InsertPoint(8, 0.5, 0, 0)
-hexPoints.InsertPoint(9, 1, 0.5, 0)
-hexPoints.InsertPoint(10, 0.5, 1, 0)
-hexPoints.InsertPoint(11, 0, 0.5, 0)
-hexPoints.InsertPoint(12, 0.5, 0, 1)
-hexPoints.InsertPoint(13, 1, 0.5, 1)
-hexPoints.InsertPoint(14, 0.5, 1, 1)
-hexPoints.InsertPoint(15, 0, 0.5, 1)
-hexPoints.InsertPoint(16, 0, 0, 0.5)
-hexPoints.InsertPoint(17, 1, 0, 0.5)
-hexPoints.InsertPoint(18, 1, 1, 0.5)
-hexPoints.InsertPoint(19, 0, 1, 0.5)
+hexPointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [1, 1, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [1, 0, 1],
+    [1, 1, 1],
+    [0, 1, 1],
+    [0.5, 0, 0],
+    [1, 0.5, 0],
+    [0.5, 1, 0],
+    [0, 0.5, 0],
+    [0.5, 0, 1],
+    [1, 0.5, 1],
+    [0.5, 1, 1],
+    [0, 0.5, 1],
+    [0, 0, 0.5],
+    [1, 0, 0.5],
+    [1, 1, 0.5],
+    [0, 1, 0.5]])
+hexPoints.SetData(ntov(hexPointsCoords))
 hexScalars = vtk.vtkFloatArray()
 hexScalars.SetNumberOfTuples(20)
 hexScalars.InsertValue(0, 1.0)
@@ -358,26 +353,8 @@ hexScalars.InsertValue(17, 0.0)
 hexScalars.InsertValue(18, 0.0)
 hexScalars.InsertValue(19, 0.0)
 aHex = vtk.vtkQuadraticHexahedron()
-aHex.GetPointIds().SetId(0, 0)
-aHex.GetPointIds().SetId(1, 1)
-aHex.GetPointIds().SetId(2, 2)
-aHex.GetPointIds().SetId(3, 3)
-aHex.GetPointIds().SetId(4, 4)
-aHex.GetPointIds().SetId(5, 5)
-aHex.GetPointIds().SetId(6, 6)
-aHex.GetPointIds().SetId(7, 7)
-aHex.GetPointIds().SetId(8, 8)
-aHex.GetPointIds().SetId(9, 9)
-aHex.GetPointIds().SetId(10, 10)
-aHex.GetPointIds().SetId(11, 11)
-aHex.GetPointIds().SetId(12, 12)
-aHex.GetPointIds().SetId(13, 13)
-aHex.GetPointIds().SetId(14, 14)
-aHex.GetPointIds().SetId(15, 15)
-aHex.GetPointIds().SetId(16, 16)
-aHex.GetPointIds().SetId(17, 17)
-aHex.GetPointIds().SetId(18, 18)
-aHex.GetPointIds().SetId(19, 19)
+for i in range(aHex.GetNumberOfPoints()):
+    aHex.GetPointIds().SetId(i, i)
 aHexGrid = vtk.vtkUnstructuredGrid()
 aHexGrid.Allocate(1, 1)
 aHexGrid.InsertNextCell(aHex.GetCellType(), aHex.GetPointIds())
@@ -403,33 +380,35 @@ aHexclipActor.GetProperty().SetAmbient(1.0)
 # TriQuadratic hexahedron
 TQhexPoints = vtk.vtkPoints()
 TQhexPoints.SetNumberOfPoints(27)
-TQhexPoints.InsertPoint(0, 0, 0, 0)
-TQhexPoints.InsertPoint(1, 1, 0, 0)
-TQhexPoints.InsertPoint(2, 1, 1, 0)
-TQhexPoints.InsertPoint(3, 0, 1, 0)
-TQhexPoints.InsertPoint(4, 0, 0, 1)
-TQhexPoints.InsertPoint(5, 1, 0, 1)
-TQhexPoints.InsertPoint(6, 1, 1, 1)
-TQhexPoints.InsertPoint(7, 0, 1, 1)
-TQhexPoints.InsertPoint(8, 0.5, 0, 0)
-TQhexPoints.InsertPoint(9, 1, 0.5, 0)
-TQhexPoints.InsertPoint(10, 0.5, 1, 0)
-TQhexPoints.InsertPoint(11, 0, 0.5, 0)
-TQhexPoints.InsertPoint(12, 0.5, 0, 1)
-TQhexPoints.InsertPoint(13, 1, 0.5, 1)
-TQhexPoints.InsertPoint(14, 0.5, 1, 1)
-TQhexPoints.InsertPoint(15, 0, 0.5, 1)
-TQhexPoints.InsertPoint(16, 0, 0, 0.5)
-TQhexPoints.InsertPoint(17, 1, 0, 0.5)
-TQhexPoints.InsertPoint(18, 1, 1, 0.5)
-TQhexPoints.InsertPoint(19, 0, 1, 0.5)
-TQhexPoints.InsertPoint(22, 0.5, 0, 0.5)
-TQhexPoints.InsertPoint(21, 1, 0.5, 0.5)
-TQhexPoints.InsertPoint(23, 0.5, 1, 0.5)
-TQhexPoints.InsertPoint(20, 0, 0.5, 0.5)
-TQhexPoints.InsertPoint(24, 0.5, 0.5, 0.0)
-TQhexPoints.InsertPoint(25, 0.5, 0.5, 1)
-TQhexPoints.InsertPoint(26, 0.5, 0.5, 0.5)
+TQhexPointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [1, 1, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [1, 0, 1],
+    [1, 1, 1],
+    [0, 1, 1],
+    [0.5, 0, 0],
+    [1, 0.5, 0],
+    [0.5, 1, 0],
+    [0, 0.5, 0],
+    [0.5, 0, 1],
+    [1, 0.5, 1],
+    [0.5, 1, 1],
+    [0, 0.5, 1],
+    [0, 0, 0.5],
+    [1, 0, 0.5],
+    [1, 1, 0.5],
+    [0, 1, 0.5],
+    [0, 0.5, 0.5],
+    [1, 0.5, 0.5],
+    [0.5, 0, 0.5],
+    [0.5, 1, 0.5],
+    [0.5, 0.5, 0.0],
+    [0.5, 0.5, 1],
+    [0.5, 0.5, 0.5]])
+TQhexPoints.SetData(ntov(TQhexPointsCoords))
 TQhexScalars = vtk.vtkFloatArray()
 TQhexScalars.SetNumberOfTuples(27)
 TQhexScalars.InsertValue(0, 1.0)
@@ -460,33 +439,8 @@ TQhexScalars.InsertValue(24, 0.0)
 TQhexScalars.InsertValue(25, 0.0)
 TQhexScalars.InsertValue(26, 0.0)
 TQHex = vtk.vtkTriQuadraticHexahedron()
-TQHex.GetPointIds().SetId(0, 0)
-TQHex.GetPointIds().SetId(1, 1)
-TQHex.GetPointIds().SetId(2, 2)
-TQHex.GetPointIds().SetId(3, 3)
-TQHex.GetPointIds().SetId(4, 4)
-TQHex.GetPointIds().SetId(5, 5)
-TQHex.GetPointIds().SetId(6, 6)
-TQHex.GetPointIds().SetId(7, 7)
-TQHex.GetPointIds().SetId(8, 8)
-TQHex.GetPointIds().SetId(9, 9)
-TQHex.GetPointIds().SetId(10, 10)
-TQHex.GetPointIds().SetId(11, 11)
-TQHex.GetPointIds().SetId(12, 12)
-TQHex.GetPointIds().SetId(13, 13)
-TQHex.GetPointIds().SetId(14, 14)
-TQHex.GetPointIds().SetId(15, 15)
-TQHex.GetPointIds().SetId(16, 16)
-TQHex.GetPointIds().SetId(17, 17)
-TQHex.GetPointIds().SetId(18, 18)
-TQHex.GetPointIds().SetId(19, 19)
-TQHex.GetPointIds().SetId(20, 20)
-TQHex.GetPointIds().SetId(21, 21)
-TQHex.GetPointIds().SetId(22, 22)
-TQHex.GetPointIds().SetId(23, 23)
-TQHex.GetPointIds().SetId(24, 24)
-TQHex.GetPointIds().SetId(25, 25)
-TQHex.GetPointIds().SetId(26, 26)
+for i in range(TQHex.GetNumberOfPoints()):
+    TQHex.GetPointIds().SetId(i, i)
 TQHexGrid = vtk.vtkUnstructuredGrid()
 TQHexGrid.Allocate(1, 1)
 TQHexGrid.InsertNextCell(TQHex.GetCellType(), TQHex.GetPointIds())
@@ -512,29 +466,32 @@ TQHexclipActor.GetProperty().SetAmbient(1.0)
 # BiQuadratic Quadratic hexahedron
 BQhexPoints = vtk.vtkPoints()
 BQhexPoints.SetNumberOfPoints(24)
-BQhexPoints.InsertPoint(0, 0, 0, 0)
-BQhexPoints.InsertPoint(1, 1, 0, 0)
-BQhexPoints.InsertPoint(2, 1, 1, 0)
-BQhexPoints.InsertPoint(3, 0, 1, 0)
-BQhexPoints.InsertPoint(4, 0, 0, 1)
-BQhexPoints.InsertPoint(5, 1, 0, 1)
-BQhexPoints.InsertPoint(6, 1, 1, 1)
-BQhexPoints.InsertPoint(7, 0, 1, 1)
-BQhexPoints.InsertPoint(8, 0.5, 0, 0)
-BQhexPoints.InsertPoint(9, 1, 0.5, 0)
-BQhexPoints.InsertPoint(10, 0.5, 1, 0)
-BQhexPoints.InsertPoint(11, 0, 0.5, 0)
-BQhexPoints.InsertPoint(12, 0.5, 0, 1)
-BQhexPoints.InsertPoint(13, 1, 0.5, 1)
-BQhexPoints.InsertPoint(14, 0.5, 1, 1)
-BQhexPoints.InsertPoint(15, 0, 0.5, 1)
-BQhexPoints.InsertPoint(16, 0, 0, 0.5)
-BQhexPoints.InsertPoint(17, 1, 0, 0.5)
-BQhexPoints.InsertPoint(18, 1, 1, 0.5)
-BQhexPoints.InsertPoint(19, 0, 1, 0.5)
-BQhexPoints.InsertPoint(22, 0.5, 0, 0.5)
-BQhexPoints.InsertPoint(21, 1, 0.5, 0.5)
-BQhexPoints.InsertPoint(23, 0.5, 1, 0.5)
+BQhexPointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [1, 1, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [1, 0, 1],
+    [1, 1, 1],
+    [0, 1, 1],
+    [0.5, 0, 0],
+    [1, 0.5, 0],
+    [0.5, 1, 0],
+    [0, 0.5, 0],
+    [0.5, 0, 1],
+    [1, 0.5, 1],
+    [0.5, 1, 1],
+    [0, 0.5, 1],
+    [0, 0, 0.5],
+    [1, 0, 0.5],
+    [1, 1, 0.5],
+    [0, 1, 0.5],
+    [0, 0.5, 0.5],
+    [1, 0.5, 0.5],
+    [0.5, 0, 0.5],
+    [0.5, 1, 0.5]])
+BQhexPoints.SetData(ntov(BQhexPointsCoords))
 BQhexPoints.InsertPoint(20, 0, 0.5, 0.5)
 BQhexScalars = vtk.vtkFloatArray()
 BQhexScalars.SetNumberOfTuples(24)
@@ -563,30 +520,8 @@ BQhexScalars.InsertValue(21, 0.0)
 BQhexScalars.InsertValue(22, 0.0)
 BQhexScalars.InsertValue(23, 0.0)
 BQHex = vtk.vtkBiQuadraticQuadraticHexahedron()
-BQHex.GetPointIds().SetId(0, 0)
-BQHex.GetPointIds().SetId(1, 1)
-BQHex.GetPointIds().SetId(2, 2)
-BQHex.GetPointIds().SetId(3, 3)
-BQHex.GetPointIds().SetId(4, 4)
-BQHex.GetPointIds().SetId(5, 5)
-BQHex.GetPointIds().SetId(6, 6)
-BQHex.GetPointIds().SetId(7, 7)
-BQHex.GetPointIds().SetId(8, 8)
-BQHex.GetPointIds().SetId(9, 9)
-BQHex.GetPointIds().SetId(10, 10)
-BQHex.GetPointIds().SetId(11, 11)
-BQHex.GetPointIds().SetId(12, 12)
-BQHex.GetPointIds().SetId(13, 13)
-BQHex.GetPointIds().SetId(14, 14)
-BQHex.GetPointIds().SetId(15, 15)
-BQHex.GetPointIds().SetId(16, 16)
-BQHex.GetPointIds().SetId(17, 17)
-BQHex.GetPointIds().SetId(18, 18)
-BQHex.GetPointIds().SetId(19, 19)
-BQHex.GetPointIds().SetId(20, 20)
-BQHex.GetPointIds().SetId(21, 21)
-BQHex.GetPointIds().SetId(22, 22)
-BQHex.GetPointIds().SetId(23, 23)
+for i in range(BQHex.GetNumberOfPoints()):
+    BQHex.GetPointIds().SetId(i, i)
 BQHexGrid = vtk.vtkUnstructuredGrid()
 BQHexGrid.Allocate(1, 1)
 BQHexGrid.InsertNextCell(BQHex.GetCellType(), BQHex.GetPointIds())
@@ -612,21 +547,23 @@ BQHexclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic wedge
 wedgePoints = vtk.vtkPoints()
 wedgePoints.SetNumberOfPoints(15)
-wedgePoints.InsertPoint(0, 0, 0, 0)
-wedgePoints.InsertPoint(1, 1, 0, 0)
-wedgePoints.InsertPoint(2, 0, 1, 0)
-wedgePoints.InsertPoint(3, 0, 0, 1)
-wedgePoints.InsertPoint(4, 1, 0, 1)
-wedgePoints.InsertPoint(5, 0, 1, 1)
-wedgePoints.InsertPoint(6, 0.5, 0, 0)
-wedgePoints.InsertPoint(7, 0.5, 0.5, 0)
-wedgePoints.InsertPoint(8, 0, 0.5, 0)
-wedgePoints.InsertPoint(9, 0.5, 0, 1)
-wedgePoints.InsertPoint(10, 0.5, 0.5, 1)
-wedgePoints.InsertPoint(11, 0, 0.5, 1)
-wedgePoints.InsertPoint(12, 0, 0, 0.5)
-wedgePoints.InsertPoint(13, 1, 0, 0.5)
-wedgePoints.InsertPoint(14, 0, 1, 0.5)
+wedgePointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [1, 0, 1],
+    [0, 1, 1],
+    [0.5, 0, 0],
+    [0.5, 0.5, 0],
+    [0, 0.5, 0],
+    [0.5, 0, 1],
+    [0.5, 0.5, 1],
+    [0, 0.5, 1],
+    [0, 0, 0.5],
+    [1, 0, 0.5],
+    [0, 1, 0.5]])
+wedgePoints.SetData(ntov(wedgePointsCoords))
 wedgeScalars = vtk.vtkFloatArray()
 wedgeScalars.SetNumberOfTuples(15)
 wedgeScalars.InsertValue(0, 1.0)
@@ -645,21 +582,8 @@ wedgeScalars.InsertValue(12, 0.0)
 wedgeScalars.InsertValue(13, 0.0)
 wedgeScalars.InsertValue(14, 0.0)
 aWedge = vtk.vtkQuadraticWedge()
-aWedge.GetPointIds().SetId(0, 0)
-aWedge.GetPointIds().SetId(1, 1)
-aWedge.GetPointIds().SetId(2, 2)
-aWedge.GetPointIds().SetId(3, 3)
-aWedge.GetPointIds().SetId(4, 4)
-aWedge.GetPointIds().SetId(5, 5)
-aWedge.GetPointIds().SetId(6, 6)
-aWedge.GetPointIds().SetId(7, 7)
-aWedge.GetPointIds().SetId(8, 8)
-aWedge.GetPointIds().SetId(9, 9)
-aWedge.GetPointIds().SetId(10, 10)
-aWedge.GetPointIds().SetId(11, 11)
-aWedge.GetPointIds().SetId(12, 12)
-aWedge.GetPointIds().SetId(13, 13)
-aWedge.GetPointIds().SetId(14, 14)
+for i in range(aWedge.GetNumberOfPoints()):
+    aWedge.GetPointIds().SetId(i, i)
 aWedgeGrid = vtk.vtkUnstructuredGrid()
 aWedgeGrid.Allocate(1, 1)
 aWedgeGrid.InsertNextCell(aWedge.GetCellType(), aWedge.GetPointIds())
@@ -685,18 +609,20 @@ aWedgeclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic linear wedge
 QLwedgePoints = vtk.vtkPoints()
 QLwedgePoints.SetNumberOfPoints(12)
-QLwedgePoints.InsertPoint(0, 0, 0, 0)
-QLwedgePoints.InsertPoint(1, 1, 0, 0)
-QLwedgePoints.InsertPoint(2, 0, 1, 0)
-QLwedgePoints.InsertPoint(3, 0, 0, 1)
-QLwedgePoints.InsertPoint(4, 1, 0, 1)
-QLwedgePoints.InsertPoint(5, 0, 1, 1)
-QLwedgePoints.InsertPoint(6, 0.5, 0, 0)
-QLwedgePoints.InsertPoint(7, 0.5, 0.5, 0)
-QLwedgePoints.InsertPoint(8, 0, 0.5, 0)
-QLwedgePoints.InsertPoint(9, 0.5, 0, 1)
-QLwedgePoints.InsertPoint(10, 0.5, 0.5, 1)
-QLwedgePoints.InsertPoint(11, 0, 0.5, 1)
+QLwedgePointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [1, 0, 1],
+    [0, 1, 1],
+    [0.5, 0, 0],
+    [0.5, 0.5, 0],
+    [0, 0.5, 0],
+    [0.5, 0, 1],
+    [0.5, 0.5, 1],
+    [0, 0.5, 1]])
+QLwedgePoints.SetData(ntov(QLwedgePointsCoords))
 QLwedgeScalars = vtk.vtkFloatArray()
 QLwedgeScalars.SetNumberOfTuples(12)
 QLwedgeScalars.InsertValue(0, 1.0)
@@ -712,20 +638,8 @@ QLwedgeScalars.InsertValue(9, 0.0)
 QLwedgeScalars.InsertValue(10, 0.0)
 QLwedgeScalars.InsertValue(11, 0.0)
 QLWedge = vtk.vtkQuadraticLinearWedge()
-QLWedge.GetPointIds().SetId(0, 0)
-QLWedge.GetPointIds().SetId(1, 1)
-QLWedge.GetPointIds().SetId(2, 2)
-QLWedge.GetPointIds().SetId(3, 3)
-QLWedge.GetPointIds().SetId(4, 4)
-QLWedge.GetPointIds().SetId(5, 5)
-QLWedge.GetPointIds().SetId(6, 6)
-QLWedge.GetPointIds().SetId(7, 7)
-QLWedge.GetPointIds().SetId(8, 8)
-QLWedge.GetPointIds().SetId(9, 9)
-QLWedge.GetPointIds().SetId(10, 10)
-QLWedge.GetPointIds().SetId(11, 11)
-
-# QLaWedge DebugOn
+for i in range(QLWedge.GetNumberOfPoints()):
+    QLWedge.GetPointIds().SetId(i, i)
 QLWedgeGrid = vtk.vtkUnstructuredGrid()
 QLWedgeGrid.Allocate(1, 1)
 QLWedgeGrid.InsertNextCell(QLWedge.GetCellType(), QLWedge.GetPointIds())
@@ -739,7 +653,7 @@ QLWedgeclipMapper.SetInputConnection(QLwedgeclips.GetOutputPort())
 QLWedgeclipMapper.ScalarVisibilityOff()
 QLWedgeMapper = vtk.vtkDataSetMapper()
 QLWedgeMapper.SetInputData(QLWedgeGrid)
-aWedgeMapper.ScalarVisibilityOff()
+QLWedgeMapper.ScalarVisibilityOff()
 QLWedgeActor = vtk.vtkActor()
 QLWedgeActor.SetMapper(QLWedgeMapper)
 QLWedgeActor.GetProperty().SetRepresentationToWireframe()
@@ -751,24 +665,26 @@ QLWedgeclipActor.GetProperty().SetAmbient(1.0)
 # BiQuadratic wedge
 BQwedgePoints = vtk.vtkPoints()
 BQwedgePoints.SetNumberOfPoints(18)
-BQwedgePoints.InsertPoint(0, 0, 0, 0)
-BQwedgePoints.InsertPoint(1, 1, 0, 0)
-BQwedgePoints.InsertPoint(2, 0, 1, 0)
-BQwedgePoints.InsertPoint(3, 0, 0, 1)
-BQwedgePoints.InsertPoint(4, 1, 0, 1)
-BQwedgePoints.InsertPoint(5, 0, 1, 1)
-BQwedgePoints.InsertPoint(6, 0.5, 0, 0)
-BQwedgePoints.InsertPoint(7, 0.5, 0.5, 0)
-BQwedgePoints.InsertPoint(8, 0, 0.5, 0)
-BQwedgePoints.InsertPoint(9, 0.5, 0, 1)
-BQwedgePoints.InsertPoint(10, 0.5, 0.5, 1)
-BQwedgePoints.InsertPoint(11, 0, 0.5, 1)
-BQwedgePoints.InsertPoint(12, 0, 0, 0.5)
-BQwedgePoints.InsertPoint(13, 1, 0, 0.5)
-BQwedgePoints.InsertPoint(14, 0, 1, 0.5)
-BQwedgePoints.InsertPoint(15, 0.5, 0, 0.5)
-BQwedgePoints.InsertPoint(16, 0.5, 0.5, 0.5)
-BQwedgePoints.InsertPoint(17, 0, 0.5, 0.5)
+BQwedgePointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [1, 0, 1],
+    [0, 1, 1],
+    [0.5, 0, 0],
+    [0.5, 0.5, 0],
+    [0, 0.5, 0],
+    [0.5, 0, 1],
+    [0.5, 0.5, 1],
+    [0, 0.5, 1],
+    [0, 0, 0.5],
+    [1, 0, 0.5],
+    [0, 1, 0.5],
+    [0.5, 0, 0.5],
+    [0.5, 0.5, 0.5],
+    [0, 0.5, 0.5]])
+BQwedgePoints.SetData(ntov(BQwedgePointsCoords))
 BQwedgeScalars = vtk.vtkFloatArray()
 BQwedgeScalars.SetNumberOfTuples(18)
 BQwedgeScalars.InsertValue(0, 1.0)
@@ -790,26 +706,8 @@ BQwedgeScalars.InsertValue(15, 0.0)
 BQwedgeScalars.InsertValue(16, 0.0)
 BQwedgeScalars.InsertValue(17, 0.0)
 BQWedge = vtk.vtkBiQuadraticQuadraticWedge()
-BQWedge.GetPointIds().SetId(0, 0)
-BQWedge.GetPointIds().SetId(1, 1)
-BQWedge.GetPointIds().SetId(2, 2)
-BQWedge.GetPointIds().SetId(3, 3)
-BQWedge.GetPointIds().SetId(4, 4)
-BQWedge.GetPointIds().SetId(5, 5)
-BQWedge.GetPointIds().SetId(6, 6)
-BQWedge.GetPointIds().SetId(7, 7)
-BQWedge.GetPointIds().SetId(8, 8)
-BQWedge.GetPointIds().SetId(9, 9)
-BQWedge.GetPointIds().SetId(10, 10)
-BQWedge.GetPointIds().SetId(11, 11)
-BQWedge.GetPointIds().SetId(12, 12)
-BQWedge.GetPointIds().SetId(13, 13)
-BQWedge.GetPointIds().SetId(14, 14)
-BQWedge.GetPointIds().SetId(15, 15)
-BQWedge.GetPointIds().SetId(16, 16)
-BQWedge.GetPointIds().SetId(17, 17)
-
-# BQWedge DebugOn
+for i in range(BQWedge.GetNumberOfPoints()):
+    BQWedge.GetPointIds().SetId(i, i)
 BQWedgeGrid = vtk.vtkUnstructuredGrid()
 BQWedgeGrid.Allocate(1, 1)
 BQWedgeGrid.InsertNextCell(BQWedge.GetCellType(), BQWedge.GetPointIds())
@@ -835,19 +733,21 @@ BQWedgeclipActor.GetProperty().SetAmbient(1.0)
 # Quadratic pyramid
 pyraPoints = vtk.vtkPoints()
 pyraPoints.SetNumberOfPoints(13)
-pyraPoints.InsertPoint(0, 0, 0, 0)
-pyraPoints.InsertPoint(1, 1, 0, 0)
-pyraPoints.InsertPoint(2, 1, 1, 0)
-pyraPoints.InsertPoint(3, 0, 1, 0)
-pyraPoints.InsertPoint(4, 0, 0, 1)
-pyraPoints.InsertPoint(5, 0.5, 0, 0)
-pyraPoints.InsertPoint(6, 1, 0.5, 0)
-pyraPoints.InsertPoint(7, 0.5, 1, 0)
-pyraPoints.InsertPoint(8, 0, 0.5, 0)
-pyraPoints.InsertPoint(9, 0, 0, 0.5)
-pyraPoints.InsertPoint(10, 0.5, 0, 0.5)
-pyraPoints.InsertPoint(11, 0.5, 0.5, 0.5)
-pyraPoints.InsertPoint(12, 0, 0.5, 0.5)
+pyraPointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [1, 1, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [0.5, 0, 0],
+    [1, 0.5, 0],
+    [0.5, 1, 0],
+    [0, 0.5, 0],
+    [0, 0, 0.5],
+    [0.5, 0, 0.5],
+    [0.5, 0.5, 0.5],
+    [0, 0.5, 0.5]])
+pyraPoints.SetData(ntov(pyraPointsCoords))
 pyraScalars = vtk.vtkFloatArray()
 pyraScalars.SetNumberOfTuples(13)
 pyraScalars.InsertValue(0, 1.0)
@@ -864,19 +764,8 @@ pyraScalars.InsertValue(10, 0.0)
 pyraScalars.InsertValue(11, 0.0)
 pyraScalars.InsertValue(12, 0.0)
 aPyramid = vtk.vtkQuadraticPyramid()
-aPyramid.GetPointIds().SetId(0, 0)
-aPyramid.GetPointIds().SetId(1, 1)
-aPyramid.GetPointIds().SetId(2, 2)
-aPyramid.GetPointIds().SetId(3, 3)
-aPyramid.GetPointIds().SetId(4, 4)
-aPyramid.GetPointIds().SetId(5, 5)
-aPyramid.GetPointIds().SetId(6, 6)
-aPyramid.GetPointIds().SetId(7, 7)
-aPyramid.GetPointIds().SetId(8, 8)
-aPyramid.GetPointIds().SetId(9, 9)
-aPyramid.GetPointIds().SetId(10, 10)
-aPyramid.GetPointIds().SetId(11, 11)
-aPyramid.GetPointIds().SetId(12, 12)
+for i in range(aPyramid.GetNumberOfPoints()):
+    aPyramid.GetPointIds().SetId(i, i)
 aPyramidGrid = vtk.vtkUnstructuredGrid()
 aPyramidGrid.Allocate(1, 1)
 aPyramidGrid.InsertNextCell(aPyramid.GetCellType(), aPyramid.GetPointIds())
@@ -899,6 +788,76 @@ aPyramidclipActor = vtk.vtkActor()
 aPyramidclipActor.SetMapper(aPyramidclipMapper)
 aPyramidclipActor.GetProperty().SetAmbient(1.0)
 
+# TriQuadratic pyramid
+TQpyraPoints = vtk.vtkPoints()
+TQpyraPoints.SetNumberOfPoints(19)
+TQpyraPointsCoords = np.array([
+    [0, 0, 0],
+    [1, 0, 0],
+    [1, 1, 0],
+    [0, 1, 0],
+    [0, 0, 1],
+    [0.5, 0, 0],
+    [1, 0.5, 0],
+    [0.5, 1, 0],
+    [0, 0.5, 0],
+    [0, 0, 0.5],
+    [0.5, 0, 0.5],
+    [0.5, 0.5, 0.5],
+    [0, 0.5, 0.5],
+    [0.5, 0.5, 0],
+    [1.0 / 3.0, 0, 1.0 / 3.0],
+    [2.0 / 3.0, 1.0 / 3.0, 1.0 / 3.0],
+    [1.0 / 3.0, 2.0 / 3.0, 1.0 / 3.0],
+    [0, 1.0 / 3.0, 1.0 / 3.0],
+    [0.4, 0.4, 0.2]])
+TQpyraPoints.SetData(ntov(TQpyraPointsCoords))
+TQpyraScalars = vtk.vtkFloatArray()
+TQpyraScalars.SetNumberOfTuples(19)
+TQpyraScalars.InsertValue(0, 1.0)
+TQpyraScalars.InsertValue(1, 1.0)
+TQpyraScalars.InsertValue(2, 1.0)
+TQpyraScalars.InsertValue(3, 1.0)
+TQpyraScalars.InsertValue(4, 1.0)
+TQpyraScalars.InsertValue(5, 0.0)
+TQpyraScalars.InsertValue(6, 0.0)
+TQpyraScalars.InsertValue(7, 0.0)
+TQpyraScalars.InsertValue(8, 0.0)
+TQpyraScalars.InsertValue(9, 0.0)
+TQpyraScalars.InsertValue(10, 0.0)
+TQpyraScalars.InsertValue(11, 0.0)
+TQpyraScalars.InsertValue(12, 0.0)
+TQpyraScalars.InsertValue(13, 0.0)
+TQpyraScalars.InsertValue(14, 0.0)
+TQpyraScalars.InsertValue(15, 0.0)
+TQpyraScalars.InsertValue(16, 0.0)
+TQpyraScalars.InsertValue(17, 0.0)
+TQpyraScalars.InsertValue(18, 0.0)
+aTQPyramid = vtk.vtkTriQuadraticPyramid()
+for i in range(aTQPyramid.GetNumberOfPoints()):
+    aTQPyramid.GetPointIds().SetId(i, i)
+aTQPyramidGrid = vtk.vtkUnstructuredGrid()
+aTQPyramidGrid.Allocate(1, 1)
+aTQPyramidGrid.InsertNextCell(aTQPyramid.GetCellType(), aTQPyramid.GetPointIds())
+aTQPyramidGrid.SetPoints(TQpyraPoints)
+aTQPyramidGrid.GetPointData().SetScalars(TQpyraScalars)
+TQpyraClips = vtk.vtkClipDataSet()
+TQpyraClips.SetInputData(aTQPyramidGrid)
+TQpyraClips.SetValue(0.5)
+aTQPyramidClipMapper = vtk.vtkDataSetMapper()
+aTQPyramidClipMapper.SetInputConnection(TQpyraClips.GetOutputPort())
+aTQPyramidClipMapper.ScalarVisibilityOff()
+aTQPyramidMapper = vtk.vtkDataSetMapper()
+aTQPyramidMapper.SetInputData(aTQPyramidGrid)
+aTQPyramidMapper.ScalarVisibilityOff()
+aTQPyramidActor = vtk.vtkActor()
+aTQPyramidActor.SetMapper(aTQPyramidMapper)
+aTQPyramidActor.GetProperty().SetRepresentationToWireframe()
+aTQPyramidActor.GetProperty().SetAmbient(1.0)
+aTQPyramidClipActor = vtk.vtkActor()
+aTQPyramidClipActor.SetMapper(aTQPyramidClipMapper)
+aTQPyramidClipActor.GetProperty().SetAmbient(1.0)
+
 # Create the rendering related stuff.
 # Since some of our actors are a single vertex, we need to remove all
 # cullers so the single vertex actors will render
@@ -952,6 +911,9 @@ ren1.AddActor(QLWedgeclipActor)
 ren1.AddActor(aPyramidActor)
 ren1.AddActor(aPyramidclipActor)
 
+ren1.AddActor(aTQPyramidActor)
+ren1.AddActor(aTQPyramidClipActor)
+
 # places everyone!!
 aEdgeclipActor.AddPosition(0, 2, 0)
 aTriActor.AddPosition(2, 0, 0)
@@ -977,7 +939,9 @@ aWedgeclipActor.AddPosition(10, 2, 0)
 QLWedgeclipActor.AddPosition(10, 2, 2)
 BQWedgeclipActor.AddPosition(10, 2, 4)
 aPyramidActor.AddPosition(12, 0, 0)
+aTQPyramidActor.AddPosition(12, 0, 2)
 aPyramidclipActor.AddPosition(12, 2, 0)
+aTQPyramidClipActor.AddPosition(12, 2, 2)
 
 [base, back, left] = backdrop.BuildBackdrop(-1, 15, -1, 4, -1, 6, .1)
 
@@ -997,4 +961,4 @@ renWin.Render()
 # render the image
 #
 iren.Initialize()
-#iren.Start()
+# iren.Start()
