@@ -23,7 +23,7 @@
  *
  * @sa
  * vtkAppendFilter vtkAppendPolyData
-*/
+ */
 
 #ifndef vtkAppendPoints_h
 #define vtkAppendPoints_h
@@ -31,14 +31,15 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGENERAL_EXPORT vtkAppendPoints : public vtkPolyDataAlgorithm
 {
 public:
-  static vtkAppendPoints *New();
-  vtkTypeMacro(vtkAppendPoints,vtkPolyDataAlgorithm);
+  static vtkAppendPoints* New();
+  vtkTypeMacro(vtkAppendPoints, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Sets the output array name to fill with the input connection index
    * for each point. This provides a way to trace a point back to a
@@ -46,9 +47,9 @@ public:
    */
   vtkSetStringMacro(InputIdArrayName);
   vtkGetStringMacro(InputIdArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output type. See the documentation
    * for the vtkAlgorithm::DesiredOutputPrecision enum for an explanation of
@@ -58,26 +59,25 @@ public:
    * precision is DEFAULT_PRECISION and all the inputs are single precision,
    * then the output will be single precision.
    */
-  vtkSetMacro(OutputPointsPrecision,int);
-  vtkGetMacro(OutputPointsPrecision,int);
-  //@}
+  vtkSetMacro(OutputPointsPrecision, int);
+  vtkGetMacro(OutputPointsPrecision, int);
+  ///@}
 
 protected:
   vtkAppendPoints();
   ~vtkAppendPoints() override;
 
   // Usual data generation method
-  int RequestData(vtkInformation *,
-                  vtkInformationVector **, vtkInformationVector *) override;
-  int FillInputPortInformation(int, vtkInformation *) override;
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
+  int FillInputPortInformation(int, vtkInformation*) override;
 
   char* InputIdArrayName;
   int OutputPointsPrecision;
+
 private:
   vtkAppendPoints(const vtkAppendPoints&) = delete;
   void operator=(const vtkAppendPoints&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-
