@@ -87,6 +87,7 @@
 #include <sstream>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCellValidator);
 
 //------------------------------------------------------------------------------
@@ -351,7 +352,7 @@ bool vtkCellValidator::Convex(vtkCell* cell, double vtkNotUsed(tolerance))
         polyhedron_pointIds[i] = i;
       }
 
-      // udpate the face ids
+      // update the face ids
       vtkIdType cpt = 0;
       for (vtkIdType i = 0; i < faces_n; i++)
       {
@@ -1919,6 +1920,10 @@ int vtkCellValidator::RequestData(vtkInformation* vtkNotUsed(request),
   State state;
   for (it->InitTraversal(); !it->IsDoneWithTraversal(); it->GoToNextCell())
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     it->GetCell(cell);
     state = Check(cell, this->Tolerance);
     stateArray->SetValue(counter, static_cast<short>(state));
@@ -1982,3 +1987,4 @@ void vtkCellValidator::PrintState(vtkCellValidator::State state, ostream& os, vt
     }
   }
 }
+VTK_ABI_NAMESPACE_END
