@@ -43,6 +43,7 @@
 #include <utility>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkClipClosedSurface);
 
 vtkCxxSetObjectMacro(vtkClipClosedSurface, ClippingPlanes, vtkPlaneCollection);
@@ -385,7 +386,8 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   if (this->ScalarMode == VTK_CCS_SCALAR_MODE_COLORS)
   {
     numberOfScalarComponents = 3;
-    this->CreateColorValues(this->BaseColor, this->ClipColor, this->ActivePlaneColor, colors);
+    vtkClipClosedSurface::CreateColorValues(
+      this->BaseColor, this->ClipColor, this->ActivePlaneColor, colors);
   }
   else if (this->ScalarMode == VTK_CCS_SCALAR_MODE_LABELS)
   {
@@ -436,7 +438,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   vtkCellArray* lines = vtkCellArray::New();
   if (input->GetLines() && input->GetLines()->GetNumberOfCells() > 0)
   {
-    this->BreakPolylines(
+    vtkClipClosedSurface::BreakPolylines(
       input->GetLines(), lines, inputScalars, firstLineScalar, lineScalars, colors[0]);
   }
 
@@ -454,9 +456,9 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
     }
 
     polys = vtkCellArray::New();
-    this->CopyPolygons(
+    vtkClipClosedSurface::CopyPolygons(
       input->GetPolys(), polys, inputScalars, firstPolyScalar, polyScalars, colors[0]);
-    this->BreakTriangleStrips(
+    vtkClipClosedSurface::BreakTriangleStrips(
       input->GetStrips(), polys, inputScalars, firstStripScalar, polyScalars, colors[0]);
 
     // Check if the input has polys and quads or just triangles
@@ -527,7 +529,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   for (int planeId = 0; planes && (plane = planes->GetNextPlane(iter)); planeId++)
   {
     this->UpdateProgress((planeId + 1.0) / (numPlanes + 1.0));
-    if (this->GetAbortExecute())
+    if (this->CheckAbort())
     {
       break;
     }
@@ -769,7 +771,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   outPolyData->Delete();
 
   // Finally, store the points in the output
-  this->SqueezeOutputPoints(output, points, pointData, inputPointsType);
+  vtkClipClosedSurface::SqueezeOutputPoints(output, points, pointData, inputPointsType);
   output->Squeeze();
 
   points->Delete();
@@ -1294,8 +1296,8 @@ void vtkClipClosedSurface::TriangulateContours(vtkPolyData* data, vtkIdType firs
   }
 
   double nnormal[3] = { -normal[0], -normal[1], -normal[2] };
-  int rval =
-    vtkContourTriangulator::TriangulateContours(data, firstLine, numLines, outputPolys, nnormal);
+  int rval = vtkContourTriangulator::TriangulateContours(
+    data, firstLine, numLines, outputPolys, nnormal, this);
 
   if (rval == 0 && this->TriangulationErrorDisplay)
   {
@@ -1309,3 +1311,4 @@ int vtkClipClosedSurface::TriangulatePolygon(
 {
   return vtkContourTriangulator::TriangulatePolygon(polygon, points, triangles);
 }
+VTK_ABI_NAMESPACE_END
