@@ -33,6 +33,7 @@
 #include <utility>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkContourTriangulator);
 
 //------------------------------------------------------------------------------
@@ -78,21 +79,21 @@ int vtkContourTriangulator::RequestData(vtkInformation* vtkNotUsed(request),
 
   input->BuildCells();
 
-  vtkCellArray* polys = vtkCellArray::New();
+  vtkNew<vtkCellArray> polys;
   output->SetPolys(polys);
   output->SetPoints(input->GetPoints());
   output->GetPointData()->PassData(input->GetPointData());
 
-  polys->Delete();
-
   this->TriangulationError = !vtkContourTriangulator::TriangulateContours(
-    input, input->GetNumberOfVerts(), lines->GetNumberOfCells(), polys, nullptr);
+    input, input->GetNumberOfVerts(), lines->GetNumberOfCells(), polys, nullptr, this);
 
   if (this->TriangulationError && this->TriangulationErrorDisplay)
   {
     vtkErrorMacro("Triangulation failed, output might have holes.");
   }
 
+  this->CheckAbort();
+
   return 1;
 }
 
@@ -870,10 +871,10 @@ int vtkCCSSplitAtPinchPoints(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
   std::vector<vtkCCSPolyGroup>& polyGroups, std::vector<vtkCCSPolyEdges>& polyEdges,
   const double normal[3], bool oriented)
 {
-  vtkPoints* tryPoints = vtkPoints::New();
+  vtkNew<vtkPoints> tryPoints;
   tryPoints->SetDataTypeToDouble();
 
-  vtkIncrementalOctreePointLocator* locator = vtkIncrementalOctreePointLocator::New();
+  vtkNew<vtkIncrementalOctreePointLocator> locator;
 
   int splitCount = 0;
 
@@ -1013,9 +1014,6 @@ int vtkCCSSplitAtPinchPoints(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
     }
   }
 
-  tryPoints->Delete();
-  locator->Delete();
-
   return splitCount;
 }
 
@@ -1607,6 +1605,14 @@ void vtkCCSPrepareForPolyInPoly(
   // Find the bounding box and tolerance for the polygon
   tol2 = (vtkCCSPolygonBounds(outerPoly, points, bounds) *
     (VTK_CCS_POLYGON_TOLERANCE * VTK_CCS_POLYGON_TOLERANCE));
+
+  // Expand the bounds
+  double tol = sqrt(tol2);
+  for (int i = 0; i < 3; i++)
+  {
+    bounds[2 * i] -= tol;
+    bounds[2 * i + 1] += tol;
+  }
 }
 
 // ---------------------------------------------------
@@ -2330,7 +2336,7 @@ int vtkCCSCutHoleyPolys(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
 
   // Go through all groups and cut out the first inner poly that is
   // found.  Every time an inner poly is cut out, the groupId counter
-  // is reset because a cutting a poly creates a new group.
+  // is reset because cutting a poly creates a new group.
   size_t groupId = 0;
   while (groupId < polyGroups.size())
   {
@@ -2386,7 +2392,7 @@ int vtkCCSCutHoleyPolys(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
         // Only add if innerPolyId hasn't been set already.
         // Having the same poly occur as both polyGroup and
         // innerPoly would cause an infinite loop.
-        if (polyGroups[innerPolyId].size() < 1)
+        if (polyGroups[innerPolyId].empty())
         {
           polyGroups[innerPolyId].push_back(innerPolyId);
         }
@@ -2400,7 +2406,7 @@ int vtkCCSCutHoleyPolys(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
           // Only add if innerPolyId hasn't been set already.
           // Having the same poly occur as both polyGroup and
           // innerPoly would cause an infinite loop.
-          if (polyGroups[innerPolyId].size() < 1)
+          if (polyGroups[innerPolyId].empty())
           {
             polyGroups[innerPolyId].push_back(innerPolyId);
           }
@@ -2419,6 +2425,7 @@ int vtkCCSCutHoleyPolys(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
         double tol2;
         vtkCCSPrepareForPolyInPoly(poly1, points, pp, bounds, tol2);
 
+        size_t nextGroupId = groupId;
         size_t ii = 1;
         while (ii < polyGroup.size())
         {
@@ -2429,26 +2436,21 @@ int vtkCCSCutHoleyPolys(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
           }
           else
           {
-            // If innerPolyId and groupId are the same then adding to the list would cause an
-            // infinte loop since the size of polyGroup would never decrease.
-            if (innerPolyId != groupId)
-            {
-              // Move this poly to poly2 group
-              polyGroups[innerPolyId].push_back(polyGroup[ii]);
-            }
+            // Move this poly to poly2 group
+            polyGroups[innerPolyId].push_back(polyGroup[ii]);
             polyGroup.erase(polyGroup.begin() + ii);
 
-            // Reduce the groupId to ensure that this new group
-            // will get cut
-            if (innerPolyId < groupId)
+            // Reduce the groupId to ensure that this new group will get cut
+            if (innerPolyId < nextGroupId)
             {
-              groupId = innerPolyId;
+              nextGroupId = innerPolyId;
             }
           }
         }
         delete[] pp;
 
-        // Continue without incrementing groupId
+        // Set the groupId for the next iteration
+        groupId = nextGroupId;
         continue;
       }
     }
@@ -2478,7 +2480,7 @@ int vtkCCSCutHoleyPolys(std::vector<vtkCCSPoly>& polys, vtkPoints* points,
 //#define VTK_CCS_SHOW_FAILED_POLYS
 
 int vtkContourTriangulator::TriangulateContours(vtkPolyData* data, vtkIdType firstLine,
-  vtkIdType numLines, vtkCellArray* polys, const double normal[3])
+  vtkIdType numLines, vtkCellArray* polys, const double normal[3], vtkPolyDataAlgorithm* self)
 {
   int triangulationFailure = 0;
 
@@ -2582,6 +2584,10 @@ int vtkContourTriangulator::TriangulateContours(vtkPolyData* data, vtkIdType fir
   // Go through all polys and triangulate them
   for (size_t polyId = 0; polyId < polyGroups.size(); polyId++)
   {
+    if (self && self->CheckAbort())
+    {
+      break;
+    }
     // If group is empty, then poly was a hole without a containing poly
     if (polyGroups[polyId].empty())
     {
@@ -2636,3 +2642,4 @@ int vtkContourTriangulator::TriangulatePolygon(
   }
   return success;
 }
+VTK_ABI_NAMESPACE_END
