@@ -34,6 +34,7 @@
 
 #include <memory> // For unique_ptr
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCurvatures);
 
 //-------------------------------------------------------//
@@ -115,6 +116,10 @@ void vtkCurvatures::GetMeanCurvature(vtkPolyData* mesh)
 
   for (vtkIdType f = 0; f < F; ++f)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     polyData->GetCellPoints(f, vertices);
     const vtkIdType nv = vertices->GetNumberOfIds();
 
@@ -223,6 +228,10 @@ void vtkCurvatures::GetGaussCurvature(vtkPolyData* output)
   vtkNew<vtkCellArray> triangleStrip;
   for (vtkIdType cellId = 0; cellId < output->GetNumberOfCells(); ++cellId)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     if (output->GetCellType(cellId) == VTK_TRIANGLE_STRIP)
     {
       vtkCell* cell = output->GetCell(cellId);
@@ -286,6 +295,10 @@ void vtkCurvatures::ComputeGaussCurvature(
   facets->InitTraversal();
   while (facets->GetNextCell(f, vert))
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     output->GetPoint(vert[0], v0);
     output->GetPoint(vert[1], v1);
     output->GetPoint(vert[2], v2);
@@ -311,19 +324,9 @@ void vtkCurvatures::ComputeGaussCurvature(
     e2[1] -= v2[1];
     e2[2] -= v2[2];
 
-    // normalise
-    vtkMath::Normalize(e0);
-    vtkMath::Normalize(e1);
-    vtkMath::Normalize(e2);
-    // angles
-    // I get lots of acos domain errors so clamp the value to +/-1 as the
-    // normalize function can return 1.000000001 etc (I think)
-    double ac1 = vtkMath::Dot(e1, e2);
-    double ac2 = vtkMath::Dot(e2, e0);
-    double ac3 = vtkMath::Dot(e0, e1);
-    alpha0 = acos(-CLAMP_MACRO(ac1));
-    alpha1 = acos(-CLAMP_MACRO(ac2));
-    alpha2 = acos(-CLAMP_MACRO(ac3));
+    alpha0 = vtkMath::Pi() - vtkMath::AngleBetweenVectors(e1, e2);
+    alpha1 = vtkMath::Pi() - vtkMath::AngleBetweenVectors(e2, e0);
+    alpha2 = vtkMath::Pi() - vtkMath::AngleBetweenVectors(e0, e1);
 
     // surf. area
     A = double(vtkTriangle::TriangleArea(v0, v1, v2));
@@ -368,6 +371,11 @@ void vtkCurvatures::GetMaximumCurvature(vtkPolyData* input, vtkPolyData* output)
 
   for (vtkIdType i = 0; i < numPts; i++)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
+
     k = gauss->GetComponent(i, 0);
     h = mean->GetComponent(i, 0);
     tmp = h * h - k;
@@ -377,10 +385,13 @@ void vtkCurvatures::GetMaximumCurvature(vtkPolyData* input, vtkPolyData* output)
     }
     else
     {
-      vtkDebugMacro(<< "Maximum Curvature undefined at point: " << i);
-      // k_max can be any real number. Undefined points will be indistinguishable
-      // from points that actually have a k_max == 0
-      k_max = 0;
+      k_max = h;
+      if (tmp < -0.1)
+      {
+        vtkWarningMacro(
+          << "The Gaussian or mean curvature at point " << i
+          << " have a large computation error... The maximum curvature is likely off.");
+      }
     }
     maximumCurvature->SetComponent(i, 0, k_max);
   }
@@ -408,6 +419,11 @@ void vtkCurvatures::GetMinimumCurvature(vtkPolyData* input, vtkPolyData* output)
 
   for (vtkIdType i = 0; i < numPts; i++)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
+
     k = gauss->GetComponent(i, 0);
     h = mean->GetComponent(i, 0);
     tmp = h * h - k;
@@ -417,10 +433,13 @@ void vtkCurvatures::GetMinimumCurvature(vtkPolyData* input, vtkPolyData* output)
     }
     else
     {
-      vtkDebugMacro(<< "Minimum Curvature undefined at point: " << i);
-      // k_min can be any real number. Undefined points will be indistinguishable
-      // from points that actually have a k_min == 0
-      k_min = 0;
+      k_min = h;
+      if (tmp < -0.1)
+      {
+        vtkWarningMacro(
+          << "The Gaussian or mean curvature at point " << i
+          << " have a large computation error... The minimum curvature is likely off.");
+      }
     }
     minimumCurvature->SetComponent(i, 0, k_min);
   }
@@ -484,3 +503,4 @@ void vtkCurvatures::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "CurvatureType: " << this->CurvatureType << "\n";
   os << indent << "InvertMeanCurvature: " << this->InvertMeanCurvature << "\n";
 }
+VTK_ABI_NAMESPACE_END
