@@ -67,29 +67,30 @@
 
 #include "vtkSmartPointer.h" // For protected ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDoubleArray;
 class vtkPolyData;
 
 class VTKFILTERSGENERAL_EXPORT vtkDeformPointSet : public vtkPointSetAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiable (i.e., concrete) class.
    */
   static vtkDeformPointSet* New();
   vtkTypeMacro(vtkDeformPointSet, vtkPointSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the control mesh to deform the input vtkPointSet. The control
    * mesh must be a closed, non-self-intersecting, manifold mesh.
    */
   void SetControlMeshData(vtkPolyData* controlMesh);
   vtkPolyData* GetControlMeshData();
-  //@}
+  ///@}
 
   /**
    * Specify the point locations used to probe input. Any geometry
@@ -97,7 +98,7 @@ public:
    */
   void SetControlMeshConnection(vtkAlgorithmOutput* algOutput);
 
-  //@{
+  ///@{
   /**
    * Specify whether to regenerate interpolation weights or not. Initially
    * the filter will reexecute no matter what this flag is set to (initial
@@ -109,7 +110,7 @@ public:
   vtkSetMacro(InitializeWeights, vtkTypeBool);
   vtkGetMacro(InitializeWeights, vtkTypeBool);
   vtkBooleanMacro(InitializeWeights, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkDeformPointSet();
@@ -131,4 +132,5 @@ private:
   void operator=(const vtkDeformPointSet&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
