@@ -48,6 +48,7 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 
 class VTKFILTERSGENERAL_EXPORT vtkDiscreteFlyingEdges2D : public vtkPolyDataAlgorithm
@@ -101,7 +102,7 @@ public:
    */
   vtkIdType GetNumberOfContours() { return this->ContourValues->GetNumberOfContours(); }
 
-  //@{
+  ///@{
   /**
    * Generate numContours equally spaced contour values between specified
    * range. Contour values will include min/max range values.
@@ -114,9 +115,9 @@ public:
   {
     this->ContourValues->GenerateValues(numContours, rangeStart, rangeEnd);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Option to set the point scalars of the output.  The scalars will be the
    * label values.  By default this flag is on.
@@ -124,15 +125,15 @@ public:
   vtkSetMacro(ComputeScalars, int);
   vtkGetMacro(ComputeScalars, int);
   vtkBooleanMacro(ComputeScalars, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get which component of the scalar array to contour on; defaults to 0.
    */
   vtkSetMacro(ArrayComponent, int);
   vtkGetMacro(ArrayComponent, int);
-  //@}
+  ///@}
 
 protected:
   vtkDiscreteFlyingEdges2D();
@@ -150,4 +151,5 @@ private:
   void operator=(const vtkDiscreteFlyingEdges2D&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
