@@ -33,6 +33,7 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkDiscreteFlyingEdges3D);
 
 //------------------------------------------------------------------------------
@@ -183,9 +184,20 @@ public:
         *connIter++ = eIds[*edges++];
         *connIter++ = eIds[*edges++];
       }
-
-      // Write the last offset:
-      *offsetIter = static_cast<ValueType>(3 * triId);
+    }
+  };
+  // Finalize the triangle cell array: after all the tris are inserted,
+  // the last offset has to be added to complete the offsets array.
+  struct FinalizeTrisImpl
+  {
+    template <typename CellStateT>
+    void operator()(CellStateT& state, vtkIdType numTris)
+    {
+      using ValueType = typename CellStateT::ValueType;
+      auto* offsets = state.GetOffsets();
+      auto offsetRange = vtk::DataArrayValueRange<1>(offsets);
+      auto offsetIter = offsetRange.begin() + numTris;
+      *offsetIter = static_cast<ValueType>(3 * numTris);
     }
   };
   void GenerateTris(unsigned char eCase, unsigned char numTris, vtkIdType* eIds, vtkIdType& triId)
@@ -312,19 +324,31 @@ public:
   public:
     vtkDiscreteFlyingEdges3DAlgorithm<TT>* Algo;
     double Value;
-    Pass1(vtkDiscreteFlyingEdges3DAlgorithm<TT>* algo, double value)
+    vtkDiscreteFlyingEdges3D* Filter;
+    Pass1(
+      vtkDiscreteFlyingEdges3DAlgorithm<TT>* algo, double value, vtkDiscreteFlyingEdges3D* filter)
     {
       this->Algo = algo;
       this->Value = value;
+      this->Filter = filter;
     }
     void operator()(vtkIdType slice, vtkIdType end)
     {
       vtkIdType row;
       TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
-      for (; slice < end; ++slice)
+      bool isFirst = vtkSMPTools::GetSingleThread();
+      for (; slice < end && !this->Filter->GetAbortOutput(); ++slice)
       {
         for (row = 0, rowPtr = slicePtr; row < this->Algo->Dims[1]; ++row)
         {
+          if (isFirst)
+          {
+            this->Filter->CheckAbort();
+          }
+          if (this->Filter->GetAbortOutput())
+          {
+            break;
+          }
           this->Algo->ProcessXEdge(this->Value, rowPtr, row, slice);
           rowPtr += this->Algo->Inc1;
         } // for all rows in this slice
@@ -336,14 +360,28 @@ public:
   class Pass2
   {
   public:
-    Pass2(vtkDiscreteFlyingEdges3DAlgorithm<TT>* algo) { this->Algo = algo; }
+    Pass2(vtkDiscreteFlyingEdges3DAlgorithm<TT>* algo, vtkDiscreteFlyingEdges3D* filter)
+    {
+      this->Algo = algo;
+      this->Filter = filter;
+    }
     vtkDiscreteFlyingEdges3DAlgorithm<TT>* Algo;
+    vtkDiscreteFlyingEdges3D* Filter;
     void operator()(vtkIdType slice, vtkIdType end)
     {
-      for (; slice < end; ++slice)
+      bool isFirst = vtkSMPTools::GetSingleThread();
+      for (; slice < end && !this->Filter->GetAbortOutput(); ++slice)
       {
         for (vtkIdType row = 0; row < (this->Algo->Dims[1] - 1); ++row)
         {
+          if (isFirst)
+          {
+            this->Filter->CheckAbort();
+          }
+          if (this->Filter->GetAbortOutput())
+          {
+            break;
+          }
           this->Algo->ProcessYZEdges(row, slice);
         } // for all rows in this slice
       }   // for all slices in this batch
@@ -353,21 +391,33 @@ public:
   class Pass4
   {
   public:
-    Pass4(vtkDiscreteFlyingEdges3DAlgorithm<TT>* algo, double value)
+    Pass4(
+      vtkDiscreteFlyingEdges3DAlgorithm<TT>* algo, double value, vtkDiscreteFlyingEdges3D* filter)
     {
       this->Algo = algo;
       this->Value = value;
+      this->Filter = filter;
     }
     vtkDiscreteFlyingEdges3DAlgorithm<TT>* Algo;
     double Value;
+    vtkDiscreteFlyingEdges3D* Filter;
     void operator()(vtkIdType slice, vtkIdType end)
     {
       vtkIdType row;
       vtkIdType* eMD0 = this->Algo->EdgeMetaData + slice * 6 * this->Algo->Dims[1];
       vtkIdType* eMD1 = eMD0 + 6 * this->Algo->Dims[1];
       TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
+      bool isFirst = vtkSMPTools::GetSingleThread();
       for (; slice < end; ++slice)
       {
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
         // It's possible to skip entire slices if there is nothing to generate
         if (eMD1[3] > eMD0[3]) // there are triangle primitives!
         {
@@ -447,7 +497,7 @@ vtkDiscreteFlyingEdges3DAlgorithm<T>::vtkDiscreteFlyingEdges3DAlgorithm()
   int i, j, k, l, ii, eCase, index, numTris;
   static const int vertMap[8] = { 0, 1, 3, 2, 4, 5, 7, 6 };
   static const int CASE_MASK[8] = { 1, 2, 4, 8, 16, 32, 64, 128 };
-  EDGE_LIST* edge;
+  int* edge;
   vtkMarchingCubesTriangleCases* triCase;
   unsigned char* edgeCase;
 
@@ -1236,19 +1286,23 @@ void vtkDiscreteFlyingEdges3DAlgorithm<T>::Contour(vtkDiscreteFlyingEdges3D* sel
   // Loop across each contour value. This encompasses all three passes.
   for (vidx = 0; vidx < numContours; vidx++)
   {
+    if (self->CheckAbort())
+    {
+      break;
+    }
     value = values[vidx];
 
     // PASS 1: Traverse all x-rows building edge cases and counting number of
     // intersections (i.e., accumulate information necessary for later output
     // memory allocation, e.g., the number of output points along the x-rows
     // are counted).
-    Pass1<T> pass1(&algo, value);
+    Pass1<T> pass1(&algo, value, self);
     vtkSMPTools::For(0, algo.Dims[2], pass1);
 
     // PASS 2: Traverse all voxel x-rows and process voxel y&z edges.  The
     // result is a count of the number of y- and z-intersections, as well as
     // the number of triangles generated along these voxel rows.
-    Pass2<T> pass2(&algo);
+    Pass2<T> pass2(&algo, self);
     vtkSMPTools::For(0, algo.Dims[2] - 1, pass2);
 
     // PASS 3: Now allocate and generate output. First we have to update the
@@ -1294,6 +1348,7 @@ void vtkDiscreteFlyingEdges3DAlgorithm<T>::Contour(vtkDiscreteFlyingEdges3D* sel
       newPts->GetData()->WriteVoidPointer(0, 3 * totalPts);
       algo.NewPoints = static_cast<float*>(newPts->GetVoidPointer(0));
       newTris->ResizeExact(numOutTris, 3 * numOutTris);
+      newTris->Visit(FinalizeTrisImpl{}, numOutTris);
       algo.NewTris = newTris;
       if (newScalars)
       {
@@ -1335,7 +1390,7 @@ void vtkDiscreteFlyingEdges3DAlgorithm<T>::Contour(vtkDiscreteFlyingEdges3D* sel
       // Note that we are simultaneously generating triangles and interpolating
       // points. These could be split into separate, parallel operations for
       // maximum performance.
-      Pass4<T> pass4(&algo, value);
+      Pass4<T> pass4(&algo, value, self);
       vtkSMPTools::For(0, algo.Dims[2] - 1, pass4);
     } // if anything generated
 
@@ -1463,28 +1518,28 @@ int vtkDiscreteFlyingEdges3D::RequestData(
 
   // Create necessary objects to hold output. We will defer the
   // actual allocation to a later point.
-  vtkCellArray* newTris = vtkCellArray::New();
-  vtkPoints* newPts = vtkPoints::New();
+  vtkNew<vtkCellArray> newTris;
+  vtkNew<vtkPoints> newPts;
   newPts->SetDataTypeToFloat();
-  vtkDataArray* newScalars = nullptr;
-  vtkFloatArray* newNormals = nullptr;
-  vtkFloatArray* newGradients = nullptr;
+  vtkSmartPointer<vtkDataArray> newScalars;
+  vtkSmartPointer<vtkFloatArray> newNormals;
+  vtkSmartPointer<vtkFloatArray> newGradients;
 
   if (this->ComputeScalars)
   {
-    newScalars = inScalars->NewInstance();
+    newScalars.TakeReference(inScalars->NewInstance());
     newScalars->SetNumberOfComponents(1);
     newScalars->SetName(inScalars->GetName());
   }
   if (this->ComputeNormals)
   {
-    newNormals = vtkFloatArray::New();
+    newNormals = vtkSmartPointer<vtkFloatArray>::New();
     newNormals->SetNumberOfComponents(3);
     newNormals->SetName("Normals");
   }
   if (this->ComputeGradients)
   {
-    newGradients = vtkFloatArray::New();
+    newGradients = vtkSmartPointer<vtkFloatArray>::New();
     newGradients->SetNumberOfComponents(3);
     newGradients->SetName("Gradients");
   }
@@ -1504,30 +1559,24 @@ int vtkDiscreteFlyingEdges3D::RequestData(
   // Update ourselves.  Because we don't know up front how many lines
   // we've created, take care to reclaim memory.
   output->SetPoints(newPts);
-  newPts->Delete();
-
   output->SetPolys(newTris);
-  newTris->Delete();
 
   if (newScalars)
   {
     int idx = output->GetPointData()->AddArray(newScalars);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::SCALARS);
-    newScalars->Delete();
   }
 
   if (newNormals)
   {
     int idx = output->GetPointData()->AddArray(newNormals);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::NORMALS);
-    newNormals->Delete();
   }
 
   if (newGradients)
   {
     int idx = output->GetPointData()->AddArray(newGradients);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::VECTORS);
-    newGradients->Delete();
   }
 
   vtkImageTransform::TransformPointSet(input, output);
@@ -1555,3 +1604,4 @@ void vtkDiscreteFlyingEdges3D::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Interpolate Attributes: " << (this->InterpolateAttributes ? "On\n" : "Off\n");
   os << indent << "ArrayComponent: " << this->ArrayComponent << endl;
 }
+VTK_ABI_NAMESPACE_END
