@@ -34,6 +34,7 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGENERAL_EXPORT vtkGraphToPoints : public vtkPolyDataAlgorithm
 {
 public:
@@ -60,4 +61,5 @@ private:
   void operator=(const vtkGraphToPoints&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
