@@ -28,6 +28,7 @@
 #include "vtkStructuredPoints.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInterpolateDataSetAttributes);
 
 // Create object with no input or output.
@@ -191,7 +192,7 @@ int vtkInterpolateDataSetAttributes::RequestData(vtkInformation* vtkNotUsed(requ
     if (!(i % 10000))
     {
       this->UpdateProgress(static_cast<double>(i) / numPts * 0.50);
-      if (this->GetAbortExecute())
+      if (this->CheckAbort())
       {
         break;
       }
@@ -206,7 +207,7 @@ int vtkInterpolateDataSetAttributes::RequestData(vtkInformation* vtkNotUsed(requ
     if (!(i % 10000))
     {
       this->UpdateProgress(0.5 + static_cast<double>(i) / numCells * 0.50);
-      if (this->GetAbortExecute())
+      if (this->CheckAbort())
       {
         break;
       }
@@ -241,3 +242,4 @@ void vtkInterpolateDataSetAttributes ::ReportReferences(vtkGarbageCollector* col
   this->Superclass::ReportReferences(collector);
   vtkGarbageCollectorReport(collector, this->InputList, "InputList");
 }
+VTK_ABI_NAMESPACE_END
