@@ -51,6 +51,7 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkDataArray;
 class vtkDoubleArray;
@@ -68,29 +69,29 @@ public:
    */
   static vtkLinkEdgels* New();
 
-  //@{
+  ///@{
   /**
    * Set/Get the threshold for Phi vs. Alpha link thresholding.
    */
   vtkSetMacro(LinkThreshold, double);
   vtkGetMacro(LinkThreshold, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the threshold for Phi vs. Phi link thresholding.
    */
   vtkSetMacro(PhiThreshold, double);
   vtkGetMacro(PhiThreshold, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the threshold for image gradient thresholding.
    */
   vtkSetMacro(GradientThreshold, double);
   vtkGetMacro(GradientThreshold, double);
-  //@}
+  ///@}
 
 protected:
   vtkLinkEdgels();
@@ -111,4 +112,5 @@ private:
   void operator=(const vtkLinkEdgels&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
