@@ -49,6 +49,7 @@
 
 //------------------------------------------------------------------------------
 // Helper typedefs and data structures.
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
@@ -315,7 +316,7 @@ int vtkLoopBooleanPolyDataFilter::Impl::FindRegionTipToe(int inputIndex, int fil
           this->Mesh[inputIndex]->GetCellEdgeNeighbors(cellId, p1, p2, neighbors);
           vtkIdType numNeighbors = neighbors->GetNumberOfIds();
 
-          // Check to make sure it is an oustide surface cell,
+          // Check to make sure it is an outside surface cell,
           // i.e. one neighbor
           if (numNeighbors == 1)
           {
@@ -635,6 +636,7 @@ int vtkLoopBooleanPolyDataFilter::Impl::GetCellOrientation(
     vtkSmartPointer<vtkTransformPolyDataFilter>::New();
   transformer->SetInputData(cellPD);
   transformer->SetTransform(transform);
+  transformer->SetContainerAlgorithm(this->ParentFilter);
   transformer->Update();
 
   vtkSmartPointer<vtkPolyData> transPD = vtkSmartPointer<vtkPolyData>::New();
@@ -775,7 +777,6 @@ vtkStandardNewMacro(vtkLoopBooleanPolyDataFilter);
 
 //------------------------------------------------------------------------------
 vtkLoopBooleanPolyDataFilter::vtkLoopBooleanPolyDataFilter()
-  : vtkPolyDataAlgorithm()
 {
   this->Operation = VTK_UNION;
 
@@ -830,8 +831,9 @@ int vtkLoopBooleanPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request
   polydataIntersection->SplitFirstOutputOn();
   polydataIntersection->SplitSecondOutputOn();
   polydataIntersection->SetTolerance(this->Tolerance);
+  polydataIntersection->SetContainerAlgorithm(this);
   polydataIntersection->Update();
-  if (polydataIntersection->GetStatus() != 1)
+  if (this->CheckAbort() || polydataIntersection->GetStatus() != 1)
   {
     this->Status = 0;
     return 0;
@@ -853,7 +855,7 @@ int vtkLoopBooleanPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request
   if (this->NumberOfIntersectionPoints == 0 || this->NumberOfIntersectionLines == 0)
   {
     vtkWarningMacro(<< "No intersections!");
-    if (this->NoIntersectionOutput == 0)
+    if (this->CheckAbort() || this->NoIntersectionOutput == 0)
     {
       delete impl;
       return 1;
@@ -900,6 +902,7 @@ int vtkLoopBooleanPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request
         vtkSmartPointer<vtkAppendPolyData> appender = vtkSmartPointer<vtkAppendPolyData>::New();
         appender->AddInputData(impl->Mesh[0]);
         appender->AddInputData(impl->Mesh[1]);
+        appender->SetContainerAlgorithm(this);
         appender->Update();
         outputSurface->DeepCopy(appender->GetOutput());
       }
@@ -956,6 +959,7 @@ int vtkLoopBooleanPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request
   vtkSmartPointer<vtkPolyDataNormals> normaler = vtkSmartPointer<vtkPolyDataNormals>::New();
   normaler->SetInputData(outputSurface);
   normaler->AutoOrientNormalsOn();
+  normaler->SetContainerAlgorithm(this);
   normaler->Update();
   outputSurface->DeepCopy(normaler->GetOutput());
 
@@ -1029,7 +1033,7 @@ void vtkLoopBooleanPolyDataFilter::Impl::DetermineIntersection(std::vector<simLo
 
   for (vtkIdType interPt = 0; interPt < numInterPts; interPt++)
   {
-    if (usedPt[interPt] == false)
+    if (!usedPt[interPt])
     {
       simLoop newloop;
       vtkSmartPointer<vtkIdList> cellIds = vtkSmartPointer<vtkIdList>::New();
@@ -1231,11 +1235,11 @@ int vtkLoopBooleanPolyDataFilter::Impl::RunLoopTest(
       nextPt = pointIds->GetId(0);
     }
 
-    if (usedPt[nextPt] == true)
+    if (usedPt[nextPt])
     {
       vtkDebugWithObjectMacro(this->ParentFilter, << "Bad One");
     }
-    if (cellId != stopCell && usedPt[nextPt] != true)
+    if (cellId != stopCell && !usedPt[nextPt])
     {
       simLine newline;
       newline.id = cellId;
@@ -1321,7 +1325,9 @@ void vtkLoopBooleanPolyDataFilter::Impl::PerformBoolean(vtkPolyData* output, int
   this->ThresholdRegions(surfaces);
   // thresholder->SetInputData(this->Mesh[0]);
   // thresholder->SetInputArrayToProcess(0, 0, 0, 1, "BooleanRegion");
-  // thresholder->ThresholdBetween(-1, -1);
+  // thresholder->SetThresholdFunction(vtkThreshold::THRESHOLD_BETWEEN);
+  // thresholder->SetLowerThreshold(-1.0);
+  // thresholder->SetUpperThreshold(-1.0);
   // thresholder->Update();
   // surfacer->SetInputData(thresholder->GetOutput());
   // surfacer->Update();
@@ -1329,7 +1335,9 @@ void vtkLoopBooleanPolyDataFilter::Impl::PerformBoolean(vtkPolyData* output, int
 
   // thresholder->SetInputData(this->Mesh[0]);
   // thresholder->SetInputArrayToProcess(0, 0, 0, 1, "BooleanRegion");
-  // thresholder->ThresholdBetween(1, 1);
+  // thresholder->SetThresholdFunction(vtkThreshold::THRESHOLD_BETWEEN);
+  // thresholder->SetLowerThreshold(1.0);
+  // thresholder->SetUpperThreshold(1.0);
   // thresholder->Update();
   // surfacer->SetInputData(thresholder->GetOutput());
   // surfacer->Update();
@@ -1337,7 +1345,9 @@ void vtkLoopBooleanPolyDataFilter::Impl::PerformBoolean(vtkPolyData* output, int
 
   // thresholder->SetInputData(this->Mesh[1]);
   // thresholder->SetInputArrayToProcess(0, 0, 0, 1, "BooleanRegion");
-  // thresholder->ThresholdBetween(1, 1);
+  // thresholder->SetThresholdFunction(vtkThreshold::THRESHOLD_BETWEEN);
+  // thresholder->SetLowerThreshold(1.0);
+  // thresholder->SetUpperThreshold(1.0);
   // thresholder->Update();
   // surfacer->SetInputData(thresholder->GetOutput());
   // surfacer->Update();
@@ -1345,7 +1355,9 @@ void vtkLoopBooleanPolyDataFilter::Impl::PerformBoolean(vtkPolyData* output, int
 
   // thresholder->SetInputData(this->Mesh[1]);
   // thresholder->SetInputArrayToProcess(0, 0, 0, 1, "BooleanRegion");
-  // thresholder->ThresholdBetween(-1, -1);
+  // thresholder->SetThresholdFunction(vtkThreshold::THRESHOLD_BETWEEN);
+  // thresholder->SetLowerThreshold(-1.0);
+  // thresholder->SetUpperThreshold(-1.0);
   // thresholder->Update();
   // surfacer->SetInputData(thresholder->GetOutput());
   // surfacer->Update();
@@ -1398,6 +1410,7 @@ void vtkLoopBooleanPolyDataFilter::Impl::PerformBoolean(vtkPolyData* output, int
     appender->AddInputData(surfaces[0]);
     appender->AddInputData(surfaces[3]);
   }
+  appender->SetContainerAlgorithm(this->ParentFilter);
   appender->Update();
 
   output->DeepCopy(appender->GetOutput());
@@ -1487,3 +1500,4 @@ void vtkLoopBooleanPolyDataFilter::Impl::ThresholdRegions(vtkPolyData** surfaces
     booleanCells[i]->Delete();
   }
 }
+VTK_ABI_NAMESPACE_END
