@@ -20,6 +20,7 @@
 =========================================================================*/
 
 #include "vtkMatricizeArray.h"
+#include "vtkArrayData.h"
 #include "vtkCommand.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -32,6 +33,7 @@
 ///////////////////////////////////////////////////////////////////////////////
 // vtkMatricizeArray
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMatricizeArray);
 
 vtkMatricizeArray::vtkMatricizeArray()
@@ -111,6 +113,10 @@ int vtkMatricizeArray::RequestData(
   const vtkIdType element_count = input_array->GetNonNullSize();
   for (vtkIdType n = 0; n != element_count; ++n)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     input_array->GetCoordinatesN(n, coordinates);
 
     new_coordinates[0] = coordinates[this->SliceDimension];
@@ -129,3 +135,4 @@ int vtkMatricizeArray::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
