@@ -16,34 +16,36 @@
 
 #include "vtkCellData.h"
 #include "vtkDataSet.h"
-#include "vtkMultiBlockDataSet.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkMultiBlockDataSet.h"
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMultiBlockMergeFilter);
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiBlockMergeFilter::vtkMultiBlockMergeFilter() = default;
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiBlockMergeFilter::~vtkMultiBlockMergeFilter() = default;
 
-//-----------------------------------------------------------------------------
-int vtkMultiBlockMergeFilter::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+//------------------------------------------------------------------------------
+int vtkMultiBlockMergeFilter::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   vtkInformation* info = outputVector->GetInformationObject(0);
-  vtkMultiBlockDataSet *output = vtkMultiBlockDataSet::SafeDownCast(
-    info->Get(vtkDataObject::DATA_OBJECT()));
-  if (!output) {return 0;}
+  vtkMultiBlockDataSet* output =
+    vtkMultiBlockDataSet::SafeDownCast(info->Get(vtkDataObject::DATA_OBJECT()));
+  if (!output)
+  {
+    return 0;
+  }
 
   int numInputs = inputVector[0]->GetNumberOfInformationObjects();
-  if (numInputs<0)
+  if (numInputs < 0)
   {
-    vtkErrorMacro("Too many inputs to algorithm.")
+    vtkErrorMacro("Too many inputs to algorithm.");
     return 0;
   }
   unsigned int usNInputs = static_cast<unsigned int>(numInputs);
@@ -51,20 +53,23 @@ int vtkMultiBlockMergeFilter::RequestData(
   int first = 1;
   for (int idx = 0; idx < numInputs; ++idx)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkMultiBlockDataSet* input = nullptr;
     vtkInformation* inInfo = inputVector[0]->GetInformationObject(idx);
     if (inInfo)
     {
-      input = vtkMultiBlockDataSet::SafeDownCast(
-        inInfo->Get(vtkDataObject::DATA_OBJECT()));
+      input = vtkMultiBlockDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
     }
     if (input)
     {
       if (first)
       {
-        //shallow copy first input to output to start off with
-        //cerr << "Copy first input" << endl;
-        output->ShallowCopy(vtkMultiBlockDataSet::SafeDownCast(input));
+        // shallow copy first input to output to start off with
+        // cerr << "Copy first input" << endl;
+        output->CompositeShallowCopy(vtkMultiBlockDataSet::SafeDownCast(input));
         first = 0;
       }
       else
@@ -103,11 +108,11 @@ int vtkMultiBlockMergeFilter::RequestData(
   return !first;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkMultiBlockMergeFilter::IsMultiPiece(vtkMultiBlockDataSet* mb)
 {
   unsigned int numBlocks = mb->GetNumberOfBlocks();
-  for (unsigned int cc=0; cc < numBlocks; cc++)
+  for (unsigned int cc = 0; cc < numBlocks; cc++)
   {
     vtkDataObject* block = mb->GetBlock(cc);
     if (block && !block->IsA("vtkDataSet"))
@@ -118,10 +123,9 @@ int vtkMultiBlockMergeFilter::IsMultiPiece(vtkMultiBlockDataSet* mb)
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkMultiBlockMergeFilter::Merge(unsigned int numPieces, unsigned int pieceNo,
-  vtkMultiBlockDataSet* output,
-  vtkMultiBlockDataSet* input)
+  vtkMultiBlockDataSet* output, vtkMultiBlockDataSet* input)
 {
   if (!input && !output)
   {
@@ -146,11 +150,10 @@ int vtkMultiBlockMergeFilter::Merge(unsigned int numPieces, unsigned int pieceNo
 
   if (!mpInput && !mpOutput && (numInBlocks == numOutBlocks))
   {
-    for (unsigned int cc=0; cc < numInBlocks; cc++)
+    for (unsigned int cc = 0; cc < numInBlocks; cc++)
     {
-      if (!this->Merge(numPieces, pieceNo,
-          vtkMultiBlockDataSet::SafeDownCast(output->GetBlock(cc)),
-          vtkMultiBlockDataSet::SafeDownCast(input->GetBlock(cc))))
+      if (!this->Merge(numPieces, pieceNo, vtkMultiBlockDataSet::SafeDownCast(output->GetBlock(cc)),
+            vtkMultiBlockDataSet::SafeDownCast(input->GetBlock(cc))))
       {
         return 0;
       }
@@ -161,7 +164,7 @@ int vtkMultiBlockMergeFilter::Merge(unsigned int numPieces, unsigned int pieceNo
   {
     output->SetNumberOfBlocks(numPieces);
     unsigned int inIndex = 0;
-    //inputs are allowed to have either 1 or N datasets in each group
+    // inputs are allowed to have either 1 or N datasets in each group
     if (numInBlocks == numPieces)
     {
       inIndex = pieceNo;
@@ -179,22 +182,20 @@ int vtkMultiBlockMergeFilter::Merge(unsigned int numPieces, unsigned int pieceNo
   return 0;
 }
 
-
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiBlockMergeFilter::AddInputData(vtkDataObject* input)
 {
   this->AddInputData(0, input);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiBlockMergeFilter::AddInputData(int index, vtkDataObject* input)
 {
   this->AddInputDataInternal(index, input);
 }
 
-//-----------------------------------------------------------------------------
-int vtkMultiBlockMergeFilter::FillInputPortInformation(
-  int, vtkInformation *info)
+//------------------------------------------------------------------------------
+int vtkMultiBlockMergeFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkMultiBlockDataSet");
   info->Set(vtkAlgorithm::INPUT_IS_REPEATABLE(), 1);
@@ -202,8 +203,9 @@ int vtkMultiBlockMergeFilter::FillInputPortInformation(
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiBlockMergeFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
