@@ -19,11 +19,9 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkNormalizeMatrixVectors.h"
 #include "vtkArrayCoordinates.h"
+#include "vtkArrayData.h"
 #include "vtkCommand.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -32,10 +30,12 @@
 #include "vtkTypedArray.h"
 
 #include <algorithm>
+#include <cmath>
 
 ///////////////////////////////////////////////////////////////////////////////
 // vtkNormalizeMatrixVectors
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkNormalizeMatrixVectors);
 
 vtkNormalizeMatrixVectors::vtkNormalizeMatrixVectors()
@@ -93,6 +93,10 @@ int vtkNormalizeMatrixVectors::RequestData(
   vtkArrayCoordinates coordinates;
   for (vtkIdType n = 0; n != value_count; ++n)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     output_array->GetCoordinatesN(n, coordinates);
     weight[coordinates[vector_dimension] - vectors.GetBegin()] +=
       pow(output_array->GetValueN(n), p_value);
@@ -101,6 +105,10 @@ int vtkNormalizeMatrixVectors::RequestData(
   // Convert the sums into weights, avoiding divide-by-zero ...
   for (vtkIdType i = 0; i != vectors.GetSize(); ++i)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     const double length = pow(weight[i], 1.0 / p_value);
     weight[i] = length ? 1.0 / length : 0.0;
   }
@@ -108,6 +116,10 @@ int vtkNormalizeMatrixVectors::RequestData(
   // Apply the weights to each vector ...
   for (vtkIdType n = 0; n != value_count; ++n)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     output_array->GetCoordinatesN(n, coordinates);
     output_array->SetValueN(
       n, output_array->GetValueN(n) * weight[coordinates[vector_dimension] - vectors.GetBegin()]);
@@ -120,3 +132,4 @@ int vtkNormalizeMatrixVectors::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
