@@ -74,6 +74,7 @@
 #include "vtkDataObjectAlgorithm.h"
 #include "vtkFiltersGeneralModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGENERAL_EXPORT vtkPassArrays : public vtkDataObjectAlgorithm
 {
 public:
@@ -99,7 +100,7 @@ public:
   virtual void RemoveCellDataArray(const char* name);
   virtual void RemoveFieldDataArray(const char* name);
 
-  //@{
+  ///@{
   /**
    * Clear all arrays to pass through.
    */
@@ -107,9 +108,9 @@ public:
   virtual void ClearPointDataArrays();
   virtual void ClearCellDataArrays();
   virtual void ClearFieldDataArrays();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Instead of passing only the specified arrays, remove the specified arrays
    * and keep all other arrays. Default is off.
@@ -117,9 +118,9 @@ public:
   vtkSetMacro(RemoveArrays, bool);
   vtkGetMacro(RemoveArrays, bool);
   vtkBooleanMacro(RemoveArrays, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Process only those field types explicitly specified with AddFieldType.
    * Otherwise, processes field types associated with at least one specified
@@ -128,7 +129,7 @@ public:
   vtkSetMacro(UseFieldTypes, bool);
   vtkGetMacro(UseFieldTypes, bool);
   vtkBooleanMacro(UseFieldTypes, bool);
-  //@}
+  ///@}
 
   /**
    * Add a field type to process.
@@ -179,4 +180,5 @@ private:
   void operator=(const vtkPassArrays&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
