@@ -41,6 +41,7 @@
 #include "vtkUnsignedLongLongArray.h"
 #include "vtkUnsignedShortArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRandomAttributeGenerator);
 
 //------------------------------------------------------------------------------
@@ -70,6 +71,9 @@ vtkRandomAttributeGenerator::vtkRandomAttributeGenerator()
   this->AttributesConstantPerBlock = false;
 }
 
+namespace
+{
+
 //------------------------------------------------------------------------------
 template <class T>
 void GenerateRandomTuple(
@@ -107,6 +111,8 @@ void CopyTupleFrom0Bit(vtkDataArray* data, vtkIdType i, int minComp, int maxComp
   }
 }
 
+}
+
 //------------------------------------------------------------------------------
 // This function template creates random attributes within a given range. It is
 // assumed that the input data array may have a variable number of components.
@@ -125,7 +131,7 @@ void vtkRandomAttributeGenerator::GenerateRandomTuples(
     if (!(i % tenth))
     {
       this->UpdateProgress(static_cast<double>(i) / total);
-      if (this->GetAbortExecute())
+      if (this->CheckAbort())
       {
         break;
       }
@@ -283,7 +289,7 @@ vtkDataArray* vtkRandomAttributeGenerator::GenerateData(
         if (!(i % tenth))
         {
           this->UpdateProgress(static_cast<double>(i) / total);
-          if (this->GetAbortExecute())
+          if (this->CheckAbort())
           {
             break;
           }
@@ -321,6 +327,10 @@ int vtkRandomAttributeGenerator::RequestData(
   it.TakeReference(input->NewIterator());
   for (it->InitTraversal(); !it->IsDoneWithTraversal(); it->GoToNextItem())
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkDataSet* inputDS = vtkDataSet::SafeDownCast(it->GetCurrentDataObject());
     vtkSmartPointer<vtkDataSet> outputDS;
     outputDS.TakeReference(inputDS->NewInstance());
@@ -562,3 +572,4 @@ int vtkRandomAttributeGenerator::FillInputPortInformation(
   info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkCompositeDataSet");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
