@@ -34,6 +34,7 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkRectilinearGridAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGENERAL_EXPORT vtkRectilinearGridClip : public vtkRectilinearGridAlgorithm
 {
 public:
@@ -41,7 +42,7 @@ public:
   vtkTypeMacro(vtkRectilinearGridClip, vtkRectilinearGridAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The whole extent of the output has to be set explicitly.
    */
@@ -49,11 +50,11 @@ public:
   void SetOutputWholeExtent(int minX, int maxX, int minY, int maxY, int minZ, int maxZ);
   void GetOutputWholeExtent(int extent[6]);
   int* GetOutputWholeExtent() { return this->OutputWholeExtent; }
-  //@}
+  ///@}
 
   void ResetOutputWholeExtent();
 
-  //@{
+  ///@{
   /**
    * By default, ClipData is off, and only the WholeExtent is modified.
    * the data's extent may actually be larger.  When this flag is on,
@@ -62,7 +63,7 @@ public:
   vtkSetMacro(ClipData, vtkTypeBool);
   vtkGetMacro(ClipData, vtkTypeBool);
   vtkBooleanMacro(ClipData, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkRectilinearGridClip();
@@ -86,4 +87,5 @@ private:
   void operator=(const vtkRectilinearGridClip&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
