@@ -27,6 +27,7 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkCellData;
 class vtkIdList;
@@ -40,16 +41,16 @@ public:
   vtkTypeMacro(vtkSubdivisionFilter, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/get the number of subdivisions.
    * Default is 1.
    */
   vtkSetMacro(NumberOfSubdivisions, int);
   vtkGetMacro(NumberOfSubdivisions, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get CheckForTriangles
    * Should subdivision check that the dataset only contains triangles?
@@ -58,7 +59,7 @@ public:
   vtkSetClampMacro(CheckForTriangles, vtkTypeBool, 0, 1);
   vtkGetMacro(CheckForTriangles, vtkTypeBool);
   vtkBooleanMacro(CheckForTriangles, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkSubdivisionFilter();
@@ -74,4 +75,5 @@ private:
   void operator=(const vtkSubdivisionFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
