@@ -35,11 +35,13 @@
 
 #include <vector> // Use of dynamically allocated array
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGENERAL_EXPORT vtkSynchronizeTimeFilter : public vtkPassInputTypeAlgorithm
 {
 public:
   static vtkSynchronizeTimeFilter* New();
   vtkTypeMacro(vtkSynchronizeTimeFilter, vtkPassInputTypeAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Specify the input that we may potentially replace time
@@ -93,4 +95,5 @@ private:
   double RelativeTolerance;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
