@@ -25,6 +25,7 @@
 #include "vtkPolyData.h"
 #include "vtkStructuredPoints.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkVoxelContoursToSurfaceFilter);
 
 vtkVoxelContoursToSurfaceFilter::vtkVoxelContoursToSurfaceFilter()
@@ -79,6 +80,11 @@ void vtkVoxelContoursToSurfaceFilter::SortLineList()
   double tmp[4];
   double tmpval;
 
+  if (!this->LineListLength)
+  {
+    return;
+  }
+
   // Make sure we have enough space in our sorted list
   if (this->SortedListSize < this->LineListLength)
   {
@@ -524,14 +530,20 @@ int vtkVoxelContoursToSurfaceFilter::RequestData(vtkInformation* vtkNotUsed(requ
   contourFilter->SetInputData(volume);
   contourFilter->SetNumberOfContours(1);
   contourFilter->SetValue(0, 0.0);
+  contourFilter->SetContainerAlgorithm(this);
 
   appendFilter = vtkAppendPolyData::New();
+  appendFilter->SetContainerAlgorithm(this);
 
   inputPolys->InitTraversal();
   inputPolys->GetNextCell(npts, pts);
 
   while (currentSlice <= lastSlice)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     // Make sure the origin of the volume is in the right
     // place so that the appended polydata all matches up
     // nicely.
@@ -643,3 +655,4 @@ void vtkVoxelContoursToSurfaceFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Spacing: " << this->Spacing[0] << " " << this->Spacing[1] << " "
      << this->Spacing[2] << endl;
 }
+VTK_ABI_NAMESPACE_END
