@@ -38,7 +38,7 @@
  *
  * @sa
  * vtkPolyDataAlgorithm
-*/
+ */
 
 #ifndef vtkVoxelContoursToSurfaceFilter_h
 #define vtkVoxelContoursToSurfaceFilter_h
@@ -46,61 +46,63 @@
 #include "vtkFiltersGeneralModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGENERAL_EXPORT vtkVoxelContoursToSurfaceFilter : public vtkPolyDataAlgorithm
 {
 public:
-  static vtkVoxelContoursToSurfaceFilter *New();
-  vtkTypeMacro(vtkVoxelContoursToSurfaceFilter,vtkPolyDataAlgorithm);
+  static vtkVoxelContoursToSurfaceFilter* New();
+  vtkTypeMacro(vtkVoxelContoursToSurfaceFilter, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set / Get the memory limit in bytes for this filter. This is the limit
    * of the size of the structured points data set that is created for
    * intermediate processing. The data will be streamed through this volume
    * in as many pieces as necessary.
    */
-  vtkSetMacro( MemoryLimitInBytes, int );
-  vtkGetMacro( MemoryLimitInBytes, int );
-  //@}
+  vtkSetMacro(MemoryLimitInBytes, int);
+  vtkGetMacro(MemoryLimitInBytes, int);
+  ///@}
 
-  vtkSetVector3Macro( Spacing, double );
-  vtkGetVectorMacro( Spacing, double, 3 );
+  vtkSetVector3Macro(Spacing, double);
+  vtkGetVectorMacro(Spacing, double, 3);
 
 protected:
   vtkVoxelContoursToSurfaceFilter();
   ~vtkVoxelContoursToSurfaceFilter() override;
 
-  int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *) override;
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
-  int     MemoryLimitInBytes;
+  int MemoryLimitInBytes;
 
-  double   Spacing[3];
+  double Spacing[3];
 
-  double   *LineList;
-  int     LineListLength;
-  int     LineListSize;
+  double* LineList;
+  int LineListLength;
+  int LineListSize;
 
-  double   *SortedXList;
-  double   *SortedYList;
-  int     SortedListSize;
+  double* SortedXList;
+  double* SortedYList;
+  int SortedListSize;
 
-  int     *WorkingList;
-  int     WorkingListLength;
+  int* WorkingList;
+  int WorkingListLength;
 
-  double   *IntersectionList;
-  int     IntersectionListLength;
+  double* IntersectionList;
+  int IntersectionListLength;
 
-  void    AddLineToLineList( double x1, double y1, double x2, double y2 );
-  void    SortLineList();
+  void AddLineToLineList(double x1, double y1, double x2, double y2);
+  void SortLineList();
 
-  void    CastLines( float *slice, double gridOrigin[3],
-                     int gridSize[3], int type );
+  void CastLines(float* slice, double gridOrigin[3], int gridSize[3], int type);
+
+  void PushDistances(float* ptr, int gridSize[3], int chunkSize);
 
-  void    PushDistances( float *ptr, int gridSize[3], int chunkSize );
 private:
   vtkVoxelContoursToSurfaceFilter(const vtkVoxelContoursToSurfaceFilter&) = delete;
   void operator=(const vtkVoxelContoursToSurfaceFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
