@@ -17,37 +17,38 @@
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkDoubleArray.h"
+#include "vtkExecutive.h"
+#include "vtkGenericAdaptorCell.h"
+#include "vtkGenericAttribute.h"
+#include "vtkGenericAttributeCollection.h"
 #include "vtkGenericCell.h"
+#include "vtkGenericCellIterator.h"
+#include "vtkGenericCellTessellator.h"
+#include "vtkGenericDataSet.h"
+#include "vtkGenericPointIterator.h"
+#include "vtkIdTypeArray.h"
 #include "vtkImageData.h"
 #include "vtkImplicitFunction.h"
-#include "vtkIdTypeArray.h"
-#include "vtkMergePoints.h"
+#include "vtkIncrementalPointLocator.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkMergePoints.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnstructuredGrid.h"
-#include "vtkGenericDataSet.h"
-#include "vtkGenericCellIterator.h"
-#include "vtkGenericAdaptorCell.h"
-#include "vtkGenericAttribute.h"
-#include "vtkGenericAttributeCollection.h"
-#include "vtkGenericPointIterator.h"
-#include "vtkGenericCellTessellator.h"
-#include "vtkExecutive.h"
-#include "vtkIncrementalPointLocator.h"
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGenericClip);
-vtkCxxSetObjectMacro(vtkGenericClip,ClipFunction,vtkImplicitFunction);
-vtkCxxSetObjectMacro(vtkGenericClip,Locator,vtkIncrementalPointLocator);
+vtkCxxSetObjectMacro(vtkGenericClip, ClipFunction, vtkImplicitFunction);
+vtkCxxSetObjectMacro(vtkGenericClip, Locator, vtkIncrementalPointLocator);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct with user-specified implicit function; InsideOut turned off; value
 // set to 0.0; and generate clip scalars turned off.
-vtkGenericClip::vtkGenericClip(vtkImplicitFunction *cf)
+vtkGenericClip::vtkGenericClip(vtkImplicitFunction* cf)
 {
   this->ClipFunction = cf;
   this->InsideOut = 0;
@@ -59,7 +60,7 @@ vtkGenericClip::vtkGenericClip(vtkImplicitFunction *cf)
   this->MergeTolerance = 0.01;
 
   this->SetNumberOfOutputPorts(2);
-  vtkUnstructuredGrid *output2 = vtkUnstructuredGrid::New();
+  vtkUnstructuredGrid* output2 = vtkUnstructuredGrid::New();
   this->GetExecutive()->SetOutputData(1, output2);
   output2->Delete();
 
@@ -70,10 +71,10 @@ vtkGenericClip::vtkGenericClip(vtkImplicitFunction *cf)
   this->SecondaryCD = vtkCellData::New();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGenericClip::~vtkGenericClip()
 {
-  if ( this->Locator )
+  if (this->Locator)
   {
     this->Locator->UnRegister(this);
     this->Locator = nullptr;
@@ -85,7 +86,7 @@ vtkGenericClip::~vtkGenericClip()
   this->SecondaryCD->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Do not say we have two outputs unless we are generating the clipped output.
 int vtkGenericClip::GetNumberOfOutputs()
 {
@@ -96,79 +97,74 @@ int vtkGenericClip::GetNumberOfOutputs()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Overload standard modified time function. If Clip functions is modified,
 // then this object is modified as well.
 vtkMTimeType vtkGenericClip::GetMTime()
 {
-  vtkMTimeType mTime=this->Superclass::GetMTime();
+  vtkMTimeType mTime = this->Superclass::GetMTime();
   vtkMTimeType time;
 
-  if ( this->ClipFunction != nullptr )
+  if (this->ClipFunction != nullptr)
   {
     time = this->ClipFunction->GetMTime();
-    mTime = ( time > mTime ? time : mTime );
+    mTime = (time > mTime ? time : mTime);
   }
-  if ( this->Locator != nullptr )
+  if (this->Locator != nullptr)
   {
     time = this->Locator->GetMTime();
-    mTime = ( time > mTime ? time : mTime );
+    mTime = (time > mTime ? time : mTime);
   }
 
   return mTime;
 }
 
-//----------------------------------------------------------------------------
-vtkUnstructuredGrid *vtkGenericClip::GetClippedOutput()
+//------------------------------------------------------------------------------
+vtkUnstructuredGrid* vtkGenericClip::GetClippedOutput()
 {
   if (!this->GenerateClippedOutput)
   {
     return nullptr;
   }
-  return vtkUnstructuredGrid::SafeDownCast(
-    this->GetExecutive()->GetOutputData(1));
+  return vtkUnstructuredGrid::SafeDownCast(this->GetExecutive()->GetOutputData(1));
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 //
 // Clip through data generating surface.
 //
-int vtkGenericClip::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkGenericClip::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkGenericDataSet *input = vtkGenericDataSet::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkUnstructuredGrid *output = vtkUnstructuredGrid::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkGenericDataSet* input =
+    vtkGenericDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkUnstructuredGrid* output =
+    vtkUnstructuredGrid::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  if(input==nullptr)
+  if (input == nullptr)
   {
     return 1;
   }
 
-  vtkUnstructuredGrid *clippedOutput = this->GetClippedOutput();
+  vtkUnstructuredGrid* clippedOutput = this->GetClippedOutput();
 
   vtkIdType numPts = input->GetNumberOfPoints();
   vtkIdType numCells = input->GetNumberOfCells();
-  vtkPointData *outPD = output->GetPointData();
-  vtkCellData *outCD[2];
-  vtkIdType npts=0;
-  vtkIdType *pts;
+  vtkPointData* outPD = output->GetPointData();
+  vtkCellData* outCD[2];
+  vtkIdType npts = 0;
+  const vtkIdType* pts;
   int cellType = 0;
   int j;
   vtkIdType estimatedSize;
-  vtkUnsignedCharArray *types[2];
-  vtkIdTypeArray *locs[2];
+  vtkUnsignedCharArray* types[2];
   int numOutputs = 1;
-  vtkGenericAdaptorCell *cell;
+  vtkGenericAdaptorCell* cell;
 
   outCD[0] = nullptr;
   outCD[1] = nullptr;
@@ -177,85 +173,81 @@ int vtkGenericClip::RequestData(
 
   // Initialize self; create output objects
   //
-  if ( numPts < 1 )
+  if (numPts < 1)
   {
-    vtkErrorMacro(<<"No data to clip");
+    vtkErrorMacro(<< "No data to clip");
     return 1;
   }
 
-  if ( !this->ClipFunction && this->GenerateClipScalars )
+  if (!this->ClipFunction && this->GenerateClipScalars)
   {
-    vtkErrorMacro(<<"Cannot generate clip scalars if no clip function defined");
+    vtkErrorMacro(<< "Cannot generate clip scalars if no clip function defined");
     return 1;
   }
 
   // allocate the output and associated helper classes
   estimatedSize = numCells;
-  estimatedSize = estimatedSize / 1024 * 1024; //multiple of 1024
+  estimatedSize = estimatedSize / 1024 * 1024; // multiple of 1024
   if (estimatedSize < 1024)
   {
     estimatedSize = 1024;
   }
 
-  vtkPoints *newPoints = vtkPoints::New();
-  newPoints->Allocate(numPts,numPts/2);
+  vtkPoints* newPoints = vtkPoints::New();
+  newPoints->Allocate(numPts, numPts / 2);
 
-  vtkCellArray *conn[2];
+  vtkCellArray* conn[2];
   conn[0] = vtkCellArray::New();
-  conn[0]->Allocate(estimatedSize,estimatedSize/2);
+  conn[0]->AllocateEstimate(estimatedSize, 1);
   conn[0]->InitTraversal();
   types[0] = vtkUnsignedCharArray::New();
-  types[0]->Allocate(estimatedSize,estimatedSize/2);
-  locs[0] = vtkIdTypeArray::New();
-  locs[0]->Allocate(estimatedSize,estimatedSize/2);
+  types[0]->Allocate(estimatedSize, estimatedSize / 2);
 
-  if(this->GenerateClippedOutput)
+  if (this->GenerateClippedOutput)
   {
     numOutputs = 2;
     conn[1] = vtkCellArray::New();
-    conn[1]->Allocate(estimatedSize,estimatedSize/2);
+    conn[1]->AllocateEstimate(estimatedSize, 1);
     conn[1]->InitTraversal();
     types[1] = vtkUnsignedCharArray::New();
-    types[1]->Allocate(estimatedSize,estimatedSize/2);
-    locs[1] = vtkIdTypeArray::New();
-    locs[1]->Allocate(estimatedSize,estimatedSize/2);
+    types[1]->Allocate(estimatedSize, estimatedSize / 2);
   }
 
   // locator used to merge potentially duplicate points
-  if ( this->Locator == nullptr )
+  if (this->Locator == nullptr)
   {
     this->CreateDefaultLocator();
   }
-  this->Locator->InitPointInsertion (newPoints, input->GetBounds());
+  this->Locator->InitPointInsertion(newPoints, input->GetBounds());
 
   // prepare the output attributes
-  vtkGenericAttributeCollection *attributes=input->GetAttributes();
-  vtkGenericAttribute *attribute;
-  vtkDataArray *attributeArray;
+  vtkGenericAttributeCollection* attributes = input->GetAttributes();
+  vtkGenericAttribute* attribute;
+  vtkDataArray* attributeArray;
 
-  int c=attributes->GetNumberOfAttributes();
-  vtkDataSetAttributes *secondaryAttributes;
+  int c = attributes->GetNumberOfAttributes();
+  vtkDataSetAttributes* secondaryAttributes;
 
   int attributeType;
 
   vtkIdType i;
-  for(i = 0; i<c; ++i)
+  for (i = 0; i < c; ++i)
   {
-    attribute=attributes->GetAttribute(i);
-    attributeType=attribute->GetType();
-    if(attribute->GetCentering()==vtkPointCentered)
+    attribute = attributes->GetAttribute(i);
+    attributeType = attribute->GetType();
+    if (attribute->GetCentering() == vtkPointCentered)
     {
-      secondaryAttributes=this->SecondaryPD;
+      secondaryAttributes = this->SecondaryPD;
 
-      attributeArray=vtkDataArray::CreateDataArray(attribute->GetComponentType());
+      attributeArray = vtkDataArray::CreateDataArray(attribute->GetComponentType());
       attributeArray->SetNumberOfComponents(attribute->GetNumberOfComponents());
       attributeArray->SetName(attribute->GetName());
       this->InternalPD->AddArray(attributeArray);
       attributeArray->Delete();
-      if(this->InternalPD->GetAttribute(attributeType)==nullptr)
+      if (this->InternalPD->GetAttribute(attributeType) == nullptr)
       {
         this->InternalPD->SetActiveAttribute(
-          this->InternalPD->GetNumberOfArrays()-1,attributeType);
+          this->InternalPD->GetNumberOfArrays() - 1, attributeType);
       }
     }
     else // vtkCellCentered
@@ -269,127 +261,122 @@ int vtkGenericClip::RequestData(
     secondaryAttributes->AddArray(attributeArray);
     attributeArray->Delete();
 
-    if(secondaryAttributes->GetAttribute(attributeType)==nullptr)
+    if (secondaryAttributes->GetAttribute(attributeType) == nullptr)
     {
-      secondaryAttributes->SetActiveAttribute(secondaryAttributes->GetNumberOfArrays()-1,
-                                              attributeType);
+      secondaryAttributes->SetActiveAttribute(
+        secondaryAttributes->GetNumberOfArrays() - 1, attributeType);
     }
   }
-  outPD->InterpolateAllocate(this->SecondaryPD,estimatedSize,estimatedSize/2);
+  outPD->InterpolateAllocate(this->SecondaryPD, estimatedSize, estimatedSize / 2);
 
   outCD[0] = output->GetCellData();
-  outCD[0]->CopyAllocate(this->SecondaryCD,estimatedSize,estimatedSize/2);
-  if ( this->GenerateClippedOutput )
+  outCD[0]->CopyAllocate(this->SecondaryCD, estimatedSize, estimatedSize / 2);
+  if (this->GenerateClippedOutput)
   {
     outCD[1] = clippedOutput->GetCellData();
-    outCD[1]->CopyAllocate(this->SecondaryCD,estimatedSize,estimatedSize/2);
+    outCD[1]->CopyAllocate(this->SecondaryCD, estimatedSize, estimatedSize / 2);
   }
 
-  //vtkGenericPointIterator *pointIt = input->GetPoints();
-  vtkGenericCellIterator *cellIt = input->NewCellIterator();  //explicit cell could be 2D or 3D
+  // vtkGenericPointIterator *pointIt = input->GetPoints();
+  vtkGenericCellIterator* cellIt = input->NewCellIterator(); // explicit cell could be 2D or 3D
 
-  //Process all cells and clip each in turn
+  // Process all cells and clip each in turn
   //
-  int abort = 0;
-  vtkIdType updateTime = numCells/20 + 1;  // update roughly every 5%
+  bool abort = false;
+  vtkIdType updateTime = numCells / 20 + 1; // update roughly every 5%
 
-  int num[2]; num[0] = num[1] = 0;
-  int numNew[2]; numNew[0] = numNew[1] = 0;
+  int num[2];
+  num[0] = num[1] = 0;
+  int numNew[2];
+  numNew[0] = numNew[1] = 0;
   vtkIdType cellId;
 
-
   input->GetTessellator()->InitErrorMetrics(input);
 
   for (cellId = 0, cellIt->Begin(); !cellIt->IsAtEnd() && !abort; cellId++, cellIt->Next())
   {
     cell = cellIt->GetCell();
-    if ( !(cellId % updateTime) )
+    if (!(cellId % updateTime))
     {
       this->UpdateProgress(static_cast<double>(cellId) / numCells);
-      abort = this->GetAbortExecute();
+      abort = this->CheckAbort();
     }
 
     // perform the clipping
 
-    cell->Clip(this->Value, this->ClipFunction, input->GetAttributes(),
-               input->GetTessellator(),this->InsideOut,this->Locator,conn[0],
-               outPD,outCD[0],this->InternalPD,this->SecondaryPD,
-               this->SecondaryCD);
+    cell->Clip(this->Value, this->ClipFunction, input->GetAttributes(), input->GetTessellator(),
+      this->InsideOut, this->Locator, conn[0], outPD, outCD[0], this->InternalPD, this->SecondaryPD,
+      this->SecondaryCD);
     numNew[0] = conn[0]->GetNumberOfCells() - num[0];
     num[0] = conn[0]->GetNumberOfCells();
 
-    if ( this->GenerateClippedOutput )
+    if (this->GenerateClippedOutput)
     {
-      cell->Clip(this->Value, this->ClipFunction, input->GetAttributes(),
-                 input->GetTessellator(),this->InsideOut,this->Locator,conn[1],
-                 outPD,outCD[1],this->InternalPD,this->SecondaryPD,
-                 this->SecondaryCD);
+      cell->Clip(this->Value, this->ClipFunction, input->GetAttributes(), input->GetTessellator(),
+        this->InsideOut, this->Locator, conn[1], outPD, outCD[1], this->InternalPD,
+        this->SecondaryPD, this->SecondaryCD);
 
       numNew[1] = conn[1]->GetNumberOfCells() - num[1];
       num[1] = conn[1]->GetNumberOfCells();
     }
 
-    for (i=0; i<numOutputs; i++) //for both outputs
+    for (i = 0; i < numOutputs; i++) // for both outputs
     {
-      for (j=0; j < numNew[i]; j++)
+      for (j = 0; j < numNew[i]; j++)
       {
-        locs[i]->InsertNextValue(conn[i]->GetTraversalLocation());
-        conn[i]->GetNextCell(npts,pts);
+        conn[i]->GetNextCell(npts, pts);
 
-        //For each new cell added, got to set the type of the cell
-        switch ( cell->GetDimension() )
+        // For each new cell added, got to set the type of the cell
+        switch (cell->GetDimension())
         {
-          case 0: //points are generated--------------------------------
+          case 0: // points are generated--------------------------------
             cellType = (npts > 1 ? VTK_POLY_VERTEX : VTK_VERTEX);
             break;
 
-          case 1: //lines are generated---------------------------------
+          case 1: // lines are generated---------------------------------
             cellType = (npts > 2 ? VTK_POLY_LINE : VTK_LINE);
             break;
 
-          case 2: //polygons are generated------------------------------
-            cellType = (npts == 3 ? VTK_TRIANGLE :
-                        (npts == 4 ? VTK_QUAD : VTK_POLYGON));
+          case 2: // polygons are generated------------------------------
+            cellType = (npts == 3 ? VTK_TRIANGLE : (npts == 4 ? VTK_QUAD : VTK_POLYGON));
             break;
 
-          case 3: //tetrahedra or wedges are generated------------------
+          case 3: // tetrahedra or wedges are generated------------------
             cellType = (npts == 4 ? VTK_TETRA : VTK_WEDGE);
             break;
-        } //switch
+        } // switch
 
         types[i]->InsertNextValue(cellType);
-      } //for each new cell
-    } //for both outputs
-  } //for each cell
+      } // for each new cell
+    }   // for both outputs
+  }     // for each cell
   cellIt->Delete();
 
   output->SetPoints(newPoints);
-  output->SetCells(types[0], locs[0], conn[0]);
+  output->SetCells(types[0], conn[0]);
   conn[0]->Delete();
   types[0]->Delete();
-  locs[0]->Delete();
 
-  if ( this->GenerateClippedOutput )
+  if (this->GenerateClippedOutput)
   {
     clippedOutput->SetPoints(newPoints);
-    clippedOutput->SetCells(types[1], locs[1], conn[1]);
+    clippedOutput->SetCells(types[1], conn[1]);
     conn[1]->Delete();
     types[1]->Delete();
-    locs[1]->Delete();
   }
 
   newPoints->Delete();
-  this->Locator->Initialize();//release any extra memory
+  this->Locator->Initialize(); // release any extra memory
   output->Squeeze();
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Specify a spatial locator for merging points. By default,
 // an instance of vtkMergePoints is used.
 void vtkGenericClip::CreateDefaultLocator()
 {
-  if ( this->Locator == nullptr )
+  if (this->Locator == nullptr)
   {
     this->Locator = vtkMergePoints::New();
     this->Locator->Register(this);
@@ -397,13 +384,13 @@ void vtkGenericClip::CreateDefaultLocator()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGenericClip::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Merge Tolerance: " << this->MergeTolerance << "\n";
-  if ( this->ClipFunction )
+  if (this->ClipFunction)
   {
     os << indent << "Clip Function: " << this->ClipFunction << "\n";
   }
@@ -413,7 +400,7 @@ void vtkGenericClip::PrintSelf(ostream& os, vtkIndent indent)
   }
   os << indent << "InsideOut: " << (this->InsideOut ? "On\n" : "Off\n");
   os << indent << "Value: " << this->Value << "\n";
-  if ( this->Locator )
+  if (this->Locator)
   {
     os << indent << "Locator: " << this->Locator << "\n";
   }
@@ -422,25 +409,23 @@ void vtkGenericClip::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Locator: (none)\n";
   }
 
-  os << indent << "Generate Clip Scalars: "
-     << (this->GenerateClipScalars ? "On\n" : "Off\n");
+  os << indent << "Generate Clip Scalars: " << (this->GenerateClipScalars ? "On\n" : "Off\n");
 
-  os << indent << "Generate Clipped Output: "
-     << (this->GenerateClippedOutput ? "On\n" : "Off\n");
+  os << indent << "Generate Clipped Output: " << (this->GenerateClippedOutput ? "On\n" : "Off\n");
 
   if (this->InputScalarsSelection)
   {
-    os << indent << "InputScalarsSelection: "
-       << this->InputScalarsSelection << endl;
+    os << indent << "InputScalarsSelection: " << this->InputScalarsSelection << endl;
   }
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGenericClip::FillInputPortInformation(int port, vtkInformation* info)
 {
-  if(!this->Superclass::FillInputPortInformation(port, info))
+  if (!this->Superclass::FillInputPortInformation(port, info))
   {
     return 0;
   }
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkGenericDataSet");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
