@@ -35,6 +35,7 @@
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGenericDataSetTessellator);
 
 vtkCxxSetObjectMacro(vtkGenericDataSetTessellator, Locator, vtkIncrementalPointLocator);
@@ -85,7 +86,7 @@ int vtkGenericDataSetTessellator::RequestData(vtkInformation* vtkNotUsed(request
   vtkCellData* outputCD = output->GetCellData();
   vtkGenericAdaptorCell* cell;
   vtkIdType numInserted = 0, numNew, i;
-  int abortExecute = 0;
+  bool abortExecute = false;
 
   // Copy original points and point data
   vtkPoints* newPts = vtkPoints::New();
@@ -174,7 +175,7 @@ int vtkGenericDataSetTessellator::RequestData(vtkInformation* vtkNotUsed(request
     if (!(count % updateCount))
     {
       this->UpdateProgress(static_cast<double>(count) / numCells);
-      abortExecute = this->GetAbortExecute();
+      abortExecute = this->CheckAbort();
     }
 
     cell = cellIt->GetCell();
@@ -281,3 +282,4 @@ vtkMTimeType vtkGenericDataSetTessellator::GetMTime()
   }
   return mTime;
 }
+VTK_ABI_NAMESPACE_END
