@@ -36,6 +36,7 @@
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGenericStreamTracer);
 vtkCxxSetObjectMacro(vtkGenericStreamTracer, Integrator, vtkInitialValueProblemSolver);
 vtkCxxSetObjectMacro(
@@ -782,7 +783,7 @@ void vtkGenericStreamTracer::Integrate(vtkGenericDataSet* input0, vtkPolyData* o
   vtkIdType numPtsTotal = 0;
   double velocity[3];
 
-  int shouldAbort = 0;
+  bool shouldAbort = false;
 
   for (int currentLine = 0; currentLine < numLines; currentLine++)
   {
@@ -916,9 +917,9 @@ void vtkGenericStreamTracer::Integrate(vtkGenericDataSet* input0, vtkPolyData* o
         progress = (currentLine + propagation / this->MaximumPropagation.Interval) / numLines;
         this->UpdateProgress(progress);
 
-        if (this->GetAbortExecute())
+        if (this->CheckAbort())
         {
-          shouldAbort = 1;
+          shouldAbort = true;
           break;
         }
       }
@@ -978,7 +979,7 @@ void vtkGenericStreamTracer::Integrate(vtkGenericDataSet* input0, vtkPolyData* o
         break;
       }
 
-      // Make sure we use the dataset found by the vtkInterpolatedVelocityField
+      // Make sure we use the dataset found by the vtkCompositeInterpolatedVelocityField
       input = func->GetLastDataSet();
 
       inVectors = input->GetAttributes()->GetAttribute(
@@ -1145,7 +1146,7 @@ void vtkGenericStreamTracer::GenerateNormals(vtkPolyData* output, double* firstN
       normals->SetNumberOfComponents(3);
       normals->SetNumberOfTuples(numPts);
 
-      lineNormalGenerator->GenerateSlidingNormals(outputPoints, outputLines, normals, firstNormal);
+      vtkPolyLine::GenerateSlidingNormals(outputPoints, outputLines, normals, firstNormal);
       lineNormalGenerator->Delete();
 
       int i, j;
@@ -1351,3 +1352,4 @@ void vtkGenericStreamTracer::SetSourceConnection(vtkAlgorithmOutput* algOutput)
 {
   this->SetInputConnection(1, algOutput);
 }
+VTK_ABI_NAMESPACE_END
