@@ -26,8 +26,7 @@
  * preferred filter to use in most cases and may be deprecated in the
  * future.)
  *
- * The filter only has only a few options: whether to produce triangle strips
- * when the input dataset type is structured; methods for passing through
+ * The filter only has only a few options: methods for passing through
  * point and cell ids (to support picking); and controls for nonlinear cell
  * subdivision. At this time vtkDataSetSurfaceFilter has the distinction of
  * being able to process non-linear cells requiring subdivision. For this
@@ -38,6 +37,17 @@
  * vtkGeometryFilter will delegate to vtkDataSetSurfaceFilter when it
  * encounters nonlinear cells.)
  *
+ * @section FastMode Fast Mode
+ *
+ * vtkDataSetSurfaceFilter is sometimes used to simply render a 3D
+ * dataset. In which case we only are concerned about an approximate
+ * representation of the data and not necessarily the true exterior surface. In
+ * that case, simply set the FastMode flag to true.
+ *
+ * Currently FastMode is used when extracting surface from a structured dataset
+ * or when `Delegation` is true. When Delegation is true, the flag is passed on
+ * to `vtkGeometryFilter` (see `vtkGeometryFilter:SetFastMode`).
+ *
  * @warning
  * At one time, vtkDataSetSurfaceFilter was a faster version of
  * vtkGeometryFilter when processing unstructured grids, however
@@ -82,10 +92,18 @@
 #include "vtkGeometryFilter.h"        // To facilitate delegation
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
+template <typename ArrayType>
+class vtkSmartPointer;
+
+class vtkCellIterator;
 class vtkPointData;
 class vtkPoints;
 class vtkIdTypeArray;
+class vtkImageData;
+class vtkRectilinearGrid;
 class vtkStructuredGrid;
+class vtkUnstructuredGridBase;
 
 // Helper structure for hashing faces.
 struct vtkFastGeomQuadStruct
@@ -100,7 +118,7 @@ typedef struct vtkFastGeomQuadStruct vtkFastGeomQuad;
 class VTKFILTERSGEOMETRY_EXPORT vtkDataSetSurfaceFilter : public vtkPolyDataAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Statndard methods for object instantiation, type information, and printing.
    */
@@ -108,18 +126,7 @@ public:
   vtkTypeMacro(vtkDataSetSurfaceFilter, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
-  /**
-   * When input is structured data, this flag will generate faces with
-   * triangle strips.  This should render faster and use less memory, but no
-   * cell data is copied.  By default, UseStrips is Off.
-   */
-  vtkSetMacro(UseStrips, vtkTypeBool);
-  vtkGetMacro(UseStrips, vtkTypeBool);
-  vtkBooleanMacro(UseStrips, vtkTypeBool);
-  //@}
-
-  //@{
+  ///@{
   /**
    * If PieceInvariant is true, vtkDataSetSurfaceFilter requests
    * 1 ghost level from input in order to remove internal surface
@@ -127,16 +134,14 @@ public:
    */
   vtkSetMacro(PieceInvariant, int);
   vtkGetMacro(PieceInvariant, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If on, the output polygonal dataset will have a celldata array that
    * holds the cell index of the original 3D cell that produced each output
    * cell. This is useful for cell picking. The default is off to conserve
-   * memory. Note that PassThroughCellIds will be ignored if UseStrips is on,
-   * since in that case each tringle strip can represent more than on of the
-   * input cells.
+   * memory.
    */
   vtkSetMacro(PassThroughCellIds, vtkTypeBool);
   vtkGetMacro(PassThroughCellIds, vtkTypeBool);
@@ -144,9 +149,21 @@ public:
   vtkSetMacro(PassThroughPointIds, vtkTypeBool);
   vtkGetMacro(PassThroughPointIds, vtkTypeBool);
   vtkBooleanMacro(PassThroughPointIds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Turn on/off fast mode execution. If enabled, fast mode typically runs
+   * much faster (2-3x) than the standard algorithm, however the output is an
+   * approximation to the correct result. Also, note that the FastMode
+   * depends on the data member Degree for its execution.
+   */
+  vtkSetMacro(FastMode, bool);
+  vtkGetMacro(FastMode, bool);
+  vtkBooleanMacro(FastMode, bool);
+  ///@}
+
+  ///@{
   /**
    * If PassThroughCellIds or PassThroughPointIds is on, then these ivars
    * control the name given to the field in which the ids are written into.  If
@@ -163,9 +180,9 @@ public:
   {
     return (this->OriginalPointIdsName ? this->OriginalPointIdsName : "vtkOriginalPointIds");
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If the input is an unstructured grid with nonlinear faces, this parameter
    * determines how many times the face is subdivided into linear faces.  If 0,
@@ -179,9 +196,9 @@ public:
    */
   vtkSetMacro(NonlinearSubdivisionLevel, int);
   vtkGetMacro(NonlinearSubdivisionLevel, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Disable delegation to an internal vtkGeometryFilter. The geometry filter runs
    * much faster (especially for unstructured grids); however the two filters
@@ -190,9 +207,9 @@ public:
   vtkSetMacro(Delegation, vtkTypeBool);
   vtkGetMacro(Delegation, vtkTypeBool);
   vtkBooleanMacro(Delegation, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Direct access methods so that this class can be used as an
    * algorithm without using it as a filter (i.e., no pipeline updates).
@@ -200,7 +217,8 @@ public:
   virtual int StructuredExecute(
     vtkDataSet* input, vtkPolyData* output, vtkIdType* ext, vtkIdType* wholeExt);
 #ifdef VTK_USE_64BIT_IDS
-  virtual int StructuredExecute(vtkDataSet* input, vtkPolyData* output, int* ext32, int* wholeExt32)
+  virtual int StructuredExecute(
+    vtkDataSet* input, vtkPolyData* output, const int* ext32, const int* wholeExt32)
   {
     vtkIdType ext[6];
     vtkIdType wholeExt[6];
@@ -212,16 +230,35 @@ public:
     return this->StructuredExecute(input, output, ext, wholeExt);
   }
 #endif
+
+  /**
+   * Execute the filter on \a input and store the result in \a output.
+   * The correct function should be used accordingly to the type of the input.
+   *
+   * Input can be any subclass of \a vtkUnstructuredGridBase.
+   * In case of a \a vtkUnstructuredGrid or subclass instance, an optimized version
+   * of the filter is executed.
+   */
   virtual int UnstructuredGridExecute(vtkDataSet* input, vtkPolyData* output);
-  int UnstructuredGridExecute(
-    vtkDataSet* input, vtkPolyData* output, vtkGeometryFilterHelper* info);
+  ///@{
+  /**
+   * Execute the filter on \a input and store the result in \a output.
+   * The correct function should be used accordingly to the type of the input.
+   */
   virtual int DataSetExecute(vtkDataSet* input, vtkPolyData* output);
-  virtual int StructuredWithBlankingExecute(vtkStructuredGrid* input, vtkPolyData* output);
   virtual int UniformGridExecute(vtkDataSet* input, vtkPolyData* output, vtkIdType* ext,
     vtkIdType* wholeExt, bool extractface[6]);
+  ///@}
+
+  /**
+   * Optimized \a UnstructuredGridExecute function for vtkUnstructuredGrid and subclass instances
+   * only. This function is used in vtkGeometryFilter.
+   */
+  int UnstructuredGridExecute(
+    vtkDataSet* input, vtkPolyData* output, vtkGeometryFilterHelper* info);
 #ifdef VTK_USE_64BIT_IDS
-  virtual int UniformGridExecute(
-    vtkDataSet* input, vtkPolyData* output, int* ext32, int* wholeExt32, bool extractface[6])
+  virtual int UniformGridExecute(vtkDataSet* input, vtkPolyData* output, const int* ext32,
+    const int* wholeExt32, bool extractface[6])
   {
     vtkIdType ext[6];
     vtkIdType wholeExt[6];
@@ -233,14 +270,12 @@ public:
     return this->UniformGridExecute(input, output, ext, wholeExt, extractface);
   }
 #endif
-  //@}
+  ///@}
 
 protected:
   vtkDataSetSurfaceFilter();
   ~vtkDataSetSurfaceFilter() override;
 
-  vtkTypeBool UseStrips;
-
   int RequestUpdateExtent(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
   int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
@@ -258,9 +293,6 @@ protected:
   void EstimateStructuredDataArraySizes(
     vtkIdType* ext, vtkIdType* wholeExt, vtkIdType& numPoints, vtkIdType& numCells);
 
-  void ExecuteFaceStrips(vtkDataSet* input, vtkPolyData* output, int maxFlag, vtkIdType* ext,
-    int aAxis, int bAxis, int cAxis, vtkIdType* wholeExt);
-
   void ExecuteFaceQuads(vtkDataSet* input, vtkPolyData* output, int maxFlag, vtkIdType* ext,
     int aAxis, int bAxis, int cAxis, vtkIdType* wholeExt, bool checkVisibility);
 
@@ -285,13 +317,16 @@ protected:
   vtkIdType* PointMap;
   vtkIdType GetOutputPointId(
     vtkIdType inPtId, vtkDataSet* input, vtkPoints* outPts, vtkPointData* outPD);
+  vtkIdType GetOutputPointIdAndInterpolate(vtkIdType inPtId, vtkDataSet* input, vtkCell* cell,
+    double* weights, vtkPoints* outPts, vtkPointData* outPD);
 
   class vtkEdgeInterpolationMap;
 
   vtkEdgeInterpolationMap* EdgeMap;
   vtkIdType GetInterpolatedPointId(vtkIdType edgePtA, vtkIdType edgePtB, vtkDataSet* input,
-    vtkCell* cell, double pcoords[3], vtkPoints* outPts, vtkPointData* outPD);
-
+    vtkCell* cell, double pcoords[3], double* weights, vtkPoints* outPts, vtkPointData* outPD);
+  vtkIdType GetInterpolatedPointId(vtkDataSet* input, vtkCell* cell, double pcoords[3],
+    double* weights, vtkPoints* outPts, vtkPointData* outPD);
   vtkIdType NumberOfNewCells;
 
   // Better memory allocation for faces (hash)
@@ -320,12 +355,20 @@ protected:
   char* OriginalPointIdsName;
 
   int NonlinearSubdivisionLevel;
-
   vtkTypeBool Delegation;
+  bool FastMode;
 
 private:
+  int UnstructuredGridBaseExecute(vtkDataSet* input, vtkPolyData* output);
+  int UnstructuredGridExecuteInternal(vtkUnstructuredGridBase* input, vtkPolyData* output,
+    bool handleSubdivision, vtkSmartPointer<vtkCellIterator> cellIter);
+
+  int StructuredExecuteNoBlanking(
+    vtkDataSet* input, vtkPolyData* output, vtkIdType* ext, vtkIdType* wholeExt);
+
   vtkDataSetSurfaceFilter(const vtkDataSetSurfaceFilter&) = delete;
   void operator=(const vtkDataSetSurfaceFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
