@@ -19,6 +19,7 @@
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExplicitStructuredGridSurfaceFilter);
 
 //------------------------------------------------------------------------------
@@ -138,16 +139,16 @@ int vtkExplicitStructuredGridSurfaceFilter::ExtractSurface(
   vtkNew<vtkIdList> cellIds;
   vtkUnsignedCharArray* connectivityFlags = nullptr;
 
-  char* facesConnectivityFlagsArrayName = input->GetFacesConnectivityFlagsArrayName();
+  const char* facesConnectivityFlagsArrayName = input->GetFacesConnectivityFlagsArrayName();
   if (facesConnectivityFlagsArrayName)
   {
     connectivityFlags = vtkUnsignedCharArray::SafeDownCast(
       input->GetCellData()->GetAbstractArray(facesConnectivityFlagsArrayName));
-    if (!connectivityFlags)
-    {
-      vtkErrorMacro("Make sure Connectivity Flags have been computed before using this filter");
-      return 0;
-    }
+  }
+  if (!connectivityFlags)
+  {
+    vtkErrorMacro("Make sure Connectivity Flags have been computed before using this filter");
+    return 0;
   }
 
   vtkPoints* points = input->GetPoints();
@@ -173,7 +174,7 @@ int vtkExplicitStructuredGridSurfaceFilter::ExtractSurface(
   outputCD->CopyAllocate(cd, numCells);
 
   // Traverse cells to extract geometry
-  int abort = 0;
+  bool abort = false;
   vtkIdType progressInterval = numCells / 20 + 1;
   vtkIdType npts;
   const vtkIdType* pts;
@@ -189,7 +190,7 @@ int vtkExplicitStructuredGridSurfaceFilter::ExtractSurface(
     {
       vtkDebugMacro(<< "Process cell #" << cellId);
       this->UpdateProgress(static_cast<double>(cellId) / numCells);
-      abort = this->GetAbortExecute();
+      abort = this->CheckAbort();
     }
 
     // Ignore blank cells and ghost cells
@@ -266,3 +267,4 @@ void vtkExplicitStructuredGridSurfaceFilter::PrintSelf(ostream& os, vtkIndent in
   os << indent << "OriginalCellIdsName: " << this->GetOriginalCellIdsName() << endl;
   os << indent << "OriginalPointIdsName: " << this->GetOriginalPointIdsName() << endl;
 }
+VTK_ABI_NAMESPACE_END
