@@ -43,19 +43,6 @@
  * The output precision of created points (if they need to be created) can
  * also be specified.
  *
- * In some cases (especially for large unstructured grids) the
- * vtkGeometryFilter can be slow. Consequently the filter has an optional
- * "fast mode" that may execute significantly faster (>4-5x) than normal
- * execution. The fast mode visits a subset of cells that may be on the
- * boundary of the dataset (and skips interior cells which contribute nothing
- * to the output). The set of subsetted cells is determined by inspecting
- * the topological connectivity degree of each point (i.e., the number of
- * unique cells using a particular point is that point's degree). With fast
- * mode enabled, those cells connected to a point with degree <= Degree
- * are visited. Note that this approach may miss some cells which contribute
- * boundary faces--thus the output is an approximation to the normal
- * execution of vtkGeometryFilter.
- *
  * Finally, this filter takes an optional second, vtkPolyData input. This
  * input represents a list of faces that are to be excluded from the output
  * of vtkGeometryFilter.
@@ -63,14 +50,14 @@
  * @warning
  * While vtkGeometryFilter and vtkDataSetSurfaceFilter perform similar operations,
  * there are important differences as follows:
- * 1. vtkGeometryFilter preserves topological connectivity. vtkDataSetSurfaceFilter
- *    produces output primitives which may be disconnected from one another.
+ * 1. vtkGeometryFilter can preserve (using RemoveGhostInterfaces) topological connectivity.
+ *    vtkDataSetSurfaceFilter produces output primitives which may be disconnected from one another.
  * 2. vtkGeometryFilter can generate output based on cell ids, point ids, and/or
  *    extent (bounding box) clipping. vtkDataSetSurfaceFilter strictly extracts
  *    the boundary surface of a dataset.
- * 3. vtkGeometryFilter is much faster than vtkDataSetSurfaceFilter, especially
- *    for vtkUnstructuredGrids. As a result, vtkDataSetSurfaceFilter will
- *    delegate the processing of linear unstructured grids to vtkGeometryFilter.
+ * 3. vtkGeometryFilter is much faster than vtkDataSetSurfaceFilter, because it's
+ *    multi-threaded. As a result, vtkDataSetSurfaceFilter will delegate the processing
+ *    of linear unstructured grids to vtkGeometryFilter.
  * 4. vtkGeometryFilter can (currently) only handle linear cells. The filter
  *    will delegate to vtkDataSetSurfaceFilter for higher-order cells. (This
  *    is a historical artifact and may be rectified in the future.)
@@ -83,6 +70,10 @@
  * output polydata cells.
  *
  * @warning
+ * This class is templated. It may run slower than serial execution if the code
+ * is not optimized during compilation. Build in Release or ReleaseWithDebugInfo.
+ *
+ * @warning
  * This class has been threaded with vtkSMPTools. Using TBB or other
  * non-sequential type (set in the CMake variable
  * VTK_SMP_IMPLEMENTATION_TYPE) may improve performance significantly.
@@ -99,108 +90,146 @@
 #include "vtkFiltersGeometryModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+#include <array> // For std::array
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIncrementalPointLocator;
 class vtkStructuredGrid;
-class vtkUnstructuredGrid;
+class vtkUnstructuredGridBase;
 class vtkGeometryFilter;
 class vtkDataSetSurfaceFilter;
 struct vtkGeometryFilterHelper;
-struct vtkExcludedFaces;
 
 // Used to coordinate delegation to vtkDataSetSurfaceFilter
 struct VTKFILTERSGEOMETRY_EXPORT vtkGeometryFilterHelper
 {
+  enum CellType
+  {
+    VERTS = 0,
+    LINES = 1,
+    POLYS = 2,
+    STRIPS = 3,
+    OTHER_LINEAR_CELLS = 4,
+    NON_LINEAR_CELLS = 5,
+    NUM_CELL_TYPES
+  };
+  using CellTypesInformation = std::array<bool, NUM_CELL_TYPES>;
+  CellTypesInformation CellTypesInfo;
   unsigned char IsLinear;
-  static vtkGeometryFilterHelper* CharacterizeUnstructuredGrid(vtkUnstructuredGrid*);
+  static vtkGeometryFilterHelper* CharacterizeUnstructuredGrid(vtkUnstructuredGridBase*);
   static void CopyFilterParams(vtkGeometryFilter* gf, vtkDataSetSurfaceFilter* dssf);
   static void CopyFilterParams(vtkDataSetSurfaceFilter* dssf, vtkGeometryFilter* gf);
+  bool HasOnlyVerts()
+  {
+    return this->CellTypesInfo[VERTS] && !this->CellTypesInfo[LINES] &&
+      !this->CellTypesInfo[POLYS] && !this->CellTypesInfo[STRIPS] &&
+      !this->CellTypesInfo[OTHER_LINEAR_CELLS] && !this->CellTypesInfo[NON_LINEAR_CELLS];
+  }
+  bool HasOnlyLines()
+  {
+    return !this->CellTypesInfo[VERTS] && this->CellTypesInfo[LINES] &&
+      !this->CellTypesInfo[POLYS] && !this->CellTypesInfo[STRIPS] &&
+      !this->CellTypesInfo[OTHER_LINEAR_CELLS] && !this->CellTypesInfo[NON_LINEAR_CELLS];
+  }
+  bool HasOnlyPolys()
+  {
+    return !this->CellTypesInfo[VERTS] && !this->CellTypesInfo[LINES] &&
+      this->CellTypesInfo[POLYS] && !this->CellTypesInfo[STRIPS] &&
+      !this->CellTypesInfo[OTHER_LINEAR_CELLS] && !this->CellTypesInfo[NON_LINEAR_CELLS];
+  }
+  bool HasOnlyStrips()
+  {
+    return !this->CellTypesInfo[VERTS] && !this->CellTypesInfo[LINES] &&
+      !this->CellTypesInfo[POLYS] && this->CellTypesInfo[STRIPS] &&
+      !this->CellTypesInfo[OTHER_LINEAR_CELLS] && !this->CellTypesInfo[NON_LINEAR_CELLS];
+  }
 };
 
 class VTKFILTERSGEOMETRY_EXPORT vtkGeometryFilter : public vtkPolyDataAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, type information, and printing.
    */
   static vtkGeometryFilter* New();
   vtkTypeMacro(vtkGeometryFilter, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off selection of geometry by point id.
    */
   vtkSetMacro(PointClipping, bool);
   vtkGetMacro(PointClipping, bool);
   vtkBooleanMacro(PointClipping, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off selection of geometry by cell id.
    */
   vtkSetMacro(CellClipping, bool);
   vtkGetMacro(CellClipping, bool);
   vtkBooleanMacro(CellClipping, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off selection of geometry via bounding box.
    */
   vtkSetMacro(ExtentClipping, bool);
   vtkGetMacro(ExtentClipping, bool);
   vtkBooleanMacro(ExtentClipping, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the minimum point id for point id selection.
    */
   vtkSetClampMacro(PointMinimum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(PointMinimum, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the maximum point id for point id selection.
    */
   vtkSetClampMacro(PointMaximum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(PointMaximum, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the minimum cell id for point id selection.
    */
   vtkSetClampMacro(CellMinimum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(CellMinimum, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the maximum cell id for point id selection.
    */
   vtkSetClampMacro(CellMaximum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(CellMaximum, vtkIdType);
-  //@}
+  ///@}
 
   /**
    * Specify a (xmin,xmax, ymin,ymax, zmin,zmax) bounding box to clip data.
    */
   void SetExtent(double xMin, double xMax, double yMin, double yMax, double zMin, double zMax);
 
-  //@{
+  ///@{
   /**
    * Set / get a (xmin,xmax, ymin,ymax, zmin,zmax) bounding box to clip data.
    */
   void SetExtent(double extent[6]);
   double* GetExtent() VTK_SIZEHINT(6) { return this->Extent; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off merging of points. This will reduce the number of output
    * points, at some cost to performance. If Merging is off, then if possible
@@ -212,9 +241,9 @@ public:
   vtkSetMacro(Merging, bool);
   vtkGetMacro(Merging, bool);
   vtkBooleanMacro(Merging, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output types. See the
    * documentation for the vtkAlgorithm::DesiredOutputPrecision enum for an
@@ -224,21 +253,22 @@ public:
    */
   void SetOutputPointsPrecision(int precision);
   int GetOutputPointsPrecision() const;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off fast mode execution. If enabled, fast mode typically runs
    * much faster (2-3x) than the standard algorithm, however the output is an
-   * approximation to the correct result. Also, note that the FastMode
-   * depends on the data member Degree for its execution.
+   * approximation to the correct result. FastMode is only meaningful when
+   * the input is vtkImageData/vtkRectilinearGrid/vtkStructuredGrid and there
+   * are blank cells.
    */
   vtkSetMacro(FastMode, bool);
   vtkGetMacro(FastMode, bool);
   vtkBooleanMacro(FastMode, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If fast mode is enabled, then Degree controls which cells are
    * visited. Basically, any cell connected to a point with connectivity
@@ -246,46 +276,53 @@ public:
    * located on the boundary of datasets - thus attached cells frequently
    * produce output boundary fragments.
    */
-  vtkSetClampMacro(Degree, unsigned int, 1, VTK_INT_MAX);
-  vtkGetMacro(Degree, unsigned int);
-  //@}
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
+  virtual void SetDegree(unsigned int vtkNotUsed(arg)) {}
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
+  virtual unsigned int GetDegreeMinValue() { return 1; }
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
+  virtual unsigned int GetDegreeMaxValue() { return static_cast<int>(~0u >> 1); }
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
+  virtual unsigned int GetDegree() { return 4; }
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / get a spatial locator for merging points. By default an instance
    * of vtkMergePoints is used. (This method is now deprecated and has no
    * effect.)
    */
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
   void SetLocator(vtkIncrementalPointLocator* locator);
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
   vtkGetObjectMacro(Locator, vtkIncrementalPointLocator);
-  //@}
+  ///@}
 
   /**
    * Create default locator. Used to create one when none is specified.
    * This method is now deprecated.
    */
+  VTK_DEPRECATED_IN_9_2_0("This method is no longer used and has no effect.")
   void CreateDefaultLocator();
 
   // The following are methods compatible with vtkDataSetSurfaceFilter.
 
-  //@{
+  ///@{
   /**
-   * If PieceInvariant is true, vtkDataSetSurfaceFilter requests
+   * If PieceInvariant is true, vtkGeometryFilter requests
    * 1 ghost level from input in order to remove internal surface
    * that are between processes. False by default.
    */
   vtkSetMacro(PieceInvariant, int);
   vtkGetMacro(PieceInvariant, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If on, the output polygonal dataset will have a celldata array that
    * holds the cell index of the original 3D cell that produced each output
    * cell. This is useful for cell picking. The default is off to conserve
-   * memory. Note that PassThroughCellIds will be ignored if UseStrips is on,
-   * since in that case each tringle strip can represent more than on of the
-   * input cells.
+   * memory.
    */
   vtkSetMacro(PassThroughCellIds, vtkTypeBool);
   vtkGetMacro(PassThroughCellIds, vtkTypeBool);
@@ -293,9 +330,9 @@ public:
   vtkSetMacro(PassThroughPointIds, vtkTypeBool);
   vtkGetMacro(PassThroughPointIds, vtkTypeBool);
   vtkBooleanMacro(PassThroughPointIds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If PassThroughCellIds or PassThroughPointIds is on, then these ivars
    * control the name given to the field in which the ids are written into.  If
@@ -312,9 +349,9 @@ public:
   {
     return (this->OriginalPointIdsName ? this->OriginalPointIdsName : "vtkOriginalPointIds");
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If a second, vtkPolyData input is provided, this second input specifies
    * a list of faces to be excluded from the output (in the
@@ -329,9 +366,9 @@ public:
   void SetExcludedFacesData(vtkPolyData*);
   void SetExcludedFacesConnection(vtkAlgorithmOutput* algOutput);
   vtkPolyData* GetExcludedFaces();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If the input is an unstructured grid with nonlinear faces, this parameter
    * determines how many times the face is subdivided into linear faces.  If 0,
@@ -345,37 +382,61 @@ public:
    */
   vtkSetMacro(NonlinearSubdivisionLevel, int);
   vtkGetMacro(NonlinearSubdivisionLevel, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Disable delegation to an internal vtkDataSetSurfaceFilter.
    */
   vtkSetMacro(Delegation, vtkTypeBool);
   vtkGetMacro(Delegation, vtkTypeBool);
   vtkBooleanMacro(Delegation, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Set/Get if Ghost interfaces will be removed.
+   * When you are rendering you want to remove ghost interfaces that originate from duplicate cells.
+   *
+   * There are certain algorithms though that need the ghost interfaces, such as GhostCellGenerator
+   * and FeatureEdges.
+   *
+   * Since Rendering is the most common case, the Default is on.
+   *
+   * Note: DON'T change it if there are no ghost cells.
+   */
+  vtkSetMacro(RemoveGhostInterfaces, bool);
+  vtkBooleanMacro(RemoveGhostInterfaces, bool);
+  vtkGetMacro(RemoveGhostInterfaces, bool);
+  ///@}
+
+  ///@{
   /**
    * Direct access methods so that this class can be used as an
    * algorithm without using it as a filter (i.e., no pipeline updates).
    * Also some internal methods with additional options.
    */
-  int PolyDataExecute(vtkDataSet* input, vtkPolyData* output, vtkExcludedFaces* exc);
+  int PolyDataExecute(vtkDataSet* input, vtkPolyData* output, vtkPolyData* exc);
   virtual int PolyDataExecute(vtkDataSet*, vtkPolyData*);
 
   int UnstructuredGridExecute(
-    vtkDataSet* input, vtkPolyData* output, vtkGeometryFilterHelper* info, vtkExcludedFaces* exc);
+    vtkDataSet* input, vtkPolyData* output, vtkGeometryFilterHelper* info, vtkPolyData* exc);
   virtual int UnstructuredGridExecute(vtkDataSet* input, vtkPolyData* output);
 
-  int StructuredExecute(
-    vtkDataSet* input, vtkPolyData* output, vtkInformation* inInfo, vtkExcludedFaces* exc);
-  virtual int StructuredExecute(vtkDataSet* input, vtkPolyData* output, vtkInformation* inInfo);
+  VTK_DEPRECATED_IN_9_3_0("Use the new version that has int* instead of vtkInformation*")
+  int StructuredExecute(vtkDataSet* input, vtkPolyData* output, vtkInformation* inInfo,
+    vtkPolyData* exc, bool* extractFace = nullptr);
+  int StructuredExecute(vtkDataSet* input, vtkPolyData* output, int* wholeExtent, vtkPolyData* exc,
+    bool* extractFace = nullptr);
+  VTK_DEPRECATED_IN_9_3_0("Use the new version that has int* instead of vtkInformation*")
+  virtual int StructuredExecute(
+    vtkDataSet* input, vtkPolyData* output, vtkInformation* inInfo, bool* extractFace = nullptr);
+  virtual int StructuredExecute(
+    vtkDataSet* input, vtkPolyData* output, int* wholeExt, bool* extractFace = nullptr);
 
-  int DataSetExecute(vtkDataSet* input, vtkPolyData* output, vtkExcludedFaces* exc);
+  int DataSetExecute(vtkDataSet* input, vtkPolyData* output, vtkPolyData* exc);
   virtual int DataSetExecute(vtkDataSet* input, vtkPolyData* output);
-  //@}
+  ///@}
 
 protected:
   vtkGeometryFilter();
@@ -396,14 +457,14 @@ protected:
   bool CellClipping;
   bool ExtentClipping;
   int OutputPointsPrecision;
+  bool RemoveGhostInterfaces;
 
   bool Merging;
   vtkIncrementalPointLocator* Locator;
 
   bool FastMode;
-  unsigned int Degree;
 
-  // This methods support compatability with vtkDataSetSurfaceFilter
+  // These methods support compatibility with vtkDataSetSurfaceFilter
   int PieceInvariant;
   vtkTypeBool PassThroughCellIds;
   char* OriginalCellIdsName;
@@ -420,4 +481,5 @@ private:
   void operator=(const vtkGeometryFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
