@@ -41,6 +41,7 @@
 #include "vtkFiltersGeometryModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGEOMETRY_EXPORT vtkRectilinearGridGeometryFilter : public vtkPolyDataAlgorithm
 {
 public:
@@ -52,13 +53,13 @@ public:
    */
   static vtkRectilinearGridGeometryFilter* New();
 
-  //@{
+  ///@{
   /**
    * Get the extent in topological coordinate range (imin,imax, jmin,jmax,
    * kmin,kmax).
    */
   vtkGetVectorMacro(Extent, int, 6);
-  //@}
+  ///@}
 
   /**
    * Specify (imin,imax, jmin,jmax, kmin,kmax) indices.
@@ -84,4 +85,5 @@ private:
   void operator=(const vtkRectilinearGridGeometryFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
