@@ -47,6 +47,7 @@
 #include "vtkFiltersGeometryModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSGEOMETRY_EXPORT vtkStructuredGridGeometryFilter : public vtkPolyDataAlgorithm
 {
 public:
@@ -54,13 +55,13 @@ public:
   vtkTypeMacro(vtkStructuredGridGeometryFilter, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get the extent in topological coordinate range (imin,imax, jmin,jmax,
    * kmin,kmax).
    */
   vtkGetVectorMacro(Extent, int, 6);
-  //@}
+  ///@}
 
   /**
    * Specify (imin,imax, jmin,jmax, kmin,kmax) indices.
@@ -87,4 +88,5 @@ private:
   void operator=(const vtkStructuredGridGeometryFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
