@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkUnstructuredGridGeometryFilter.h"
 
 #include "vtkBezierHexahedron.h"
@@ -57,6 +54,7 @@
 #include "vtkStructuredGrid.h"
 #include "vtkTetra.h"
 #include "vtkTriQuadraticHexahedron.h"
+#include "vtkTriQuadraticPyramid.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnstructuredGrid.h"
 #include "vtkVoxel.h"
@@ -65,6 +63,7 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkUnstructuredGridGeometryFilter);
 
 #if 0
@@ -985,7 +984,7 @@ int vtkUnstructuredGridGeometryFilter::RequestData(vtkInformation* vtkNotUsed(re
 
   // Traverse cells to extract geometry
   int progressCount = 0;
-  int abort = 0;
+  bool abort = false;
   vtkIdType progressInterval = numCells / 20 + 1;
 
   vtkPoolManager<vtkSurfel>* pool = new vtkPoolManager<vtkSurfel>;
@@ -1001,7 +1000,7 @@ int vtkUnstructuredGridGeometryFilter::RequestData(vtkInformation* vtkNotUsed(re
     {
       vtkDebugMacro(<< "Process cell #" << cellId);
       this->UpdateProgress((double)cellId / numCells);
-      abort = this->GetAbortExecute();
+      abort = this->CheckAbort();
       progressCount = 0;
     }
     progressCount++;
@@ -1120,6 +1119,12 @@ int vtkUnstructuredGridGeometryFilter::RequestData(vtkInformation* vtkNotUsed(re
             this->HashTable->InsertFaces<vtkQuadraticPyramid, 1, 5, 6, VTK_QUADRATIC_TRIANGLE>(
               pts, cellId);
             break;
+          case VTK_TRIQUADRATIC_PYRAMID:
+            this->HashTable->InsertFaces<vtkTriQuadraticPyramid, 0, 1, 9, VTK_BIQUADRATIC_QUAD>(
+              pts, cellId);
+            this->HashTable->InsertFaces<vtkTriQuadraticPyramid, 1, 5, 7, VTK_BIQUADRATIC_TRIANGLE>(
+              pts, cellId);
+            break;
           case VTK_TRIQUADRATIC_HEXAHEDRON:
             this->HashTable->InsertFaces<vtkTriQuadraticHexahedron, 0, 6, 9, VTK_BIQUADRATIC_QUAD>(
               pts, cellId);
@@ -1264,10 +1269,9 @@ int vtkUnstructuredGridGeometryFilter::RequestData(vtkInformation* vtkNotUsed(re
       vtkIdType newCellId = output->InsertNextCell(cellType2D, cellIds);
       outputCD->CopyData(cd, cellId, newCellId);
 
-      if (outputCD->SetActiveAttribute(
-            "HigherOrderDegrees", vtkDataSetAttributes::AttributeTypes::HIGHERORDERDEGREES) != -1)
+      vtkDataArray* v = outputCD->GetHigherOrderDegrees();
+      if (v)
       {
-        vtkDataArray* v = outputCD->GetHigherOrderDegrees();
         double degrees[3];
         degrees[0] = surfel->Degrees[0];
         degrees[1] = surfel->Degrees[1];
@@ -1429,3 +1433,4 @@ int vtkUnstructuredGridGeometryFilter::RequestUpdateExtent(vtkInformation* vtkNo
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
