@@ -29,6 +29,7 @@
 #include "vtkFiltersHybridModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSHYBRID_EXPORT vtkEarthSource : public vtkPolyDataAlgorithm
 {
 public:
@@ -36,15 +37,15 @@ public:
   vtkTypeMacro(vtkEarthSource, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set radius of earth.
    */
   vtkSetClampMacro(Radius, double, 0.0, VTK_FLOAT_MAX);
   vtkGetMacro(Radius, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on every nth entity. This controls how much detail the model
    * will have. The maximum ratio is sixteen. (The smaller OnRatio, the more
@@ -52,9 +53,9 @@ public:
    */
   vtkSetClampMacro(OnRatio, int, 1, 16);
   vtkGetMacro(OnRatio, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off drawing continents as filled polygons or as wireframe outlines.
    * Warning: some graphics systems will have trouble with the very large, concave
@@ -64,7 +65,7 @@ public:
   vtkSetMacro(Outline, vtkTypeBool);
   vtkGetMacro(Outline, vtkTypeBool);
   vtkBooleanMacro(Outline, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkEarthSource();
@@ -81,4 +82,5 @@ private:
   void operator=(const vtkEarthSource&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
