@@ -39,6 +39,7 @@
 
 #include <map>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolyDataSilhouette);
 
 vtkCxxSetObjectMacro(vtkPolyDataSilhouette, Camera, vtkCamera);
@@ -277,6 +278,10 @@ int vtkPolyDataSilhouette::RequestData(vtkInformation* vtkNotUsed(request),
     for (std::map<vtkOrderedEdge, vtkTwoNormals>::iterator it = this->PreComp->edges.begin();
          it != this->PreComp->edges.end(); ++it)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       double d1, d2;
 
       // does this edge have two co-faces ?
@@ -478,3 +483,4 @@ void vtkPolyDataSilhouette::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "EnableFeatureAngle: " << this->EnableFeatureAngle << "\n";
   os << indent << "BorderEdges: " << this->BorderEdges << "\n";
 }
+VTK_ABI_NAMESPACE_END
