@@ -41,6 +41,7 @@
 #include "vtkFiltersHybridModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCamera;
 class vtkProp3D;
 class vtkTransform;
@@ -57,23 +58,23 @@ public:
   vtkTypeMacro(vtkPolyDataSilhouette, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Enables or Disables generation of silhouette edges along sharp edges
    */
   vtkSetMacro(EnableFeatureAngle, int);
   vtkGetMacro(EnableFeatureAngle, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets/Gets minimal angle for sharp edges detection. Default is 60
    */
   vtkSetMacro(FeatureAngle, double);
   vtkGetMacro(FeatureAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enables or Disables generation of border edges. Note: borders exist only
    * in case of non closed surface
@@ -81,9 +82,9 @@ public:
   vtkSetMacro(BorderEdges, vtkTypeBool);
   vtkGetMacro(BorderEdges, vtkTypeBool);
   vtkBooleanMacro(BorderEdges, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enables or Disables piece invariance. This is useful when dealing with
    * multi-block data sets. Note: requires one level of ghost cells
@@ -91,7 +92,7 @@ public:
   vtkSetMacro(PieceInvariant, vtkTypeBool);
   vtkGetMacro(PieceInvariant, vtkTypeBool);
   vtkBooleanMacro(PieceInvariant, vtkTypeBool);
-  //@}
+  ///@}
 
   enum Directions
   {
@@ -101,7 +102,7 @@ public:
     VTK_DIRECTION_CAMERA_VECTOR = 3
   };
 
-  //@{
+  ///@{
   /**
    * Specify how view direction is computed. By default, the
    * camera origin (eye) is used.
@@ -112,9 +113,9 @@ public:
   void SetDirectionToSpecifiedOrigin() { this->SetDirection(VTK_DIRECTION_SPECIFIED_ORIGIN); }
   void SetDirectionToCameraVector() { this->SetDirection(VTK_DIRECTION_CAMERA_VECTOR); }
   void SetDirectionToCameraOrigin() { this->SetDirection(VTK_DIRECTION_CAMERA_ORIGIN); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a camera that is used to define the view direction.  This ivar
    * only has effect if the direction is set to VTK_DIRECTION_CAMERA_ORIGIN or
@@ -122,9 +123,9 @@ public:
    */
   virtual void SetCamera(vtkCamera VTK_WRAP_EXTERN*);
   vtkGetObjectMacro(Camera, vtkCamera VTK_WRAP_EXTERN);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a transformation matrix (via the vtkProp3D::GetMatrix() method)
    * that is used to include the effects of transformation. This ivar only has
@@ -134,9 +135,9 @@ public:
    */
   void SetProp3D(vtkProp3D VTK_WRAP_EXTERN*);
   vtkProp3D VTK_WRAP_EXTERN* GetProp3D();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the sort direction. This ivar only has effect if the sort
    * direction is set to SetDirectionToSpecifiedVector(). The edge detection
@@ -144,9 +145,9 @@ public:
    */
   vtkSetVector3Macro(Vector, double);
   vtkGetVectorMacro(Vector, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the sort origin. This ivar only has effect if the sort direction
    * is set to SetDirectionToSpecifiedOrigin(). The edge detection occurs in
@@ -154,7 +155,7 @@ public:
    */
   vtkSetVector3Macro(Origin, double);
   vtkGetVectorMacro(Origin, double, 3);
-  //@}
+  ///@}
 
   /**
    * Return MTime also considering the dependent objects: the camera
@@ -189,4 +190,5 @@ private:
   void operator=(const vtkPolyDataSilhouette&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
