@@ -33,6 +33,7 @@
 #include <algorithm>
 #include <functional>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTemporalArrayOperatorFilter);
 
 //------------------------------------------------------------------------------
@@ -174,20 +175,17 @@ int vtkTemporalArrayOperatorFilter::RequestUpdateExtent(vtkInformation* vtkNotUs
 }
 
 //------------------------------------------------------------------------------
-int vtkTemporalArrayOperatorFilter::RequestData(vtkInformation* vtkNotUsed(theRequest),
-  vtkInformationVector** inputInfoVector, vtkInformationVector* outputInfoVector)
+int vtkTemporalArrayOperatorFilter::Execute(vtkInformation*,
+  const std::vector<vtkSmartPointer<vtkDataObject>>& inputs, vtkInformationVector* outputVector)
 {
-  vtkMultiBlockDataSet* inputMultiBlock = vtkMultiBlockDataSet::GetData(inputInfoVector[0]);
-
-  int numberTimeSteps = inputMultiBlock->GetNumberOfBlocks();
-  if (numberTimeSteps != 2)
+  if (inputs.size() != 2)
   {
     vtkErrorMacro(<< "The number of time blocks is incorrect.");
     return 0;
   }
 
-  vtkDataObject* data0 = inputMultiBlock->GetBlock(0);
-  vtkDataObject* data1 = inputMultiBlock->GetBlock(1);
+  auto& data0 = inputs[0];
+  auto& data1 = inputs[1];
   if (!data0 || !data1)
   {
     vtkErrorMacro(<< "Unable to retrieve data objects.");
@@ -197,10 +195,12 @@ int vtkTemporalArrayOperatorFilter::RequestData(vtkInformation* vtkNotUsed(theRe
   vtkSmartPointer<vtkDataObject> newOutData;
   newOutData.TakeReference(this->Process(data0, data1));
 
-  vtkInformation* outInfo = outputInfoVector->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
   vtkDataObject* outData = vtkDataObject::GetData(outInfo);
   outData->ShallowCopy(newOutData);
 
+  this->CheckAbort();
+
   return newOutData != nullptr ? 1 : 0;
 }
 
@@ -223,12 +223,16 @@ vtkDataObject* vtkTemporalArrayOperatorFilter::Process(
     vtkCompositeDataSet* compositeDataSet1 = vtkCompositeDataSet::SafeDownCast(inputData1);
 
     vtkCompositeDataSet* outputCompositeDataSet = compositeDataSet0->NewInstance();
-    outputCompositeDataSet->ShallowCopy(inputData0);
+    outputCompositeDataSet->CompositeShallowCopy(compositeDataSet0);
 
     vtkSmartPointer<vtkCompositeDataIterator> iter;
     iter.TakeReference(compositeDataSet0->NewIterator());
     for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       vtkDataObject* dataObj0 = iter->GetCurrentDataObject();
       vtkDataObject* dataObj1 = compositeDataSet1->GetDataSet(iter);
       if (!dataObj0 || !dataObj1)
@@ -348,6 +352,8 @@ vtkDataObject* vtkTemporalArrayOperatorFilter::ProcessDataObject(
       break;
   }
 
+  this->CheckAbort();
+
   return outputDataObject;
 }
 
@@ -446,3 +452,4 @@ vtkDataArray* vtkTemporalArrayOperatorFilter::ProcessDataArray(
 
   return outputDataArray;
 }
+VTK_ABI_NAMESPACE_END
