@@ -37,6 +37,7 @@
 #include <map>    // used for the cache
 #include <vector> // used for the timestep records
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSHYBRID_EXPORT vtkTemporalDataSetCache : public vtkAlgorithm
 {
 public:
@@ -44,16 +45,16 @@ public:
   vtkTypeMacro(vtkTemporalDataSetCache, vtkAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * This is the maximum number of time steps that can be retained in memory.
    * it defaults to 10.
    */
   void SetCacheSize(int size);
   vtkGetMacro(CacheSize, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Tells the filter that it should store the dataobjects it holds in memkind
    * extended memory space rather than in normal memory space.
@@ -61,9 +62,9 @@ public:
   vtkSetMacro(CacheInMemkind, bool);
   vtkGetMacro(CacheInMemkind, bool);
   vtkBooleanMacro(CacheInMemkind, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Tells the filter that needs to act as a pipeline source rather than a midpipline filter. In
    * that situation it needs to react differently in a few cases.
@@ -71,7 +72,7 @@ public:
   vtkSetMacro(IsASource, bool);
   vtkGetMacro(IsASource, bool);
   vtkBooleanMacro(IsASource, bool);
-  //@}
+  ///@}
 
 protected:
   vtkTemporalDataSetCache();
@@ -115,4 +116,5 @@ private:
   vtkDataObject* Ejected;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
