@@ -34,6 +34,7 @@
 #include <algorithm>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTemporalInterpolator);
 
 //------------------------------------------------------------------------------
@@ -169,7 +170,7 @@ int vtkTemporalInterpolator::RequestInformation(vtkInformation* vtkNotUsed(reque
     {
       OutputTimeValues.push_back((double)(i) * this->DiscreteTimeStepInterval + outRange[0]);
     }
-    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &OutputTimeValues[0],
+    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), OutputTimeValues.data(),
       NumberOfOutputTimeSteps);
   }
   else if (this->ResampleFactor > 0)
@@ -188,7 +189,11 @@ int vtkTemporalInterpolator::RequestInformation(vtkInformation* vtkNotUsed(reque
         OutputTimeValues.push_back(newT);
       }
     }
-    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &OutputTimeValues[0],
+
+    // Add the last timestep, as it is never reached
+    OutputTimeValues.push_back(inTimes[numTimes - 1]);
+
+    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), OutputTimeValues.data(),
       static_cast<int>(OutputTimeValues.size()));
   }
   else
@@ -202,35 +207,34 @@ int vtkTemporalInterpolator::RequestInformation(vtkInformation* vtkNotUsed(reque
   return 1;
 }
 
-int vtkTemporalInterpolator::RequestData(
-  vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
+//------------------------------------------------------------------------------
+int vtkTemporalInterpolator::Execute(vtkInformation*,
+  const std::vector<vtkSmartPointer<vtkDataObject>>& inputs, vtkInformationVector* outputVector)
 {
-  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
   vtkDataObject* outData = vtkDataObject::GetData(outInfo);
 
   // get the requested update times
   double upTime = outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP());
 
-  vtkMultiBlockDataSet* inData =
-    vtkMultiBlockDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  int numTimeSteps = inData->GetNumberOfBlocks();
+  const int numTimeSteps = static_cast<int>(inputs.size());
 
   // below the range
   if (numTimeSteps == 1)
   {
     // pass the lowest data
-    outData->ShallowCopy(inData->GetBlock(0));
+    outData->ShallowCopy(inputs[0]);
   }
-  else
+  else if (numTimeSteps == 2)
   {
-    vtkDataObject* data0 = inData->GetBlock(0);
-    vtkDataObject* data1 = inData->GetBlock(1);
+    auto& data0 = inputs[0];
+    auto& data1 = inputs[1];
     if (data0 == nullptr && data1 == nullptr)
     {
       vtkErrorMacro("Null data set");
       return 0;
     }
+
     // interpolate i-1 and i
     double t0 = data0->GetInformation()->Get(vtkDataObject::DATA_TIME_STEP());
     double t1 = data1->GetInformation()->Get(vtkDataObject::DATA_TIME_STEP());
@@ -249,14 +253,17 @@ int vtkTemporalInterpolator::RequestData(
   originalTimes->SetNumberOfTuples(numTimeSteps);
   for (int i = 0; i < numTimeSteps; i++)
   {
-    originalTimes->SetValue(
-      i, inData->GetBlock(i)->GetInformation()->Get(vtkDataObject::DATA_TIME_STEP()));
+    if (this->CheckAbort())
+    {
+      break;
+    }
+    originalTimes->SetValue(i, inputs[i]->GetInformation()->Get(vtkDataObject::DATA_TIME_STEP()));
   }
   outData->GetFieldData()->AddArray(originalTimes);
-
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkTemporalInterpolator::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -487,7 +494,7 @@ vtkDataSet* vtkTemporalInterpolator ::InterpolateDataSet(
     if (arrays[1])
     {
       // do a quick check to see if all arrays have the same number of tuples
-      if (this->VerifyArrays(&arrays[0], 2) != MATCHED)
+      if (this->VerifyArrays(arrays.data(), 2) != MATCHED)
       {
         vtkWarningMacro(<< "Interpolation aborted for array "
                         << (scalarname ? scalarname : "(unnamed array)")
@@ -498,7 +505,7 @@ vtkDataSet* vtkTemporalInterpolator ::InterpolateDataSet(
       {
         // allocate double for output if input is double - otherwise float
         vtkDataArray* outarray =
-          this->InterpolateDataArray(ratio, &arrays[0], arrays[0]->GetNumberOfTuples());
+          this->InterpolateDataArray(ratio, arrays.data(), arrays[0]->GetNumberOfTuples());
         output->GetPointData()->AddArray(outarray);
         outarray->Delete();
       }
@@ -542,7 +549,7 @@ vtkDataSet* vtkTemporalInterpolator ::InterpolateDataSet(
     if (arrays[1])
     {
       // do a quick check to see if all arrays have the same number of tuples
-      if (this->VerifyArrays(&arrays[0], 2) != MATCHED)
+      if (this->VerifyArrays(arrays.data(), 2) != MATCHED)
       {
         vtkWarningMacro(<< "Interpolation aborted for array "
                         << (scalarname ? scalarname : "(unnamed array)")
@@ -551,7 +558,7 @@ vtkDataSet* vtkTemporalInterpolator ::InterpolateDataSet(
       }
       // allocate double for output if input is double - otherwise float
       vtkDataArray* outarray =
-        this->InterpolateDataArray(ratio, &arrays[0], arrays[0]->GetNumberOfTuples());
+        this->InterpolateDataArray(ratio, arrays.data(), arrays[0]->GetNumberOfTuples());
       output->GetCellData()->AddArray(outarray);
       outarray->Delete();
     }
@@ -596,7 +603,7 @@ vtkDataArray* vtkTemporalInterpolator ::InterpolateDataArray(
   //
   // Create the output
   //
-  vtkAbstractArray* aa = arrays[0]->CreateArray(arrays[0]->GetDataType());
+  vtkAbstractArray* aa = vtkDataArray::CreateArray(arrays[0]->GetDataType());
   vtkDataArray* output = vtkArrayDownCast<vtkDataArray>(aa);
 
   int numComp = arrays[0]->GetNumberOfComponents();
@@ -616,3 +623,4 @@ vtkDataArray* vtkTemporalInterpolator ::InterpolateDataArray(
 
   return output;
 }
+VTK_ABI_NAMESPACE_END
