@@ -74,6 +74,7 @@
 #include "vtkFiltersHybridModule.h" // For export macro
 #include "vtkPointSetAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractTransform;
 
 class VTKFILTERSHYBRID_EXPORT vtkWeightedTransformFilter : public vtkPointSetAlgorithm
@@ -88,7 +89,7 @@ public:
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * WeightArray is the string name of the DataArray in the input's
    * FieldData that holds the weighting coefficients for each point.
@@ -100,9 +101,9 @@ public:
    */
   vtkSetStringMacro(WeightArray);
   vtkGetStringMacro(WeightArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * TransformIndexArray is the string name of the DataArray in the input's
    * FieldData that holds the indices for the transforms for each point.
@@ -121,9 +122,9 @@ public:
    */
   vtkSetStringMacro(TransformIndexArray);
   vtkGetStringMacro(TransformIndexArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The CellDataWeightArray is analogous to the WeightArray, except
    * for CellData.  The array is searched for first in the CellData
@@ -133,18 +134,18 @@ public:
    */
   vtkSetStringMacro(CellDataWeightArray);
   vtkGetStringMacro(CellDataWeightArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The CellDataTransformIndexArray is like a TransformIndexArray,
    * except for cell data.  The array must have type UnsignedShort.
    */
   vtkSetStringMacro(CellDataTransformIndexArray);
   vtkGetStringMacro(CellDataTransformIndexArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set or Get one of the filter's transforms. The transform number must
    * be less than the number of transforms allocated for the object.  Setting
@@ -153,9 +154,9 @@ public:
    */
   virtual void SetTransform(vtkAbstractTransform* transform, int num);
   virtual vtkAbstractTransform* GetTransform(int num);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the number of transforms for the filter.  References to non-existent
    * filter numbers in the data array is equivalent to a weight of zero
@@ -164,9 +165,9 @@ public:
    */
   virtual void SetNumberOfTransforms(int num);
   vtkGetMacro(NumberOfTransforms, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If AddInputValues is true, the output values of this filter will be
    * offset from the input values.  The effect is exactly equivalent to
@@ -175,7 +176,7 @@ public:
   vtkBooleanMacro(AddInputValues, vtkTypeBool);
   vtkSetMacro(AddInputValues, vtkTypeBool);
   vtkGetMacro(AddInputValues, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkAbstractTransform** Transforms;
@@ -198,4 +199,5 @@ private:
   void operator=(const vtkWeightedTransformFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
