@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkHyperTreeGridContour.h"
 
 #include "vtkBitArray.h"
@@ -41,6 +38,7 @@
 #include "vtkUnsignedCharArray.h"
 #include "vtkVoxel.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 static const unsigned int MooreCursors1D[2] = { 0, 2 };
 static const unsigned int MooreCursors2D[8] = { 0, 1, 2, 3, 5, 6, 7, 8 };
 static const unsigned int MooreCursors3D[26] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 14, 15,
@@ -288,11 +286,11 @@ int vtkHyperTreeGridContour::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObject
   // Retrieve material mask
   this->InMask = input->HasMask() ? input->GetMask() : nullptr;
 
-  // Retrive ghost cells
+  // Retrieve ghost cells
   this->InGhostArray = input->GetGhostCells();
 
   // Estimate output size as a multiple of 1024
-  vtkIdType numCells = input->GetNumberOfVertices();
+  vtkIdType numCells = input->GetNumberOfCells();
   vtkIdType numContours = this->ContourValues->GetNumberOfContours();
   vtkIdType estimatedSize = static_cast<vtkIdType>(pow(static_cast<double>(numCells), .75));
   estimatedSize *= numContours;
@@ -343,7 +341,8 @@ int vtkHyperTreeGridContour::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObject
   this->SelectedCells->SetNumberOfTuples(numCells);
 
   // Initialize storage for signs and values
-  this->CellSigns = (vtkBitArray**)malloc(numContours * sizeof(vtkBitArray*));
+  // NOLINTNEXTLINE(bugprone-sizeof-expression)
+  this->CellSigns = (vtkBitArray**)malloc(numContours * sizeof(*this->CellSigns));
   this->Signs.resize(numContours, true);
   for (int c = 0; c < numContours; ++c)
   {
@@ -358,6 +357,10 @@ int vtkHyperTreeGridContour::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObject
   vtkNew<vtkHyperTreeGridNonOrientedCursor> cursor;
   while (it.GetNextTree(index))
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     // Initialize new grid cursor at root of current input tree
     input->InitializeNonOrientedCursor(cursor, index);
     // Pre-process tree recursively
@@ -369,6 +372,10 @@ int vtkHyperTreeGridContour::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObject
   vtkNew<vtkHyperTreeGridNonOrientedMooreSuperCursor> supercursor;
   while (it.GetNextTree(index))
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     // Initialize new Moore cursor at root of current tree
     input->InitializeNonOrientedMooreSuperCursor(supercursor, index);
     // Compute contours recursively
@@ -436,6 +443,10 @@ bool vtkHyperTreeGridContour::RecursivelyPreProcessTree(vtkHyperTreeGridNonOrien
     int numChildren = cursor->GetNumberOfChildren();
     for (int child = 0; child < numChildren; ++child)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       // Create storage for signs relative to contour values
       std::vector<bool> signs(numContours);
 
@@ -527,7 +538,7 @@ void vtkHyperTreeGridContour::RecursivelyProcessTree(
       // Retrieve sign with respect to contour value at current cursor
       bool sign = (this->CellSigns[c]->GetTuple1(id) != 0.0);
 
-      // Iterate over all cursors of Von Neumann neighborhood around center
+      // Iterate over all cursors of Moore neighborhood around center
       unsigned int nn = supercursor->GetNumberOfCursors() - 1;
       for (unsigned int neighbor = 0; neighbor < nn && !selected; ++neighbor)
       {
@@ -629,3 +640,4 @@ void vtkHyperTreeGridContour::RecursivelyProcessTree(
     }   // cornerIdx
   }     // else if ( ! this->InMask || this->InMask->GetTuple1( id ) )
 }
+VTK_ABI_NAMESPACE_END
