@@ -27,6 +27,7 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHyperTreeGridEvaluateCoarse);
 
 //------------------------------------------------------------------------------
@@ -97,6 +98,10 @@ int vtkHyperTreeGridEvaluateCoarse::ProcessTrees(vtkHyperTreeGrid* input, vtkDat
   vtkNew<vtkHyperTreeGridNonOrientedCursor> outCursor;
   while (in.GetNextTree(index))
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     // Initialize new cursor at root of current output tree
     output->InitializeNonOrientedCursor(outCursor, index);
     // Recursively
@@ -123,6 +128,10 @@ void vtkHyperTreeGridEvaluateCoarse::ProcessNode(vtkHyperTreeGridNonOrientedCurs
     // Coarse
     for (int ichild = 0; ichild < this->NbChilds; ++ichild)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       outCursor->ToChild(ichild);
       // We go through the children's cells
       ProcessNode(outCursor);
@@ -137,6 +146,10 @@ void vtkHyperTreeGridEvaluateCoarse::ProcessNode(vtkHyperTreeGridNonOrientedCurs
   // Coarse
   for (int ichild = 0; ichild < this->NbChilds; ++ichild)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     outCursor->ToChild(ichild);
     // Iterate children
     ProcessNode(outCursor);
@@ -161,6 +174,10 @@ void vtkHyperTreeGridEvaluateCoarse::ProcessNode(vtkHyperTreeGridNonOrientedCurs
   // Reduction operation
   for (int i = 0; i < nbArray; ++i)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkDataArray* arr = this->OutData->GetArray(i);
     int nbC = arr->GetNumberOfComponents();
     for (int iC = 0; iC < nbC; ++iC)
@@ -308,3 +325,4 @@ double vtkHyperTreeGridEvaluateCoarse::SplattingAverage(const std::vector<double
   }
   return sum / this->SplattingFactor;
 }
+VTK_ABI_NAMESPACE_END
