@@ -43,19 +43,31 @@
 #include "vtkFiltersHyperTreeModule.h" // For export macro
 #include "vtkHyperTreeGridAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBitArray;
 class vtkCellArray;
 class vtkHyperTreeGrid;
+class vtkIdTypeArray;
 class vtkPoints;
 class vtkUnstructuredGrid;
 class vtkHyperTreeGridNonOrientedGeometryCursor;
 
-class VTKFILTERSHYPERTREE_EXPORT vtkHyperTreeGridToUnstructuredGrid : public vtkHyperTreeGridAlgorithm
+class VTKFILTERSHYPERTREE_EXPORT vtkHyperTreeGridToUnstructuredGrid
+  : public vtkHyperTreeGridAlgorithm
 {
 public:
   static vtkHyperTreeGridToUnstructuredGrid* New();
-  vtkTypeMacro( vtkHyperTreeGridToUnstructuredGrid, vtkHyperTreeGridAlgorithm );
-  void PrintSelf( ostream&, vtkIndent ) override;
+  vtkTypeMacro(vtkHyperTreeGridToUnstructuredGrid, vtkHyperTreeGridAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
+
+  ///@{
+  /**
+   * Add a cell array with original HTG ids
+   */
+  vtkGetMacro(AddOriginalIds, bool);
+  vtkSetMacro(AddOriginalIds, bool);
+  vtkBooleanMacro(AddOriginalIds, bool);
+  ///@}
 
 protected:
   vtkHyperTreeGridToUnstructuredGrid();
@@ -64,22 +76,22 @@ protected:
   /**
    * For this algorithm the output is a vtkUnstructuredGrid instance
    */
-  int FillOutputPortInformation( int, vtkInformation* ) override;
+  int FillOutputPortInformation(int, vtkInformation*) override;
 
   /**
    * Main routine to convert the grid of tree into an unstructured grid
    */
-  int ProcessTrees( vtkHyperTreeGrid*, vtkDataObject* ) override;
+  int ProcessTrees(vtkHyperTreeGrid*, vtkDataObject*) override;
 
   /**
    * Recursively descend into tree down to leaves
    */
-  void RecursivelyProcessTree( vtkHyperTreeGridNonOrientedGeometryCursor* );
+  void RecursivelyProcessTree(vtkHyperTreeGridNonOrientedGeometryCursor*);
 
   /**
    * Helper method to generate a 2D or 3D cell
    */
-  void AddCell( vtkIdType, double*, double* );
+  void AddCell(vtkIdType, double*, double*);
 
   /**
    * Storage for points of output unstructured mesh
@@ -98,9 +110,13 @@ protected:
   unsigned int Orientation;
   const unsigned int* Axes;
 
+  bool AddOriginalIds;
+  vtkIdTypeArray* OriginalIds;
+
 private:
   vtkHyperTreeGridToUnstructuredGrid(const vtkHyperTreeGridToUnstructuredGrid&) = delete;
   void operator=(const vtkHyperTreeGridToUnstructuredGrid&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* vtkHyperTreeGridToUnstructuredGrid_h */
