@@ -33,6 +33,7 @@
 
 #include "vtkHyperTreeGridNonOrientedCursor.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageDataToHyperTreeGrid);
 
 //------------------------------------------------------------------------------
@@ -144,6 +145,10 @@ int vtkImageDataToHyperTreeGrid::RequestData(vtkInformation* vtkNotUsed(request)
   vtkNew<vtkHyperTreeGridNonOrientedCursor> cursor;
   for (vtkIdType itree = 0; itree < nbTrees; ++itree)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkIdType index = itree;
 
     unsigned int i, j, k;
@@ -244,8 +249,6 @@ void vtkImageDataToHyperTreeGrid::ProcessPixels(
       }
     }
   }
-
-  return;
 }
 
 int vtkImageDataToHyperTreeGrid::ProcessTrees(
@@ -269,3 +272,4 @@ int vtkImageDataToHyperTreeGrid::FillInputPortInformation(
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkImageData");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
