@@ -38,6 +38,7 @@
 #define VTK_PROJECTED_TEXTURE_USE_PINHOLE 0
 #define VTK_PROJECTED_TEXTURE_USE_TWO_MIRRORS 1
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSMODELING_EXPORT vtkProjectedTexture : public vtkDataSetAlgorithm
 {
 public:
@@ -45,15 +46,15 @@ public:
   vtkTypeMacro(vtkProjectedTexture, vtkDataSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the position of the focus of the projector.
    */
   vtkSetVector3Macro(Position, double);
   vtkGetVectorMacro(Position, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the focal point of the projector (a point that lies along
    * the center axis of the projector's frustum).
@@ -61,9 +62,9 @@ public:
   void SetFocalPoint(double focalPoint[3]);
   void SetFocalPoint(double x, double y, double z);
   vtkGetVectorMacro(FocalPoint, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the camera mode of the projection -- pinhole projection or
    * two mirror projection.
@@ -72,32 +73,32 @@ public:
   vtkGetMacro(CameraMode, int);
   void SetCameraModeToPinhole() { this->SetCameraMode(VTK_PROJECTED_TEXTURE_USE_PINHOLE); }
   void SetCameraModeToTwoMirror() { this->SetCameraMode(VTK_PROJECTED_TEXTURE_USE_TWO_MIRRORS); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the mirror separation for the two mirror system.
    */
   vtkSetMacro(MirrorSeparation, double);
   vtkGetMacro(MirrorSeparation, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the normalized orientation vector of the projector.
    */
   vtkGetVectorMacro(Orientation, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the up vector of the projector.
    */
   vtkSetVector3Macro(Up, double);
   vtkGetVectorMacro(Up, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the aspect ratio of a perpendicular cross-section of the
    * the projector's frustum.  The aspect ratio consists of three
@@ -110,23 +111,23 @@ public:
    */
   vtkSetVector3Macro(AspectRatio, double);
   vtkGetVectorMacro(AspectRatio, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify s-coordinate range for texture s-t coordinate pair.
    */
   vtkSetVector2Macro(SRange, double);
   vtkGetVectorMacro(SRange, double, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify t-coordinate range for texture s-t coordinate pair.
    */
   vtkSetVector2Macro(TRange, double);
   vtkGetVectorMacro(TRange, double, 2);
-  //@}
+  ///@}
 
 protected:
   vtkProjectedTexture();
@@ -151,4 +152,5 @@ private:
   void operator=(const vtkProjectedTexture&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
