@@ -35,6 +35,7 @@
 #include "vtkStaticCellLocator.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSelectEnclosedPoints);
 
 //------------------------------------------------------------------------------
@@ -59,6 +60,7 @@ struct SelectInOutCheck
   vtkTypeBool InsideOut;
   vtkRandomPool* Sequence;
   vtkSMPThreadLocal<vtkIntersectionCounter> Counter;
+  vtkSelectEnclosedPoints* Filter;
 
   // Don't want to allocate working arrays on every thread invocation. Thread local
   // storage eliminates lots of new/delete.
@@ -67,7 +69,7 @@ struct SelectInOutCheck
 
   SelectInOutCheck(vtkIdType numPts, vtkDataSet* ds, vtkPolyData* surface, double bds[6],
     double tol, vtkStaticCellLocator* loc, unsigned char* hits, vtkSelectEnclosedPoints* sel,
-    vtkTypeBool io)
+    vtkTypeBool io, vtkSelectEnclosedPoints* filter)
     : NumPts(numPts)
     , DataSet(ds)
     , Surface(surface)
@@ -76,6 +78,7 @@ struct SelectInOutCheck
     , Hits(hits)
     , Selector(sel)
     , InsideOut(io)
+    , Filter(filter)
   {
     this->Bounds[0] = bds[0];
     this->Bounds[1] = bds[1];
@@ -109,12 +112,21 @@ struct SelectInOutCheck
     vtkGenericCell*& cell = this->Cell.Local();
     vtkIdList*& cellIds = this->CellIds.Local();
     vtkIntersectionCounter& counter = this->Counter.Local();
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     for (; ptId < endPtId; ++ptId)
     {
+      if (isFirst)
+      {
+        this->Filter->CheckAbort();
+      }
+      if (this->Filter->GetAbortOutput())
+      {
+        break;
+      }
       this->DataSet->GetPoint(ptId, x);
 
-      if (this->Selector->IsInsideSurface(x, this->Surface, this->Bounds, this->Length,
+      if (vtkSelectEnclosedPoints::IsInsideSurface(x, this->Surface, this->Bounds, this->Length,
             this->Tolerance, this->Locator, cellIds, cell, counter, this->Sequence, ptId))
       {
         *hits++ = (this->InsideOut ? 0 : 1);
@@ -131,7 +143,7 @@ struct SelectInOutCheck
   static void Execute(vtkIdType numPts, vtkDataSet* ds, vtkPolyData* surface, double bds[6],
     double tol, vtkStaticCellLocator* loc, unsigned char* hits, vtkSelectEnclosedPoints* sel)
   {
-    SelectInOutCheck inOut(numPts, ds, surface, bds, tol, loc, hits, sel, sel->GetInsideOut());
+    SelectInOutCheck inOut(numPts, ds, surface, bds, tol, loc, hits, sel, sel->GetInsideOut(), sel);
     vtkSMPTools::For(0, numPts, inOut);
   }
 }; // SelectInOutCheck
@@ -192,12 +204,12 @@ int vtkSelectEnclosedPoints::RequestData(vtkInformation* vtkNotUsed(request),
   vtkDebugMacro("Selecting enclosed points");
 
   // If requested, check that the surface is closed
-  if (this->CheckSurface && !this->IsSurfaceClosed(surface))
+  if (this->CheckSurface && !vtkSelectEnclosedPoints::IsSurfaceClosed(surface))
   {
     return 0;
   }
 
-  // Initiailize search structures
+  // Initialize search structures
   this->Initialize(surface);
 
   // Create array to mark inside/outside
@@ -308,15 +320,15 @@ int vtkSelectEnclosedPoints::IsInsideSurface(double x[3])
 {
   vtkIntersectionCounter counter(this->Tolerance, this->Length);
 
-  return this->IsInsideSurface(x, this->Surface, this->Bounds, this->Length, this->Tolerance,
-    this->CellLocator, this->CellIds, this->Cell, counter);
+  return vtkSelectEnclosedPoints::IsInsideSurface(x, this->Surface, this->Bounds, this->Length,
+    this->Tolerance, this->CellLocator, this->CellIds, this->Cell, counter);
 }
 
 //------------------------------------------------------------------------------
 // General method uses ray casting to determine in/out. Since this is a
 // numerically delicate operation, we use a crude "statistical" method (based
 // on voting) to provide a better answer. Plus there is a process to merge
-// nearly conincident points along the intersection rays.
+// nearly coincident points along the intersection rays.
 //
 // This is a static method so it can be used by other filters; hence the
 // many parameters used.
@@ -508,3 +520,4 @@ void vtkSelectEnclosedPoints::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Tolerance: " << this->Tolerance << "\n";
 }
+VTK_ABI_NAMESPACE_END
