@@ -22,7 +22,8 @@
 
 using namespace OT;
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 Sample* vtkOTUtilities::SingleDimArraysToSample(vtkDataArrayCollection* arrays)
 {
   if (arrays == nullptr)
@@ -48,9 +49,8 @@ Sample* vtkOTUtilities::SingleDimArraysToSample(vtkDataArrayCollection* arrays)
     {
       // TODO nullptr Object
       vtkErrorWithObjectMacro(arrays,
-        "An array has not the expected number of tuples. Expecting: " << numTuples << " , got: "
-                                                                      << array->GetNumberOfTuples()
-                                                                      << " , dropping it");
+        "An array has not the expected number of tuples. Expecting: "
+          << numTuples << " , got: " << array->GetNumberOfTuples() << " , dropping it");
       continue;
     }
     for (int i = 0; i < numTuples; ++i)
@@ -63,7 +63,7 @@ Sample* vtkOTUtilities::SingleDimArraysToSample(vtkDataArrayCollection* arrays)
   return ns;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 Sample* vtkOTUtilities::ArrayToSample(vtkDataArray* arr)
 {
   if (arr == nullptr)
@@ -85,7 +85,7 @@ Sample* vtkOTUtilities::ArrayToSample(vtkDataArray* arr)
   return ns;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArray* vtkOTUtilities::SampleToArray(Sample* ns)
 {
   if (ns == nullptr)
@@ -109,3 +109,4 @@ vtkDataArray* vtkOTUtilities::SampleToArray(Sample* ns)
   }
   return arr;
 }
+VTK_ABI_NAMESPACE_END
