@@ -16,16 +16,20 @@
  * @brief
  * Set of utilities for OpenTURNS<->VTK conversions
  *
-*/
+ */
 
 #ifndef vtkOTUtilities_h
 #define vtkOTUtilities_h
 
+#include "vtkABINamespace.h"
+
 namespace OT
 {
 class Sample;
 }
 
+VTK_ABI_NAMESPACE_BEGIN
+
 class vtkDataArray;
 class vtkDataArrayCollection;
 class vtkPoints;
@@ -62,5 +66,6 @@ public:
   static vtkDataArray* SampleToArray(OT::Sample* ns);
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkOTUtilities.h
