@@ -44,7 +44,7 @@ class MyProcess : public vtkProcess
 public:
   static MyProcess* New();
 
-  virtual void Execute();
+  void Execute() override;
 
   void SetArgs(int anArgc, char* anArgv[]);
 
