@@ -27,6 +27,7 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkAggregateDataSetFilter);
 
 //------------------------------------------------------------------------------
@@ -129,7 +130,7 @@ int vtkAggregateDataSetFilter::RequestData(
 
   std::vector<vtkIdType> pointCount(subNumProcs, 0);
   vtkIdType numPoints = input->GetNumberOfPoints();
-  subController->AllGather(&numPoints, &pointCount[0], 1);
+  subController->AllGather(&numPoints, pointCount.data(), 1);
 
   // The first process in the subcontroller to have points is the one that data will
   // be aggregated to. All of the other processes send their data set to that process.
@@ -204,3 +205,4 @@ void vtkAggregateDataSetFilter::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "NumberOfTargetProcesses: " << this->NumberOfTargetProcesses << endl;
 }
+VTK_ABI_NAMESPACE_END
