@@ -31,9 +31,10 @@
 #include "vtkUnstructuredGrid.h"
 
 // Needed to let vtkPDistributedDataFilter be instantiated when available
-vtkObjectFactoryNewMacro(vtkDistributedDataFilter)
+VTK_ABI_NAMESPACE_BEGIN
+vtkObjectFactoryNewMacro(vtkDistributedDataFilter);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDistributedDataFilter::vtkDistributedDataFilter()
 {
   this->Kdtree = nullptr;
@@ -61,7 +62,7 @@ vtkDistributedDataFilter::vtkDistributedDataFilter()
   this->UserCuts = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDistributedDataFilter::~vtkDistributedDataFilter()
 {
   if (this->Kdtree)
@@ -72,13 +73,13 @@ vtkDistributedDataFilter::~vtkDistributedDataFilter()
 
   this->SetController(nullptr);
 
-  delete [] this->Target;
-  this->Target= nullptr;
+  delete[] this->Target;
+  this->Target = nullptr;
 
-  delete [] this->Source;
-  this->Source= nullptr;
+  delete[] this->Source;
+  this->Source = nullptr;
 
-  delete [] this->ConvexSubRegionBounds;
+  delete[] this->ConvexSubRegionBounds;
   this->ConvexSubRegionBounds = nullptr;
 
   if (this->UserCuts)
@@ -88,8 +89,8 @@ vtkDistributedDataFilter::~vtkDistributedDataFilter()
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkDistributedDataFilter::SetController(vtkMultiProcessController *c)
+//------------------------------------------------------------------------------
+void vtkDistributedDataFilter::SetController(vtkMultiProcessController* c)
 {
   if (this->Kdtree)
   {
@@ -102,33 +103,17 @@ void vtkDistributedDataFilter::SetController(vtkMultiProcessController *c)
     this->MyId = 0;
   }
 
-  if (this->Controller == c)
+  vtkSetObjectBodyMacro(Controller, vtkMultiProcessController, c);
+
+  if (c)
   {
-    return;
+    this->NumProcesses = c->GetNumberOfProcesses();
+    this->MyId = c->GetLocalProcessId();
   }
-
-  this->Modified();
-
-  if (this->Controller != nullptr)
-  {
-    this->Controller->UnRegister(this);
-    this->Controller = nullptr;
-  }
-
-  if (c == nullptr)
-  {
-    return;
-  }
-
-  this->Controller = c;
-
-  c->Register(this);
-  this->NumProcesses = c->GetNumberOfProcesses();
-  this->MyId    = c->GetLocalProcessId();
 }
 
-//-------------------------------------------------------------------------
-vtkPKdTree *vtkDistributedDataFilter::GetKdtree()
+//------------------------------------------------------------------------------
+vtkPKdTree* vtkDistributedDataFilter::GetKdtree()
 {
   if (this->Kdtree == nullptr)
   {
@@ -140,7 +125,7 @@ vtkPKdTree *vtkDistributedDataFilter::GetKdtree()
   return this->Kdtree;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDistributedDataFilter::SetBoundaryMode(int mode)
 {
   int include_all, clip_cells;
@@ -169,7 +154,7 @@ void vtkDistributedDataFilter::SetBoundaryMode(int mode)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkDistributedDataFilter::GetBoundaryMode()
 {
   if (!this->IncludeAllIntersectingCells && !this->ClipCells)
@@ -188,16 +173,14 @@ int vtkDistributedDataFilter::GetBoundaryMode()
   return -1;
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
-int vtkDistributedDataFilter::RequestUpdateExtent(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkDistributedDataFilter::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   int piece, numPieces, ghostLevels;
 
@@ -208,16 +191,14 @@ int vtkDistributedDataFilter::RequestUpdateExtent(
   ghostLevels = 0;
 
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), piece);
-  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
-              numPieces);
-  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-              ghostLevels);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), numPieces);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), ghostLevels);
   inInfo->Set(vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(), 1);
 
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDistributedDataFilter::SetCuts(vtkBSPCuts* cuts)
 {
   if (cuts == this->UserCuts)
@@ -242,13 +223,12 @@ void vtkDistributedDataFilter::SetCuts(vtkBSPCuts* cuts)
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
-void vtkDistributedDataFilter::SetUserRegionAssignments(
-  const int *map, int numRegions)
+//------------------------------------------------------------------------------
+void vtkDistributedDataFilter::SetUserRegionAssignments(const int* map, int numRegions)
 {
   std::vector<int> copy(this->UserRegionAssignments);
   this->UserRegionAssignments.resize(numRegions);
-  for (int cc=0; cc < numRegions; cc++)
+  for (int cc = 0; cc < numRegions; cc++)
   {
     this->UserRegionAssignments[cc] = map[cc];
   }
@@ -258,37 +238,30 @@ void vtkDistributedDataFilter::SetUserRegionAssignments(
   }
 }
 
-
-//----------------------------------------------------------------------------
-int vtkDistributedDataFilter::RequestInformation(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+//------------------------------------------------------------------------------
+int vtkDistributedDataFilter::RequestInformation(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
-               inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()),
-               6);
+    inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()), 6);
 
   return 1;
 }
 
-//----------------------------------------------------------------------------
-int vtkDistributedDataFilter::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+//------------------------------------------------------------------------------
+int vtkDistributedDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output.
-  vtkDataObject* input =
-    vtkDataObject::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataObject* input = vtkDataObject::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
   vtkUnstructuredGrid* outputUG =
     vtkUnstructuredGrid::SafeDownCast(outInfo->Get(vtkUnstructuredGrid::DATA_OBJECT()));
   vtkCompositeDataSet* outputCD =
@@ -300,10 +273,9 @@ int vtkDistributedDataFilter::RequestData(
     return 0;
   }
 
-
   if (outputCD)
   {
-    outputCD->ShallowCopy(input);
+    outputCD->CompositeShallowCopy(vtkCompositeDataSet::SafeDownCast(input));
   }
   else
   {
@@ -319,10 +291,9 @@ int vtkDistributedDataFilter::RequestData(
   return 1;
 }
 
-//-------------------------------------------------------------------------
-int vtkDistributedDataFilter::RequestDataObject(vtkInformation*,
-  vtkInformationVector** inputVector,
-  vtkInformationVector* outputVector)
+//------------------------------------------------------------------------------
+int vtkDistributedDataFilter::RequestDataObject(
+  vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   if (!inInfo)
@@ -330,16 +301,15 @@ int vtkDistributedDataFilter::RequestDataObject(vtkInformation*,
     return 0;
   }
 
-  vtkDataObject *input = vtkDataObject::GetData(inInfo);
+  vtkDataObject* input = vtkDataObject::GetData(inInfo);
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
   if (input)
   {
-    vtkDataObject *output = vtkDataObject::GetData(outInfo);
+    vtkDataObject* output = vtkDataObject::GetData(outInfo);
     // If input is composite dataset, output is a vtkMultiBlockDataSet of
     // unstructrued grids.
     // If input is a dataset, output is an unstructured grid.
-    if (!output ||
-      (input->IsA("vtkCompositeDataSet") && !output->IsA("vtkMultiBlockDataSet")) ||
+    if (!output || (input->IsA("vtkCompositeDataSet") && !output->IsA("vtkMultiBlockDataSet")) ||
       (input->IsA("vtkDataSet") && !output->IsA("vtkUnstructuredGrid")))
     {
       vtkDataObject* newOutput = nullptr;
@@ -360,8 +330,8 @@ int vtkDistributedDataFilter::RequestDataObject(vtkInformation*,
   return 0;
 }
 
-//-------------------------------------------------------------------------
-int vtkDistributedDataFilter::FillInputPortInformation(int, vtkInformation *info)
+//------------------------------------------------------------------------------
+int vtkDistributedDataFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Remove(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE());
   info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkCompositeDataSet");
@@ -369,8 +339,9 @@ int vtkDistributedDataFilter::FillInputPortInformation(int, vtkInformation *info
   return 1;
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDistributedDataFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
