@@ -40,6 +40,7 @@
 
 #include <vector> // for vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBSPCuts;
 class vtkMultiProcessController;
 class vtkPKdTree;
@@ -53,13 +54,13 @@ public:
 
   static vtkDistributedDataFilter* New();
 
-  //@{
+  ///@{
   /**
    * Set/Get the communicator object
    */
   void SetController(vtkMultiProcessController* c);
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
-  //@}
+  ///@}
 
   /**
    * Get a pointer to the parallel k-d tree object.  Required for changing
@@ -126,7 +127,7 @@ public:
     SPLIT_BOUNDARY_CELLS = 2
   };
 
-  //@{
+  ///@{
   /**
    * Handling of ClipCells and IncludeAllIntersectingCells.
    */
@@ -144,7 +145,7 @@ public:
     this->SetBoundaryMode(vtkDistributedDataFilter::SPLIT_BOUNDARY_CELLS);
   }
   int GetBoundaryMode();
-  //@}
+  ///@}
 
   /**
    * Ensure previous filters don't send up ghost cells
@@ -261,4 +262,5 @@ private:
   vtkDistributedDataFilter(const vtkDistributedDataFilter&) = delete;
   void operator=(const vtkDistributedDataFilter&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 #endif
