@@ -39,6 +39,7 @@
 #include <cassert>
 #include <queue>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 class TimeLog // Similar to vtkTimerLogScope, but can be disabled at runtime.
@@ -102,26 +103,31 @@ const int vtkPKdTree::UserDefinedAssignment = 2;
 const int vtkPKdTree::RoundRobinAssignment = 3;
 
 #define FreeList(list)                                                                             \
-  if (list)                                                                                        \
+  do                                                                                               \
   {                                                                                                \
     delete[] list;                                                                                 \
     list = nullptr;                                                                                \
-  }
+  } while (false)
 #define FreeObject(item)                                                                           \
-  if (item)                                                                                        \
+  do                                                                                               \
   {                                                                                                \
-    item->Delete();                                                                                \
-    item = nullptr;                                                                                \
-  }
+    if (item)                                                                                      \
+    {                                                                                              \
+      item->Delete();                                                                              \
+      item = nullptr;                                                                              \
+    }                                                                                              \
+  } while (false)
 
 #define VTKERROR(s)                                                                                \
+  do                                                                                               \
   {                                                                                                \
     vtkErrorMacro(<< "(process " << this->MyId << ") " << s);                                      \
-  }
+  } while (false)
 #define VTKWARNING(s)                                                                              \
+  do                                                                                               \
   {                                                                                                \
     vtkWarningMacro(<< "(process " << this->MyId << ") " << s);                                    \
-  }
+  } while (false)
 
 vtkPKdTree::vtkPKdTree()
 {
@@ -287,6 +293,7 @@ void vtkPKdTree::AllCheckParameters()
 }
 
 #define BoundsToMinMax(bounds, min, max)                                                           \
+  do                                                                                               \
   {                                                                                                \
     min[0] = bounds[0];                                                                            \
     min[1] = bounds[2];                                                                            \
@@ -294,8 +301,9 @@ void vtkPKdTree::AllCheckParameters()
     max[0] = bounds[1];                                                                            \
     max[1] = bounds[3];                                                                            \
     max[2] = bounds[5];                                                                            \
-  }
+  } while (false)
 #define MinMaxToBounds(bounds, min, max)                                                           \
+  do                                                                                               \
   {                                                                                                \
     bounds[0] = min[0];                                                                            \
     bounds[2] = min[1];                                                                            \
@@ -303,8 +311,9 @@ void vtkPKdTree::AllCheckParameters()
     bounds[1] = max[0];                                                                            \
     bounds[3] = max[1];                                                                            \
     bounds[5] = max[2];                                                                            \
-  }
+  } while (false)
 #define BoundsToMinMaxUpdate(bounds, min, max)                                                     \
+  do                                                                                               \
   {                                                                                                \
     min[0] = (bounds[0] < min[0] ? bounds[0] : min[0]);                                            \
     min[1] = (bounds[2] < min[1] ? bounds[2] : min[1]);                                            \
@@ -312,7 +321,7 @@ void vtkPKdTree::AllCheckParameters()
     max[0] = (bounds[1] > max[0] ? bounds[1] : max[0]);                                            \
     max[1] = (bounds[3] > max[1] ? bounds[3] : max[1]);                                            \
     max[2] = (bounds[5] > max[2] ? bounds[5] : max[2]);                                            \
-  }
+  } while (false)
 
 bool vtkPKdTree::VolumeBounds(double* volBounds)
 {
@@ -446,7 +455,7 @@ void vtkPKdTree::BuildLocator()
     this->AllCheckParameters(); // global operation to ensure same parameters
 
     double volBounds[6];
-    if (this->VolumeBounds(volBounds) == false) // global operation to get bounds
+    if (!this->VolumeBounds(volBounds)) // global operation to get bounds
     {
       goto doneError;
     }
@@ -608,7 +617,7 @@ void vtkPKdTree::SingleProcessBuildLocator()
   }
 }
 
-typedef struct _vtkNodeInfo
+typedef struct vtkNodeInfo_
 {
   vtkKdNode* kd;
   int L;
@@ -617,14 +626,15 @@ typedef struct _vtkNodeInfo
 } * vtkNodeInfo;
 
 #define ENQUEUE(a, b, c, d)                                                                        \
+  do                                                                                               \
   {                                                                                                \
-    vtkNodeInfo rec = new struct _vtkNodeInfo;                                                     \
+    vtkNodeInfo rec = new struct vtkNodeInfo_;                                                     \
     rec->kd = a;                                                                                   \
     rec->L = b;                                                                                    \
     rec->level = c;                                                                                \
     rec->tag = d;                                                                                  \
     Queue.push(rec);                                                                               \
-  }
+  } while (false)
 
 int vtkPKdTree::BreadthFirstDivide(double* volBounds)
 {
@@ -1184,8 +1194,8 @@ int* vtkPKdTree::PartitionSubArray(int L, int R, int K, int dim, int p1, int p2)
 
   if ((me < p1) || (me > p2))
   {
-    this->SubGroup->Broadcast(&this->SelectBuffer[0], 2, rootrank);
-    return &this->SelectBuffer[0];
+    this->SubGroup->Broadcast(this->SelectBuffer.data(), 2, rootrank);
+    return this->SelectBuffer.data();
   }
 
   if (p1 == p2)
@@ -1256,7 +1266,7 @@ int* vtkPKdTree::PartitionSubArray(int L, int R, int K, int dim, int p1, int p2)
 
   int nprocs = p2 - p1 + 1;
 
-  int* buf = &this->SelectBuffer[0];
+  int* buf = this->SelectBuffer.data();
 
   int* left = buf;
   buf += nprocs; // global index of my leftmost
@@ -1450,9 +1460,9 @@ int* vtkPKdTree::PartitionSubArray(int L, int R, int K, int dim, int p1, int p2)
 
   rootrank = this->SubGroup->getLocalRank(p1);
 
-  this->SubGroup->Broadcast(&this->SelectBuffer[0], 2, rootrank);
+  this->SubGroup->Broadcast(this->SelectBuffer.data(), 2, rootrank);
 
-  return &this->SelectBuffer[0];
+  return this->SelectBuffer.data();
 }
 
 // This routine partitions the array from element L through element
@@ -1472,7 +1482,7 @@ int* vtkPKdTree::PartitionSubArray(int L, int R, int K, int dim, int p1, int p2)
 int* vtkPKdTree::PartitionAboutOtherValue(int L, int R, float T, int dim)
 {
   float *Ipt, *Jpt, Lval, Rval;
-  int* vals = &this->SelectBuffer[0];
+  int* vals = this->SelectBuffer.data();
   int numTValues = 0;
   int numGreater = 0;
   int numLess = 0;
@@ -1688,7 +1698,7 @@ int* vtkPKdTree::PartitionAboutMyValue(int L, int R, int K, int dim)
   float T;
   int I, J;
   int manyTValues = 0;
-  int* vals = &this->SelectBuffer[0];
+  int* vals = this->SelectBuffer.data();
 
   // Set up so after first exchange in the loop, we have either
   //   X[L] = T and X[R] >= T
@@ -1959,11 +1969,11 @@ int vtkPKdTree::CompleteTree()
 
 #ifdef YIELDS_INCONSISTENT_REGION_BOUNDARIES
 
-  this->RetrieveData(this->Top, &buf[0]);
+  this->RetrieveData(this->Top, buf.data());
 
 #else
 
-  this->ReduceData(this->Top, &buf[0]);
+  this->ReduceData(this->Top, buf.data());
 
   if (this->MyId == 0)
   {
@@ -2327,33 +2337,6 @@ void vtkPKdTree::FreeSelectBuffer()
   this->SelectBuffer.clear();
 }
 
-#define FreeListOfLists(list, len)                                                                 \
-  {                                                                                                \
-    int i;                                                                                         \
-    if (list)                                                                                      \
-    {                                                                                              \
-      for (i = 0; i < (len); i++)                                                                  \
-      {                                                                                            \
-        if (list[i])                                                                               \
-          delete[] list[i];                                                                        \
-      }                                                                                            \
-      delete[] list;                                                                               \
-      list = nullptr;                                                                              \
-    }                                                                                              \
-  }
-
-#define MakeList(field, type, len)                                                                 \
-  {                                                                                                \
-    if ((len) > 0)                                                                                 \
-    {                                                                                              \
-      field = new type[len];                                                                       \
-      if (field)                                                                                   \
-      {                                                                                            \
-        memset(field, 0, (len) * sizeof(type));                                                    \
-      }                                                                                            \
-    }                                                                                              \
-  }
-
 // global index lists -----------------------------------------------
 
 void vtkPKdTree::InitializeGlobalIndexLists()
@@ -2385,9 +2368,9 @@ int vtkPKdTree::BuildGlobalIndexLists(vtkIdType numMyCells)
 
   this->AllocateAndZeroGlobalIndexLists();
 
-  this->SubGroup->Gather(&numMyCells, &this->NumCells[0], 1, 0);
+  this->SubGroup->Gather(&numMyCells, this->NumCells.data(), 1, 0);
 
-  this->SubGroup->Broadcast(&this->NumCells[0], this->NumProcesses, 0);
+  this->SubGroup->Broadcast(this->NumCells.data(), this->NumProcesses, 0);
 
   this->StartVal[0] = 0;
   this->EndVal[0] = this->NumCells[0] - 1;
@@ -2540,7 +2523,7 @@ void vtkPKdTree::AllocateAndZeroFieldArrayMinMax()
     this->CellDataMax.resize(this->NumCellArrays, 0);
 
     std::fill(this->CellDataName.begin(), this->CellDataName.end(), std::string());
-    this->CellDataName.resize(this->NumCellArrays, nullptr);
+    this->CellDataName.resize(this->NumCellArrays, std::string());
   }
 
   if (this->NumPointArrays > 0)
@@ -2627,15 +2610,15 @@ int vtkPKdTree::CreateProcessCellCountData()
 
   if (this->NumProcesses > 1)
   {
-    this->SubGroup->Gather(myData, &this->DataLocationMap[0], this->GetNumberOfRegions(), 0);
+    this->SubGroup->Gather(myData, this->DataLocationMap.data(), this->GetNumberOfRegions(), 0);
     this->SubGroup->Broadcast(
-      &this->DataLocationMap[0], this->GetNumberOfRegions() * this->NumProcesses, 0);
+      this->DataLocationMap.data(), this->GetNumberOfRegions() * this->NumProcesses, 0);
   }
 
   // Other helpful tables - not the fastest way to create this
   //   information, but it uses the least memory
 
-  procData = &this->DataLocationMap[0];
+  procData = this->DataLocationMap.data();
 
   for (proc = 0; proc < this->NumProcesses; proc++)
   {
@@ -2672,7 +2655,7 @@ int vtkPKdTree::CreateProcessCellCountData()
     }
   }
 
-  procData = &this->DataLocationMap[0];
+  procData = this->DataLocationMap.data();
 
   for (proc = 0; proc < this->NumProcesses; proc++)
   {
@@ -2681,9 +2664,9 @@ int vtkPKdTree::CreateProcessCellCountData()
     {
       if (*procData)
       {
-        this->AddEntry(&this->ProcessList[reg][0], this->NumProcessesInRegion[reg], proc);
+        this->AddEntry(this->ProcessList[reg].data(), this->NumProcessesInRegion[reg], proc);
 
-        this->AddEntry(&this->ParallelRegionList[proc][0], this->NumRegionsInProcess[proc], reg);
+        this->AddEntry(this->ParallelRegionList[proc].data(), this->NumRegionsInProcess[proc], reg);
       }
       procData++;
     }
@@ -2691,14 +2674,14 @@ int vtkPKdTree::CreateProcessCellCountData()
 
   // Cell counts per process per region
   std::vector<int> tempbuf;
-  int* tempbufptr = &cellCounts[0];
+  int* tempbufptr = cellCounts.data();
   if (this->NumProcesses > 1)
   {
     tempbuf.resize(this->GetNumberOfRegions() * this->NumProcesses);
 
-    this->SubGroup->Gather(&cellCounts[0], &tempbuf[0], this->GetNumberOfRegions(), 0);
-    this->SubGroup->Broadcast(&tempbuf[0], this->NumProcesses * this->GetNumberOfRegions(), 0);
-    tempbufptr = &tempbuf[0];
+    this->SubGroup->Gather(cellCounts.data(), tempbuf.data(), this->GetNumberOfRegions(), 0);
+    this->SubGroup->Broadcast(tempbuf.data(), this->NumProcesses * this->GetNumberOfRegions(), 0);
+    tempbufptr = tempbuf.data();
   }
 
   for (proc = 0; proc < this->NumProcesses; proc++)
@@ -2710,7 +2693,7 @@ int vtkPKdTree::CreateProcessCellCountData()
       if (procCount[reg] > 0)
       {
         this->AddEntry(
-          &this->CellCountList[reg][0], this->NumProcessesInRegion[reg], procCount[reg]);
+          this->CellCountList[reg].data(), this->NumProcessesInRegion[reg], procCount[reg]);
       }
     }
   }
@@ -2757,9 +2740,9 @@ int vtkPKdTree::CreateGlobalDataArrayBounds()
 
       for (ar = 0; ar < ncellarrays; ar++)
       {
-        vtkDataArray* array = this->GetDataSet(set)->GetCellData()->GetArray(ar);
-
-        array->GetRange(range);
+        vtkCellData* cd = this->GetDataSet(set)->GetCellData();
+        cd->GetRange(ar, range);
+        vtkDataArray* array = cd->GetArray(ar);
 
         this->CellDataMin[nc] = range[0];
         this->CellDataMax[nc] = range[1];
@@ -2772,12 +2755,12 @@ int vtkPKdTree::CreateGlobalDataArrayBounds()
     if (this->NumProcesses > 1)
     {
       this->SubGroup->ReduceMin(
-        &this->CellDataMin[0], &this->CellDataMin[0], this->NumCellArrays, 0);
-      this->SubGroup->Broadcast(&this->CellDataMin[0], this->NumCellArrays, 0);
+        this->CellDataMin.data(), this->CellDataMin.data(), this->NumCellArrays, 0);
+      this->SubGroup->Broadcast(this->CellDataMin.data(), this->NumCellArrays, 0);
 
       this->SubGroup->ReduceMax(
-        &this->CellDataMax[0], &this->CellDataMax[0], this->NumCellArrays, 0);
-      this->SubGroup->Broadcast(&this->CellDataMax[0], this->NumCellArrays, 0);
+        this->CellDataMax.data(), this->CellDataMax.data(), this->NumCellArrays, 0);
+      this->SubGroup->Broadcast(this->CellDataMax.data(), this->NumCellArrays, 0);
     }
   }
 
@@ -2789,9 +2772,9 @@ int vtkPKdTree::CreateGlobalDataArrayBounds()
 
       for (ar = 0; ar < npointarrays; ar++)
       {
-        vtkDataArray* array = this->GetDataSet(set)->GetPointData()->GetArray(ar);
-
-        array->GetRange(range);
+        vtkPointData* pd = this->GetDataSet(set)->GetPointData();
+        pd->GetRange(ar, range);
+        vtkDataArray* array = pd->GetArray(ar);
 
         this->PointDataMin[np] = range[0];
         this->PointDataMax[np] = range[1];
@@ -2804,12 +2787,12 @@ int vtkPKdTree::CreateGlobalDataArrayBounds()
     if (this->NumProcesses > 1)
     {
       this->SubGroup->ReduceMin(
-        &this->PointDataMin[0], &this->PointDataMin[0], this->NumPointArrays, 0);
-      this->SubGroup->Broadcast(&this->PointDataMin[0], this->NumPointArrays, 0);
+        this->PointDataMin.data(), this->PointDataMin.data(), this->NumPointArrays, 0);
+      this->SubGroup->Broadcast(this->PointDataMin.data(), this->NumPointArrays, 0);
 
       this->SubGroup->ReduceMax(
-        &this->PointDataMax[0], &this->PointDataMax[0], this->NumPointArrays, 0);
-      this->SubGroup->Broadcast(&this->PointDataMax[0], this->NumPointArrays, 0);
+        this->PointDataMax.data(), this->PointDataMax.data(), this->NumPointArrays, 0);
+      this->SubGroup->Broadcast(this->PointDataMax.data(), this->NumPointArrays, 0);
     }
   }
 
@@ -3394,7 +3377,7 @@ int vtkPKdTree::GetRegionAssignmentList(int procId, vtkIntArray* list)
   }
 
   int nregions = this->NumRegionsAssigned[procId];
-  int* regionIds = &this->ProcessAssignmentMap[procId][0];
+  int* regionIds = this->ProcessAssignmentMap[procId].data();
 
   list->Initialize();
   list->SetNumberOfValues(nregions);
@@ -3671,8 +3654,8 @@ void vtkPKdTree::PrintTables(ostream& os, vtkIndent indent)
 
   if (!this->RegionAssignmentMap.empty())
   {
-    int* map = &this->RegionAssignmentMap[0];
-    int* num = &this->NumRegionsAssigned[0];
+    int* map = this->RegionAssignmentMap.data();
+    int* num = this->NumRegionsAssigned.data();
     int halfr = this->GetRegionAssignmentMapLength() / 2;
     int halfp = nprocs / 2;
 
@@ -3803,3 +3786,4 @@ void vtkPKdTree::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "NextPtArray: " << this->NextPtArray << endl;
   os << indent << "SelectBuffer (size): " << this->SelectBuffer.size() << endl;
 }
+VTK_ABI_NAMESPACE_END
