@@ -26,6 +26,7 @@
 #include "vtkFiltersParallelModule.h" // For export macro
 #include "vtkReflectionFilter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController;
 
 class VTKFILTERSPARALLEL_EXPORT vtkPReflectionFilter : public vtkReflectionFilter
@@ -35,13 +36,13 @@ public:
   vtkTypeMacro(vtkPReflectionFilter, vtkReflectionFilter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the parallel controller.
    */
   void SetController(vtkMultiProcessController*);
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
-  //@}
+  ///@}
 
 protected:
   vtkPReflectionFilter();
@@ -59,4 +60,5 @@ private:
   void operator=(const vtkPReflectionFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
