@@ -41,6 +41,7 @@
 #include <set>    // For block selection
 #include <vector> // For pieces number
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataIterator;
 class vtkCompositeDataSet;
 class vtkDataObjectTreeIterator;
@@ -55,7 +56,7 @@ public:
   vtkTypeMacro(vtkPeriodicFilter, vtkMultiBlockDataSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get Iteration mode.
    * VTK_ITERATION_MODE_DIRECT_NB to specify the number of periods,
@@ -65,16 +66,16 @@ public:
   vtkGetMacro(IterationMode, int);
   void SetIterationModeToDirectNb() { this->SetIterationMode(VTK_ITERATION_MODE_DIRECT_NB); }
   void SetIterationModeToMax() { this->SetIterationMode(VTK_ITERATION_MODE_MAX); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get Number of periods.
    * Used only with ITERATION_MODE_DIRECT_NB.
    */
   vtkSetMacro(NumberOfPeriods, int);
   vtkGetMacro(NumberOfPeriods, int);
-  //@}
+  ///@}
 
   /**
    * Select the periodic pieces indices.
@@ -130,4 +131,5 @@ private:
   std::set<vtkIdType> Indices; // Selected indices
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
