@@ -26,6 +26,7 @@
 #include "vtkAlgorithm.h"
 #include "vtkFiltersParallelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataObject;
 
 class VTKFILTERSPARALLEL_EXPORT vtkPieceRequestFilter : public vtkAlgorithm
@@ -35,37 +36,37 @@ public:
   vtkTypeMacro(vtkPieceRequestFilter, vtkAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The total number of pieces.
    */
   vtkSetClampMacro(NumberOfPieces, int, 0, VTK_INT_MAX);
   vtkGetMacro(NumberOfPieces, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The piece to extract.
    */
   vtkSetClampMacro(Piece, int, 0, VTK_INT_MAX);
   vtkGetMacro(Piece, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the output data object for a port on this algorithm.
    */
   vtkDataObject* GetOutput();
   vtkDataObject* GetOutput(int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set an input of this algorithm.
    */
   void SetInputData(vtkDataObject*);
   void SetInputData(int, vtkDataObject*);
-  //@}
+  ///@}
 
   /**
    * see vtkAlgorithm for details
@@ -95,4 +96,5 @@ private:
   void operator=(const vtkPieceRequestFilter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
