@@ -25,36 +25,33 @@
 #include "vtkPointData.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPieceScalars);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPieceScalars::vtkPieceScalars()
 {
   this->CellScalarsFlag = 0;
   this->RandomMode = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPieceScalars::~vtkPieceScalars() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Append data sets into single unstructured grid
-int vtkPieceScalars::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkPieceScalars::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkDataSet *input = vtkDataSet::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkDataSet *output = vtkDataSet::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataSet* input = vtkDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataSet* output = vtkDataSet::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  vtkDataArray *pieceColors;
+  vtkDataArray* pieceColors;
   vtkIdType num;
 
   if (this->CellScalarsFlag)
@@ -95,10 +92,10 @@ int vtkPieceScalars::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
-vtkIntArray *vtkPieceScalars::MakePieceScalars(int piece, vtkIdType num)
+//------------------------------------------------------------------------------
+vtkIntArray* vtkPieceScalars::MakePieceScalars(int piece, vtkIdType num)
 {
-  vtkIntArray *pieceColors = vtkIntArray::New();
+  vtkIntArray* pieceColors = vtkIntArray::New();
   pieceColors->SetNumberOfTuples(num);
 
   for (vtkIdType i = 0; i < num; ++i)
@@ -109,13 +106,13 @@ vtkIntArray *vtkPieceScalars::MakePieceScalars(int piece, vtkIdType num)
   return pieceColors;
 }
 
-//----------------------------------------------------------------------------
-vtkFloatArray *vtkPieceScalars::MakeRandomScalars(int piece, vtkIdType num)
+//------------------------------------------------------------------------------
+vtkFloatArray* vtkPieceScalars::MakeRandomScalars(int piece, vtkIdType num)
 {
   vtkMath::RandomSeed(piece);
   float randomValue = static_cast<float>(vtkMath::Random());
 
-  vtkFloatArray *pieceColors = vtkFloatArray::New();
+  vtkFloatArray* pieceColors = vtkFloatArray::New();
   pieceColors->SetNumberOfTuples(num);
 
   for (vtkIdType i = 0; i < num; ++i)
@@ -126,10 +123,10 @@ vtkFloatArray *vtkPieceScalars::MakeRandomScalars(int piece, vtkIdType num)
   return pieceColors;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPieceScalars::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "RandomMode: " << this->RandomMode << endl;
   if (this->CellScalarsFlag)
@@ -141,3 +138,4 @@ void vtkPieceScalars::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "ScalarMode: PointData\n";
   }
 }
+VTK_ABI_NAMESPACE_END
