@@ -12,6 +12,7 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
 #include "vtkExtractSubsetWithSeed.h"
 
 #include "vtkBoundingBox.h"
@@ -56,6 +57,7 @@
 #include <functional>
 #include <set>
 
+VTK_ABI_NAMESPACE_BEGIN
 template <typename T, int Size>
 bool operator<(const vtkVector<T, Size>& lhs, const vtkVector<T, Size>& rhs)
 {
@@ -405,7 +407,7 @@ int vtkExtractSubsetWithSeed::RequestData(
 {
   auto input = vtkDataObject::GetData(inputVector[0], 0);
 
-  auto datasets = vtkDIYUtilities::GetDataSets(input);
+  auto datasets = vtkCompositeDataSet::GetDataSets(input);
   // prune non-structured grid datasets.
   auto prunePredicate = [](vtkDataObject* ds) {
     auto sg = vtkStructuredGrid::SafeDownCast(ds);
@@ -472,7 +474,7 @@ int vtkExtractSubsetWithSeed::RequestData(
       {
         const auto dest = rp.out_link().target(i);
         rp.enqueue(dest, bds, 6);
-      };
+      }
     }
     else
     {
@@ -586,7 +588,7 @@ int vtkExtractSubsetWithSeed::RequestData(
         for (const auto& neighbor : cp.link()->neighbors())
         {
           vtkLogF(
-            TRACE, "r=%d: enqueing %d --> (%d, %d)", round, cp.gid(), neighbor.gid, neighbor.proc);
+            TRACE, "r=%d: enqueuing %d --> (%d, %d)", round, cp.gid(), neighbor.gid, neighbor.proc);
           cp.enqueue(neighbor, next_seeds);
         }
       }
@@ -708,7 +710,7 @@ int vtkExtractSubsetWithSeed::RequestData(
 
     // now, put the pieces in output_blocks in the output MB.
     // we use a trick, copy into to output and then replace
-    outputMB->ShallowCopy(inputMB);
+    outputMB->CompositeShallowCopy(inputMB);
 
     std::function<vtkDataObject*(vtkDataObject*)> replaceLeaves;
     replaceLeaves = [&replaceLeaves, &input_dataset_map, &output_blocks](
@@ -784,3 +786,4 @@ int vtkExtractSubsetWithSeed::RequestInformation(
   info->Remove(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
   return 1;
 }
+VTK_ABI_NAMESPACE_END
