@@ -12,9 +12,11 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
 #include "vtkPResampleToImage.h"
 
 #include "vtkArrayDispatch.h"
+#include "vtkBoundingBox.h"
 #include "vtkCharArray.h"
 #include "vtkCompositeDataProbeFilter.h"
 #include "vtkCompositeDataSet.h"
@@ -47,9 +49,11 @@
 #include <algorithm>
 #include <iterator>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPResampleToImage);
 
 vtkCxxSetObjectMacro(vtkPResampleToImage, Controller, vtkMultiProcessController);
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
@@ -312,28 +316,6 @@ void SetPointsToImage(
   points.Indices.clear(); // reset the points structure to a valid empty state
 }
 
-//------------------------------------------------------------------------------
-inline void ComputeGlobalBounds(
-  diy::mpi::communicator& comm, const double lbounds[6], double gbounds[6])
-{
-  Array<double, 3> localBoundsMin, localBoundsMax;
-  for (std::size_t i = 0; i < 3; ++i)
-  {
-    localBoundsMin[i] = lbounds[2 * i];
-    localBoundsMax[i] = lbounds[2 * i + 1];
-  }
-
-  Array<double, 3> globalBoundsMin, globalBoundsMax;
-  diy::mpi::all_reduce(comm, localBoundsMin, globalBoundsMin, diy::mpi::minimum<double>());
-  diy::mpi::all_reduce(comm, localBoundsMax, globalBoundsMax, diy::mpi::maximum<double>());
-
-  for (std::size_t i = 0; i < 3; ++i)
-  {
-    gbounds[2 * i] = globalBoundsMin[i];
-    gbounds[2 * i + 1] = globalBoundsMax[i];
-  }
-}
-
 inline void GetGlobalFieldMetaData(
   diy::mpi::communicator& comm, vtkDataSetAttributes* data, std::vector<FieldMetaData>* metadata)
 {
@@ -446,6 +428,7 @@ void Redistribute(
 
 } // anonymous namespace
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 vtkPResampleToImage::vtkPResampleToImage()
   : Controller(nullptr)
@@ -494,7 +477,17 @@ int vtkPResampleToImage::RequestData(
   double samplingBounds[6];
   if (this->UseInputBounds)
   {
-    ComputeGlobalBounds(comm, localBounds, samplingBounds);
+    vtkBoundingBox bbox(localBounds);
+    vtkDIYUtilities::AllReduce(comm, bbox);
+
+    // To avoid accidentally sampling outside the dataset due to floating point roundoff,
+    // nudge the bounds inward by epsilon.
+    // Note: this is same as what's done in the non-parallel version of this
+    // filter i.e. vtkResampleToImage. So just doing the same here for
+    // consistency.
+    const double epsilon = 1.0e-6;
+    bbox.ScaleAboutCenter(1.0 - epsilon);
+    bbox.GetBounds(samplingBounds);
   }
   else
   {
@@ -542,6 +535,7 @@ int vtkPResampleToImage::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
 
 //------------------------------------------------------------------------------
 namespace diy
@@ -558,8 +552,8 @@ struct mpi_datatype<Array<T, Len>>
   typedef Array<T, Len> ArrayType;
 
   static MPI_Datatype datatype() { return get_mpi_datatype<T>(); }
-  static const void* address(const ArrayType& x) { return &x[0]; }
-  static void* address(ArrayType& x) { return &x[0]; }
+  static const void* address(const ArrayType& x) { return x.data(); }
+  static void* address(ArrayType& x) { return x.data(); }
   static int count(const ArrayType&) { return Len; }
 };
 
