@@ -15,6 +15,7 @@
 #include "vtkAlgorithm.h"
 #include "vtkCellArray.h"
 #include "vtkFloatArray.h"
+#include "vtkGhostCellsGenerator.h"
 #include "vtkIdList.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
@@ -29,16 +30,20 @@
 #include "vtkPoints.h"
 #include "vtkPolyDataMapper.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
+
 #include <vector>
 
 #define EXPECT(expected, actual, msg, so)                                                          \
-  if (!(expected == actual))                                                                       \
+  do                                                                                               \
   {                                                                                                \
-    vtkGenericWarningMacro(<< msg << " Expecting a value of " << expected                          \
-                           << " but getting a value of " << actual << " for static option of "     \
-                           << so);                                                                 \
-    return EXIT_FAILURE;                                                                           \
-  }
+    if (!(expected == actual))                                                                     \
+    {                                                                                              \
+      vtkGenericWarningMacro(<< msg << " Expecting a value of " << expected                        \
+                             << " but getting a value of " << actual << " for static option of "   \
+                             << so);                                                               \
+      return EXIT_FAILURE;                                                                         \
+    }                                                                                              \
+  } while (false)
 
 class TestTimeSource : public vtkAlgorithm
 {
@@ -132,7 +137,7 @@ protected:
     }
   }
 
-  ~TestTimeSource() {}
+  ~TestTimeSource() override = default;
 
   vtkTypeBool ProcessRequest(vtkInformation* request, vtkInformationVector** inputVector,
     vtkInformationVector* outputVector) override
@@ -166,7 +171,7 @@ protected:
     double range[2] = { 0, 9 };
     outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), range, 2);
 
-    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &this->TimeSteps[0],
+    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), this->TimeSteps.data(),
       static_cast<int>(this->TimeSteps.size()));
 
     outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), this->Extent, 6);
@@ -268,7 +273,6 @@ private:
   std::vector<double> TimeSteps;
   int Extent[6];
   double BoundingBox[6];
-  int Spacing;
 };
 
 vtkStandardNewMacro(TestTimeSource);
@@ -280,6 +284,9 @@ int TestPParticleTracer(vtkMPIController* c, int staticOption)
   imageSource->SetExtent(0, size - 1, 0, 1, 0, size - 1);
   imageSource->SetBoundingBox(-1, 1, -1, 1, -1, 1);
 
+  vtkNew<vtkGhostCellsGenerator> ghosts;
+  ghosts->SetInputConnection(0, imageSource->GetOutputPort());
+
   vtkNew<vtkPoints> points;
   points->InsertNextPoint(0.5, 0, 0.001);
   // points->InsertNextPoint(0.99,0,0.99);
@@ -288,9 +295,9 @@ int TestPParticleTracer(vtkMPIController* c, int staticOption)
   ps->SetPoints(points);
 
   vtkNew<vtkPParticleTracer> filter;
-  filter->SetStaticMesh(staticOption);
+  filter->SetMeshOverTime(staticOption);
   filter->SetStaticSeeds(staticOption);
-  filter->SetInputConnection(0, imageSource->GetOutputPort());
+  filter->SetInputConnection(0, ghosts->GetOutputPort());
   filter->SetInputData(1, ps);
   filter->SetStartTime(0.0);
 
@@ -319,6 +326,12 @@ int TestPParticleTracer(vtkMPIController* c, int staticOption)
     traceMapper->Update();
 
     vtkPolyData* out = filter->GetOutput();
+    if (out->GetPointData()->GetArray(vtkDataSetAttributes::GhostArrayName()))
+    {
+      vtkGenericWarningMacro("ParticleTracer generating a ghost array when it should not");
+      return EXIT_FAILURE;
+    }
+
     vtkPoints* pts = out->GetPoints();
 
     numTraced += pts->GetNumberOfPoints();
@@ -349,7 +362,7 @@ int TestPParticlePathFilter(vtkMPIController* c, int staticOption)
   ps->SetPoints(points);
 
   vtkNew<vtkParticlePathFilter> filter;
-  filter->SetStaticMesh(staticOption);
+  filter->SetMeshOverTime(staticOption);
   filter->SetStaticSeeds(staticOption);
   filter->SetInputConnection(0, imageSource->GetOutputPort());
   filter->SetInputData(1, ps);
@@ -417,7 +430,7 @@ int TestPStreaklineFilter(vtkMPIController* c, int staticOption)
   ps->SetPoints(points);
 
   vtkNew<vtkPStreaklineFilter> filter;
-  filter->SetStaticMesh(staticOption);
+  filter->SetMeshOverTime(staticOption);
   filter->SetStaticSeeds(staticOption);
   filter->SetInputConnection(0, imageSource->GetOutputPort());
   filter->SetInputData(1, ps);
