@@ -22,7 +22,6 @@
 #include "vtkIdList.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
-#include "vtkInterpolatedVelocityField.h"
 #include "vtkMPIController.h"
 #include "vtkMath.h"
 #include "vtkNew.h"
@@ -107,13 +106,13 @@ protected:
       return 0;
     }
 
-    output->ShallowCopy(input);
+    output->DeepCopy(input);
 
-    for (unsigned int level = 0; level < input->GetNumberOfLevels(); ++level)
+    for (unsigned int level = 0; level < output->GetNumberOfLevels(); ++level)
     {
-      for (unsigned int idx = 0; idx < input->GetNumberOfDataSets(level); ++idx)
+      for (unsigned int idx = 0; idx < output->GetNumberOfDataSets(level); ++idx)
       {
-        vtkUniformGrid* grid = input->GetDataSet(level, idx);
+        vtkUniformGrid* grid = output->GetDataSet(level, idx);
         if (!grid)
         {
           continue;
@@ -155,8 +154,9 @@ int TestPStreamAMR(int argc, char* argv[])
   int Rank = c->GetLocalProcessId();
   if (numProcs != 4)
   {
-    cerr << "Cannot Create four MPI Processes. Success is only norminal";
-    return EXIT_SUCCESS;
+    std::cerr << "Test requires 4 processes." << std::endl;
+    c->Finalize();
+    return EXIT_FAILURE;
   }
 
   char* fname =
@@ -175,6 +175,8 @@ int TestPStreamAMR(int argc, char* argv[])
   imageSource->SetCellArrayStatus("y-velocity", 1);
   imageSource->SetCellArrayStatus("z-velocity", 1);
 
+  delete[] fname;
+
   vtkNew<TestAMRVectorSource> gradientSource;
   gradientSource->SetInputConnection(imageSource->GetOutputPort());
 
