@@ -14,9 +14,7 @@
 =========================================================================*/
 #include "vtkPParticlePathFilter.h"
 
-#include "vtkPointData.h"
 #include "vtkCellArray.h"
-#include "vtkCharArray.h"
 #include "vtkDataArray.h"
 #include "vtkDoubleArray.h"
 #include "vtkFloatArray.h"
@@ -24,9 +22,12 @@
 #include "vtkInformationVector.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
+#include "vtkPointData.h"
+#include "vtkSignedCharArray.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPParticlePathFilter);
 
 vtkPParticlePathFilter::vtkPParticlePathFilter()
@@ -38,12 +39,12 @@ vtkPParticlePathFilter::vtkPParticlePathFilter()
 
 vtkPParticlePathFilter::~vtkPParticlePathFilter()
 {
-  if(this->SimulationTime)
+  if (this->SimulationTime)
   {
     this->SimulationTime->Delete();
     this->SimulationTime = nullptr;
   }
-  if(this->SimulationTimeStep)
+  if (this->SimulationTimeStep)
   {
     this->SimulationTimeStep->Delete();
     this->SimulationTimeStep = nullptr;
@@ -57,7 +58,7 @@ void vtkPParticlePathFilter::ResetCache()
 
 void vtkPParticlePathFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  Superclass::PrintSelf(os,indent);
+  Superclass::PrintSelf(os, indent);
 }
 
 int vtkPParticlePathFilter::OutputParticles(vtkPolyData* particles)
@@ -65,41 +66,44 @@ int vtkPParticlePathFilter::OutputParticles(vtkPolyData* particles)
   vtkNew<vtkPolyData> tailPoly;
   tailPoly->SetPoints(vtkSmartPointer<vtkPoints>::New());
 
-  vtkPointData* tailPD= tailPoly->GetPointData();
+  vtkPointData* tailPD = tailPoly->GetPointData();
   assert(tailPD);
   tailPD->CopyAllocate(particles->GetPointData());
 
-  for(unsigned int i=0; i<this->Tail.size();i++)
+  for (unsigned int i = 0; i < this->Tail.size(); i++)
   {
     vtkParticleTracerBaseNamespace::ParticleInformation& info(this->Tail[i].Previous);
     vtkPointData* pd = this->Tail[i].PreviousPD;
 
-    const double    *coord = info.CurrentPosition.x;
+    const double* coord = info.CurrentPosition.x;
     vtkIdType tempId = tailPoly->GetPoints()->InsertNextPoint(coord);
-    for(int j=0; j<pd->GetNumberOfArrays();j++)
+    for (int j = 0; j < pd->GetNumberOfArrays(); j++)
     {
       vtkDataArray* arrFrom = pd->GetArray(j);
       vtkDataArray* arrTo = tailPD->GetArray(arrFrom->GetName());
       assert(arrTo);
-      assert(arrTo->GetNumberOfComponents()==arrFrom->GetNumberOfComponents());
-      arrTo->InsertTuple(tempId,arrFrom->GetTuple(0));
+      assert(arrTo->GetNumberOfComponents() == arrFrom->GetNumberOfComponents());
+      arrTo->InsertTuple(tempId, arrFrom->GetTuple(0));
     }
 
-    this->GetParticleIds(tailPD)->InsertValue(tempId,info.UniqueParticleId);
-    this->GetParticleSourceIds(tailPD)->InsertValue(tempId,info.SourceID);
+    this->GetParticleIds(tailPD)->InsertValue(tempId, info.UniqueParticleId);
+    this->GetParticleSourceIds(tailPD)->InsertValue(tempId, info.SourceID);
     this->GetInjectedPointIds(tailPD)->InsertValue(tempId, info.InjectedPointId);
     this->GetInjectedStepIds(tailPD)->InsertValue(tempId, info.InjectedStepId);
     this->GetErrorCodeArr(tailPD)->InsertValue(tempId, info.ErrorCode);
     this->GetParticleAge(tailPD)->InsertValue(tempId, info.age);
 
-    vtkArrayDownCast<vtkDoubleArray>(tailPD->GetArray("SimulationTime"))->InsertValue(tempId, info.SimulationTime);
-    vtkArrayDownCast<vtkIntArray>(tailPD->GetArray("SimulationTimeStep"))->InsertValue(tempId, info.InjectedStepId+info.TimeStepAge);
+    vtkArrayDownCast<vtkDoubleArray>(tailPD->GetArray("SimulationTime"))
+      ->InsertValue(tempId, info.SimulationTime);
+    vtkArrayDownCast<vtkIntArray>(tailPD->GetArray("SimulationTimeStep"))
+      ->InsertValue(tempId, info.InjectedStepId + info.TimeStepAge);
 
-    if(this->GetComputeVorticity())
+    if (this->GetComputeVorticity())
     {
-//      this->GetParticleVorticity(tailPD)->InsertNextTuple(info.vorticity); missing in implementation
-      this->GetParticleAngularVel(tailPD)->InsertValue(tempId,info.angularVel);
-      this->GetParticleRotation(tailPD)->InsertValue(tempId,info.rotation);
+      //      this->GetParticleVorticity(tailPD)->InsertNextTuple(info.vorticity); missing in
+      //      implementation
+      this->GetParticleAngularVel(tailPD)->InsertValue(tempId, info.angularVel);
+      this->GetParticleRotation(tailPD)->InsertValue(tempId, info.rotation);
     }
   }
 
@@ -110,24 +114,24 @@ int vtkPParticlePathFilter::OutputParticles(vtkPolyData* particles)
 
 void vtkPParticlePathFilter::InitializeExtraPointDataArrays(vtkPointData* outputPD)
 {
-  if(this->SimulationTime == nullptr)
+  if (this->SimulationTime == nullptr)
   {
     this->SimulationTime = vtkDoubleArray::New();
     this->SimulationTime->SetName("SimulationTime");
   }
-  if(outputPD->GetArray("SimulationTime"))
+  if (outputPD->GetArray("SimulationTime"))
   {
     outputPD->RemoveArray("SimulationTime");
   }
   this->SimulationTime->SetNumberOfTuples(0);
   outputPD->AddArray(this->SimulationTime);
 
-  if(this->SimulationTimeStep == nullptr)
+  if (this->SimulationTimeStep == nullptr)
   {
     this->SimulationTimeStep = vtkIntArray::New();
     this->SimulationTimeStep->SetName("SimulationTimeStep");
   }
-  if(outputPD->GetArray("SimulationTimeStep"))
+  if (outputPD->GetArray("SimulationTimeStep"))
   {
     outputPD->RemoveArray("SimulationTimeStep");
   }
@@ -135,11 +139,11 @@ void vtkPParticlePathFilter::InitializeExtraPointDataArrays(vtkPointData* output
   outputPD->AddArray(this->SimulationTimeStep);
 }
 
-void vtkPParticlePathFilter::AppendToExtraPointDataArrays(
-  vtkParticleTracerBaseNamespace::ParticleInformation &info)
+void vtkPParticlePathFilter::SetToExtraPointDataArrays(
+  vtkIdType particleId, vtkParticleTracerBaseNamespace::ParticleInformation& info)
 {
-  this->SimulationTime->InsertNextValue(info.SimulationTime);
-  this->SimulationTimeStep->InsertNextValue(info.InjectedStepId+info.TimeStepAge);
+  this->SimulationTime->SetValue(particleId, info.SimulationTime);
+  this->SimulationTimeStep->SetValue(particleId, info.InjectedStepId + info.TimeStepAge);
 }
 
 void vtkPParticlePathFilter::Finalize()
@@ -148,9 +152,9 @@ void vtkPParticlePathFilter::Finalize()
 }
 
 int vtkPParticlePathFilter::RequestInformation(
-  vtkInformation *request, vtkInformationVector **inputVector, vtkInformationVector *outputVector)
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // The output data of this filter has no time associated with it.  It is the
   // result of computations that happen over all time.
@@ -159,3 +163,4 @@ int vtkPParticlePathFilter::RequestInformation(
 
   return this->Superclass::RequestInformation(request, inputVector, outputVector);
 }
+VTK_ABI_NAMESPACE_END
