@@ -21,7 +21,7 @@
  *
  * @sa
  * vtkPParticlePathFilterBase has the details of the algorithms
-*/
+ */
 
 #ifndef vtkPParticlePathFilter_h
 #define vtkPParticlePathFilter_h
@@ -30,31 +30,32 @@
 #include "vtkParticlePathFilter.h" //for utility
 
 #include "vtkFiltersParallelFlowPathsModule.h" // For export macro
-class  VTKFILTERSPARALLELFLOWPATHS_EXPORT vtkPParticlePathFilter: public vtkPParticleTracerBase
+VTK_ABI_NAMESPACE_BEGIN
+class VTKFILTERSPARALLELFLOWPATHS_EXPORT vtkPParticlePathFilter : public vtkPParticleTracerBase
 {
 public:
-  vtkTypeMacro(vtkPParticlePathFilter,vtkPParticleTracerBase)
+  vtkTypeMacro(vtkPParticlePathFilter, vtkPParticleTracerBase);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  static vtkPParticlePathFilter *New();
+  static vtkPParticlePathFilter* New();
 
 protected:
   vtkPParticlePathFilter();
-  ~vtkPParticlePathFilter();
+  ~vtkPParticlePathFilter() override;
 
-  virtual void ResetCache() override;
-  virtual int OutputParticles(vtkPolyData* poly) override;
-  virtual void InitializeExtraPointDataArrays(vtkPointData* outputPD) override;
-  virtual void AppendToExtraPointDataArrays(vtkParticleTracerBaseNamespace::ParticleInformation &) override;
+  void ResetCache() override;
+  int OutputParticles(vtkPolyData* poly) override;
+  void InitializeExtraPointDataArrays(vtkPointData* outputPD) override;
+  void SetToExtraPointDataArrays(
+    vtkIdType particleId, vtkParticleTracerBaseNamespace::ParticleInformation&) override;
   void Finalize() override;
 
   //
   // Store any information we need in the output and fetch what we can
   // from the input
   //
-  int RequestInformation(vtkInformation* request,
-                         vtkInformationVector** inputVector,
-                         vtkInformationVector* outputVector) override;
+  int RequestInformation(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
 
   ParticlePathFilterInternal It;
   vtkDoubleArray* SimulationTime;
@@ -64,4 +65,5 @@ private:
   vtkPParticlePathFilter(const vtkPParticlePathFilter&) = delete;
   void operator=(const vtkPParticlePathFilter&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 #endif
