@@ -16,16 +16,18 @@
 
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTransmitImageDataPiece);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTransmitImageDataPiece::vtkTransmitImageDataPiece() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTransmitImageDataPiece::~vtkTransmitImageDataPiece() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTransmitImageDataPiece::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
