@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkDistributedPointCloudFilter.h,v $
+  Module:    vtkDistributedPointCloudFilter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -33,11 +33,11 @@
 #include <algorithm>
 
 // Histogram precision to divide space in two
+VTK_ABI_NAMESPACE_BEGIN
 static const int HISTOGRAM_SIZE = 1024;
 
 vtkStandardNewMacro(vtkDistributedPointCloudFilter);
-vtkSetObjectImplementationMacro(
-  vtkDistributedPointCloudFilter, Controller, vtkMultiProcessController);
+vtkCxxSetObjectMacro(vtkDistributedPointCloudFilter, Controller, vtkMultiProcessController);
 
 //------------------------------------------------------------------------------
 vtkDistributedPointCloudFilter::vtkDistributedPointCloudFilter()
@@ -91,7 +91,7 @@ int vtkDistributedPointCloudFilter::RequestData(
   {
     double bounds[6];
     this->OptimizeBoundingBox(subControllersTree, input, bounds);
-    this->GetPointsInsideBounds(controller, input, output, bounds);
+    vtkDistributedPointCloudFilter::GetPointsInsideBounds(controller, input, output, bounds);
   }
   else
   {
@@ -611,3 +611,4 @@ void vtkDistributedPointCloudFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
