@@ -30,6 +30,7 @@
 #include "vtkTable.h"
 #include "vtkVariant.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPDescriptiveStatistics);
 vtkCxxSetObjectMacro(vtkPDescriptiveStatistics, Controller, vtkMultiProcessController);
 //------------------------------------------------------------------------------
@@ -187,22 +188,4 @@ void vtkPDescriptiveStatistics::Learn(
   }
   delete[] n_g;
 }
-
-//------------------------------------------------------------------------------
-int vtkPDescriptiveStatistics::RequestData(
-  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
-{
-  int retVal = this->Superclass::RequestData(request, inputVector, outputVector);
-
-  if (this->Controller && this->Controller->GetLocalProcessId() != 0)
-  {
-    vtkMultiBlockDataSet* outModel = vtkMultiBlockDataSet::GetData(outputVector, OUTPUT_MODEL);
-    std::vector<vtkDataObject*> outputs = vtkCompositeDataSet::GetDataSets<vtkDataObject>(outModel);
-    for (vtkDataObject* output : outputs)
-    {
-      output->Initialize();
-    }
-  }
-
-  return retVal;
-}
+VTK_ABI_NAMESPACE_END
