@@ -17,8 +17,8 @@
   Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
   the U.S. Government retains certain rights in this software.
   -------------------------------------------------------------------------*/
-#include "vtkToolkits.h"
 
+#include "vtkPKMeansStatistics.h"
 #include "vtkCommunicator.h"
 #include "vtkDoubleArray.h"
 #include "vtkIdTypeArray.h"
@@ -27,23 +27,23 @@
 #include "vtkKMeansStatistics.h"
 #include "vtkMultiProcessController.h"
 #include "vtkObjectFactory.h"
-#include "vtkPKMeansStatistics.h"
 #include "vtkTable.h"
 #include "vtkVariantArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPKMeansStatistics);
 vtkCxxSetObjectMacro(vtkPKMeansStatistics, Controller, vtkMultiProcessController);
 //------------------------------------------------------------------------------
 vtkPKMeansStatistics::vtkPKMeansStatistics()
 {
-  this->Controller = 0;
+  this->Controller = nullptr;
   this->SetController(vtkMultiProcessController::GetGlobalController());
 }
 
 //------------------------------------------------------------------------------
 vtkPKMeansStatistics::~vtkPKMeansStatistics()
 {
-  this->SetController(0);
+  this->SetController(nullptr);
 }
 
 //------------------------------------------------------------------------------
@@ -245,3 +245,4 @@ void vtkPKMeansStatistics::CreateInitialClusterCenters(vtkIdType numToAllocate,
 
   this->DistanceFunctor->DeallocateElementArray(localElements);
 }
+VTK_ABI_NAMESPACE_END
