@@ -19,7 +19,6 @@ PURPOSE.  See the above copyright notice for more information.
   -------------------------------------------------------------------------*/
 
 #include "vtkPOrderStatistics.h"
-#include "vtkToolkits.h"
 
 #include "vtkCommunicator.h"
 #include "vtkIdTypeArray.h"
@@ -37,19 +36,20 @@ PURPOSE.  See the above copyright notice for more information.
 #include <set>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPOrderStatistics);
 vtkCxxSetObjectMacro(vtkPOrderStatistics, Controller, vtkMultiProcessController);
 //------------------------------------------------------------------------------
 vtkPOrderStatistics::vtkPOrderStatistics()
 {
-  this->Controller = 0;
+  this->Controller = nullptr;
   this->SetController(vtkMultiProcessController::GetGlobalController());
 }
 
 //------------------------------------------------------------------------------
 vtkPOrderStatistics::~vtkPOrderStatistics()
 {
-  this->SetController(0);
+  this->SetController(nullptr);
 }
 
 //------------------------------------------------------------------------------
@@ -60,12 +60,11 @@ void vtkPOrderStatistics::PrintSelf(ostream& os, vtkIndent indent)
 }
 
 //------------------------------------------------------------------------------
-static void StringVectorToStringBuffer(
-  const std::vector<vtkStdString>& strings, vtkStdString& buffer)
+static void StringVectorToStringBuffer(const std::vector<std::string>& strings, std::string& buffer)
 {
   buffer.clear();
 
-  for (std::vector<vtkStdString>::const_iterator it = strings.begin(); it != strings.end(); ++it)
+  for (std::vector<std::string>::const_iterator it = strings.begin(); it != strings.end(); ++it)
   {
     buffer.append(*it);
     buffer.push_back(0);
@@ -73,9 +72,9 @@ static void StringVectorToStringBuffer(
 }
 
 //------------------------------------------------------------------------------
-static void StringArrayToStringBuffer(vtkStringArray* sVals, vtkStdString& sPack)
+static void StringArrayToStringBuffer(vtkStringArray* sVals, std::string& sPack)
 {
-  std::vector<vtkStdString> sVect; // consecutive strings
+  std::vector<std::string> sVect; // consecutive strings
 
   vtkIdType nv = sVals->GetNumberOfValues();
   for (vtkIdType i = 0; i < nv; ++i)
@@ -90,7 +89,7 @@ static void StringArrayToStringBuffer(vtkStringArray* sVals, vtkStdString& sPack
 
 //------------------------------------------------------------------------------
 static void StringHistoToBuffers(
-  const std::map<vtkStdString, vtkIdType>& histo, vtkStdString& buffer, vtkIdTypeArray* card)
+  const std::map<vtkStdString, vtkIdType>& histo, std::string& buffer, vtkIdTypeArray* card)
 {
   buffer.clear();
 
@@ -107,20 +106,19 @@ static void StringHistoToBuffers(
 }
 
 //------------------------------------------------------------------------------
-static void StringBufferToStringVector(
-  const vtkStdString& buffer, std::vector<vtkStdString>& strings)
+static void StringBufferToStringVector(const std::string& buffer, std::vector<std::string>& strings)
 {
   strings.clear();
 
-  const char* const bufferEnd = &buffer[0] + buffer.size();
+  const char* const bufferEnd = buffer.data() + buffer.size();
 
-  for (const char* start = &buffer[0]; start != bufferEnd; ++start)
+  for (const char* start = buffer.data(); start != bufferEnd; ++start)
   {
     for (const char* finish = start; finish != bufferEnd; ++finish)
     {
       if (!*finish)
       {
-        strings.push_back(vtkStdString(start));
+        strings.emplace_back(start);
         start = finish;
         break;
       }
@@ -264,7 +262,7 @@ void vtkPOrderStatistics::Learn(
       vtkStringArray* sVals = vtkArrayDownCast<vtkStringArray>(vals);
 
       // Packing step: concatenate all string values
-      vtkStdString sPack_l;
+      std::string sPack_l;
       StringArrayToStringBuffer(sVals, sPack_l);
 
       // (All) gather all string sizes
@@ -283,7 +281,7 @@ void vtkPOrderStatistics::Learn(
       }
 
       // Allocate receive buffer on reducer process, based on the global size obtained above
-      char* sPack_g = 0;
+      char* sPack_g = nullptr;
       if (myRank == rProc)
       {
         sPack_g = new char[ncTotal];
@@ -294,9 +292,14 @@ void vtkPOrderStatistics::Learn(
       if (!com->GatherV(&(*sPack_l.begin()), sPack_g, nc_l, nc_g, offsets, rProc))
       {
         vtkErrorMacro("Process " << myRank << "could not gather string values.");
+        delete[] nc_g;
+        delete[] offsets;
+        delete[] sPack_g;
 
         return;
       }
+      delete[] nc_g;
+      delete[] offsets;
 
       // Reduce to global histogram on process rProc
       std::map<vtkStdString, vtkIdType> histogram;
@@ -304,9 +307,11 @@ void vtkPOrderStatistics::Learn(
       {
         if (this->Reduce(card_g, ncTotal, sPack_g, histogram))
         {
+          delete[] sPack_g;
           return;
         }
       } // if ( myRank == rProc )
+      delete[] sPack_g;
 
       // Create column for global histogram values of the same type as the values
       vtkStringArray* sVals_g = vtkStringArray::New();
@@ -317,6 +322,7 @@ void vtkPOrderStatistics::Learn(
       {
         vtkErrorMacro("Process " << com->GetLocalProcessId()
                                  << " could not broadcast reduced histogram values.");
+        sVals_g->Delete();
 
         return;
       }
@@ -403,8 +409,8 @@ bool vtkPOrderStatistics::Reduce(vtkIdTypeArray* card_g, vtkIdType& ncTotal, cha
   std::map<vtkStdString, vtkIdType>& histogram)
 {
   // First, unpack the packet of strings
-  std::vector<vtkStdString> sVect_g;
-  StringBufferToStringVector(vtkStdString(sPack_g, ncTotal), sVect_g);
+  std::vector<std::string> sVect_g;
+  StringBufferToStringVector(std::string(sPack_g, ncTotal), sVect_g);
 
   // Second, check consistency: we must have as many values as cardinality entries
   vtkIdType nRow_g = card_g->GetNumberOfTuples();
@@ -421,7 +427,7 @@ bool vtkPOrderStatistics::Reduce(vtkIdTypeArray* card_g, vtkIdType& ncTotal, cha
   // Third, reduce to the global histogram
   vtkIdType c;
   vtkIdType i = 0;
-  for (std::vector<vtkStdString>::iterator vit = sVect_g.begin(); vit != sVect_g.end(); ++vit, ++i)
+  for (std::vector<std::string>::iterator vit = sVect_g.begin(); vit != sVect_g.end(); ++vit, ++i)
   {
     // First, retrieve cardinality
     c = card_g->GetValue(i);
@@ -440,7 +446,7 @@ bool vtkPOrderStatistics::Broadcast(std::map<vtkStdString, vtkIdType>& histogram
   vtkCommunicator* com = this->Controller->GetCommunicator();
 
   // Concatenate string keys of histogram into single string and put values into resized array
-  vtkStdString sPack;
+  std::string sPack;
   StringHistoToBuffers(histogram, sPack, card);
 
   // Broadcast size of string buffer
@@ -466,7 +472,7 @@ bool vtkPOrderStatistics::Broadcast(std::map<vtkStdString, vtkIdType>& histogram
   }
 
   // Unpack the packet of strings
-  std::vector<vtkStdString> sVect;
+  std::vector<std::string> sVect;
   StringBufferToStringVector(sPack, sVect);
 
   // Broadcast histogram cardinalities
@@ -483,10 +489,11 @@ bool vtkPOrderStatistics::Broadcast(std::map<vtkStdString, vtkIdType>& histogram
 
   // Then store reduced histogram into array
   vtkIdType r = 0;
-  for (std::vector<vtkStdString>::iterator vit = sVect.begin(); vit != sVect.end(); ++vit, ++r)
+  for (std::vector<std::string>::iterator vit = sVect.begin(); vit != sVect.end(); ++vit, ++r)
   {
     sVals->SetValue(r, *vit);
   }
 
   return false;
 }
+VTK_ABI_NAMESPACE_END
