@@ -18,13 +18,20 @@
 #include "vtkMultiProcessController.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPCellSizeFilter);
 
 //------------------------------------------------------------------------------
-vtkPCellSizeFilter::vtkPCellSizeFilter() {}
+void vtkPCellSizeFilter::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
 
 //------------------------------------------------------------------------------
-vtkPCellSizeFilter::~vtkPCellSizeFilter() {}
+vtkPCellSizeFilter::vtkPCellSizeFilter() = default;
+
+//------------------------------------------------------------------------------
+vtkPCellSizeFilter::~vtkPCellSizeFilter() = default;
 
 //------------------------------------------------------------------------------
 void vtkPCellSizeFilter::ComputeGlobalSum(double sum[4])
@@ -40,3 +47,4 @@ void vtkPCellSizeFilter::ComputeGlobalSum(double sum[4])
     }
   }
 }
+VTK_ABI_NAMESPACE_END
