@@ -24,6 +24,7 @@
 #include "vtkPoints.h"
 #include "vtkPolyData.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBoundedPointSource);
 
 //------------------------------------------------------------------------------
@@ -78,12 +79,11 @@ int vtkBoundedPointSource::RequestData(vtkInformation* vtkNotUsed(request),
   double zmin = (this->Bounds[4] < this->Bounds[5] ? this->Bounds[4] : this->Bounds[5]);
   double zmax = (this->Bounds[4] < this->Bounds[5] ? this->Bounds[5] : this->Bounds[4]);
 
-  vtkMath* math = vtkMath::New();
   for (ptId = 0; ptId < this->NumberOfPoints; ptId++)
   {
-    x[0] = math->Random(xmin, xmax);
-    x[1] = math->Random(ymin, ymax);
-    x[2] = math->Random(zmin, zmax);
+    x[0] = vtkMath::Random(xmin, xmax);
+    x[1] = vtkMath::Random(ymin, ymax);
+    x[2] = vtkMath::Random(zmin, zmax);
     newPoints->SetPoint(ptId, x);
   }
   output->SetPoints(newPoints);
@@ -102,7 +102,7 @@ int vtkBoundedPointSource::RequestData(vtkInformation* vtkNotUsed(request),
       (this->ScalarRange[0] < this->ScalarRange[1] ? this->ScalarRange[1] : this->ScalarRange[0]);
     for (ptId = 0; ptId < this->NumberOfPoints; ptId++)
     {
-      *s++ = math->Random(sMin, sMax);
+      *s++ = vtkMath::Random(sMin, sMax);
     }
     output->GetPointData()->SetScalars(scalars);
     scalars->Delete();
@@ -122,7 +122,6 @@ int vtkBoundedPointSource::RequestData(vtkInformation* vtkNotUsed(request),
     newVerts->Delete();
   }
 
-  math->Delete();
   return 1;
 }
 
@@ -145,3 +144,4 @@ void vtkBoundedPointSource::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Produce Random Scalars: " << (this->ProduceRandomScalars ? "On\n" : "Off\n");
   os << indent << "Scalar Range (" << this->ScalarRange[0] << "," << this->ScalarRange[1] << ")\n";
 }
+VTK_ABI_NAMESPACE_END
