@@ -32,7 +32,7 @@
  * where S is the local scalar value; E is a user-defined eccentricity factor
  * that controls the elliptical shape of the splat; z is the distance of the
  * current voxel sample point along the local normal N; and rxy is the
- * distance to neighbor point x in the direction prependicular to N.
+ * distance to neighbor point x in the direction perpendicular to N.
  *
  * @warning
  * The weights are normalized so that SUM(Wi) = 1. If a neighbor point p
@@ -51,6 +51,7 @@
 #include "vtkGeneralizedKernel.h"
 #include "vtkStdString.h" // For vtkStdString ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkDataArray;
 class vtkDoubleArray;
@@ -58,14 +59,14 @@ class vtkDoubleArray;
 class VTKFILTERSPOINTS_EXPORT vtkEllipsoidalGaussianKernel : public vtkGeneralizedKernel
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, obtaining type information, and printing.
    */
   static vtkEllipsoidalGaussianKernel* New();
   vtkTypeMacro(vtkEllipsoidalGaussianKernel, vtkGeneralizedKernel);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Initialize the kernel. Overload the superclass to set up scalars and
@@ -93,7 +94,7 @@ public:
   vtkIdType ComputeWeights(
     double x[3], vtkIdList* pIds, vtkDoubleArray* prob, vtkDoubleArray* weights) override;
 
-  //@{
+  ///@{
   /**
    * Specify whether vector values should be used to affect the shape
    * of the Gaussian distribution. By default this is on.
@@ -101,9 +102,9 @@ public:
   vtkSetMacro(UseNormals, bool);
   vtkGetMacro(UseNormals, bool);
   vtkBooleanMacro(UseNormals, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the normals array name. Used to orient the ellipsoid. Note that
    * by default the input normals are used (i.e. the input to
@@ -112,9 +113,9 @@ public:
    */
   vtkSetMacro(NormalsArrayName, vtkStdString);
   vtkGetMacro(NormalsArrayName, vtkStdString);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether scalar values should be used to scale the weights.
    * By default this is off.
@@ -122,9 +123,9 @@ public:
   vtkSetMacro(UseScalars, bool);
   vtkGetMacro(UseScalars, bool);
   vtkBooleanMacro(UseScalars, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the scalars array name. Used to scale the ellipsoid. Note that
    * by default the input scalars are used (i.e. the input to
@@ -133,9 +134,9 @@ public:
    */
   vtkSetMacro(ScalarsArrayName, vtkStdString);
   vtkGetMacro(ScalarsArrayName, vtkStdString);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Multiply the Gaussian splat distribution by this value. If UseScalars is
    * on and a scalar array is provided, then the scalar value will be
@@ -143,9 +144,9 @@ public:
    */
   vtkSetClampMacro(ScaleFactor, double, 0.0, VTK_DOUBLE_MAX);
   vtkGetMacro(ScaleFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / Get the sharpness (i.e., falloff) of the Gaussian. By default
    * Sharpness=2. As the sharpness increases the effects of distant points
@@ -153,9 +154,9 @@ public:
    */
   vtkSetClampMacro(Sharpness, double, 1, VTK_FLOAT_MAX);
   vtkGetMacro(Sharpness, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / Get the eccentricity of the ellipsoidal Gaussian. A value=1.0
    * produces a spherical distribution. Values < 1 produce a needle like
@@ -164,7 +165,7 @@ public:
    */
   vtkSetClampMacro(Eccentricity, double, 0.000001, VTK_FLOAT_MAX);
   vtkGetMacro(Eccentricity, double);
-  //@}
+  ///@}
 
 protected:
   vtkEllipsoidalGaussianKernel();
@@ -192,4 +193,5 @@ private:
   void operator=(const vtkEllipsoidalGaussianKernel&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
