@@ -56,19 +56,20 @@
 #include "vtkFiltersPointsModule.h" // For export macro
 #include "vtkPointCloudFilter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSPOINTS_EXPORT vtkExtractEnclosedPoints : public vtkPointCloudFilter
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, type information, and printing.
    */
   static vtkExtractEnclosedPoints* New();
   vtkTypeMacro(vtkExtractEnclosedPoints, vtkPointCloudFilter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the surface to be used to test for containment. Two methods are
    * provided: one directly for vtkPolyData, and one for the output of a
@@ -76,17 +77,17 @@ public:
    */
   void SetSurfaceData(vtkPolyData* pd);
   void SetSurfaceConnection(vtkAlgorithmOutput* algOutput);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return a pointer to the enclosing surface.
    */
   vtkPolyData* GetSurface();
   vtkPolyData* GetSurface(vtkInformationVector* sourceInfo);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether to check the surface for closure. If on, then the
    * algorithm first checks to see if the surface is closed and manifold.
@@ -94,16 +95,16 @@ public:
   vtkSetMacro(CheckSurface, vtkTypeBool);
   vtkBooleanMacro(CheckSurface, vtkTypeBool);
   vtkGetMacro(CheckSurface, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the tolerance on the intersection. The tolerance is expressed as
    * a fraction of the diagonal of the bounding box of the enclosing surface.
    */
   vtkSetClampMacro(Tolerance, double, 0.0, VTK_FLOAT_MAX);
   vtkGetMacro(Tolerance, double);
-  //@}
+  ///@}
 
 protected:
   vtkExtractEnclosedPoints();
@@ -126,4 +127,5 @@ private:
   void operator=(const vtkExtractEnclosedPoints&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
