@@ -27,6 +27,7 @@
 #include "vtkPoints.h"
 #include "vtkSMPTools.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHierarchicalBinningFilter);
 
 namespace
@@ -34,7 +35,7 @@ namespace
 
 //------------------------------------------------------------------------------
 // Number ^ index: power function for integers.
-static int power(int number, int level)
+int power(int number, int level)
 {
   if (level == 0)
   {
@@ -49,7 +50,7 @@ static int power(int number, int level)
 }
 
 //------------------------------------------------------------------------------
-static int GetLevelOffset(int level, int divs[3])
+int GetLevelOffset(int level, int divs[3])
 {
   int block = divs[0] * divs[1] * divs[2];
   int offset = 0;
@@ -236,7 +237,6 @@ struct vtkBinTree
   {
     for (level = this->NumLevels - 1; globalBin < this->Tree[level]->LevelOffset; --level)
     {
-      ;
     }
     localBin = globalBin - this->Tree[level]->LevelOffset;
   }
@@ -387,7 +387,6 @@ struct BinTree : public vtkBinTree
 
         for (level = numLevels - 1; idx < this->Thresh[level]; --level)
         {
-          ;
         }
         t->Bin = this->Tree->Tree[level]->GetBinIndex(p);
       } // for all points in this batch
@@ -450,7 +449,7 @@ struct BinTree : public vtkBinTree
       {
         for (; curPt->Bin == prevPt->Bin && curPt <= endBatchPt; ++curPt)
         {
-          ; // advance
+          // advance
         }
         // Fill in any gaps in the offset array
         std::fill_n(offsets + prevPt->Bin + 1, curPt->Bin - prevPt->Bin, curPt - this->Tree->Map);
@@ -600,7 +599,7 @@ struct BinTree : public vtkBinTree
     vtkPointData* outPD = output->GetPointData();
     outPD->CopyAllocate(inPD, this->NumPts);
 
-    char* name;
+    const char* name;
     vtkDataArray *iArray, *oArray;
     void *iD, *oD;
     int i, numComp, numArrays = inPD->GetNumberOfArrays();
@@ -900,3 +899,4 @@ void vtkHierarchicalBinningFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Divisions: (" << this->Divisions[0] << "," << this->Divisions[1] << ","
      << this->Divisions[2] << ")\n";
 }
+VTK_ABI_NAMESPACE_END
