@@ -70,6 +70,7 @@
 #include "vtkStdString.h"           // For vtkStdString ivars
 #include <vector>                   //For STL vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractPointLocator;
 class vtkIdList;
 class vtkDoubleArray;
@@ -79,7 +80,7 @@ class vtkCharArray;
 class VTKFILTERSPOINTS_EXPORT vtkPointInterpolator : public vtkDataSetAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiating, obtaining type information, and
    * printing.
@@ -87,9 +88,9 @@ public:
   static vtkPointInterpolator* New();
   vtkTypeMacro(vtkPointInterpolator, vtkDataSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the dataset Pc that will be probed by the input points P.  The
    * Input P defines the dataset structure (the points and cells) for the
@@ -99,7 +100,7 @@ public:
    */
   void SetSourceData(vtkDataObject* source);
   vtkDataObject* GetSource();
-  //@}
+  ///@}
 
   /**
    * Specify the dataset Pc that will be probed by the input points P.  The
@@ -109,7 +110,7 @@ public:
    */
   void SetSourceConnection(vtkAlgorithmOutput* algOutput);
 
-  //@{
+  ///@{
   /**
    * Specify a point locator. By default a vtkStaticPointLocator is
    * used. The locator performs efficient searches to locate near a
@@ -117,9 +118,9 @@ public:
    */
   void SetLocator(vtkAbstractPointLocator* locator);
   vtkGetObjectMacro(Locator, vtkAbstractPointLocator);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify an interpolation kernel. By default a vtkLinearKernel is used
    * (i.e., linear combination of closest points). The interpolation kernel
@@ -127,7 +128,7 @@ public:
    */
   void SetKernel(vtkInterpolationKernel* kernel);
   vtkGetObjectMacro(Kernel, vtkInterpolationKernel);
-  //@}
+  ///@}
 
   enum Strategy
   {
@@ -136,7 +137,7 @@ public:
     CLOSEST_POINT = 2
   };
 
-  //@{
+  ///@{
   /**
    * Specify a strategy to use when encountering a "null" point during the
    * interpolation process. Null points occur when the local neighborhood (of
@@ -153,9 +154,9 @@ public:
   void SetNullPointsStrategyToMaskPoints() { this->SetNullPointsStrategy(MASK_POINTS); }
   void SetNullPointsStrategyToNullValue() { this->SetNullPointsStrategy(NULL_VALUE); }
   void SetNullPointsStrategyToClosestPoint() { this->SetNullPointsStrategy(CLOSEST_POINT); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If the NullPointsStrategy == MASK_POINTS, then an array is generated for
    * each input point. This vtkCharArray is placed into the output of the filter,
@@ -164,9 +165,9 @@ public:
    */
   vtkSetMacro(ValidPointsMaskArrayName, vtkStdString);
   vtkGetMacro(ValidPointsMaskArrayName, vtkStdString);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the null point value. When a null point is encountered then all
    * components of each null tuple are set to this value. By default the
@@ -174,9 +175,9 @@ public:
    */
   vtkSetMacro(NullValue, double);
   vtkGetMacro(NullValue, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Adds an array to the list of arrays which are to be excluded from the
    * interpolation process.
@@ -186,9 +187,9 @@ public:
     this->ExcludedArrays.push_back(excludedArray);
     this->Modified();
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Clears the contents of excluded array list.
    */
@@ -197,14 +198,14 @@ public:
     this->ExcludedArrays.clear();
     this->Modified();
   }
-  //@}
+  ///@}
 
   /**
    * Return the number of excluded arrays.
    */
   int GetNumberOfExcludedArrays() { return static_cast<int>(this->ExcludedArrays.size()); }
 
-  //@{
+  ///@{
   /**
    * Return the name of the ith excluded array.
    */
@@ -216,9 +217,9 @@ public:
     }
     return this->ExcludedArrays[i].c_str();
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If enabled, then input arrays that are non-real types (i.e., not float
    * or double) are promoted to float type on output. This is because the
@@ -228,9 +229,9 @@ public:
   vtkSetMacro(PromoteOutputArrays, bool);
   vtkBooleanMacro(PromoteOutputArrays, bool);
   vtkGetMacro(PromoteOutputArrays, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Indicate whether to shallow copy the input point data arrays to the
    * output.  On by default.
@@ -238,9 +239,9 @@ public:
   vtkSetMacro(PassPointArrays, bool);
   vtkBooleanMacro(PassPointArrays, bool);
   vtkGetMacro(PassPointArrays, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Indicate whether to shallow copy the input cell data arrays to the
    * output.  On by default.
@@ -248,9 +249,9 @@ public:
   vtkSetMacro(PassCellArrays, bool);
   vtkBooleanMacro(PassCellArrays, bool);
   vtkGetMacro(PassCellArrays, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Indicate whether to pass the field-data arrays from the input to the
    * output. On by default.
@@ -258,7 +259,7 @@ public:
   vtkSetMacro(PassFieldArrays, bool);
   vtkBooleanMacro(PassFieldArrays, bool);
   vtkGetMacro(PassFieldArrays, bool);
-  //@}
+  ///@}
 
   /**
    * Get the MTime of this object also considering the locator and kernel.
@@ -311,4 +312,5 @@ private:
   void operator=(const vtkPointInterpolator&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
