@@ -37,6 +37,7 @@
 #include "vtkSmartPointer.h"
 #include "vtkStaticPointLocator.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPointSmoothingFilter);
 
 vtkCxxSetObjectMacro(vtkPointSmoothingFilter, FrameFieldArray, vtkDataArray);
@@ -914,8 +915,14 @@ struct CharacterizeMesh
   void Reduce()
   {
     // Don't need scratch storage anymore
-    delete[] this->LocalNeiPoints.Local();
-    delete[] this->LocalNeiNormals.Local();
+    for (auto& iter : this->LocalNeiPoints)
+    {
+      delete[] iter;
+    }
+    for (auto& iter : this->LocalNeiNormals)
+    {
+      delete[] iter;
+    }
 
     // Min / max edge lengths
     double min = VTK_DOUBLE_MAX;
@@ -1084,7 +1091,13 @@ struct SmoothPoints
     } // for all points in this batch
   }   // operator()
 
-  void Reduce() { delete[] this->LocalNeiPoints.Local(); }
+  void Reduce()
+  {
+    for (auto& iter : this->LocalNeiPoints)
+    {
+      delete[] iter;
+    }
+  }
 
 }; // SmoothPoints
 
@@ -1247,7 +1260,7 @@ int vtkPointSmoothingFilter::RequestData(vtkInformation* vtkNotUsed(request),
   else if (smoothingMode == SCALAR_SMOOTHING)
   {
     double range[2];
-    inScalars->GetRange(range);
+    inPD->GetRange(inScalars->GetName(), range);
     disp =
       new ScalarDisplacement(inScalars, radius, this->PackingFactor, this->AttractionFactor, range);
   }
@@ -1387,3 +1400,4 @@ void vtkPointSmoothingFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Motion Constraint: " << this->MotionConstraint << "\n";
   os << indent << "Plane: " << this->Plane << "\n";
 }
+VTK_ABI_NAMESPACE_END
