@@ -33,12 +33,14 @@
 #include "vtkSMPThreadLocalObject.h"
 #include "vtkSMPTools.h"
 #include "vtkSPHQuinticKernel.h"
+#include "vtkSmartPointer.h"
 #include "vtkStaticPointLocator.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkVoronoiKernel.h"
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSPHInterpolator);
 vtkCxxSetObjectMacro(vtkSPHInterpolator, Locator, vtkAbstractPointLocator);
 vtkCxxSetObjectMacro(vtkSPHInterpolator, Kernel, vtkSPHKernel);
@@ -109,14 +111,14 @@ struct ProbePoints
       {
         vtkStdString outName = arrayName;
         outName += "_deriv";
-        if (vtkDataArray* outArray = this->DerivArrays.AddArrayPair(
-              array->GetNumberOfTuples(), array, outName, nullV, this->Promote))
+        if (vtkDataArray* outArray = vtkArrayDownCast<vtkDataArray>(this->DerivArrays.AddArrayPair(
+              array->GetNumberOfTuples(), array, outName, nullV, this->Promote)))
         {
           outPD->AddArray(outArray);
         }
       }
     }
-    this->ComputeDerivArrays = (!this->DerivArrays.Arrays.empty() ? true : false);
+    this->ComputeDerivArrays = !this->DerivArrays.Arrays.empty();
   }
 
   // Just allocate a little bit of memory to get started.
@@ -324,6 +326,7 @@ void vtkSPHInterpolator::Probe(vtkDataSet* input, vtkDataSet* source, vtkDataSet
 
   // Set up the interpolation process
   vtkIdType numPts = input->GetNumberOfPoints();
+  vtkPointData* inputPD = input->GetPointData();
   vtkPointData* sourcePD = source->GetPointData();
   vtkPointData* outPD = output->GetPointData();
 
@@ -345,21 +348,22 @@ void vtkSPHInterpolator::Probe(vtkDataSet* input, vtkDataSet* source, vtkDataSet
   }
 
   // Shepard summation if requested
-  vtkTypeBool computeShepardSum = this->ComputeShepardSum || this->ShepardNormalization;
+  vtkSmartPointer<vtkFloatArray> shepardSumArray;
   float* shepardArray = nullptr;
-  if (computeShepardSum)
+  if (this->ComputeShepardSum || this->ShepardNormalization)
   {
-    this->ShepardSumArray = vtkFloatArray::New();
-    this->ShepardSumArray->SetNumberOfTuples(numPts);
-    shepardArray = this->ShepardSumArray->GetPointer(0);
+    shepardSumArray = vtkSmartPointer<vtkFloatArray>::New();
+    shepardSumArray->SetName(this->ShepardSumArrayName.c_str());
+    shepardSumArray->SetNumberOfTuples(numPts);
+    shepardArray = shepardSumArray->GetPointer(0);
   }
 
   // Initialize the SPH kernel
   if (this->Kernel->GetRequiresInitialization())
   {
-    this->Kernel->SetCutoffArray(sourcePD->GetArray(this->CutoffArrayName));
-    this->Kernel->SetDensityArray(sourcePD->GetArray(this->DensityArrayName));
-    this->Kernel->SetMassArray(sourcePD->GetArray(this->MassArrayName));
+    this->Kernel->SetCutoffArray(inputPD->GetArray(this->CutoffArrayName.c_str()));
+    this->Kernel->SetDensityArray(sourcePD->GetArray(this->DensityArrayName.c_str()));
+    this->Kernel->SetMassArray(sourcePD->GetArray(this->MassArrayName.c_str()));
     this->Kernel->Initialize(this->Locator, source, sourcePD);
   }
 
@@ -383,22 +387,19 @@ void vtkSPHInterpolator::Probe(vtkDataSet* input, vtkDataSet* source, vtkDataSet
           vtkTemplateMacro(NormalizeArray<VTK_TT>::Execute(
             numPts, (VTK_TT*)ptr, da->GetNumberOfComponents(), shepardArray));
         }
-      } // not denisty array
+      } // not density array
     }   // for all arrays
   }     // if Shepard normalization
 
   // Clean up
-  if (this->ShepardSumArray)
+  if (shepardSumArray)
   {
-    this->ShepardSumArray->SetName(this->ShepardSumArrayName);
-    outPD->AddArray(this->ShepardSumArray);
-    this->ShepardSumArray->Delete();
-    this->ShepardSumArray = nullptr;
+    outPD->AddArray(shepardSumArray);
   }
 
   if (mask)
   {
-    this->ValidPointsMask->SetName(this->ValidPointsMaskArrayName);
+    this->ValidPointsMask->SetName(this->ValidPointsMaskArrayName.c_str());
     outPD->AddArray(this->ValidPointsMask);
     this->ValidPointsMask->Delete();
     this->ValidPointsMask = nullptr;
@@ -562,12 +563,10 @@ void vtkSPHInterpolator::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Null Points Strategy: " << this->NullPointsStrategy << endl;
   os << indent << "Null Value: " << this->NullValue << "\n";
-  os << indent << "Valid Points Mask Array Name: "
-     << (this->ValidPointsMaskArrayName ? this->ValidPointsMaskArrayName : "(none)") << "\n";
+  os << indent << "Valid Points Mask Array Name: " << this->ValidPointsMaskArrayName << "\n";
 
   os << indent << "Compute Shepard Sum: " << (this->ComputeShepardSum ? "On" : " Off") << "\n";
-  os << indent << "Shepard Sum Array Name: "
-     << (this->ShepardSumArrayName ? this->ShepardSumArrayName : "(none)") << "\n";
+  os << indent << "Shepard Sum Array Name: " << this->ShepardSumArrayName << "\n";
 
   os << indent << "Promote Output Arrays: " << (this->PromoteOutputArrays ? "On" : " Off") << "\n";
 
@@ -577,3 +576,4 @@ void vtkSPHInterpolator::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Shepard Normalization: " << (this->ShepardNormalization ? "On" : " Off") << "\n";
 }
+VTK_ABI_NAMESPACE_END
