@@ -41,20 +41,21 @@
 #include "vtkSPHKernel.h"
 #include <algorithm> // For std::min()
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkDoubleArray;
 
 class VTKFILTERSPOINTS_EXPORT vtkSPHQuarticKernel : public vtkSPHKernel
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, obtaining type information, and printing.
    */
   static vtkSPHQuarticKernel* New();
   vtkTypeMacro(vtkSPHQuarticKernel, vtkSPHKernel);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Produce the computational parameters for the kernel. Invoke this method
@@ -62,33 +63,33 @@ public:
    */
   void Initialize(vtkAbstractPointLocator* loc, vtkDataSet* ds, vtkPointData* pd) override;
 
-  //@{
+  ///@{
   /**
    * Compute weighting factor given a normalized distance from a sample point.
    */
   double ComputeFunctionWeight(const double d) override
   {
-    double tmp1 = 2.5 - std::min(d, 2.5);
-    double tmp2 = 1.5 - std::min(d, 1.5);
-    double tmp3 = 0.5 - std::min(d, 0.5);
+    double tmp1 = 2.5 - (std::min)(d, 2.5);
+    double tmp2 = 1.5 - (std::min)(d, 1.5);
+    double tmp3 = 0.5 - (std::min)(d, 0.5);
     return (tmp1 * tmp1 * tmp1 * tmp1 - 5.0 * tmp2 * tmp2 * tmp2 * tmp2 +
       10.0 * tmp3 * tmp3 * tmp3 * tmp3);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Compute weighting factor for derivative quantities given a normalized
    * distance from a sample point.
    */
   double ComputeDerivWeight(const double d) override
   {
-    double tmp1 = 2.5 - std::min(d, 2.5);
-    double tmp2 = 1.5 - std::min(d, 1.5);
-    double tmp3 = 0.5 - std::min(d, 0.5);
+    double tmp1 = 2.5 - (std::min)(d, 2.5);
+    double tmp2 = 1.5 - (std::min)(d, 1.5);
+    double tmp3 = 0.5 - (std::min)(d, 0.5);
     return (-4.0 * tmp1 * tmp1 * tmp1 + 20.0 * tmp2 * tmp2 * tmp2 - 40.0 * tmp3 * tmp3 * tmp3);
   }
-  //@}
+  ///@}
 
 protected:
   vtkSPHQuarticKernel();
@@ -99,4 +100,5 @@ private:
   void operator=(const vtkSPHQuarticKernel&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
