@@ -36,7 +36,7 @@
  * This filter has one other unusual capability: it is possible to append
  * data in a sequence of operations to generate a single output. This is
  * useful when you have multiple point clouds (e.g., possibly from multiple
- * acqusition scans) and want to incrementally accumulate all the data.
+ * acquisition scans) and want to incrementally accumulate all the data.
  * However, the user must be careful to either specify the Bounds or
  * order the input such that the bounds of the first input completely
  * contains all other input data.  This is because the geometry and topology
@@ -72,13 +72,14 @@
 #include "vtkFiltersPointsModule.h" // For export macro
 #include "vtkImageAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPolyData;
 class vtkAbstractPointLocator;
 
 class VTKFILTERSPOINTS_EXPORT vtkSignedDistance : public vtkImageAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiating the class, providing type information,
    * and printing.
@@ -86,27 +87,27 @@ public:
   static vtkSignedDistance* New();
   vtkTypeMacro(vtkSignedDistance, vtkImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the i-j-k dimensions on which to computer the distance function.
    */
   vtkGetVectorMacro(Dimensions, int, 3);
   void SetDimensions(int i, int j, int k);
   void SetDimensions(const int dim[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / get the region in space in which to perform the sampling. If
    * not specified, it will be computed automatically.
    */
   vtkSetVector6Macro(Bounds, double);
   vtkGetVectorMacro(Bounds, double, 6);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / get the radius of influence of each point. Smaller values
    * generally improve performance markedly. Note that after the signed
@@ -115,9 +116,9 @@ public:
    */
   vtkSetClampMacro(Radius, double, 0.0, VTK_FLOAT_MAX);
   vtkGetMacro(Radius, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a point locator. By default a vtkStaticPointLocator is
    * used. The locator performs efficient searches to locate points
@@ -125,7 +126,7 @@ public:
    */
   void SetLocator(vtkAbstractPointLocator* locator);
   vtkGetObjectMacro(Locator, vtkAbstractPointLocator);
-  //@}
+  ///@}
 
   /**
    * Initialize the filter for appending data. You must invoke the
@@ -174,4 +175,5 @@ private:
   void operator=(const vtkSignedDistance&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
