@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkUnsignedDistance.h
+  Module:    vtkUnsignedDistance.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -29,6 +29,7 @@
 #include "vtkStaticPointLocator.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkUnsignedDistance);
 vtkCxxSetObjectMacro(vtkUnsignedDistance, Locator, vtkAbstractPointLocator);
 
@@ -119,7 +120,7 @@ void ComputeModelBounds(vtkPolyData* input, int dims[3], int adjustBounds, doubl
     (modelBounds[0] < modelBounds[1] && modelBounds[2] < modelBounds[3] &&
       modelBounds[4] < modelBounds[5]))
   {
-    ; // do nothing
+    // do nothing
   }
 
   else // automatically adjust the bounds
@@ -532,3 +533,4 @@ void vtkUnsignedDistance::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Locator: " << this->Locator << "\n";
 }
+VTK_ABI_NAMESPACE_END
