@@ -35,20 +35,21 @@
 #include "vtkFiltersPointsModule.h" // For export macro
 #include "vtkInterpolationKernel.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkDoubleArray;
 
 class VTKFILTERSPOINTS_EXPORT vtkVoronoiKernel : public vtkInterpolationKernel
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, obtaining type information, and printing.
    */
   static vtkVoronoiKernel* New();
   vtkTypeMacro(vtkVoronoiKernel, vtkInterpolationKernel);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Given a point x (and optional associated ptId), determine the points
@@ -79,4 +80,5 @@ private:
   void operator=(const vtkVoronoiKernel&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
