@@ -28,10 +28,11 @@
 #include <algorithm>
 #include <boost/pending/disjoint_sets.hpp>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 //------------------------------------------------------------------------------
-inline static bool vtkReebGraphVertexSoS(
+inline bool vtkReebGraphVertexSoS(
   const std::pair<int, double>& v0, const std::pair<int, double>& v1)
 {
   return ((v0.second < v1.second) || ((v0.second == v1.second) && (v0.first < v1.first)));
@@ -264,7 +265,7 @@ int vtkReebGraphToJoinSplitTreeFilter::RequestData(vtkInformation* vtkNotUsed(re
       // prepare the unionFind
       std::vector<int> rank(vertexList.size());
       std::vector<int> parent(vertexList.size());
-      boost::disjoint_sets<int*, int*> unionFind(&rank[0], &parent[0]);
+      boost::disjoint_sets<int*, int*> unionFind(rank.data(), parent.data());
 
       // enables a compressed usage of the UF
       std::vector<int> vertexToUFQueryMap(vertexList.size());
@@ -307,7 +308,7 @@ int vtkReebGraphToJoinSplitTreeFilter::RequestData(vtkInformation* vtkNotUsed(re
               // twice.
               //
               // High-index degenerate merge have a very very low probability of
-              // appearance which is roughly inversely proportionnal to way more
+              // appearance which is roughly inversely proportional to way more
               // than its index.
               if (representatives[k] == representative)
               {
@@ -430,3 +431,4 @@ int vtkReebGraphToJoinSplitTreeFilter::RequestData(vtkInformation* vtkNotUsed(re
   }
   return 0;
 }
+VTK_ABI_NAMESPACE_END
