@@ -30,6 +30,7 @@
 #include "vtkUnstructuredGrid.h"
 #include "vtkVariantArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkReebGraphVolumeSkeletonFilter);
 
 //------------------------------------------------------------------------------
@@ -112,7 +113,7 @@ int vtkReebGraphVolumeSkeletonFilter::RequestData(vtkInformation* vtkNotUsed(req
     if (output)
     {
 
-      // Retrieve the information regarding the critical noes.
+      // Retrieve the information regarding the critical nodes.
       vtkDataArray* vertexInfo =
         vtkArrayDownCast<vtkDataArray>(inputGraph->GetVertexData()->GetAbstractArray("Vertex Ids"));
       if (!vertexInfo)
@@ -364,3 +365,4 @@ int vtkReebGraphVolumeSkeletonFilter::RequestData(vtkInformation* vtkNotUsed(req
   }
   return 0;
 }
+VTK_ABI_NAMESPACE_END
