@@ -17,34 +17,35 @@
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkDataArray.h"
+#include "vtkDemandDrivenPipeline.h"
 #include "vtkGenericCell.h"
+#include "vtkInformation.h"
+#include "vtkInformationVector.h"
+#include "vtkMergePoints.h"
+#include "vtkMultiBlockDataSet.h"
+#include "vtkMultiPieceDataSet.h"
 #include "vtkNew.h"
 #include "vtkNonMergingPointLocator.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
-#include "vtkSmartPointer.h"
-#include "vtkUnstructuredGrid.h"
-#include "vtkMergePoints.h"
-#include "vtkMultiBlockDataSet.h"
-#include "vtkMultiPieceDataSet.h"
-#include "vtkSMPTools.h"
-#include "vtkSMPThreadLocal.h"
-#include "vtkSMPThreadLocalObject.h"
-#include "vtkInformation.h"
 #include "vtkSMPMergePoints.h"
 #include "vtkSMPMergePolyDataHelper.h"
-#include "vtkInformationVector.h"
-#include "vtkDemandDrivenPipeline.h"
+#include "vtkSMPThreadLocal.h"
+#include "vtkSMPThreadLocalObject.h"
+#include "vtkSMPTools.h"
+#include "vtkSmartPointer.h"
 #include "vtkSpanSpace.h"
+#include "vtkUnstructuredGrid.h"
 
 #include "vtkTimerLog.h"
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSMPContourGrid);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct object with initial range (0,1) and single contour value
 // of 0.0.
 vtkSMPContourGrid::vtkSMPContourGrid()
@@ -52,10 +53,10 @@ vtkSMPContourGrid::vtkSMPContourGrid()
   this->MergePieces = true;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSMPContourGrid::~vtkSMPContourGrid() = default;
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This is to support parallel processing and potential polydata merging.
 namespace
 {
@@ -64,16 +65,20 @@ struct vtkLocalDataType
 {
   vtkPolyData* Output;
   vtkSMPMergePoints* Locator;
-  vtkIdList* VertOffsets;
-  vtkIdList* LineOffsets;
-  vtkIdList* PolyOffsets;
+  vtkIdList* VertCellOffsets;
+  vtkIdList* VertConnOffsets;
+  vtkIdList* LineCellOffsets;
+  vtkIdList* LineConnOffsets;
+  vtkIdList* PolyCellOffsets;
+  vtkIdList* PolyConnOffsets;
 
-  vtkLocalDataType() : Output(nullptr)
+  vtkLocalDataType()
+    : Output(nullptr)
   {
   }
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This functor uses thread local storage to create one vtkPolyData per
 // thread. Each execution of the functor adds to the vtkPolyData that is
 // local to the thread it is running on.
@@ -101,17 +106,14 @@ public:
   int NumValues;
   double* Values;
 
-  vtkContourGridFunctor(vtkSMPContourGrid* filter,
-                        vtkUnstructuredGrid* input,
-                        vtkDataArray* inScalars,
-                        int numValues,
-                        double* values,
-                        vtkDataObject* output) : Filter(filter),
-                                                 Input(input),
-                                                 InScalars(inScalars),
-                                                 Output(output),
-                                                 NumValues(numValues),
-                                                 Values(values)
+  vtkContourGridFunctor(vtkSMPContourGrid* filter, vtkUnstructuredGrid* input,
+    vtkDataArray* inScalars, int numValues, double* values, vtkDataObject* output)
+    : Filter(filter)
+    , Input(input)
+    , InScalars(inScalars)
+    , Output(output)
+    , NumValues(numValues)
+    , Values(values)
   {
   }
 
@@ -119,23 +121,24 @@ public:
   {
     // Cleanup all temporaries
 
-    vtkSMPThreadLocal<vtkDataArray*>::iterator cellScalarsIter =
-      this->CellScalars.begin();
-    while(cellScalarsIter != this->CellScalars.end())
+    vtkSMPThreadLocal<vtkDataArray*>::iterator cellScalarsIter = this->CellScalars.begin();
+    while (cellScalarsIter != this->CellScalars.end())
     {
       (*cellScalarsIter)->Delete();
       ++cellScalarsIter;
     }
 
-    vtkSMPThreadLocal<vtkLocalDataType>::iterator dataIter =
-      this->LocalData.begin();
-    while(dataIter != this->LocalData.end())
+    vtkSMPThreadLocal<vtkLocalDataType>::iterator dataIter = this->LocalData.begin();
+    while (dataIter != this->LocalData.end())
     {
       (*dataIter).Output->Delete();
       (*dataIter).Locator->Delete();
-      (*dataIter).VertOffsets->Delete();
-      (*dataIter).LineOffsets->Delete();
-      (*dataIter).PolyOffsets->Delete();
+      (*dataIter).VertCellOffsets->Delete();
+      (*dataIter).VertConnOffsets->Delete();
+      (*dataIter).LineCellOffsets->Delete();
+      (*dataIter).LineConnOffsets->Delete();
+      (*dataIter).PolyCellOffsets->Delete();
+      (*dataIter).PolyConnOffsets->Delete();
       ++dataIter;
     }
   }
@@ -147,9 +150,12 @@ public:
 
     vtkPointLocator* locator;
     vtkPolyData* output;
-    vtkIdList* vertOffsets;
-    vtkIdList* lineOffsets;
-    vtkIdList* polyOffsets;
+    vtkIdList* vertCellOffsets;
+    vtkIdList* vertConnOffsets;
+    vtkIdList* lineCellOffsets;
+    vtkIdList* lineConnOffsets;
+    vtkIdList* polyCellOffsets;
+    vtkIdList* polyConnOffsets;
 
     vtkLocalDataType& localData = this->LocalData.Local();
 
@@ -159,27 +165,33 @@ public:
     localData.Locator = vtkSMPMergePoints::New();
     locator = localData.Locator;
 
-    localData.VertOffsets = vtkIdList::New();
-    vertOffsets = localData.VertOffsets;
+    localData.VertCellOffsets = vtkIdList::New();
+    vertCellOffsets = localData.VertCellOffsets;
+    localData.VertConnOffsets = vtkIdList::New();
+    vertConnOffsets = localData.VertConnOffsets;
 
-    localData.LineOffsets = vtkIdList::New();
-    lineOffsets = localData.LineOffsets;
+    localData.LineCellOffsets = vtkIdList::New();
+    lineCellOffsets = localData.LineCellOffsets;
+    localData.LineConnOffsets = vtkIdList::New();
+    lineConnOffsets = localData.LineConnOffsets;
 
-    localData.PolyOffsets = vtkIdList::New();
-    polyOffsets = localData.PolyOffsets;
+    localData.PolyCellOffsets = vtkIdList::New();
+    polyCellOffsets = localData.PolyCellOffsets;
+    localData.PolyConnOffsets = vtkIdList::New();
+    polyConnOffsets = localData.PolyConnOffsets;
 
     vtkPoints*& newPts = this->NewPts.Local();
 
     // set precision for the points in the output
-    if(this->Filter->GetOutputPointsPrecision() == vtkAlgorithm::DEFAULT_PRECISION)
+    if (this->Filter->GetOutputPointsPrecision() == vtkAlgorithm::DEFAULT_PRECISION)
     {
       newPts->SetDataType(this->Input->GetPoints()->GetDataType());
     }
-    else if(this->Filter->GetOutputPointsPrecision() == vtkAlgorithm::SINGLE_PRECISION)
+    else if (this->Filter->GetOutputPointsPrecision() == vtkAlgorithm::SINGLE_PRECISION)
     {
       newPts->SetDataType(VTK_FLOAT);
     }
-    else if(this->Filter->GetOutputPointsPrecision() == vtkAlgorithm::DOUBLE_PRECISION)
+    else if (this->Filter->GetOutputPointsPrecision() == vtkAlgorithm::DOUBLE_PRECISION)
     {
       newPts->SetDataType(VTK_DOUBLE);
     }
@@ -188,9 +200,8 @@ public:
 
     vtkIdType numCells = this->Input->GetNumberOfCells();
 
-    vtkIdType estimatedSize=static_cast<vtkIdType>(
-      pow(static_cast<double>(numCells),.75));
-    estimatedSize = estimatedSize / 1024 * 1024; //multiple of 1024
+    vtkIdType estimatedSize = static_cast<vtkIdType>(pow(static_cast<double>(numCells), .75));
+    estimatedSize = estimatedSize / 1024 * 1024; // multiple of 1024
     if (estimatedSize < 1024)
     {
       estimatedSize = 1024;
@@ -198,31 +209,32 @@ public:
 
     newPts->Allocate(estimatedSize, estimatedSize);
 
-    vertOffsets->Allocate(estimatedSize);
-    lineOffsets->Allocate(estimatedSize);
-    polyOffsets->Allocate(estimatedSize);
+    vertCellOffsets->Allocate(estimatedSize);
+    vertConnOffsets->Allocate(estimatedSize);
+    lineCellOffsets->Allocate(estimatedSize);
+    lineConnOffsets->Allocate(estimatedSize);
+    polyCellOffsets->Allocate(estimatedSize);
+    polyConnOffsets->Allocate(estimatedSize);
 
-    //locator->SetPoints(newPts);
-    locator->InitPointInsertion (newPts,
-                                 this->Input->GetBounds(),
-                                 this->Input->GetNumberOfPoints());
+    // locator->SetPoints(newPts);
+    locator->InitPointInsertion(newPts, this->Input->GetBounds(), this->Input->GetNumberOfPoints());
 
     vtkCellArray*& newVerts = this->NewVerts.Local();
-    newVerts->Allocate(estimatedSize,estimatedSize);
+    newVerts->AllocateExact(estimatedSize, estimatedSize);
     output->SetVerts(newVerts);
 
     vtkCellArray*& newLines = this->NewLines.Local();
-    newLines->Allocate(estimatedSize,estimatedSize);
+    newLines->AllocateExact(estimatedSize, estimatedSize);
     output->SetLines(newLines);
 
     vtkCellArray*& newPolys = this->NewPolys.Local();
-    newPolys->Allocate(estimatedSize,estimatedSize);
+    newPolys->AllocateExact(estimatedSize, estimatedSize);
     output->SetPolys(newPolys);
 
     vtkDataArray*& cellScalars = this->CellScalars.Local();
     cellScalars = this->InScalars->NewInstance();
     cellScalars->SetNumberOfComponents(this->InScalars->GetNumberOfComponents());
-    cellScalars->Allocate(VTK_CELL_SIZE*this->InScalars->GetNumberOfComponents());
+    cellScalars->Allocate(VTK_CELL_SIZE * this->InScalars->GetNumberOfComponents());
 
     vtkPointData* outPd = output->GetPointData();
     vtkCellData* outCd = output->GetCellData();
@@ -256,9 +268,12 @@ public:
 
     vtkPointLocator* loc = localData.Locator;
 
-    vtkIdList* vertOffsets = localData.VertOffsets;
-    vtkIdList* lineOffsets = localData.LineOffsets;
-    vtkIdList* polyOffsets = localData.PolyOffsets;
+    vtkIdList* vertCellOffsets = localData.VertCellOffsets;
+    vtkIdList* vertConnOffsets = localData.VertConnOffsets;
+    vtkIdList* lineCellOffsets = localData.LineCellOffsets;
+    vtkIdList* lineConnOffsets = localData.LineConnOffsets;
+    vtkIdList* polyCellOffsets = localData.PolyCellOffsets;
+    vtkIdList* polyConnOffsets = localData.PolyConnOffsets;
 
     const double* values = this->Values;
     int numValues = this->NumValues;
@@ -266,70 +281,70 @@ public:
     vtkNew<vtkIdList> pids;
     T range[2];
     vtkIdType cellid;
+    bool isFirst = vtkSMPTools::GetSingleThread();
 
     // If UseScalarTree is enabled at this point, we assume that a scalar
     // tree has been computed and thus the way cells are traversed changes.
-    if ( ! this->Filter->GetUseScalarTree() )
+    if (!this->Filter->GetUseScalarTree())
     {
       // This code assumes no scalar tree, thus it checks scalar range prior
       // to invoking contour.
-      for ( cellid=begin; cellid < end; cellid++)
+      for (cellid = begin; cellid < end; cellid++)
       {
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
         this->Input->GetCellPoints(cellid, pids);
         cs->SetNumberOfTuples(pids->GetNumberOfIds());
         this->InScalars->GetTuples(pids, cs);
-        int numCellScalars = cs->GetNumberOfComponents() *
-          cs->GetNumberOfTuples();
+        int numCellScalars = cs->GetNumberOfComponents() * cs->GetNumberOfTuples();
         T* cellScalarPtr = static_cast<T*>(cs->GetVoidPointer(0));
 
-        //find min and max values in scalar data
+        // find min and max values in scalar data
         range[0] = range[1] = cellScalarPtr[0];
 
-        for (T *it = cellScalarPtr + 1, *itEnd = cellScalarPtr + numCellScalars;
-             it != itEnd;
-             ++it)
+        for (T *it = cellScalarPtr + 1, *itEnd = cellScalarPtr + numCellScalars; it != itEnd; ++it)
         {
           if (*it < range[0])
           {
             range[0] = *it;
-          } //if scalar <= min range value
+          } // if scalar <= min range value
           if (*it > range[1])
           {
             range[1] = *it;
-          } //if scalar >= max range value
-        } // for all cellScalars
+          } // if scalar >= max range value
+        }   // for all cellScalars
 
         bool needCell = false;
         for (int i = 0; i < numValues; i++)
         {
           if ((values[i] >= range[0]) && (values[i] <= range[1]))
           {
-             needCell = true;
+            needCell = true;
           } // if contour value in range for this cell
-        } // end for numContours
+        }   // end for numContours
 
         if (needCell)
         {
           this->Input->GetCell(cellid, cell);
 
-          for (int i=0; i < numValues; i++)
+          for (int i = 0; i < numValues; i++)
           {
             if ((values[i] >= range[0]) && (values[i] <= range[1]))
             {
-              vtkIdType begVertSize = vrts->GetNumberOfConnectivityEntries();
-              vtkIdType begLineSize = lines->GetNumberOfConnectivityEntries();
-              vtkIdType begPolySize = polys->GetNumberOfConnectivityEntries();
-              cell->Contour(values[i],
-                            cs,
-                            loc,
-                            vrts,
-                            lines,
-                            polys,
-                            inPd,
-                            outPd,
-                            inCd,
-                            cellid,
-                            outCd);
+              vtkIdType begVertCellSize = vrts->GetNumberOfCells();
+              vtkIdType begVertConnSize = vrts->GetNumberOfConnectivityIds();
+              vtkIdType begLineCellSize = lines->GetNumberOfCells();
+              vtkIdType begLineConnSize = lines->GetNumberOfConnectivityIds();
+              vtkIdType begPolyCellSize = polys->GetNumberOfCells();
+              vtkIdType begPolyConnSize = polys->GetNumberOfConnectivityIds();
+              cell->Contour(
+                values[i], cs, loc, vrts, lines, polys, inPd, outPd, inCd, cellid, outCd);
               // We keep track of the insertion point of verts, lines and polys.
               // This is later used when merging these data structures in parallel.
               // The reason this is needed is that vtkCellArray is not normally
@@ -337,58 +352,72 @@ public:
               // So we create a semi-random-access structures in parallel. This
               // is only useful for merging since each of these indices can point
               // to multiple cells.
-              if (vrts->GetNumberOfConnectivityEntries() > begVertSize)
+              if (vrts->GetNumberOfCells() > begVertCellSize)
               {
-                vertOffsets->InsertNextId(begVertSize);
+                vertCellOffsets->InsertNextId(begVertCellSize);
               }
-              if (lines->GetNumberOfConnectivityEntries() > begLineSize)
+              if (vrts->GetNumberOfConnectivityIds() > begVertConnSize)
               {
-                lineOffsets->InsertNextId(begLineSize);
+                vertConnOffsets->InsertNextId(begVertConnSize);
               }
-              if (polys->GetNumberOfConnectivityEntries() > begPolySize)
+              if (lines->GetNumberOfCells() > begLineCellSize)
               {
-                polyOffsets->InsertNextId(begPolySize);
+                lineCellOffsets->InsertNextId(begLineCellSize);
+              }
+              if (lines->GetNumberOfConnectivityIds() > begLineConnSize)
+              {
+                lineConnOffsets->InsertNextId(begLineConnSize);
+              }
+              if (polys->GetNumberOfCells() > begPolyCellSize)
+              {
+                polyCellOffsets->InsertNextId(begPolyCellSize);
+              }
+              if (polys->GetNumberOfConnectivityIds() > begPolyConnSize)
+              {
+                polyConnOffsets->InsertNextId(begPolyConnSize);
               }
             }
           }
-        }//if cell need be contoured
-      }//for all cells
-    }//if no scalar tree requested
+        } // if cell need be contoured
+      }   // for all cells
+    }     // if no scalar tree requested
     else
-    {//scalar tree provided
+    { // scalar tree provided
       // The begin / end parameters to this function represent batches of candidate
       // cells.
-      vtkIdType numCellsContoured=0;
-      vtkScalarTree *scalarTree = this->Filter->GetScalarTree();
-      const vtkIdType *cellIds;
+      vtkIdType numCellsContoured = 0;
+      vtkScalarTree* scalarTree = this->Filter->GetScalarTree();
+      const vtkIdType* cellIds;
       vtkIdType numCells;
-      for ( vtkIdType batchNum=begin; batchNum < end; ++batchNum)
+      for (vtkIdType batchNum = begin; batchNum < end; ++batchNum)
       {
-        cellIds = scalarTree->GetCellBatch(batchNum,numCells);
-        for (vtkIdType idx=0; idx < numCells; ++idx)
+        if (isFirst)
+        {
+          this->Filter->CheckAbort();
+        }
+        if (this->Filter->GetAbortOutput())
+        {
+          break;
+        }
+        cellIds = scalarTree->GetCellBatch(batchNum, numCells);
+        for (vtkIdType idx = 0; idx < numCells; ++idx)
         {
           cellid = cellIds[idx];
           this->Input->GetCellPoints(cellid, pids);
           cs->SetNumberOfTuples(pids->GetNumberOfIds());
           this->InScalars->GetTuples(pids, cs);
 
-          //Okay let's grab the cell and contour it
+          // Okay let's grab the cell and contour it
           numCellsContoured++;
           this->Input->GetCell(cellid, cell);
-          vtkIdType begVertSize = vrts->GetNumberOfConnectivityEntries();
-          vtkIdType begLineSize = lines->GetNumberOfConnectivityEntries();
-          vtkIdType begPolySize = polys->GetNumberOfConnectivityEntries();
-          cell->Contour(scalarTree->GetScalarValue(),
-                        cs,
-                        loc,
-                        vrts,
-                        lines,
-                        polys,
-                        inPd,
-                        outPd,
-                        inCd,
-                        cellid,
-                        outCd);
+          vtkIdType begVertCellSize = vrts->GetNumberOfCells();
+          vtkIdType begVertConnSize = vrts->GetNumberOfConnectivityIds();
+          vtkIdType begLineCellSize = lines->GetNumberOfCells();
+          vtkIdType begLineConnSize = lines->GetNumberOfConnectivityIds();
+          vtkIdType begPolyCellSize = polys->GetNumberOfCells();
+          vtkIdType begPolyConnSize = polys->GetNumberOfConnectivityIds();
+          cell->Contour(scalarTree->GetScalarValue(), cs, loc, vrts, lines, polys, inPd, outPd,
+            inCd, cellid, outCd);
           // We keep track of the insertion point of verts, lines and polys.
           // This is later used when merging these data structures in parallel.
           // The reason this is needed is that vtkCellArray is not normally
@@ -396,23 +425,35 @@ public:
           // So we create a semi-random-access structures in parallel. This
           // is only useful for merging since each of these indices can point
           // to multiple cells.
-          if (vrts->GetNumberOfConnectivityEntries() > begVertSize)
+          if (vrts->GetNumberOfCells() > begVertCellSize)
           {
-            vertOffsets->InsertNextId(begVertSize);
+            vertCellOffsets->InsertNextId(begVertCellSize);
           }
-          if (lines->GetNumberOfConnectivityEntries() > begLineSize)
+          if (vrts->GetNumberOfConnectivityIds() > begVertConnSize)
           {
-            lineOffsets->InsertNextId(begLineSize);
+            vertConnOffsets->InsertNextId(begVertConnSize);
           }
-          if (polys->GetNumberOfConnectivityEntries() > begPolySize)
+          if (lines->GetNumberOfCells() > begLineCellSize)
           {
-            polyOffsets->InsertNextId(begPolySize);
+            lineCellOffsets->InsertNextId(begLineCellSize);
           }
-        }//for all cells in this batch
-      }//for this batch of cells
-    }//using scalar tree
+          if (lines->GetNumberOfConnectivityIds() > begLineConnSize)
+          {
+            lineConnOffsets->InsertNextId(begLineConnSize);
+          }
+          if (polys->GetNumberOfCells() > begPolyCellSize)
+          {
+            polyCellOffsets->InsertNextId(begPolyCellSize);
+          }
+          if (polys->GetNumberOfConnectivityIds() > begPolyConnSize)
+          {
+            polyConnOffsets->InsertNextId(begPolyConnSize);
+          }
+        } // for all cells in this batch
+      }   // for this batch of cells
+    }     // using scalar tree
 
-  }//operator()
+  } // operator()
 
   void Reduce()
   {
@@ -421,9 +462,8 @@ public:
     vtkNew<vtkMultiPieceDataSet> mp;
     int count = 0;
 
-    vtkSMPThreadLocal<vtkLocalDataType>::iterator outIter =
-      this->LocalData.begin();
-    while(outIter != this->LocalData.end())
+    vtkSMPThreadLocal<vtkLocalDataType>::iterator outIter = this->LocalData.begin();
+    while (outIter != this->LocalData.end())
     {
       vtkPolyData* output = (*outIter).Output;
 
@@ -459,15 +499,10 @@ public:
   }
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
-void DoContour(vtkSMPContourGrid* filter,
-               vtkUnstructuredGrid* input,
-               vtkIdType numCells,
-               vtkDataArray* inScalars,
-               int numContours,
-               double* values,
-               vtkDataObject* output)
+void DoContour(vtkSMPContourGrid* filter, vtkUnstructuredGrid* input, vtkIdType numCells,
+  vtkDataArray* inScalars, int numContours, double* values, vtkDataObject* output)
 {
   // Contour in parallel; create the processing functor
   vtkContourGridFunctor<T> functor(filter, input, inScalars, numContours, values, output);
@@ -475,21 +510,21 @@ void DoContour(vtkSMPContourGrid* filter,
   // If a scalar tree is used, then the way in which cells are iterated over changes.
   // With a scalar tree, batches of candidate cells are provided. Without one, then all
   // cells are iterated over one by one.
-  if ( filter->GetUseScalarTree() )
-  {//process in threaded using scalar tree
-    vtkScalarTree *scalarTree = filter->GetScalarTree();
+  if (filter->GetUseScalarTree())
+  { // process in threaded using scalar tree
+    vtkScalarTree* scalarTree = filter->GetScalarTree();
     vtkIdType numBatches;
-    for (int i=0; i < numContours; ++i)
+    for (int i = 0; i < numContours; ++i)
     {
       numBatches = scalarTree->GetNumberOfCellBatches(values[i]);
-      if ( numBatches > 0 )
+      if (numBatches > 0)
       {
         vtkSMPTools::For(0, numBatches, functor);
       }
     }
   }
   else
-  {//process all cells in parallel manner
+  { // process all cells in parallel manner
     vtkSMPTools::For(0, numCells, functor);
   }
 
@@ -502,13 +537,11 @@ void DoContour(vtkSMPContourGrid* filter,
     vtkSMPThreadLocal<vtkLocalDataType>::iterator end = functor.LocalData.end();
 
     std::vector<vtkSMPMergePolyDataHelper::InputData> mpData;
-    while(itr != end)
+    while (itr != end)
     {
-      mpData.push_back(vtkSMPMergePolyDataHelper::InputData((*itr).Output,
-                                                            (*itr).Locator,
-                                                            (*itr).VertOffsets,
-                                                            (*itr).LineOffsets,
-                                                            (*itr).PolyOffsets));
+      mpData.emplace_back((*itr).Output, (*itr).Locator, (*itr).VertCellOffsets,
+        (*itr).VertConnOffsets, (*itr).LineCellOffsets, (*itr).LineConnOffsets,
+        (*itr).PolyCellOffsets, (*itr).PolyConnOffsets);
       ++itr;
     }
 
@@ -518,18 +551,16 @@ void DoContour(vtkSMPContourGrid* filter,
   }
 }
 
-}//end namespace
+} // end namespace
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSMPContourGrid::RequestDataObject(
-  vtkInformation* vtkNotUsed(request),
-  vtkInformationVector**,
-  vtkInformationVector* outputVector)
+  vtkInformation* vtkNotUsed(request), vtkInformationVector**, vtkInformationVector* outputVector)
 {
   vtkInformation* info = outputVector->GetInformationObject(0);
   if (this->MergePieces)
   {
-    vtkPolyData *output = vtkPolyData::GetData(info);
+    vtkPolyData* output = vtkPolyData::GetData(info);
     if (!output)
     {
       vtkPolyData* newOutput = vtkPolyData::New();
@@ -539,7 +570,7 @@ int vtkSMPContourGrid::RequestDataObject(
   }
   else
   {
-    vtkMultiBlockDataSet *output = vtkMultiBlockDataSet::GetData(info);
+    vtkMultiBlockDataSet* output = vtkMultiBlockDataSet::GetData(info);
     if (!output)
     {
       vtkMultiBlockDataSet* newOutput = vtkMultiBlockDataSet::New();
@@ -550,22 +581,20 @@ int vtkSMPContourGrid::RequestDataObject(
   return 1;
 }
 
-//-----------------------------------------------------------------------------
-int vtkSMPContourGrid::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+//------------------------------------------------------------------------------
+int vtkSMPContourGrid::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // get the input and output
-  vtkUnstructuredGrid *input = vtkUnstructuredGrid::GetData(inputVector[0]);
-  vtkDataObject *output = vtkDataObject::GetData(outputVector);
+  vtkUnstructuredGrid* input = vtkUnstructuredGrid::GetData(inputVector[0]);
+  vtkDataObject* output = vtkDataObject::GetData(outputVector);
 
   if (input->GetNumberOfCells() == 0)
   {
     return 1;
   }
 
-  vtkDataArray* inScalars = this->GetInputArrayToProcess(0,inputVector);
+  vtkDataArray* inScalars = this->GetInputArrayToProcess(0, inputVector);
   if (!inScalars)
   {
     return 1;
@@ -580,15 +609,15 @@ int vtkSMPContourGrid::RequestData(
     return 1;
   }
 
-  double *values=this->GetValues();
+  double* values = this->GetValues();
 
   vtkIdType numCells = input->GetNumberOfCells();
 
   // Create scalar tree if necessary and if requested
   int useScalarTree = this->GetUseScalarTree();
-  if ( useScalarTree )
+  if (useScalarTree)
   {
-    if ( this->ScalarTree == nullptr )
+    if (this->ScalarTree == nullptr)
     {
       this->ScalarTree = vtkSpanSpace::New();
     }
@@ -601,7 +630,7 @@ int vtkSMPContourGrid::RequestData(
   {
     DoContour<float>(this, input, numCells, inScalars, numContours, values, output);
   }
-  else if(inScalars->GetDataType() == VTK_DOUBLE)
+  else if (inScalars->GetDataType() == VTK_DOUBLE)
   {
     DoContour<double>(this, input, numCells, inScalars, numContours, values, output);
   }
@@ -609,21 +638,19 @@ int vtkSMPContourGrid::RequestData(
   return 1;
 }
 
-//-----------------------------------------------------------------------------
-int vtkSMPContourGrid::FillOutputPortInformation(
-  int vtkNotUsed(port), vtkInformation* info)
+//------------------------------------------------------------------------------
+int vtkSMPContourGrid::FillOutputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkDataObject");
   return 1;
 }
 
-//-----------------------------------------------------------------------------
-vtkTypeBool vtkSMPContourGrid::ProcessRequest(vtkInformation* request,
-                                      vtkInformationVector** inputVector,
-                                      vtkInformationVector* outputVector)
+//------------------------------------------------------------------------------
+vtkTypeBool vtkSMPContourGrid::ProcessRequest(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   // generate the data
-  if(request->Has(vtkDemandDrivenPipeline::REQUEST_DATA_OBJECT()))
+  if (request->Has(vtkDemandDrivenPipeline::REQUEST_DATA_OBJECT()))
   {
     return this->RequestDataObject(request, inputVector, outputVector);
   }
@@ -631,11 +658,11 @@ vtkTypeBool vtkSMPContourGrid::ProcessRequest(vtkInformation* request,
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSMPContourGrid::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Merge Pieces: "
-     << (this->MergePieces ? "On\n" : "Off\n");
+  os << indent << "Merge Pieces: " << (this->MergePieces ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
