@@ -38,13 +38,16 @@
 #include "vtkPointData.h"
 #include "vtkPoints.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkTriQuadraticPyramid.h"
 #include "vtkUnstructuredGrid.h"
 #include "vtkVector.h"
 #include "vtkVectorOperators.h"
 
 #include <map>
-typedef std::map<std::pair<vtkIdType, vtkIdType>, vtkIdType> EdgeToPointMap;
+using EdgeToPointMap = std::map<std::pair<vtkIdType, vtkIdType>, vtkIdType>;
+using TriangleFaceToPointMap = std::map<std::tuple<vtkIdType, vtkIdType, vtkIdType>, vtkIdType>;
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCellTypeSource);
 
 namespace
@@ -56,12 +59,12 @@ const int NumberOf2DCellTypes = 8;
 const int TwoDCellTypes[NumberOf2DCellTypes] = { VTK_TRIANGLE, VTK_QUAD, VTK_QUADRATIC_TRIANGLE,
   VTK_QUADRATIC_QUAD, VTK_LAGRANGE_TRIANGLE, VTK_LAGRANGE_QUADRILATERAL, VTK_BEZIER_TRIANGLE,
   VTK_BEZIER_QUADRILATERAL };
-const int NumberOf3DCellTypes = 16;
+const int NumberOf3DCellTypes = 17;
 const int ThreeDCellTypes[NumberOf3DCellTypes] = { VTK_TETRA, VTK_HEXAHEDRON, VTK_WEDGE,
   VTK_PYRAMID, VTK_PENTAGONAL_PRISM, VTK_HEXAGONAL_PRISM, VTK_QUADRATIC_TETRA,
-  VTK_QUADRATIC_HEXAHEDRON, VTK_QUADRATIC_WEDGE, VTK_QUADRATIC_PYRAMID, VTK_LAGRANGE_TETRAHEDRON,
-  VTK_LAGRANGE_HEXAHEDRON, VTK_LAGRANGE_WEDGE, VTK_BEZIER_TETRAHEDRON, VTK_BEZIER_HEXAHEDRON,
-  VTK_BEZIER_WEDGE };
+  VTK_QUADRATIC_HEXAHEDRON, VTK_QUADRATIC_WEDGE, VTK_QUADRATIC_PYRAMID, VTK_TRIQUADRATIC_PYRAMID,
+  VTK_LAGRANGE_TETRAHEDRON, VTK_LAGRANGE_HEXAHEDRON, VTK_LAGRANGE_WEDGE, VTK_BEZIER_TETRAHEDRON,
+  VTK_BEZIER_HEXAHEDRON, VTK_BEZIER_WEDGE };
 }
 
 //------------------------------------------------------------------------------
@@ -353,6 +356,11 @@ int vtkCellTypeSource::RequestData(vtkInformation* vtkNotUsed(request),
       this->GenerateQuadraticPyramids(output, extent);
       break;
     }
+    case VTK_TRIQUADRATIC_PYRAMID:
+    {
+      this->GenerateTriQuadraticPyramids(output, extent);
+      break;
+    }
     case VTK_LAGRANGE_CURVE:
     {
       this->GenerateLagrangeCurves(output, extent);
@@ -499,7 +507,8 @@ void vtkCellTypeSource::GenerateQuadraticTriangles(vtkUnstructuredGrid* output,
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+        vtkIdType mid;
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[horizontalEdge] = mid;
         mids[0] = mid;
       }
@@ -520,7 +529,8 @@ void vtkCellTypeSource::GenerateQuadraticTriangles(vtkUnstructuredGrid* output,
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+        vtkIdType mid;
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[verticalEdge] = mid;
         mids[2] = mid;
       }
@@ -536,7 +546,8 @@ void vtkCellTypeSource::GenerateQuadraticTriangles(vtkUnstructuredGrid* output,
       {
         point1[k] = (point1[k] + point2[k]) * .5;
       }
-      vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+      vtkIdType mid;
+      this->Locator->InsertUniquePoint(point1, mid);
       mids[1] = mid;
       vtkIdType cellPoints[6] = { i + j * (firstDim + 1), i + 1 + j * (firstDim + 1),
         i + (j + 1) * (firstDim + 1), mids[0], mids[1], mids[2] };
@@ -552,7 +563,7 @@ void vtkCellTypeSource::GenerateQuadraticTriangles(vtkUnstructuredGrid* output,
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        mid = output->GetPoints()->InsertNextPoint(point1);
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[horizontalEdge] = mid;
         mids[0] = mid;
       }
@@ -571,7 +582,7 @@ void vtkCellTypeSource::GenerateQuadraticTriangles(vtkUnstructuredGrid* output,
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        mid = output->GetPoints()->InsertNextPoint(point1);
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[verticalEdge] = mid;
         mids[2] = mid;
       }
@@ -610,7 +621,8 @@ void vtkCellTypeSource::GenerateQuadraticQuads(vtkUnstructuredGrid* output, int
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+        vtkIdType mid;
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[bottomEdge] = mid;
         pointIds[4] = mid;
       }
@@ -629,7 +641,8 @@ void vtkCellTypeSource::GenerateQuadraticQuads(vtkUnstructuredGrid* output, int
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+        vtkIdType mid;
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[rightEdge] = mid;
         pointIds[5] = mid;
       }
@@ -648,7 +661,8 @@ void vtkCellTypeSource::GenerateQuadraticQuads(vtkUnstructuredGrid* output, int
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+        vtkIdType mid;
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[topEdge] = mid;
         pointIds[6] = mid;
       }
@@ -667,7 +681,8 @@ void vtkCellTypeSource::GenerateQuadraticQuads(vtkUnstructuredGrid* output, int
         {
           point1[k] = (point1[k] + point2[k]) * .5;
         }
-        vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+        vtkIdType mid;
+        this->Locator->InsertUniquePoint(point1, mid);
         edgeToPointId[leftEdge] = mid;
         pointIds[7] = mid;
       }
@@ -1025,7 +1040,7 @@ void vtkCellTypeSource::GenerateQuadraticTetras(vtkUnstructuredGrid* output, int
         {
           point1[l] = .5 * (point1[l] + point2[l]);
         }
-        hexIds[8] = output->GetPoints()->InsertNextPoint(point1);
+        this->Locator->InsertUniquePoint(point1, hexIds[8]);
 
         vtkIdType tetraIds[12][10] = { { hexIds[0], hexIds[1], hexIds[2], hexIds[8], -1, -1, -1, -1,
                                          -1, -1 },
@@ -1055,7 +1070,8 @@ void vtkCellTypeSource::GenerateQuadraticTetras(vtkUnstructuredGrid* output, int
               {
                 point1[l] = (point1[l] + point2[l]) * .5;
               }
-              vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+              vtkIdType mid;
+              this->Locator->InsertUniquePoint(point1, mid);
               edgeToPointId[edge] = mid;
               tetraIds[c][4 + e] = mid;
             }
@@ -1139,7 +1155,8 @@ void vtkCellTypeSource::GenerateQuadraticHexahedron(vtkUnstructuredGrid* output,
             {
               point1[l] = (point1[l] + point2[l]) * .5;
             }
-            vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+            vtkIdType mid;
+            this->Locator->InsertUniquePoint(point1, mid);
             edgeToPointId[edge] = mid;
             hexIds[8 + e] = mid;
           }
@@ -1214,7 +1231,8 @@ void vtkCellTypeSource::GenerateQuadraticWedges(vtkUnstructuredGrid* output, int
               {
                 point1[l] = (point1[l] + point2[l]) * .5;
               }
-              vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+              vtkIdType mid;
+              this->Locator->InsertUniquePoint(point1, mid);
               edgeToPointId[edge] = mid;
               wedgeIds[c][6 + e] = mid;
             }
@@ -1294,8 +1312,7 @@ void vtkCellTypeSource::GenerateQuadraticPyramids(vtkUnstructuredGrid* output, i
         {
           point1[l] = .5 * (point1[l] + point2[l]);
         }
-        hexIds[8] = output->GetPoints()->InsertNextPoint(point1);
-
+        this->Locator->InsertUniquePoint(point1, hexIds[8]);
         vtkIdType pyramidIds[6][13] = {
           { hexIds[0], hexIds[1], hexIds[2], hexIds[3], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1 },
           { hexIds[6], hexIds[5], hexIds[4], hexIds[7], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1 },
@@ -1320,7 +1337,8 @@ void vtkCellTypeSource::GenerateQuadraticPyramids(vtkUnstructuredGrid* output, i
               {
                 point1[l] = (point1[l] + point2[l]) * .5;
               }
-              vtkIdType mid = output->GetPoints()->InsertNextPoint(point1);
+              vtkIdType mid;
+              this->Locator->InsertUniquePoint(point1, mid);
               edgeToPointId[edge] = mid;
               pyramidIds[c][5 + e] = mid;
             }
@@ -1336,6 +1354,206 @@ void vtkCellTypeSource::GenerateQuadraticPyramids(vtkUnstructuredGrid* output, i
   }
 }
 
+void vtkCellTypeSource::GenerateTriQuadraticPyramids(vtkUnstructuredGrid* output, int extent[6])
+{
+  // cell dimensions
+  const int xDim = extent[1] - extent[0];
+  const int yDim = extent[3] - extent[2];
+  const int zDim = extent[5] - extent[4];
+  output->Allocate(static_cast<vtkIdType>(xDim * yDim * zDim * 6));
+
+  EdgeToPointMap edgeToPointId;
+  // pairs go from lower to higher point id
+  static constexpr vtkIdType edgePairs[6][8][2] = {
+    // 6 pyramids, 8 edges
+    {
+      { 0, 1 }, { 1, 2 }, { 3, 2 }, { 0, 3 }, //
+      { 0, 8 }, { 1, 8 }, { 2, 8 }, { 3, 8 }  //
+    },
+    {
+      { 5, 6 }, { 4, 5 }, { 4, 7 }, { 7, 6 }, //
+      { 6, 8 }, { 5, 8 }, { 4, 8 }, { 7, 8 }  //
+    },
+    {
+      { 1, 5 }, { 5, 6 }, { 2, 6 }, { 1, 2 }, //
+      { 1, 8 }, { 5, 8 }, { 6, 8 }, { 2, 8 }  //
+    },
+    {
+      { 0, 4 }, { 4, 5 }, { 1, 5 }, { 0, 1 }, //
+      { 0, 8 }, { 4, 8 }, { 5, 8 }, { 1, 8 }  //
+    },
+    {
+      { 0, 3 }, { 3, 7 }, { 4, 7 }, { 0, 4 }, //
+      { 0, 8 }, { 3, 8 }, { 7, 8 }, { 4, 8 }  //
+    },
+    {
+      { 7, 6 }, { 3, 7 }, { 3, 2 }, { 2, 6 }, //
+      { 6, 8 }, { 7, 8 }, { 3, 8 }, { 2, 8 }  //
+    },
+  };
+
+  TriangleFaceToPointMap triangleFaceToPointId;
+  // tuples to go from lower to higher point id
+  static constexpr vtkIdType triangleTuples[6][4][3] = {
+    // 6 pyramids, 4 triangle faces
+    {
+      { 0, 1, 8 }, { 1, 2, 8 }, { 2, 3, 8 }, { 0, 3, 8 }, //
+    },
+    {
+      { 5, 6, 8 }, { 4, 5, 8 }, { 4, 7, 8 }, { 6, 7, 8 }, //
+    },
+    {
+      { 1, 5, 8 }, { 5, 6, 8 }, { 2, 6, 8 }, { 1, 2, 8 }, //
+    },
+    {
+      { 0, 4, 8 }, { 4, 5, 8 }, { 1, 5, 8 }, { 0, 1, 8 }, //
+    },
+    {
+      { 0, 3, 8 }, { 3, 7, 8 }, { 4, 7, 8 }, { 0, 4, 8 }, //
+    },
+    {
+      { 6, 7, 8 }, { 3, 7, 8 }, { 2, 3, 8 }, { 2, 6, 8 }, //
+    },
+  };
+
+  for (int k = 0; k < zDim; k++)
+  {
+    for (int j = 0; j < yDim; j++)
+    {
+      for (int i = 0; i < xDim; i++)
+      {
+        // also add in the middle point id
+        vtkIdType hexIds[9] = {
+          i + j * (xDim + 1) + k * (xDim + 1) * (yDim + 1),
+          i + 1 + j * (xDim + 1) + k * (xDim + 1) * (yDim + 1),
+          i + 1 + (j + 1) * (xDim + 1) + k * (xDim + 1) * (yDim + 1),
+          i + (j + 1) * (xDim + 1) + k * (xDim + 1) * (yDim + 1),
+          i + j * (xDim + 1) + (k + 1) * (xDim + 1) * (yDim + 1),
+          i + 1 + j * (xDim + 1) + (k + 1) * (xDim + 1) * (yDim + 1),
+          i + 1 + (j + 1) * (xDim + 1) + (k + 1) * (xDim + 1) * (yDim + 1),
+          i + (j + 1) * (xDim + 1) + (k + 1) * (xDim + 1) * (yDim + 1),
+          -1, // this is just a placeholder, the actual id will be calculated next
+        };
+
+        // add in center point by checking the mid-point of the diagonal
+        double point1[3], point2[3], point3[3];
+        output->GetPoint(hexIds[0], point1);
+        output->GetPoint(hexIds[6], point2);
+        for (int l = 0; l < 3; l++)
+        {
+          point1[l] = 0.5 * (point1[l] + point2[l]);
+        }
+        this->Locator->InsertUniquePoint(point1, hexIds[8]); // this updates hexIds[8]
+
+        vtkIdType pyramidIds[6][19] = { { hexIds[0], hexIds[1], hexIds[2], hexIds[3], hexIds[8], -1,
+                                          -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
+          { hexIds[6], hexIds[5], hexIds[4], hexIds[7], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1,
+            -1, -1, -1, -1, -1, -1 },
+          { hexIds[1], hexIds[5], hexIds[6], hexIds[2], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1,
+            -1, -1, -1, -1, -1, -1 },
+          { hexIds[0], hexIds[4], hexIds[5], hexIds[1], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1,
+            -1, -1, -1, -1, -1, -1 },
+          { hexIds[0], hexIds[3], hexIds[7], hexIds[4], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1,
+            -1, -1, -1, -1, -1, -1 },
+          { hexIds[6], hexIds[7], hexIds[3], hexIds[2], hexIds[8], -1, -1, -1, -1, -1, -1, -1, -1,
+            -1, -1, -1, -1, -1, -1 } };
+
+        for (int pId = 0; pId < 6; pId++) // iterate over pyramids
+        {
+          for (int eId = 0; eId < 8; eId++) // iterate over edges to create mid-edge points
+          {
+            std::pair<vtkIdType, vtkIdType> edge =
+              std::make_pair(hexIds[edgePairs[pId][eId][0]], hexIds[edgePairs[pId][eId][1]]);
+            EdgeToPointMap::iterator it = edgeToPointId.find(edge);
+            if (it == edgeToPointId.end())
+            {
+              output->GetPoint(edge.first, point1);
+              output->GetPoint(edge.second, point2);
+              for (int l = 0; l < 3; l++)
+              {
+                point1[l] = (point1[l] + point2[l]) * .5;
+              }
+              vtkIdType mid;
+              this->Locator->InsertUniquePoint(point1, mid);
+              edgeToPointId[edge] = mid;
+              pyramidIds[pId][5 + eId] = mid;
+            }
+            else
+            {
+              pyramidIds[pId][5 + eId] = it->second;
+            }
+          }
+
+          // add quad mid-face point
+          double quadFacePoint[3];
+          output->GetPoint(pyramidIds[pId][0], quadFacePoint);
+          for (int quadPointId = 1; quadPointId < 4; quadPointId++)
+          {
+            double tmp[3];
+            output->GetPoint(pyramidIds[pId][quadPointId], tmp);
+            for (int d = 0; d < 3; d++)
+            {
+              quadFacePoint[d] += tmp[d];
+            }
+          }
+          for (int d = 0; d < 3; d++)
+          {
+            quadFacePoint[d] /= 4.0;
+          }
+          this->Locator->InsertUniquePoint(quadFacePoint, pyramidIds[pId][13]);
+
+          for (int f = 0; f < 4; f++) // iterate over triangle faces to create mid-face points
+          {
+            auto triangleFace = std::make_tuple(hexIds[triangleTuples[pId][f][0]],
+              hexIds[triangleTuples[pId][f][1]], hexIds[triangleTuples[pId][f][2]]);
+            TriangleFaceToPointMap::iterator it = triangleFaceToPointId.find(triangleFace);
+            if (it == triangleFaceToPointId.end())
+            {
+              output->GetPoint(std::get<0>(triangleFace), point1);
+              output->GetPoint(std::get<1>(triangleFace), point2);
+              output->GetPoint(std::get<2>(triangleFace), point3);
+              double midTriangleFacePoint[3];
+              for (int l = 0; l < 3; l++)
+              {
+                midTriangleFacePoint[l] = (point1[l] + point2[l] + point3[l]) / 3.0;
+              }
+              vtkIdType mid;
+              this->Locator->InsertUniquePoint(midTriangleFacePoint, mid);
+              triangleFaceToPointId[triangleFace] = mid;
+              pyramidIds[pId][14 + f] = mid;
+            }
+            else
+            {
+              pyramidIds[pId][14 + f] = it->second;
+            }
+          }
+
+          // add volumetric centroid point
+          double volumetricCentroidPoint[3];
+          output->GetPoint(pyramidIds[pId][0], volumetricCentroidPoint);
+          for (int corners = 1; corners < 5; corners++)
+          {
+            double tmp[3];
+            output->GetPoint(pyramidIds[pId][corners], tmp);
+            for (int d = 0; d < 3; d++)
+            {
+              volumetricCentroidPoint[d] += tmp[d];
+            }
+          }
+          for (int d = 0; d < 3; d++)
+          {
+            volumetricCentroidPoint[d] /= 5.0;
+          }
+          this->Locator->InsertUniquePoint(volumetricCentroidPoint, pyramidIds[pId][18]);
+
+          // insert bi-quadratic pyramid
+          output->InsertNextCell(VTK_TRIQUADRATIC_PYRAMID, 19, pyramidIds[pId]);
+        }
+      }
+    }
+  }
+}
+
 //------------------------------------------------------------------------------
 void vtkCellTypeSource::GenerateLagrangeCurves(vtkUnstructuredGrid* output, int extent[6])
 {
@@ -1365,7 +1583,7 @@ void vtkCellTypeSource::GenerateLagrangeCurves(vtkUnstructuredGrid* output, int
       vtkIdType innerPointId = points->InsertNextPoint(pm.GetData());
       conn[j + 1] = innerPointId;
     }
-    output->InsertNextCell(VTK_LAGRANGE_CURVE, this->CellOrder + 1, &conn[0]);
+    output->InsertNextCell(VTK_LAGRANGE_CURVE, this->CellOrder + 1, conn.data());
   }
 }
 
@@ -1448,8 +1666,8 @@ void vtkCellTypeSource::GenerateLagrangeTris(vtkUnstructuredGrid* output, int ex
         pm = (1.0 - r) * (p3 * s + p0 * (1.0 - s)) + r * (p2 * s + p1 * (1.0 - s));
         this->Locator->InsertUniquePoint(pm.GetData(), ctb[numPtsPerCell - 1]);
       }
-      output->InsertNextCell(VTK_LAGRANGE_TRIANGLE, numPtsPerCell, &cta[0]);
-      output->InsertNextCell(VTK_LAGRANGE_TRIANGLE, numPtsPerCell, &ctb[0]);
+      output->InsertNextCell(VTK_LAGRANGE_TRIANGLE, numPtsPerCell, cta.data());
+      output->InsertNextCell(VTK_LAGRANGE_TRIANGLE, numPtsPerCell, ctb.data());
     }
   }
 }
@@ -1457,7 +1675,6 @@ void vtkCellTypeSource::GenerateLagrangeTris(vtkUnstructuredGrid* output, int ex
 //------------------------------------------------------------------------------
 void vtkCellTypeSource::GenerateLagrangeQuads(vtkUnstructuredGrid* output, int extent[6])
 {
-  vtkPoints* points = output->GetPoints();
   // cell dimensions
   const int xDim = extent[1] - extent[0];
   const int yDim = extent[3] - extent[2];
@@ -1495,11 +1712,12 @@ void vtkCellTypeSource::GenerateLagrangeQuads(vtkUnstructuredGrid* output, int e
           double r = static_cast<double>(m) / order[0];
           double s = static_cast<double>(n) / order[1];
           pm = (1.0 - r) * (p3 * s + p0 * (1.0 - s)) + r * (p2 * s + p1 * (1.0 - s));
-          vtkIdType innerPointId = points->InsertNextPoint(pm.GetData());
+          vtkIdType innerPointId;
+          this->Locator->InsertUniquePoint(pm.GetData(), innerPointId);
           conn[connidx] = innerPointId;
         }
       }
-      output->InsertNextCell(VTK_LAGRANGE_QUADRILATERAL, numPtsPerCell, &conn[0]);
+      output->InsertNextCell(VTK_LAGRANGE_QUADRILATERAL, numPtsPerCell, conn.data());
     }
   }
 }
@@ -1618,7 +1836,7 @@ void vtkCellTypeSource::GenerateLagrangeTets(vtkUnstructuredGrid* output, int ex
             this->Locator->InsertUniquePoint(pm.GetData(), innerPointId);
             conn[14] = innerPointId;
           }
-          output->InsertNextCell(VTK_LAGRANGE_TETRAHEDRON, numPtsPerCell, &conn[0]);
+          output->InsertNextCell(VTK_LAGRANGE_TETRAHEDRON, numPtsPerCell, conn.data());
         }
       }
     }
@@ -1689,7 +1907,7 @@ void vtkCellTypeSource::GenerateLagrangeHexes(vtkUnstructuredGrid* output, int e
             }
           }
         }
-        output->InsertNextCell(VTK_LAGRANGE_HEXAHEDRON, numPtsPerCell, &conn[0]);
+        output->InsertNextCell(VTK_LAGRANGE_HEXAHEDRON, numPtsPerCell, conn.data());
       } // i
     }   // j
   }     // k
@@ -1712,7 +1930,8 @@ void vtkCellTypeSource::GenerateLagrangeWedges(vtkUnstructuredGrid* output, int
   // additionally holds the number of points. Since
   // vtkLagrangeWedge::PointIndexFromIJK expects the order to be a 4-array, we
   // use this convention here.
-  const int order[4] = { this->CellOrder, this->CellOrder, this->CellOrder, numPtsPerCell };
+  const int order[4] = { this->CellOrder, this->CellOrder, this->CellOrder,
+    (this->CellOrder + 1) * (this->CellOrder + 1) * (this->CellOrder + 2) / 2 };
 
   output->Allocate(numCells * (numPtsPerCell + 1));
   std::vector<vtkIdType> cta;
@@ -1825,8 +2044,8 @@ void vtkCellTypeSource::GenerateLagrangeWedges(vtkUnstructuredGrid* output, int
           cta[20] = innerA;
           ctb[20] = innerB;
         }
-        output->InsertNextCell(VTK_LAGRANGE_WEDGE, numPtsPerCell, &cta[0]);
-        output->InsertNextCell(VTK_LAGRANGE_WEDGE, numPtsPerCell, &ctb[0]);
+        output->InsertNextCell(VTK_LAGRANGE_WEDGE, numPtsPerCell, cta.data());
+        output->InsertNextCell(VTK_LAGRANGE_WEDGE, numPtsPerCell, ctb.data());
       }
     }
   }
@@ -1861,7 +2080,7 @@ void vtkCellTypeSource::GenerateBezierCurves(vtkUnstructuredGrid* output, int ex
       vtkIdType innerPointId = points->InsertNextPoint(pm.GetData());
       conn[j + 1] = innerPointId;
     }
-    output->InsertNextCell(VTK_BEZIER_CURVE, this->CellOrder + 1, &conn[0]);
+    output->InsertNextCell(VTK_BEZIER_CURVE, this->CellOrder + 1, conn.data());
   }
 }
 
@@ -1944,8 +2163,8 @@ void vtkCellTypeSource::GenerateBezierTris(vtkUnstructuredGrid* output, int exte
         pm = (1.0 - r) * (p3 * s + p0 * (1.0 - s)) + r * (p2 * s + p1 * (1.0 - s));
         this->Locator->InsertUniquePoint(pm.GetData(), ctb[numPtsPerCell - 1]);
       }
-      output->InsertNextCell(VTK_BEZIER_TRIANGLE, numPtsPerCell, &cta[0]);
-      output->InsertNextCell(VTK_BEZIER_TRIANGLE, numPtsPerCell, &ctb[0]);
+      output->InsertNextCell(VTK_BEZIER_TRIANGLE, numPtsPerCell, cta.data());
+      output->InsertNextCell(VTK_BEZIER_TRIANGLE, numPtsPerCell, ctb.data());
     }
   }
 }
@@ -1953,7 +2172,6 @@ void vtkCellTypeSource::GenerateBezierTris(vtkUnstructuredGrid* output, int exte
 //------------------------------------------------------------------------------
 void vtkCellTypeSource::GenerateBezierQuads(vtkUnstructuredGrid* output, int extent[6])
 {
-  vtkPoints* points = output->GetPoints();
   // cell dimensions
   const int xDim = extent[1] - extent[0];
   const int yDim = extent[3] - extent[2];
@@ -1991,11 +2209,12 @@ void vtkCellTypeSource::GenerateBezierQuads(vtkUnstructuredGrid* output, int ext
           double r = static_cast<double>(m) / order[0];
           double s = static_cast<double>(n) / order[1];
           pm = (1.0 - r) * (p3 * s + p0 * (1.0 - s)) + r * (p2 * s + p1 * (1.0 - s));
-          vtkIdType innerPointId = points->InsertNextPoint(pm.GetData());
+          vtkIdType innerPointId;
+          this->Locator->InsertUniquePoint(pm.GetData(), innerPointId);
           conn[connidx] = innerPointId;
         }
       }
-      output->InsertNextCell(VTK_BEZIER_QUADRILATERAL, numPtsPerCell, &conn[0]);
+      output->InsertNextCell(VTK_BEZIER_QUADRILATERAL, numPtsPerCell, conn.data());
     }
   }
 }
@@ -2114,7 +2333,7 @@ void vtkCellTypeSource::GenerateBezierTets(vtkUnstructuredGrid* output, int exte
             this->Locator->InsertUniquePoint(pm.GetData(), innerPointId);
             conn[14] = innerPointId;
           }
-          output->InsertNextCell(VTK_BEZIER_TETRAHEDRON, numPtsPerCell, &conn[0]);
+          output->InsertNextCell(VTK_BEZIER_TETRAHEDRON, numPtsPerCell, conn.data());
         }
       }
     }
@@ -2185,7 +2404,7 @@ void vtkCellTypeSource::GenerateBezierHexes(vtkUnstructuredGrid* output, int ext
             }
           }
         }
-        output->InsertNextCell(VTK_BEZIER_HEXAHEDRON, numPtsPerCell, &conn[0]);
+        output->InsertNextCell(VTK_BEZIER_HEXAHEDRON, numPtsPerCell, conn.data());
       } // i
     }   // j
   }     // k
@@ -2208,7 +2427,8 @@ void vtkCellTypeSource::GenerateBezierWedges(vtkUnstructuredGrid* output, int ex
   // additionally holds the number of points. Since
   // vtkBezierWedge::PointIndexFromIJK expects the order to be a 4-array, we
   // use this convention here.
-  const int order[4] = { this->CellOrder, this->CellOrder, this->CellOrder, numPtsPerCell };
+  const int order[4] = { this->CellOrder, this->CellOrder, this->CellOrder,
+    (this->CellOrder + 1) * (this->CellOrder + 1) * (this->CellOrder + 2) / 2 };
 
   output->Allocate(numCells * (numPtsPerCell + 1));
   std::vector<vtkIdType> cta;
@@ -2321,8 +2541,8 @@ void vtkCellTypeSource::GenerateBezierWedges(vtkUnstructuredGrid* output, int ex
           cta[20] = innerA;
           ctb[20] = innerB;
         }
-        output->InsertNextCell(VTK_BEZIER_WEDGE, numPtsPerCell, &cta[0]);
-        output->InsertNextCell(VTK_BEZIER_WEDGE, numPtsPerCell, &ctb[0]);
+        output->InsertNextCell(VTK_BEZIER_WEDGE, numPtsPerCell, cta.data());
+        output->InsertNextCell(VTK_BEZIER_WEDGE, numPtsPerCell, ctb.data());
       }
     }
   }
@@ -2396,3 +2616,4 @@ void vtkCellTypeSource::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "OutputPrecision: " << this->OutputPrecision << "\n";
   os << indent << "PolynomialFieldOrder: " << this->PolynomialFieldOrder << "\n";
 }
+VTK_ABI_NAMESPACE_END
