@@ -33,6 +33,7 @@
 #include "vtkFiltersSourcesModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSSOURCES_EXPORT vtkEllipseArcSource : public vtkPolyDataAlgorithm
 {
 public:
@@ -40,25 +41,25 @@ public:
   vtkTypeMacro(vtkEllipseArcSource, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set position of the center of the ellipse that define the arc.
    * Default is 0, 0, 0.
    */
   vtkSetVector3Macro(Center, double);
   vtkGetVectorMacro(Center, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set normal vector. Represents the plane in which the ellipse will be drawn.
    * Default 0, 0, 1.
    */
   vtkSetVector3Macro(Normal, double);
   vtkGetVectorMacro(Normal, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set Major Radius Vector. It defines the origin of polar angle and the major
    * radius size.
@@ -66,27 +67,27 @@ public:
    */
   vtkSetVector3Macro(MajorRadiusVector, double);
   vtkGetVectorMacro(MajorRadiusVector, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the start angle. The angle where the plot begins.
    * Default is 0.
    */
   vtkSetClampMacro(StartAngle, double, -360.0, 360.0);
   vtkGetMacro(StartAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Angular sector occupied by the arc, beginning at Start Angle
    * Default is 90.
    */
   vtkSetClampMacro(SegmentAngle, double, 0.0, 360.0);
   vtkGetMacro(SegmentAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Divide line into resolution number of pieces.
    * Note: if Resolution is set to 1 the arc is a
@@ -94,9 +95,9 @@ public:
    */
   vtkSetClampMacro(Resolution, int, 1, VTK_INT_MAX);
   vtkGetMacro(Resolution, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get whether to close the arc with a final line segment connecting the first
    * and last points in the arc. Off by default
@@ -104,9 +105,9 @@ public:
   vtkSetMacro(Close, bool);
   vtkGetMacro(Close, bool);
   vtkBooleanMacro(Close, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output points.
    * vtkAlgorithm::SINGLE_PRECISION - Output single-precision floating point,
@@ -115,9 +116,9 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the ratio of the ellipse, i.e. the ratio b/a _ b: minor radius;
    * a: major radius
@@ -125,7 +126,7 @@ public:
    */
   vtkSetClampMacro(Ratio, double, 0.001, 100.0);
   vtkGetMacro(Ratio, double);
-  //@}
+  ///@}
 
 protected:
   vtkEllipseArcSource();
@@ -148,4 +149,5 @@ private:
   void operator=(const vtkEllipseArcSource&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
