@@ -24,10 +24,10 @@
 #include "vtkPolyData.h"
 #include "vtkUnsignedCharArray.h"
 
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGlyphSource2D);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGlyphSource2D::vtkGlyphSource2D()
 {
   this->Center[0] = 0.0;
@@ -49,24 +49,21 @@ vtkGlyphSource2D::vtkGlyphSource2D()
   this->SetNumberOfInputPorts(0);
 }
 
-//----------------------------------------------------------------------------
-int vtkGlyphSource2D::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **vtkNotUsed(inputVector),
-  vtkInformationVector *outputVector)
+//------------------------------------------------------------------------------
+int vtkGlyphSource2D::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
   // get the info object
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the output
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
-  //Allocate storage
-  vtkPoints *pts = vtkPoints::New();
+  // Allocate storage
+  vtkPoints* pts = vtkPoints::New();
 
   // Set the desired precision for the points in the output.
-  if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
+  if (this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
   {
     pts->SetDataType(VTK_DOUBLE);
   }
@@ -75,82 +72,82 @@ int vtkGlyphSource2D::RequestData(
     pts->SetDataType(VTK_FLOAT);
   }
 
-  pts->Allocate(6,6);
-  vtkCellArray *verts = vtkCellArray::New();
-  verts->Allocate(verts->EstimateSize(1,1),1);
-  vtkCellArray *lines = vtkCellArray::New();
-  lines->Allocate(lines->EstimateSize(4,2),2);
-  vtkCellArray *polys = vtkCellArray::New();
-  polys->Allocate(polys->EstimateSize(1,4),4);
-  vtkUnsignedCharArray *colors = vtkUnsignedCharArray::New();
+  pts->Allocate(6, 6);
+  vtkCellArray* verts = vtkCellArray::New();
+  verts->AllocateEstimate(1, 1);
+  vtkCellArray* lines = vtkCellArray::New();
+  lines->AllocateEstimate(4, 2);
+  vtkCellArray* polys = vtkCellArray::New();
+  polys->AllocateEstimate(1, 4);
+  vtkUnsignedCharArray* colors = vtkUnsignedCharArray::New();
   colors->SetNumberOfComponents(3);
-  colors->Allocate(2,2);
+  colors->Allocate(2, 2);
   colors->SetName("Colors");
 
   this->ConvertColor();
 
-  //Special options
-  if ( this->Dash )
+  // Special options
+  if (this->Dash)
   {
     int filled = this->Filled;
     this->Filled = 0;
-    this->CreateDash(pts,lines,polys,colors,this->Scale2);
+    this->CreateDash(pts, lines, polys, colors, this->Scale2);
     this->Filled = filled;
   }
-  if ( this->Cross )
+  if (this->Cross)
   {
     int filled = this->Filled;
     this->Filled = 0;
-    this->CreateCross(pts,lines,polys,colors,this->Scale2);
+    this->CreateCross(pts, lines, polys, colors, this->Scale2);
     this->Filled = filled;
   }
 
-  //Call the right function
+  // Call the right function
   switch (this->GlyphType)
   {
     case VTK_NO_GLYPH:
       break;
     case VTK_VERTEX_GLYPH:
-      this->CreateVertex(pts,verts,colors);
+      this->CreateVertex(pts, verts, colors);
       break;
     case VTK_DASH_GLYPH:
-      this->CreateDash(pts,lines,polys,colors,1.0);
+      this->CreateDash(pts, lines, polys, colors, 1.0);
       break;
     case VTK_CROSS_GLYPH:
-      this->CreateCross(pts,lines,polys,colors,1.0);
+      this->CreateCross(pts, lines, polys, colors, 1.0);
       break;
     case VTK_THICKCROSS_GLYPH:
-      this->CreateThickCross(pts,lines,polys,colors);
+      this->CreateThickCross(pts, lines, polys, colors);
       break;
     case VTK_TRIANGLE_GLYPH:
-      this->CreateTriangle(pts,lines,polys,colors);
+      this->CreateTriangle(pts, lines, polys, colors);
       break;
     case VTK_SQUARE_GLYPH:
-      this->CreateSquare(pts,lines,polys,colors);
+      this->CreateSquare(pts, lines, polys, colors);
       break;
     case VTK_CIRCLE_GLYPH:
-      this->CreateCircle(pts,lines,polys,colors);
+      this->CreateCircle(pts, lines, polys, colors);
       break;
     case VTK_DIAMOND_GLYPH:
-      this->CreateDiamond(pts,lines,polys,colors);
+      this->CreateDiamond(pts, lines, polys, colors);
       break;
     case VTK_ARROW_GLYPH:
-      this->CreateArrow(pts,lines,polys,colors);
+      this->CreateArrow(pts, lines, polys, colors);
       break;
     case VTK_THICKARROW_GLYPH:
-      this->CreateThickArrow(pts,lines,polys,colors);
+      this->CreateThickArrow(pts, lines, polys, colors);
       break;
     case VTK_HOOKEDARROW_GLYPH:
-      this->CreateHookedArrow(pts,lines,polys,colors);
+      this->CreateHookedArrow(pts, lines, polys, colors);
       break;
     case VTK_EDGEARROW_GLYPH:
-      this->CreateEdgeArrow(pts,lines,polys,colors);
+      this->CreateEdgeArrow(pts, lines, polys, colors);
       break;
   }
 
   this->TransformGlyph(pts);
 
-  //Clean up
+  // Clean up
   output->SetPoints(pts);
   pts->Delete();
 
@@ -176,96 +173,95 @@ void vtkGlyphSource2D::ConvertColor()
   this->RGB[2] = static_cast<unsigned char>(255.0 * this->Color[2]);
 }
 
-void vtkGlyphSource2D::TransformGlyph(vtkPoints *pts)
+void vtkGlyphSource2D::TransformGlyph(vtkPoints* pts)
 {
   double x[3];
   vtkIdType i;
-  vtkIdType numPts=pts->GetNumberOfPoints();
+  vtkIdType numPts = pts->GetNumberOfPoints();
 
-  if ( this->RotationAngle == 0.0 )
+  if (this->RotationAngle == 0.0)
   {
-    for (i=0; i<numPts; i++)
+    for (i = 0; i < numPts; i++)
     {
-      pts->GetPoint(i,x);
+      pts->GetPoint(i, x);
       x[0] = this->Center[0] + this->Scale * x[0];
       x[1] = this->Center[1] + this->Scale * x[1];
-      pts->SetPoint(i,x);
+      pts->SetPoint(i, x);
     }
   }
   else
   {
-    double angle = vtkMath::RadiansFromDegrees( this->RotationAngle );
+    double angle = vtkMath::RadiansFromDegrees(this->RotationAngle);
     double xt;
-    for (i=0; i<numPts; i++)
+    for (i = 0; i < numPts; i++)
     {
-      pts->GetPoint(i,x);
-      xt = x[0]*cos(angle) - x[1]*sin(angle);
-      x[1] = x[0]*sin(angle) + x[1]*cos(angle);
+      pts->GetPoint(i, x);
+      xt = x[0] * cos(angle) - x[1] * sin(angle);
+      x[1] = x[0] * sin(angle) + x[1] * cos(angle);
       x[0] = xt;
       x[0] = this->Center[0] + this->Scale * x[0];
       x[1] = this->Center[1] + this->Scale * x[1];
-      pts->SetPoint(i,x);
+      pts->SetPoint(i, x);
     }
   }
 }
 
-void vtkGlyphSource2D::CreateVertex(vtkPoints *pts, vtkCellArray *verts,
-                                    vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateVertex(
+  vtkPoints* pts, vtkCellArray* verts, vtkUnsignedCharArray* colors)
 {
   vtkIdType ptIds[1];
-  ptIds[0] = pts->InsertNextPoint(0.0,0.0,0.0);
-  verts->InsertNextCell(1,ptIds);
+  ptIds[0] = pts->InsertNextPoint(0.0, 0.0, 0.0);
+  verts->InsertNextCell(1, ptIds);
   colors->InsertNextValue(this->RGB[0]);
   colors->InsertNextValue(this->RGB[1]);
   colors->InsertNextValue(this->RGB[2]);
 }
 
-void vtkGlyphSource2D::CreateCross(vtkPoints *pts, vtkCellArray *lines,
-                                   vtkCellArray *polys, vtkUnsignedCharArray *colors,
-                                   double scale)
+void vtkGlyphSource2D::CreateCross(vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys,
+  vtkUnsignedCharArray* colors, double scale)
 {
   vtkIdType ptIds[4];
 
-  if ( this->Filled )
+  if (this->Filled)
   {
-    this->CreateThickCross(pts,lines,polys,colors);
+    this->CreateThickCross(pts, lines, polys, colors);
   }
   else
   {
-    ptIds[0] = pts->InsertNextPoint(-0.5*scale, 0.0, 0.0);
-    ptIds[1] = pts->InsertNextPoint( 0.5*scale, 0.0, 0.0);
-    lines->InsertNextCell(2,ptIds);
+    ptIds[0] = pts->InsertNextPoint(-0.5 * scale, 0.0, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.5 * scale, 0.0, 0.0);
+    lines->InsertNextCell(2, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
-    ptIds[0] = pts->InsertNextPoint(0.0, -0.5*scale, 0.0);
-    ptIds[1] = pts->InsertNextPoint(0.0,  0.5*scale, 0.0);
-    lines->InsertNextCell(2,ptIds);
+    ptIds[0] = pts->InsertNextPoint(0.0, -0.5 * scale, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.0, 0.5 * scale, 0.0);
+    lines->InsertNextCell(2, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
   }
 }
 
-void vtkGlyphSource2D::CreateThickCross(vtkPoints *pts, vtkCellArray *lines,
-                                        vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateThickCross(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
-  if ( this->Filled )
+  if (this->Filled)
   {
     vtkIdType ptIds[4];
     ptIds[0] = pts->InsertNextPoint(-0.5, -0.1, 0.0);
-    ptIds[1] = pts->InsertNextPoint( 0.5, -0.1, 0.0);
-    ptIds[2] = pts->InsertNextPoint( 0.5,  0.1, 0.0);
-    ptIds[3] = pts->InsertNextPoint(-0.5,  0.1, 0.0);
-    polys->InsertNextCell(4,ptIds);
+    ptIds[1] = pts->InsertNextPoint(0.5, -0.1, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.5, 0.1, 0.0);
+    ptIds[3] = pts->InsertNextPoint(-0.5, 0.1, 0.0);
+    polys->InsertNextCell(4, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
     ptIds[0] = pts->InsertNextPoint(-0.1, -0.5, 0.0);
-    ptIds[1] = pts->InsertNextPoint( 0.1, -0.5, 0.0);
-    ptIds[2] = pts->InsertNextPoint( 0.1,  0.5, 0.0);
-    ptIds[3] = pts->InsertNextPoint(-0.1,  0.5, 0.0);
-    polys->InsertNextCell(4,ptIds);
+    ptIds[1] = pts->InsertNextPoint(0.1, -0.5, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.1, 0.5, 0.0);
+    ptIds[3] = pts->InsertNextPoint(-0.1, 0.5, 0.0);
+    polys->InsertNextCell(4, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
@@ -276,75 +272,75 @@ void vtkGlyphSource2D::CreateThickCross(vtkPoints *pts, vtkCellArray *lines,
     ptIds[0] = pts->InsertNextPoint(-0.5, -0.1, 0.0);
     ptIds[1] = pts->InsertNextPoint(-0.1, -0.1, 0.0);
     ptIds[2] = pts->InsertNextPoint(-0.1, -0.5, 0.0);
-    ptIds[3] = pts->InsertNextPoint( 0.1, -0.5, 0.0);
-    ptIds[4] = pts->InsertNextPoint( 0.1, -0.1, 0.0);
-    ptIds[5] = pts->InsertNextPoint( 0.5, -0.1, 0.0);
-    ptIds[6] = pts->InsertNextPoint( 0.5,  0.1, 0.0);
-    ptIds[7] = pts->InsertNextPoint( 0.1,  0.1, 0.0);
-    ptIds[8] = pts->InsertNextPoint( 0.1,  0.5, 0.0);
-    ptIds[9] = pts->InsertNextPoint(-0.1,  0.5, 0.0);
+    ptIds[3] = pts->InsertNextPoint(0.1, -0.5, 0.0);
+    ptIds[4] = pts->InsertNextPoint(0.1, -0.1, 0.0);
+    ptIds[5] = pts->InsertNextPoint(0.5, -0.1, 0.0);
+    ptIds[6] = pts->InsertNextPoint(0.5, 0.1, 0.0);
+    ptIds[7] = pts->InsertNextPoint(0.1, 0.1, 0.0);
+    ptIds[8] = pts->InsertNextPoint(0.1, 0.5, 0.0);
+    ptIds[9] = pts->InsertNextPoint(-0.1, 0.5, 0.0);
     ptIds[10] = pts->InsertNextPoint(-0.1, 0.1, 0.0);
     ptIds[11] = pts->InsertNextPoint(-0.5, 0.1, 0.0);
     ptIds[12] = ptIds[0];
-    lines->InsertNextCell(13,ptIds);
+    lines->InsertNextCell(13, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
   }
 }
 
-void vtkGlyphSource2D::CreateTriangle(vtkPoints *pts, vtkCellArray *lines,
-                                      vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateTriangle(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
   vtkIdType ptIds[4];
 
   ptIds[0] = pts->InsertNextPoint(-0.375, -0.25, 0.0);
-  ptIds[1] = pts->InsertNextPoint( 0.0,  0.5, 0.0);
-  ptIds[2] = pts->InsertNextPoint( 0.375, -0.25, 0.0);
+  ptIds[1] = pts->InsertNextPoint(0.0, 0.5, 0.0);
+  ptIds[2] = pts->InsertNextPoint(0.375, -0.25, 0.0);
 
-  if ( this->Filled )
+  if (this->Filled)
   {
-    polys->InsertNextCell(3,ptIds);
+    polys->InsertNextCell(3, ptIds);
   }
   else
   {
     ptIds[3] = ptIds[0];
-    lines->InsertNextCell(4,ptIds);
+    lines->InsertNextCell(4, ptIds);
   }
   colors->InsertNextValue(this->RGB[0]);
   colors->InsertNextValue(this->RGB[1]);
   colors->InsertNextValue(this->RGB[2]);
 }
 
-void vtkGlyphSource2D::CreateSquare(vtkPoints *pts, vtkCellArray *lines,
-                                    vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateSquare(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
   vtkIdType ptIds[5];
 
   ptIds[0] = pts->InsertNextPoint(-0.5, -0.5, 0.0);
-  ptIds[1] = pts->InsertNextPoint( 0.5, -0.5, 0.0);
-  ptIds[2] = pts->InsertNextPoint( 0.5,  0.5, 0.0);
-  ptIds[3] = pts->InsertNextPoint(-0.5,  0.5, 0.0);
+  ptIds[1] = pts->InsertNextPoint(0.5, -0.5, 0.0);
+  ptIds[2] = pts->InsertNextPoint(0.5, 0.5, 0.0);
+  ptIds[3] = pts->InsertNextPoint(-0.5, 0.5, 0.0);
 
-  if ( this->Filled )
+  if (this->Filled)
   {
-    polys->InsertNextCell(4,ptIds);
+    polys->InsertNextCell(4, ptIds);
   }
   else
   {
     ptIds[4] = ptIds[0];
-    lines->InsertNextCell(5,ptIds);
+    lines->InsertNextCell(5, ptIds);
   }
   colors->InsertNextValue(this->RGB[0]);
   colors->InsertNextValue(this->RGB[1]);
   colors->InsertNextValue(this->RGB[2]);
 }
 
-void vtkGlyphSource2D::CreateCircle(vtkPoints *pts, vtkCellArray *lines,
-                                    vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateCircle(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
   vtkIdList* ptIds = vtkIdList::New();
-  if ( this->Filled ) //it's a polygon!
+  if (this->Filled) // it's a polygon!
   {
     ptIds->SetNumberOfIds(this->Resolution);
   }
@@ -358,19 +354,19 @@ void vtkGlyphSource2D::CreateCircle(vtkPoints *pts, vtkCellArray *lines,
   // generate points around a circle
   x[2] = 0.0;
   theta = 2.0 * vtkMath::Pi() / static_cast<double>(this->Resolution);
-  for (int i=0; i<this->Resolution; i++)
+  for (int i = 0; i < this->Resolution; i++)
   {
-    x[0] = 0.5 * cos(i*theta);
-    x[1] = 0.5 * sin(i*theta);
+    x[0] = 0.5 * cos(i * theta);
+    x[1] = 0.5 * sin(i * theta);
     ptIds->SetId(i, pts->InsertNextPoint(x));
   }
 
-  if ( this->Filled )
+  if (this->Filled)
   {
     polys->InsertNextCell(ptIds);
   }
   else
-  {// close the line
+  { // close the line
     ptIds->SetId(this->Resolution, ptIds->GetId(0));
     lines->InsertNextCell(ptIds);
   }
@@ -381,73 +377,73 @@ void vtkGlyphSource2D::CreateCircle(vtkPoints *pts, vtkCellArray *lines,
   ptIds->Delete();
 }
 
-void vtkGlyphSource2D::CreateDiamond(vtkPoints *pts, vtkCellArray *lines,
-                                     vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateDiamond(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
   vtkIdType ptIds[5];
 
-  ptIds[0] = pts->InsertNextPoint( 0.0, -0.5, 0.0);
-  ptIds[1] = pts->InsertNextPoint( 0.5,  0.0, 0.0);
-  ptIds[2] = pts->InsertNextPoint( 0.0,  0.5, 0.0);
-  ptIds[3] = pts->InsertNextPoint(-0.5,  0.0, 0.0);
+  ptIds[0] = pts->InsertNextPoint(0.0, -0.5, 0.0);
+  ptIds[1] = pts->InsertNextPoint(0.5, 0.0, 0.0);
+  ptIds[2] = pts->InsertNextPoint(0.0, 0.5, 0.0);
+  ptIds[3] = pts->InsertNextPoint(-0.5, 0.0, 0.0);
 
-  if ( this->Filled )
+  if (this->Filled)
   {
-    polys->InsertNextCell(4,ptIds);
+    polys->InsertNextCell(4, ptIds);
   }
   else
   {
     ptIds[4] = ptIds[0];
-    lines->InsertNextCell(5,ptIds);
+    lines->InsertNextCell(5, ptIds);
   }
   colors->InsertNextValue(this->RGB[0]);
   colors->InsertNextValue(this->RGB[1]);
   colors->InsertNextValue(this->RGB[2]);
 }
 
-void vtkGlyphSource2D::CreateArrow(vtkPoints *pts, vtkCellArray *lines,
-                                   vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateArrow(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
-  if ( this->Filled ) //create two convex polygons
+  if (this->Filled) // create two convex polygons
   {
-    this->CreateThickArrow(pts,lines,polys,colors);
+    this->CreateThickArrow(pts, lines, polys, colors);
   }
   else
   {
-    //stem
+    // stem
     vtkIdType ptIds[3];
-    ptIds[0] = pts->InsertNextPoint( -0.5, 0.0, 0.0);
-    ptIds[1] = pts->InsertNextPoint(  0.5, 0.0, 0.0);
-    lines->InsertNextCell(2,ptIds);
+    ptIds[0] = pts->InsertNextPoint(-0.5, 0.0, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.5, 0.0, 0.0);
+    lines->InsertNextCell(2, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
 
-    //arrow head
-    ptIds[0] = pts->InsertNextPoint( 0.2, -0.1, 0.0);
-    ptIds[1] = pts->InsertNextPoint( 0.5,  0.0, 0.0);
-    ptIds[2] = pts->InsertNextPoint( 0.2,  0.1, 0.0);
-    lines->InsertNextCell(3,ptIds);
+    // arrow head
+    ptIds[0] = pts->InsertNextPoint(0.2, -0.1, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.5, 0.0, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.2, 0.1, 0.0);
+    lines->InsertNextCell(3, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
   }
 }
 
-void vtkGlyphSource2D::CreateThickArrow(vtkPoints *pts, vtkCellArray *lines,
-                                         vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateThickArrow(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
   vtkIdType ptIds[8];
 
-  ptIds[0] = pts->InsertNextPoint( -0.5, -0.1, 0.0);
-  ptIds[1] = pts->InsertNextPoint(  0.1, -0.1, 0.0);
-  ptIds[2] = pts->InsertNextPoint(  0.1, -0.2, 0.0);
-  ptIds[3] = pts->InsertNextPoint(  0.5,  0.0, 0.0);
-  ptIds[4] = pts->InsertNextPoint(  0.1,  0.2, 0.0);
-  ptIds[5] = pts->InsertNextPoint(  0.1,  0.1, 0.0);
-  ptIds[6] = pts->InsertNextPoint( -0.5,  0.1, 0.0);
+  ptIds[0] = pts->InsertNextPoint(-0.5, -0.1, 0.0);
+  ptIds[1] = pts->InsertNextPoint(0.1, -0.1, 0.0);
+  ptIds[2] = pts->InsertNextPoint(0.1, -0.2, 0.0);
+  ptIds[3] = pts->InsertNextPoint(0.5, 0.0, 0.0);
+  ptIds[4] = pts->InsertNextPoint(0.1, 0.2, 0.0);
+  ptIds[5] = pts->InsertNextPoint(0.1, 0.1, 0.0);
+  ptIds[6] = pts->InsertNextPoint(-0.5, 0.1, 0.0);
 
-  if ( this->Filled ) //create two convex polygons
+  if (this->Filled) // create two convex polygons
   {
     polys->InsertNextCell(4);
     polys->InsertCellPoint(ptIds[0]);
@@ -458,7 +454,7 @@ void vtkGlyphSource2D::CreateThickArrow(vtkPoints *pts, vtkCellArray *lines,
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
 
-    polys->InsertNextCell(5,ptIds+1);
+    polys->InsertNextCell(5, ptIds + 1);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
@@ -466,33 +462,33 @@ void vtkGlyphSource2D::CreateThickArrow(vtkPoints *pts, vtkCellArray *lines,
   else
   {
     ptIds[7] = ptIds[0];
-    lines->InsertNextCell(8,ptIds);
+    lines->InsertNextCell(8, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
   }
 }
 
-void vtkGlyphSource2D::CreateHookedArrow(vtkPoints *pts, vtkCellArray *lines,
-                                         vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateHookedArrow(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
-  if ( this->Filled )
+  if (this->Filled)
   {
-    //create two convex polygons
+    // create two convex polygons
     vtkIdType ptIds[4];
-    ptIds[0] = pts->InsertNextPoint( -0.5,   -0.1, 0.0);
-    ptIds[1] = pts->InsertNextPoint(  0.1,   -0.1, 0.0);
-    ptIds[2] = pts->InsertNextPoint(  0.1,  0.075, 0.0);
-    ptIds[3] = pts->InsertNextPoint( -0.5,  0.075, 0.0);
-    polys->InsertNextCell(4,ptIds);
+    ptIds[0] = pts->InsertNextPoint(-0.5, -0.1, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.1, -0.1, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.1, 0.075, 0.0);
+    ptIds[3] = pts->InsertNextPoint(-0.5, 0.075, 0.0);
+    polys->InsertNextCell(4, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
 
-    ptIds[0] = pts->InsertNextPoint( 0.1, -0.1, 0.0);
-    ptIds[1] = pts->InsertNextPoint( 0.5, -0.1, 0.0);
-    ptIds[2] = pts->InsertNextPoint( 0.1,  0.2, 0.0);
-    polys->InsertNextCell(3,ptIds);
+    ptIds[0] = pts->InsertNextPoint(0.1, -0.1, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.5, -0.1, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.1, 0.2, 0.0);
+    polys->InsertNextCell(3, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
@@ -500,82 +496,81 @@ void vtkGlyphSource2D::CreateHookedArrow(vtkPoints *pts, vtkCellArray *lines,
   else
   {
     vtkIdType ptIds[3];
-    ptIds[0] = pts->InsertNextPoint( -0.5, 0.0, 0.0);
-    ptIds[1] = pts->InsertNextPoint(  0.5, 0.0, 0.0);
-    ptIds[2] = pts->InsertNextPoint(  0.2, 0.1, 0.0);
-    lines->InsertNextCell(3,ptIds);
+    ptIds[0] = pts->InsertNextPoint(-0.5, 0.0, 0.0);
+    ptIds[1] = pts->InsertNextPoint(0.5, 0.0, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.2, 0.1, 0.0);
+    lines->InsertNextCell(3, ptIds);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
   }
 }
 
-void vtkGlyphSource2D::CreateEdgeArrow(vtkPoints *pts, vtkCellArray *lines,
-                                       vtkCellArray *polys, vtkUnsignedCharArray *colors)
+void vtkGlyphSource2D::CreateEdgeArrow(
+  vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys, vtkUnsignedCharArray* colors)
 {
   vtkIdType ptIds[3];
 
   double x = 0.5 / sqrt(3.0);
-  ptIds[0] = pts->InsertNextPoint(-1.0,   x, 0.0);
-  ptIds[1] = pts->InsertNextPoint( 0.0, 0.0, 0.0);
-  ptIds[2] = pts->InsertNextPoint(-1.0,  -x, 0.0);
+  ptIds[0] = pts->InsertNextPoint(-1.0, x, 0.0);
+  ptIds[1] = pts->InsertNextPoint(0.0, 0.0, 0.0);
+  ptIds[2] = pts->InsertNextPoint(-1.0, -x, 0.0);
 
-  if ( this->Filled )
+  if (this->Filled)
   {
-    polys->InsertNextCell(3,ptIds);
+    polys->InsertNextCell(3, ptIds);
   }
   else
   {
-    lines->InsertNextCell(3,ptIds);
+    lines->InsertNextCell(3, ptIds);
   }
   colors->InsertNextValue(this->RGB[0]);
   colors->InsertNextValue(this->RGB[1]);
   colors->InsertNextValue(this->RGB[2]);
 }
 
-void vtkGlyphSource2D::CreateDash(vtkPoints *pts, vtkCellArray *lines,
-                                  vtkCellArray *polys, vtkUnsignedCharArray *colors,
-                                                                  double scale)
+void vtkGlyphSource2D::CreateDash(vtkPoints* pts, vtkCellArray* lines, vtkCellArray* polys,
+  vtkUnsignedCharArray* colors, double scale)
 {
-  if ( this->Filled )
+  if (this->Filled)
   {
     vtkIdType ptIds[4];
     ptIds[0] = pts->InsertNextPoint(-0.5, -0.1, 0.0);
-    ptIds[1] = pts->InsertNextPoint( 0.5, -0.1, 0.0);
-    ptIds[2] = pts->InsertNextPoint( 0.5,  0.1, 0.0);
-    ptIds[3] = pts->InsertNextPoint(-0.5,  0.1, 0.0);
-    polys->InsertNextCell(4,ptIds);
+    ptIds[1] = pts->InsertNextPoint(0.5, -0.1, 0.0);
+    ptIds[2] = pts->InsertNextPoint(0.5, 0.1, 0.0);
+    ptIds[3] = pts->InsertNextPoint(-0.5, 0.1, 0.0);
+    polys->InsertNextCell(4, ptIds);
   }
   else
   {
     vtkIdType ptIds2D[2];
-    ptIds2D[0] = pts->InsertNextPoint(-0.5*scale, 0.0, 0.0);
-    ptIds2D[1] = pts->InsertNextPoint( 0.5*scale, 0.0, 0.0);
+    ptIds2D[0] = pts->InsertNextPoint(-0.5 * scale, 0.0, 0.0);
+    ptIds2D[1] = pts->InsertNextPoint(0.5 * scale, 0.0, 0.0);
     colors->InsertNextValue(this->RGB[0]);
     colors->InsertNextValue(this->RGB[1]);
     colors->InsertNextValue(this->RGB[2]);
-    lines->InsertNextCell(2,ptIds2D);
+    lines->InsertNextCell(2, ptIds2D);
   }
   colors->InsertNextValue(this->RGB[0]);
   colors->InsertNextValue(this->RGB[1]);
   colors->InsertNextValue(this->RGB[2]);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyphSource2D::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Center: (" << this->Center[0] << ", "
-     << this->Center[1] << ", " << this->Center[2] << ")\n";
+  os << indent << "Center: (" << this->Center[0] << ", " << this->Center[1] << ", "
+     << this->Center[2] << ")\n";
 
   os << indent << "Scale: " << this->Scale << "\n";
   os << indent << "Scale2: " << this->Scale2 << "\n";
   os << indent << "Rotation Angle: " << this->RotationAngle << "\n";
   os << indent << "Resolution: " << this->Resolution << "\n";
 
-  os << indent << "Color: (" << this->Color[0] << ", "
-     << this->Color[1] << ", " << this->Color[2] << ")\n";
+  os << indent << "Color: (" << this->Color[0] << ", " << this->Color[1] << ", " << this->Color[2]
+     << ")\n";
 
   os << indent << "Filled: " << (this->Filled ? "On\n" : "Off\n");
   os << indent << "Dash: " << (this->Dash ? "On\n" : "Off\n");
@@ -624,6 +619,6 @@ void vtkGlyphSource2D::PrintSelf(ostream& os, vtkIndent indent)
       os << "Edge Arrow\n";
       break;
   }
-  os << indent << "Output Points Precision: " << this->OutputPointsPrecision
-     << "\n";
+  os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
