@@ -30,6 +30,7 @@
 #include <cmath>
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkParametricFunctionSource);
 vtkCxxSetObjectMacro(vtkParametricFunctionSource, ParametricFunction, vtkParametricFunction);
 
@@ -630,8 +631,9 @@ void vtkParametricFunctionSource::PrintSelf(ostream& os, vtkIndent indent)
     default:
       s = "Unknown scalar mode.";
   }
-  os << indent << "Scalar Mode: " << s.c_str() << "\n";
+  os << indent << "Scalar Mode: " << s << "\n";
   os << indent << "GenerateTextureCoordinates:" << (this->GenerateTextureCoordinates ? "On" : "Off")
      << "\n";
   os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
