@@ -16,14 +16,15 @@
 
 #include "vtkCellArray.h"
 #include "vtkFloatArray.h"
-#include "vtkMath.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPoints.h"
 #include "vtkPolyData.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTexturedSphereSource);
 
 // Construct sphere with radius=0.5 and default resolution 8 in both Phi
@@ -41,25 +42,22 @@ vtkTexturedSphereSource::vtkTexturedSphereSource(int res)
   this->SetNumberOfInputPorts(0);
 }
 
-int vtkTexturedSphereSource::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **vtkNotUsed(inputVector),
-  vtkInformationVector *outputVector)
+int vtkTexturedSphereSource::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
   // get the info object
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the output
-  vtkPolyData *output = vtkPolyData::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   int i, j;
   int numPts;
   int numPolys;
-  vtkPoints *newPoints;
-  vtkFloatArray *newNormals;
-  vtkFloatArray *newTCoords;
-  vtkCellArray *newPolys;
+  vtkPoints* newPoints;
+  vtkFloatArray* newNormals;
+  vtkFloatArray* newTCoords;
+  vtkCellArray* newPolys;
   double x[3], deltaPhi, deltaTheta, phi, theta, radius, norm;
   vtkIdType pts[3];
   double tc[2];
@@ -75,7 +73,7 @@ int vtkTexturedSphereSource::RequestData(
   newPoints = vtkPoints::New();
 
   // Set the desired precision for the points in the output.
-  if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
+  if (this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
   {
     newPoints->SetDataType(VTK_DOUBLE);
   }
@@ -87,23 +85,23 @@ int vtkTexturedSphereSource::RequestData(
   newPoints->Allocate(numPts);
   newNormals = vtkFloatArray::New();
   newNormals->SetNumberOfComponents(3);
-  newNormals->Allocate(3*numPts);
+  newNormals->Allocate(3 * numPts);
   newTCoords = vtkFloatArray::New();
   newTCoords->SetNumberOfComponents(2);
-  newTCoords->Allocate(2*numPts);
+  newTCoords->Allocate(2 * numPts);
   newPolys = vtkCellArray::New();
-  newPolys->Allocate(newPolys->EstimateSize(numPolys,3));
+  newPolys->AllocateEstimate(numPolys, 3);
   //
   // Create sphere
   //
   // Create intermediate points
   deltaPhi = vtkMath::Pi() / this->PhiResolution;
   deltaTheta = 2.0 * vtkMath::Pi() / this->ThetaResolution;
-  for (i=0; i <= this->ThetaResolution; i++)
+  for (i = 0; i <= this->ThetaResolution; i++)
   {
     theta = i * deltaTheta;
-    tc[0] = theta/(2.0 * vtkMath::Pi());
-    for (j=0; j <= this->PhiResolution; j++)
+    tc[0] = theta / (2.0 * vtkMath::Pi());
+    for (j = 0; j <= this->PhiResolution; j++)
     {
       phi = j * deltaPhi;
       radius = this->Radius * sin((double)phi);
@@ -112,14 +110,16 @@ int vtkTexturedSphereSource::RequestData(
       x[2] = this->Radius * cos((double)phi);
       newPoints->InsertNextPoint(x);
 
-      if ( (norm = vtkMath::Norm(x)) == 0.0 )
+      if ((norm = vtkMath::Norm(x)) == 0.0)
       {
         norm = 1.0;
       }
-      x[0] /= norm; x[1] /= norm; x[2] /= norm;
+      x[0] /= norm;
+      x[1] /= norm;
+      x[2] /= norm;
       newNormals->InsertNextTuple(x);
 
-      tc[1] = 1.0 - phi/vtkMath::Pi();
+      tc[1] = 1.0 - phi / vtkMath::Pi();
       newTCoords->InsertNextTuple(tc);
     }
   }
@@ -127,23 +127,23 @@ int vtkTexturedSphereSource::RequestData(
   // Generate mesh connectivity
   //
   // bands between poles
-  for (i=0; i < this->ThetaResolution; i++)
+  for (i = 0; i < this->ThetaResolution; i++)
   {
-    for (j=0; j < this->PhiResolution; j++)
+    for (j = 0; j < this->PhiResolution; j++)
     {
-      pts[0] = (this->PhiResolution+1)*i + j;
+      pts[0] = (this->PhiResolution + 1) * i + j;
       pts[1] = pts[0] + 1;
-      pts[2] = ((this->PhiResolution+1)*(i+1)+j) + 1;
-      newPolys->InsertNextCell(3,pts);
+      pts[2] = ((this->PhiResolution + 1) * (i + 1) + j) + 1;
+      newPolys->InsertNextCell(3, pts);
 
       pts[1] = pts[2];
       pts[2] = pts[1] - 1;
-      newPolys->InsertNextCell(3,pts);
+      newPolys->InsertNextCell(3, pts);
     }
   }
-//
-// Update ourselves and release memory
-//
+  //
+  // Update ourselves and release memory
+  //
   output->SetPoints(newPoints);
   newPoints->Delete();
 
@@ -161,13 +161,13 @@ int vtkTexturedSphereSource::RequestData(
 
 void vtkTexturedSphereSource::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Theta Resolution: " << this->ThetaResolution << "\n";
   os << indent << "Phi Resolution: " << this->PhiResolution << "\n";
   os << indent << "Theta: " << this->Theta << "\n";
   os << indent << "Phi: " << this->Phi << "\n";
   os << indent << "Radius: " << this->Radius << "\n";
-  os << indent << "Output Points Precision: " << this->OutputPointsPrecision
-     << "\n";
+  os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
