@@ -1,6 +1,7 @@
 #ifndef vtkKMeansAssessFunctor_h
 #define vtkKMeansAssessFunctor_h
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkKMeansAssessFunctor : public vtkStatisticsAlgorithm::AssessFunctor
 {
   vtkDoubleArray* Distances;
@@ -9,12 +10,13 @@ class vtkKMeansAssessFunctor : public vtkStatisticsAlgorithm::AssessFunctor
 
 public:
   static vtkKMeansAssessFunctor* New();
-  vtkKMeansAssessFunctor() { }
+  vtkKMeansAssessFunctor() = default;
   ~vtkKMeansAssessFunctor() override;
-  void operator () ( vtkDoubleArray* result, vtkIdType row ) override;
-  bool Initialize( vtkTable *inData, vtkTable *reqModel, vtkKMeansDistanceFunctor *distFunc );
+  void operator()(vtkDoubleArray* result, vtkIdType row) override;
+  bool Initialize(vtkTable* inData, vtkTable* reqModel, vtkKMeansDistanceFunctor* distFunc);
   int GetNumberOfRuns() { return NumRuns; }
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkKMeansAssessFunctor_h
 // VTK-HeaderTest-Exclude: vtkKMeansAssessFunctor.h
