@@ -100,6 +100,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkFiltersStatisticsModule.h" // For export macro
 #include "vtkStatisticsAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdTypeArray;
 class vtkIntArray;
 class vtkDoubleArray;
@@ -113,47 +114,47 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent) override;
   static vtkKMeansStatistics* New();
 
-  //@{
+  ///@{
   /**
    * Set the DistanceFunctor.
    */
   virtual void SetDistanceFunctor(vtkKMeansDistanceFunctor*);
   vtkGetObjectMacro(DistanceFunctor, vtkKMeansDistanceFunctor);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the \a DefaultNumberOfClusters, used when no initial cluster coordinates are specified.
    */
   vtkSetMacro(DefaultNumberOfClusters, int);
   vtkGetMacro(DefaultNumberOfClusters, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the KValuesArrayName.
    */
   vtkSetStringMacro(KValuesArrayName);
   vtkGetStringMacro(KValuesArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the MaxNumIterations used to terminate iterations on
    * cluster center coordinates when the relative tolerance can not be met.
    */
   vtkSetMacro(MaxNumIterations, int);
   vtkGetMacro(MaxNumIterations, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the relative \a Tolerance used to terminate iterations on
    * cluster center coordinates.
    */
   vtkSetMacro(Tolerance, double);
   vtkGetMacro(Tolerance, double);
-  //@}
+  ///@}
 
   /**
    * Given a collection of models, calculate aggregate model
@@ -166,10 +167,27 @@ public:
    */
   bool SetParameter(const char* parameter, int index, vtkVariant value) override;
 
+  ///@{
+  /**
+   * If there is a ghost array in the input, then ghosts matching `GhostsToSkip` mask
+   * will be skipped. It is set to 0xff by default (every ghosts types are skipped).
+   *
+   * @sa
+   * vtkDataSetAttributes
+   * vtkFieldData
+   * vtkPointData
+   * vtkCellData
+   */
+  vtkSetMacro(GhostsToSkip, unsigned char);
+  vtkGetMacro(GhostsToSkip, unsigned char);
+  ///@}
+
 protected:
   vtkKMeansStatistics();
   ~vtkKMeansStatistics() override;
 
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
+
   /**
    * Execute the calculations required by the Learn option.
    */
@@ -257,9 +275,17 @@ protected:
    */
   vtkKMeansDistanceFunctor* DistanceFunctor;
 
+  /**
+   * Number of ghosts in input data.
+   */
+  vtkIdType NumberOfGhosts;
+
+  unsigned char GhostsToSkip;
+
 private:
   vtkKMeansStatistics(const vtkKMeansStatistics&) = delete;
   void operator=(const vtkKMeansStatistics&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
