@@ -21,6 +21,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkOrderStatistics.h"
 #include "vtkStatisticsAlgorithmPrivate.h"
 
+#include "vtkDataSetAttributes.h"
 #include "vtkDoubleArray.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
@@ -28,8 +29,10 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkMath.h"
 #include "vtkMultiBlockDataSet.h"
 #include "vtkObjectFactory.h"
+#include "vtkSMPTools.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
+#include "vtkUnsignedCharArray.h"
 #include "vtkVariantArray.h"
 
 #include <cmath>
@@ -38,6 +41,45 @@ PURPOSE.  See the above copyright notice for more information.
 #include <set>
 #include <vector>
 
+namespace
+{
+//==============================================================================
+struct GhostsCounter
+{
+  GhostsCounter(vtkUnsignedCharArray* ghosts, unsigned char ghostsToSkip)
+    : Ghosts(ghosts)
+    , GhostsToSkip(ghostsToSkip)
+    , GlobalNumberOfGhosts(0)
+  {
+  }
+
+  void Initialize() { this->NumberOfGhosts.Local() = 0; }
+
+  void operator()(vtkIdType startId, vtkIdType endId)
+  {
+    vtkIdType& numberOfGhosts = this->NumberOfGhosts.Local();
+    for (vtkIdType id = startId; id < endId; ++id)
+    {
+      numberOfGhosts += (this->Ghosts->GetValue(id) & this->GhostsToSkip) != 0;
+    }
+  }
+
+  void Reduce()
+  {
+    for (vtkIdType numberOfGhosts : this->NumberOfGhosts)
+    {
+      this->GlobalNumberOfGhosts += numberOfGhosts;
+    }
+  }
+
+  vtkUnsignedCharArray* Ghosts;
+  unsigned char GhostsToSkip;
+  vtkIdType GlobalNumberOfGhosts;
+  vtkSMPThreadLocal<vtkIdType> NumberOfGhosts;
+};
+} // anonymous namespace
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOrderStatistics);
 
 //------------------------------------------------------------------------------
@@ -52,6 +94,9 @@ vtkOrderStatistics::vtkOrderStatistics()
 
   this->AssessNames->SetNumberOfValues(1);
   this->AssessNames->SetValue(0, "Quantile");
+
+  this->NumberOfGhosts = 0;
+  this->GhostsToSkip = 0xff;
 }
 
 //------------------------------------------------------------------------------
@@ -67,6 +112,29 @@ void vtkOrderStatistics::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "MaximumHistogramSize: " << this->MaximumHistogramSize << endl;
 }
 
+//------------------------------------------------------------------------------
+int vtkOrderStatistics::RequestData(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
+{
+  if (vtkTable* inData = vtkTable::GetData(inputVector[INPUT_DATA], 0))
+  {
+    vtkUnsignedCharArray* ghosts = inData->GetRowData()->GetGhostArray();
+
+    if (ghosts)
+    {
+      ::GhostsCounter counter(ghosts, this->GhostsToSkip);
+      vtkSMPTools::For(0, ghosts->GetNumberOfValues(), counter);
+      this->NumberOfGhosts = counter.GlobalNumberOfGhosts;
+    }
+    else
+    {
+      this->NumberOfGhosts = 0;
+    }
+  }
+
+  return this->Superclass::RequestData(request, inputVector, outputVector);
+}
+
 //------------------------------------------------------------------------------
 void vtkOrderStatistics::SetQuantileDefinition(int qd)
 {
@@ -120,6 +188,8 @@ void vtkOrderStatistics::Learn(
     return;
   }
 
+  vtkUnsignedCharArray* ghosts = inData->GetRowData()->GetGhostArray();
+
   // Loop over requests
   vtkIdType nRow = inData->GetNumberOfRows();
   for (std::set<std::set<vtkStdString>>::iterator rit = this->Internals->Requests.begin();
@@ -127,15 +197,15 @@ void vtkOrderStatistics::Learn(
   {
     // Each request contains only one column of interest (if there are others, they are ignored)
     std::set<vtkStdString>::const_iterator it = rit->begin();
-    vtkStdString col = *it;
-    if (!inData->GetColumnByName(col))
+    std::string col = *it;
+    if (!inData->GetColumnByName(col.c_str()))
     {
-      vtkWarningMacro("InData table does not have a column " << col.c_str() << ". Ignoring it.");
+      vtkWarningMacro("InData table does not have a column " << col << ". Ignoring it.");
       continue;
     }
 
     // Get hold of data for this variable
-    vtkAbstractArray* vals = inData->GetColumnByName(col);
+    vtkAbstractArray* vals = inData->GetColumnByName(col.c_str());
 
     // Create histogram table for this variable
     vtkTable* histogramTab = vtkTable::New();
@@ -168,7 +238,7 @@ void vtkOrderStatistics::Learn(
     }
     else
     {
-      vtkWarningMacro("Unsupported data type for column " << col.c_str() << ". Ignoring it.");
+      vtkWarningMacro("Unsupported data type for column " << col << ". Ignoring it.");
 
       continue;
     }
@@ -188,7 +258,10 @@ void vtkOrderStatistics::Learn(
       std::map<double, vtkIdType> histogram;
       for (vtkIdType r = 0; r < nRow; ++r)
       {
-        ++histogram[dvals->GetTuple1(r)];
+        if (!ghosts || !(ghosts->GetValue(r) & this->GhostsToSkip))
+        {
+          ++histogram[dvals->GetTuple1(r)];
+        }
       }
 
       // If maximum size was requested, make sure it is satisfied
@@ -214,6 +287,10 @@ void vtkOrderStatistics::Learn(
           double quantum;
           for (vtkIdType r = 0; r < nRow; ++r)
           {
+            if (ghosts && (ghosts->GetValue(r) & this->GhostsToSkip))
+            {
+              continue;
+            }
             reading = dvals->GetTuple1(r);
             quantum = mini + std::round((reading - mini) / width) * width;
             ++histogram[quantum];
@@ -242,7 +319,10 @@ void vtkOrderStatistics::Learn(
       std::map<vtkStdString, vtkIdType> histogram;
       for (vtkIdType r = 0; r < nRow; ++r)
       {
-        ++histogram[svals->GetValue(r)];
+        if (!ghosts || !(ghosts->GetValue(r) & this->GhostsToSkip))
+        {
+          ++histogram[svals->GetValue(r)];
+        }
       }
 
       // Store histogram
@@ -263,7 +343,10 @@ void vtkOrderStatistics::Learn(
       std::map<vtkVariant, vtkIdType> histogram;
       for (vtkIdType r = 0; r < nRow; ++r)
       {
-        ++histogram[vvals->GetVariantValue(r)];
+        if (!ghosts || !(ghosts->GetValue(r) & this->GhostsToSkip))
+        {
+          ++histogram[vvals->GetVariantValue(r)];
+        }
       }
 
       // Store histogram
@@ -277,7 +360,7 @@ void vtkOrderStatistics::Learn(
     } // else if ( vals->IsA("vtkVariantArray") )
     else
     {
-      vtkWarningMacro("Unsupported data type for column " << col.c_str() << ". Ignoring it.");
+      vtkWarningMacro("Unsupported data type for column " << col << ". Ignoring it.");
 
       continue;
     } // else
@@ -332,7 +415,7 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
     if (q.rem)
     {
       // General case
-      stringCol->InsertNextValue(vtkStdString(vtkVariant(i * dq).ToString() + "-quantile").c_str());
+      stringCol->InsertNextValue((vtkVariant(i * dq).ToString() + "-quantile").c_str());
     }
     else
     {
@@ -355,8 +438,7 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
           stringCol->InsertNextValue("Maximum");
           break;
         default:
-          stringCol->InsertNextValue(
-            vtkStdString(vtkVariant(i * dq).ToString() + "-quantile").c_str());
+          stringCol->InsertNextValue((vtkVariant(i * dq).ToString() + "-quantile").c_str());
           break;
       }
     }
@@ -405,13 +487,13 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
     cardinalityTab->InsertNextRow(row);
 
     // Find or create column of probability mass function of histogram table
-    vtkStdString probaName("P");
+    std::string probaName("P");
     vtkDoubleArray* probaCol;
-    vtkAbstractArray* abstrCol = histogramTab->GetColumnByName(probaName);
+    vtkAbstractArray* abstrCol = histogramTab->GetColumnByName(probaName.c_str());
     if (!abstrCol)
     {
       probaCol = vtkDoubleArray::New();
-      probaCol->SetName(probaName);
+      probaCol->SetName(probaName.c_str());
       probaCol->SetNumberOfTuples(nRowHist);
       histogramTab->AddColumn(probaCol);
       probaCol->Delete();
@@ -523,7 +605,7 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
 
       // Create column for quantiles of the same type as the values
       vtkDataArray* quantCol = vtkDataArray::CreateDataArray(dvals->GetDataType());
-      quantCol->SetName(varName);
+      quantCol->SetName(varName.c_str());
       quantCol->SetNumberOfTuples(this->NumberOfIntervals + 1);
       quantileTab->AddColumn(quantCol);
       quantCol->Delete();
@@ -565,7 +647,7 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
 
       // Create column for quantiles of the same type as the values
       vtkStringArray* quantCol = vtkStringArray::New();
-      quantCol->SetName(varName);
+      quantCol->SetName(varName.c_str());
       quantCol->SetNumberOfTuples(this->NumberOfIntervals + 1);
       quantileTab->AddColumn(quantCol);
       quantCol->Delete();
@@ -576,7 +658,7 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
            qit != quantileIndices.end(); ++qit, ++k)
       {
         // Retrieve data value from rank into histogram
-        vtkStdString Qp = svals->GetValue(qit->first);
+        std::string Qp = svals->GetValue(qit->first);
 
         // Store quantile value
         quantCol->SetValue(k, Qp);
@@ -589,7 +671,7 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
 
       // Create column for quantiles of the same type as the values
       vtkVariantArray* quantCol = vtkVariantArray::New();
-      quantCol->SetName(varName);
+      quantCol->SetName(varName.c_str());
       quantCol->SetNumberOfTuples(this->NumberOfIntervals + 1);
       quantileTab->AddColumn(quantCol);
       quantCol->Delete();
@@ -608,8 +690,8 @@ void vtkOrderStatistics::Derive(vtkMultiBlockDataSet* inMeta)
     } // else if ( vals->IsA("vtkVariantArray") )
     else
     {
-      vtkWarningMacro("Unsupported data type for column "
-        << varName.c_str() << ". Cannot calculate quantiles for it.");
+      vtkWarningMacro(
+        "Unsupported data type for column " << varName << ". Cannot calculate quantiles for it.");
 
       continue;
     } // else
@@ -678,7 +760,7 @@ void vtkOrderStatistics::Test(vtkTable* inData, vtkMultiBlockDataSet* inMeta, vt
 
   // Prepare storage for quantiles and model CDFs
   vtkIdType nQuant = quantileTab->GetNumberOfRows();
-  std::vector<vtkStdString> quantiles(nQuant);
+  std::vector<std::string> quantiles(nQuant);
 
   // Loop over requests
   vtkIdType nRowData = inData->GetNumberOfRows();
@@ -690,30 +772,29 @@ void vtkOrderStatistics::Test(vtkTable* inData, vtkMultiBlockDataSet* inMeta, vt
   {
     // Each request contains only one column of interest (if there are others, they are ignored)
     std::set<vtkStdString>::const_iterator it = rit->begin();
-    vtkStdString varName = *it;
-    if (!inData->GetColumnByName(varName))
+    std::string varName = *it;
+    if (!inData->GetColumnByName(varName.c_str()))
     {
-      vtkWarningMacro(
-        "InData table does not have a column " << varName.c_str() << ". Ignoring it.");
+      vtkWarningMacro("InData table does not have a column " << varName << ". Ignoring it.");
       continue;
     }
 
     // Find the quantile column that corresponds to the variable of the request
-    vtkAbstractArray* quantCol = quantileTab->GetColumnByName(varName);
+    vtkAbstractArray* quantCol = quantileTab->GetColumnByName(varName.c_str());
     if (!quantCol)
     {
       vtkWarningMacro(
-        "Quantile table table does not have a column " << varName.c_str() << ". Ignoring it.");
+        "Quantile table table does not have a column " << varName << ". Ignoring it.");
       continue;
     }
 
     // First iterate over all observations to calculate empirical PDF
-    typedef std::map<vtkStdString, double> CDF;
+    typedef std::map<std::string, double> CDF;
     CDF cdfEmpirical;
     for (vtkIdType j = 0; j < nRowData; ++j)
     {
       // Read observation and update PDF
-      cdfEmpirical[inData->GetValueByName(j, varName).ToString()] += inv_card;
+      cdfEmpirical[inData->GetValueByName(j, varName.c_str()).ToString()] += inv_card;
     }
 
     // Now integrate to obtain empirical CDF
@@ -727,8 +808,7 @@ void vtkOrderStatistics::Test(vtkTable* inData, vtkMultiBlockDataSet* inMeta, vt
     // Sanity check: verify that empirical CDF = 1
     if (fabs(sum - 1.) > 1.e-6)
     {
-      vtkWarningMacro(
-        "Incorrect empirical CDF for variable:" << varName.c_str() << ". Ignoring it.");
+      vtkWarningMacro("Incorrect empirical CDF for variable:" << varName << ". Ignoring it.");
 
       continue;
     }
@@ -737,11 +817,11 @@ void vtkOrderStatistics::Test(vtkTable* inData, vtkMultiBlockDataSet* inMeta, vt
     for (vtkIdType i = 0; i < nQuant; ++i)
     {
       // Read quantile and update CDF
-      quantiles[i] = quantileTab->GetValueByName(i, varName).ToString();
+      quantiles[i] = quantileTab->GetValueByName(i, varName.c_str()).ToString();
 
       // Update empirical CDF if new value found (with unknown ECDF)
       std::pair<CDF::iterator, bool> result =
-        cdfEmpirical.insert(std::pair<vtkStdString, double>(quantiles[i], -1));
+        cdfEmpirical.insert(std::pair<std::string, double>(quantiles[i], -1));
       if (result.second)
       {
         CDF::iterator eit = result.first;
@@ -856,7 +936,7 @@ public:
   {
     result->SetNumberOfValues(1);
 
-    vtkStdString sval = this->Data->GetValue(id);
+    std::string sval = this->Data->GetValue(id);
     if (sval < this->Quantiles->GetValue(0))
     {
       // sval is smaller than lower bound
@@ -938,21 +1018,20 @@ void vtkOrderStatistics::SelectAssessFunctor(
   }
 
   // Retrieve name of variable of the request
-  vtkStdString varName = rowNames->GetValue(0);
+  std::string varName = rowNames->GetValue(0);
 
   // Grab the data for the requested variable
-  vtkAbstractArray* vals = outData->GetColumnByName(varName);
+  vtkAbstractArray* vals = outData->GetColumnByName(varName.c_str());
   if (!vals)
   {
     return;
   }
 
   // Find the quantile column that corresponds to the variable of the request
-  vtkAbstractArray* quantiles = quantileTab->GetColumnByName(varName);
+  vtkAbstractArray* quantiles = quantileTab->GetColumnByName(varName.c_str());
   if (!quantiles)
   {
-    vtkWarningMacro(
-      "Quantile table table does not have a column " << varName.c_str() << ". Ignoring it.");
+    vtkWarningMacro("Quantile table table does not have a column " << varName << ". Ignoring it.");
     return;
   }
 
@@ -972,7 +1051,8 @@ void vtkOrderStatistics::SelectAssessFunctor(
   else
   {
     vtkWarningMacro("Unsupported (data,quantiles) type for column "
-      << varName.c_str() << ": data type is " << vals->GetClassName() << " and quantiles type is "
+      << varName << ": data type is " << vals->GetClassName() << " and quantiles type is "
       << quantiles->GetClassName() << ". Ignoring it.");
   }
 }
+VTK_ABI_NAMESPACE_END
