@@ -26,6 +26,7 @@
 #define VTK_PCA_NORMCOLUMN "PCA Cov Norm"
 #define VTK_PCA_COMPCOLUMN "PCA"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkPCAStatistics);
 
 const char* vtkPCAStatistics::NormalizationSchemeEnumNames[NUM_NORMALIZATION_SCHEMES + 1] = {
@@ -68,7 +69,7 @@ void vtkPCAStatistics::GetEigenvalues(int request, vtkDoubleArray* eigenvalues)
     ss << "PCA " << eval;
 
     std::string rowName = rowNames->GetValue(i);
-    if (rowName.compare(ss.str()) == 0)
+    if (rowName == ss.str())
     {
       eigenvalues->InsertNextValue(meanCol->GetValue(i));
       eval++;
@@ -134,7 +135,7 @@ void vtkPCAStatistics::GetEigenvectors(int request, vtkDoubleArray* eigenvectors
     ss << "PCA " << eval;
 
     std::string rowName = rowNames->GetValue(i);
-    if (rowName.compare(ss.str()) == 0)
+    if (rowName == ss.str())
     {
       std::vector<double> eigenvector;
       for (int val = 0; val < numberOfEigenvalues; val++)
@@ -475,7 +476,7 @@ static void vtkPCAStatisticsNormalizeSpec(vtkVariantArray* normData, Eigen::Matr
 {
   vtkIdType i, j;
   vtkIdType m = reqModel->GetNumberOfColumns() - 2;
-  std::map<vtkStdString, vtkIdType> colNames;
+  std::map<std::string, vtkIdType> colNames;
   // Get a list of columns of interest for this request
   for (i = 0; i < m; ++i)
   {
@@ -486,7 +487,7 @@ static void vtkPCAStatisticsNormalizeSpec(vtkVariantArray* normData, Eigen::Matr
   vtkIdType n = normSpec->GetNumberOfRows();
   for (vtkIdType r = 0; r < n; ++r)
   {
-    std::map<vtkStdString, vtkIdType>::iterator it;
+    std::map<std::string, vtkIdType>::iterator it;
     if ((it = colNames.find(normSpec->GetValue(r, 0).ToString())) == colNames.end())
     {
       continue;
@@ -812,7 +813,7 @@ void vtkPCAStatistics::Test(vtkTable* inData, vtkMultiBlockDataSet* inMeta, vtkT
     }
 
     // Create and fill entries of name and mean vectors
-    std::vector<vtkStdString> varNameX(p);
+    std::vector<std::string> varNameX(p);
     std::vector<double> mX(p);
     for (int i = 0; i < p; ++i)
     {
@@ -850,7 +851,7 @@ void vtkPCAStatistics::Test(vtkTable* inData, vtkMultiBlockDataSet* inMeta, vtkT
       // Read and center observation
       for (int i = 0; i < p; ++i)
       {
-        x[i] = inData->GetValueByName(r, varNameX[i]).ToDouble() - mX[i];
+        x[i] = inData->GetValueByName(r, varNameX[i].c_str()).ToDouble() - mX[i];
       }
 
       // Now calculate skewness and kurtosis per component
@@ -1022,3 +1023,4 @@ void vtkPCAStatistics::SelectAssessFunctor(vtkTable* inData, vtkDataObject* inMe
 
   dfunc = pcafunc;
 }
+VTK_ABI_NAMESPACE_END
