@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkObject.h
+  Module:    vtkMatrixMathFilter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -13,7 +13,6 @@
 
 =========================================================================*/
 #include "vtkMatrixMathFilter.h"
-#include "vtk_verdict.h"
 
 #include "vtkCellData.h"
 #include "vtkDataSet.h"
@@ -25,6 +24,7 @@
 #include "vtkPointData.h"
 #include "vtkSmartPointer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMatrixMathFilter);
 
 vtkMatrixMathFilter::~vtkMatrixMathFilter() = default;
@@ -251,3 +251,4 @@ int vtkMatrixMathFilter::RequestData(vtkInformation* vtkNotUsed(request),
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
