@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkActor.h
+  Module:    QVTKApplication.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -21,6 +21,7 @@
 #endif
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 QVTKApplication::QVTKApplication(int& Argc, char** Argv)
   : QApplication(Argc, Argv)
 {
@@ -32,12 +33,14 @@ QVTKApplication::QVTKApplication(int& Argc, char** Argv)
 }
 
 //------------------------------------------------------------------------------
+#if defined(VTK_USE_TDX) && (defined(Q_WS_X11) || defined(Q_OS_LINUX))
 QVTKApplication::~QVTKApplication()
 {
-#if defined(VTK_USE_TDX) && (defined(Q_WS_X11) || defined(Q_OS_LINUX))
   delete this->Devices;
-#endif
 }
+#else
+QVTKApplication::~QVTKApplication() = default;
+#endif
 
 //------------------------------------------------------------------------------
 #if defined(VTK_USE_TDX) && (defined(Q_WS_X11) || defined(Q_OS_LINUX))
@@ -60,3 +63,4 @@ void QVTKApplication::setDevice(vtkTDxDevice* device)
 #endif
 }
 #endif
+VTK_ABI_NAMESPACE_END
