@@ -56,11 +56,17 @@
 #include "vtkObjectFactory.h"
 #include "vtkRenderWindow.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 QVTKInteractorInternal::QVTKInteractorInternal(QVTKInteractor* p)
   : Parent(p)
 {
   this->SignalMapper = new QSignalMapper(this);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+  QObject::connect(
+    this->SignalMapper, &QSignalMapper::mappedInt, this, &QVTKInteractorInternal::TimerEvent);
+#else
   QObject::connect(this->SignalMapper, SIGNAL(mapped(int)), this, SLOT(TimerEvent(int)));
+#endif
 }
 
 QVTKInteractorInternal::~QVTKInteractorInternal() = default;
@@ -261,3 +267,4 @@ int QVTKInteractor::InternalDestroyTimer(int platformTimerId)
   }
   return 0;
 }
+VTK_ABI_NAMESPACE_END
