@@ -15,7 +15,6 @@
 #include "QVTKOpenGLNativeWidget.h"
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QOpenGLContext>
 #include <QOpenGLFramebufferObject>
 #include <QOpenGLFunctions>
@@ -35,6 +34,7 @@
 #include "vtkOpenGLState.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 QVTKOpenGLNativeWidget::QVTKOpenGLNativeWidget(QWidget* parentWdg, Qt::WindowFlags f)
   : QVTKOpenGLNativeWidget(
       vtkSmartPointer<vtkGenericOpenGLRenderWindow>::New().GetPointer(), parentWdg, f)
@@ -294,64 +294,4 @@ bool QVTKOpenGLNativeWidget::event(QEvent* evt)
   }
   return this->Superclass::event(evt);
 }
-
-//------------------------------------------------------------------------------
-void QVTKOpenGLNativeWidget::SetRenderWindow(vtkRenderWindow* win)
-{
-  VTK_LEGACY_REPLACED_BODY(
-    QVTKOpenGLNativeWidget::SetRenderWindow, "VTK 9.0", QVTKOpenGLNativeWidget::setRenderWindow);
-  vtkGenericOpenGLRenderWindow* gwin = vtkGenericOpenGLRenderWindow::SafeDownCast(win);
-  if (gwin == nullptr && win != nullptr)
-  {
-    qDebug() << "QVTKOpenGLNativeWidget requires a `vtkGenericOpenGLRenderWindow`. `"
-             << win->GetClassName() << "` is not supported.";
-  }
-  this->setRenderWindow(gwin);
-}
-
-//------------------------------------------------------------------------------
-void QVTKOpenGLNativeWidget::SetRenderWindow(vtkGenericOpenGLRenderWindow* win)
-{
-  VTK_LEGACY_REPLACED_BODY(
-    QVTKOpenGLNativeWidget::SetRenderWindow, "VTK 9.0", QVTKOpenGLNativeWidget::setRenderWindow);
-  this->setRenderWindow(win);
-}
-
-//------------------------------------------------------------------------------
-vtkRenderWindow* QVTKOpenGLNativeWidget::GetRenderWindow()
-{
-  VTK_LEGACY_REPLACED_BODY(
-    QVTKOpenGLNativeWidget::GetRenderWindow, "VTK 9.0", QVTKOpenGLNativeWidget::renderWindow);
-  return this->renderWindow();
-}
-
-//------------------------------------------------------------------------------
-QVTKInteractorAdapter* QVTKOpenGLNativeWidget::GetInteractorAdapter()
-{
-  VTK_LEGACY_BODY(QVTKOpenGLNativeWidget::GetInteractorAdapter, "VTK 9.0");
-  return nullptr;
-}
-
-//------------------------------------------------------------------------------
-QVTKInteractor* QVTKOpenGLNativeWidget::GetInteractor()
-{
-  VTK_LEGACY_REPLACED_BODY(
-    QVTKOpenGLNativeWidget::GetInteractor, "VTK 9.0", QVTKOpenGLNativeWidget::interactor);
-  return this->interactor();
-}
-
-//------------------------------------------------------------------------------
-void QVTKOpenGLNativeWidget::setQVTKCursor(const QCursor& cursor)
-{
-  VTK_LEGACY_REPLACED_BODY(
-    QVTKOpenGLNativeWidget::setQVTKCursor, "VTK 9.0", QVTKOpenGLNativeWidget::setCursor);
-  this->setCursor(cursor);
-}
-
-//------------------------------------------------------------------------------
-void QVTKOpenGLNativeWidget::setDefaultQVTKCursor(const QCursor& cursor)
-{
-  VTK_LEGACY_REPLACED_BODY(QVTKOpenGLNativeWidget::setDefaultQVTKCursor, "VTK 9.0",
-    QVTKOpenGLNativeWidget::setDefaultCursor);
-  this->setDefaultCursor(cursor);
-}
+VTK_ABI_NAMESPACE_END
