@@ -17,13 +17,14 @@
 
 #include "vtkGUISupportQtModule.h" // For export macro
 #include "vtkTextureObject.h"
+#include <array>      // for ivar
 #include <functional> // for ivar
 
 class QGraphicsScene;
-class QOffscreenSurface;
-class QOpenGLFramebufferObject;
 class QWidget;
 
+VTK_ABI_NAMESPACE_BEGIN
+
 /**
  * @class vtkQWidgetTexture
  * @brief Allows a QWidget to be used as a texture in VTK with OpenGL
@@ -36,14 +37,15 @@ class VTKGUISUPPORTQT_EXPORT vtkQWidgetTexture : public vtkTextureObject
 public:
   static vtkQWidgetTexture* New();
   vtkTypeMacro(vtkQWidgetTexture, vtkTextureObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the QWidget that this TextureObject will render/use
    */
   void SetWidget(QWidget* w);
   QWidget* GetWidget() { return this->Widget; }
-  //@}
+  ///@}
 
   /**
    * get the QScene used for rendering, this is where events will
@@ -52,7 +54,7 @@ public:
   QGraphicsScene* GetScene() { return this->Scene; }
 
   /**
-   * Activate and Bind the texture. Ovrloaded to handle the opengl related
+   * Activate and Bind the texture. Overloaded to handle the opengl related
    * setup at the same time. as We know the context will be active then.
    */
   void Activate() override;
@@ -67,8 +69,6 @@ protected:
   ~vtkQWidgetTexture() override;
 
   QGraphicsScene* Scene;
-  QOffscreenSurface* OffscreenSurface;
-  QOpenGLFramebufferObject* Framebuffer;
   QWidget* Widget;
 
   // method called when the widget needs repainting
@@ -77,9 +77,13 @@ protected:
   // internal method to setup the scene/framebuffer/etc
   void AllocateFromWidget();
 
+  unsigned char* ImageBuffer;
+  std::array<int, 2> ImageBufferDimensions;
+
 private:
   vtkQWidgetTexture(const vtkQWidgetTexture&) = delete;
   void operator=(const vtkQWidgetTexture&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
