@@ -17,7 +17,7 @@
  *
  * This 3D widget handles events between VTK and Qt for a QWidget placed
  * in a scene. It currently takes 6dof events as from VR controllers and
- * if they intersect the widghet it converts them to Qt events and fires
+ * if they intersect the widget it converts them to Qt events and fires
  * them off.
  */
 
@@ -25,10 +25,13 @@
 #define vtkQWidgetWidget_h
 
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"        // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkGUISupportQtModule.h" // For export macro
 #include <QPointF>                 // for ivar
 
 class QWidget;
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkQWidgetRepresentation;
 
 class VTKGUISUPPORTQT_EXPORT vtkQWidgetWidget : public vtkAbstractWidget
@@ -41,13 +44,13 @@ public:
    */
   static vtkQWidgetWidget* New();
 
-  //@{
+  ///@{
   /**
    * Standard vtkObject methods
    */
   vtkTypeMacro(vtkQWidgetWidget, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Specify an instance of vtkQWidgetRepresentation used to represent this
@@ -75,6 +78,7 @@ public:
    * Set the QWidget that will receive the events.
    */
   void SetWidget(QWidget* w);
+  QWidget* GetWidget() { return this->Widget; }
 
 protected:
   vtkQWidgetWidget();
@@ -82,14 +86,20 @@ protected:
 
   // Manage the state of the widget
   int WidgetState;
-  enum _WidgetState
+  enum WidgetStateType
   {
     Start = 0,
     Active
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
 
   QWidget* Widget;
   QPointF LastWidgetCoordinates;
+  QPointF SteadyWidgetCoordinates;
+  double SelectStartTime;
 
   // These methods handle events
   static void SelectAction3D(vtkAbstractWidget*);
@@ -101,4 +111,5 @@ private:
   void operator=(const vtkQWidgetWidget&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
