@@ -30,6 +30,10 @@
 #include <QVBoxLayout>
 
 //------------------------------------------------------------------------------
+Q_DECLARE_METATYPE(vtkObjectBase*);
+
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 class vtkQtDebugLeaksView::qInternal
 {
 public:
@@ -89,15 +93,15 @@ vtkQtDebugLeaksView::vtkQtDebugLeaksView(QWidget* p)
 
   this->connect(filterHelpButton, SIGNAL(clicked()), SLOT(onFilterHelp()));
 
-  this->connect(this->Internal->TableView->selectionModel(),
+  vtkQtDebugLeaksView::connect(this->Internal->TableView->selectionModel(),
     SIGNAL(currentRowChanged(const QModelIndex&, const QModelIndex&)), this,
     SLOT(onCurrentRowChanged(const QModelIndex&)));
 
-  this->connect(this->Internal->TableView, SIGNAL(doubleClicked(const QModelIndex&)), this,
-    SLOT(onRowDoubleClicked(const QModelIndex&)));
+  vtkQtDebugLeaksView::connect(this->Internal->TableView, SIGNAL(doubleClicked(const QModelIndex&)),
+    this, SLOT(onRowDoubleClicked(const QModelIndex&)));
 
-  this->connect(this->Internal->ReferenceTableView, SIGNAL(doubleClicked(const QModelIndex&)), this,
-    SLOT(onRowDoubleClicked(const QModelIndex&)));
+  vtkQtDebugLeaksView::connect(this->Internal->ReferenceTableView,
+    SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT(onRowDoubleClicked(const QModelIndex&)));
 
   this->resize(400, 600);
   this->setWindowTitle("VTK Debug Leaks View");
@@ -162,7 +166,11 @@ void vtkQtDebugLeaksView::onFilterTextChanged(const QString& text)
 {
   if (this->filterEnabled())
   {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    this->Internal->ProxyModel->setFilterRegularExpression(text);
+#else
     this->Internal->ProxyModel->setFilterRegExp(text);
+#endif
   }
 }
 
@@ -175,7 +183,11 @@ void vtkQtDebugLeaksView::onFilterToggled()
     text = "";
   }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+  this->Internal->ProxyModel->setFilterRegularExpression(text);
+#else
   this->Internal->ProxyModel->setFilterRegExp(text);
+#endif
 }
 
 //------------------------------------------------------------------------------
@@ -202,9 +214,6 @@ void vtkQtDebugLeaksView::setFilterText(const QString& text)
   this->Internal->FilterLineEdit->setText(text);
 }
 
-//------------------------------------------------------------------------------
-Q_DECLARE_METATYPE(vtkObjectBase*);
-
 //------------------------------------------------------------------------------
 void vtkQtDebugLeaksView::onRowDoubleClicked(const QModelIndex& index)
 {
@@ -239,3 +248,4 @@ void vtkQtDebugLeaksView::onClassNameDoubleClicked(const QString& className)
 {
   Q_UNUSED(className);
 }
+VTK_ABI_NAMESPACE_END
