@@ -36,12 +36,13 @@
 #include "vtkQtAbstractModelAdapter.h"
 #include <QImage> // Needed for icon support
 
+class QMimeData;
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSelection;
 class vtkTable;
 class vtkVariant;
 
-class QMimeData;
-
 class VTKGUISUPPORTQT_EXPORT vtkQtTableModelAdapter : public vtkQtAbstractModelAdapter
 {
   Q_OBJECT
@@ -51,21 +52,21 @@ public:
   vtkQtTableModelAdapter(vtkTable* table, QObject* parent = nullptr);
   ~vtkQtTableModelAdapter() override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the VTK data object as input to this adapter
    */
   void SetVTKDataObject(vtkDataObject* data) override;
   vtkDataObject* GetVTKDataObject() const override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Selection conversion from VTK land to Qt land
    */
   vtkSelection* QModelIndexListToVTKIndexSelection(const QModelIndexList qmil) const override;
   QItemSelection VTKIndexSelectionToQItemSelection(vtkSelection* vtksel) const override;
-  //@}
+  ///@}
 
   void SetKeyColumnName(const char* name) override;
   void SetColorColumnName(const char* name) override;
@@ -99,7 +100,7 @@ public:
   bool GetSplitMultiComponentColumns() const;
   void SetSplitMultiComponentColumns(bool value);
 
-  //@{
+  ///@{
   /**
    * Set up the model based on the current table.
    */
@@ -114,7 +115,7 @@ public:
   QModelIndex parent(const QModelIndex& index) const override;
   int rowCount(const QModelIndex& parent = QModelIndex()) const override;
   int columnCount(const QModelIndex& parent = QModelIndex()) const override;
-  //@}
+  ///@}
 
   bool dropMimeData(const QMimeData* data, Qt::DropAction action, int row, int column,
     const QModelIndex& parent) override;
@@ -152,5 +153,6 @@ private:
   void operator=(const vtkQtTableModelAdapter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkQtTableModelAdapter.h
