@@ -32,10 +32,12 @@
 #include "vtkObject.h"
 #include <QDateTime> // Needed for method return types
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKGUISUPPORTQTSQL_EXPORT vtkQtTimePointUtility : public vtkObject
 {
 public:
   vtkTypeMacro(vtkQtTimePointUtility, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   static QDateTime TimePointToQDateTime(vtkTypeUInt64 time);
   static vtkTypeUInt64 QDateTimeToTimePoint(QDateTime time);
@@ -51,5 +53,5 @@ private:
   void operator=(const vtkQtTimePointUtility&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-// VTK-HeaderTest-Exclude: vtkQtTimePointUtility.h
