@@ -28,8 +28,11 @@
 #include "vtkGeovisGDALModule.h" // For export macro
 #include "vtkObject.h"
 
-// Forward declarations
+// GDAL Forward declarations
 class GDALDataset;
+
+VTK_ABI_NAMESPACE_BEGIN
+// VTK Forward declarations
 class vtkImageData;
 class vtkUniformGrid;
 
@@ -40,32 +43,28 @@ public:
   vtkTypeMacro(vtkGDALRasterConverter, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * No-data value for pixels in the source image
    * Default is NaN (not used).
    */
   vtkSetMacro(NoDataValue, double);
   vtkGetMacro(NoDataValue, double);
-  //@}
+  ///@}
 
   /**
    * Create GDAL dataset in memory.
    * This dataset must be released by the calling code,
    * using GDALClose().
    */
-  GDALDataset* CreateGDALDataset(int xDim,
-                                 int yDim,
-                                 int vtkDataType,
-                                 int numberOfBands);
+  GDALDataset* CreateGDALDataset(int xDim, int yDim, int vtkDataType, int numberOfBands);
 
   /**
    * Create GDALDataset to match vtkImageData.
    * This dataset must be released by the calling code,
    * using GDALClose().
    */
-  GDALDataset* CreateGDALDataset(
-    vtkImageData* data, const char* mapProjection, int flipAxis[3]);
+  GDALDataset* CreateGDALDataset(vtkImageData* data, const char* mapProjection, int flipAxis[3]);
 
   /**
    * Copies color interpretation and color tables
@@ -88,10 +87,8 @@ public:
   /**
    * Set geo-transform on GDAL dataset.
    */
-  void SetGDALGeoTransform(GDALDataset* dataset,
-                           double origin[2],
-                           double spacing[2],
-                           int flipAxis[2]);
+  void SetGDALGeoTransform(
+    GDALDataset* dataset, double origin[2], double spacing[2], int flipAxis[2]);
 
   /**
    * Copies NoDataValue info from 1st to 2nd dataset
@@ -101,21 +98,18 @@ public:
   /**
    * Write GDALDataset to tiff file
    */
-  void WriteTifFile(GDALDataset* dataset, const char* filename);
+  void WriteTifFile(GDALDataset* dataset, VTK_FILEPATH const char* filename);
 
   /**
    * Traverse values in specified band to find min/max.
    * Note that the bandId starts at 1, not zero.
    * Returns boolean indicating success.
    */
-  bool FindDataRange(GDALDataset* dataset,
-                     int bandId,
-                     double* minValue,
-                     double* maxValue);
+  bool FindDataRange(GDALDataset* dataset, int bandId, double* minValue, double* maxValue);
 
 protected:
   vtkGDALRasterConverter();
-  ~vtkGDALRasterConverter();
+  ~vtkGDALRasterConverter() override;
 
   double NoDataValue;
 
@@ -133,4 +127,5 @@ private:
   void operator=(const vtkGDALRasterConverter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkGDALRasterConverter_h
