@@ -38,13 +38,9 @@
 #include "vtkInformationVector.h"
 #include "vtkLongArray.h"
 #include "vtkLongLongArray.h"
-#ifdef IOADIOS2_HAVE_MPI
-#include "vtkMPI.h"
-#include "vtkMPIController.h"
-#include "vtkMultiProcessController.h" // For the MPI controller member
-#endif
 #include "vtkMultiBlockDataSet.h"
 #include "vtkMultiPieceDataSet.h"
+#include "vtkMultiProcessController.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
@@ -52,7 +48,6 @@
 #include "vtkPolyData.h"
 #include "vtkShortArray.h"
 #include "vtkSignedCharArray.h"
-#include "vtkStdString.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStringArray.h"
 #include "vtkType.h"
@@ -63,6 +58,11 @@
 #include "vtkUnstructuredGrid.h"
 #include "vtksys/SystemTools.hxx"
 
+#ifdef IOADIOS2_HAVE_MPI
+#include "vtkMPI.h"
+#include "vtkMPIController.h"
+#endif
+
 #include <adios2.h> // adios2
 #include <istream>  // istringStream
 #include <string>
@@ -71,12 +71,14 @@
 // Helper functions
 //------------------------------------------------------------------------------
 
+VTK_ABI_NAMESPACE_BEGIN
 bool StringEndsWith(const std::string& a, const std::string& b)
 {
   return a.size() >= b.size() && a.compare(a.size() - b.size(), b.size(), b) == 0;
 }
 //------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkADIOS2CoreImageReader);
+VTK_ABI_NAMESPACE_END
 namespace
 {
 inline std::vector<int> parseDimensions(const std::string& dimsStr)
@@ -91,6 +93,7 @@ inline std::vector<int> parseDimensions(const std::string& dimsStr)
   return dims;
 }
 }
+VTK_ABI_NAMESPACE_BEGIN
 
 //------------------------------------------------------------------------------
 struct vtkADIOS2CoreImageReader::vtkADIOS2CoreImageReaderImpl
@@ -305,8 +308,7 @@ void vtkADIOS2CoreImageReader::SetController(vtkMultiProcessController* controll
   }
 #endif
 
-  this->Controller = controller;
-  this->Modified();
+  vtkSetSmartPointerBodyMacro(Controller, vtkMultiProcessController, controller);
 }
 
 //------------------------------------------------------------------------------
@@ -421,10 +423,7 @@ vtkADIOS2CoreImageReader::vtkADIOS2CoreImageReader()
 }
 
 //------------------------------------------------------------------------------
-vtkADIOS2CoreImageReader::~vtkADIOS2CoreImageReader()
-{
-  this->SetController(nullptr);
-}
+vtkADIOS2CoreImageReader::~vtkADIOS2CoreImageReader() = default;
 
 //------------------------------------------------------------------------------
 int vtkADIOS2CoreImageReader::RequestInformation(
@@ -440,7 +439,7 @@ int vtkADIOS2CoreImageReader::RequestInformation(
     return 0;
   }
 
-  if (!this->Impl->AvailVars.size())
+  if (this->Impl->AvailVars.empty())
   {
     vtkErrorMacro("No variables can be inquired in the provided file. Abort reading");
     return 0;
@@ -490,7 +489,7 @@ int vtkADIOS2CoreImageReader::RequestData(vtkInformation* vtkNotUsed(request),
   // Convert user selected array names into inquire variables
   this->ConvertArraySelectionToInqVar();
 
-  if (!this->Impl->InquiredVars.size())
+  if (this->Impl->InquiredVars.empty())
   {
     this->Impl->Adios.reset(nullptr);
     vtkErrorMacro("No inquire variable is specified. Abort reading now");
@@ -510,13 +509,13 @@ int vtkADIOS2CoreImageReader::RequestData(vtkInformation* vtkNotUsed(request),
     this->RequestTimeStep = outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP());
     if (!this->Impl->TimeStepsReverseMap.count(this->RequestTimeStep))
     {
-      vtkErrorMacro("The requested time step " << this->RequestTimeStep << " is not avaible!");
+      vtkErrorMacro("The requested time step " << this->RequestTimeStep << " is not available!");
       return 0;
     }
     this->Impl->RequestStep = this->Impl->TimeStepsReverseMap[this->RequestTimeStep];
   }
 
-  // Initailize work distribution for each rank
+  // Initialize work distribution for each rank
   if (!this->InitWorkDistribution())
   {
     this->Impl->Adios.reset(nullptr);
@@ -550,7 +549,7 @@ bool vtkADIOS2CoreImageReader::InitWorkDistribution()
     if (typeStr.empty())
     {
       vtkErrorMacro("Cannot find a type for " << varName << " invalid name is provided");
-      return 1;
+      return true;
     }
     // FIXME: adios2 IO object returns an template dependent class instance instead of
     // a pointer or template independent object. Without using std::variant,
@@ -1044,3 +1043,4 @@ void vtkADIOS2CoreImageReader::GatherTimeStepsFromADIOSTimeArray()
     vtkErrorMacro("Fail to gather time steps from time array " << this->TimeStepArray << ex.what());
   }
 }
+VTK_ABI_NAMESPACE_END
