@@ -36,12 +36,12 @@
 #include <vector> // For independently time stepped array indexing
 
 #include "vtkDataObjectAlgorithm.h"
-#include "vtkMultiProcessController.h" // For the process controller
-#include "vtkSetGet.h"                 // For property get/set macros
-#include "vtkSmartPointer.h"           // For the object cache
+#include "vtkSetGet.h"       // For property get/set macros
+#include "vtkSmartPointer.h" // For the object cache
 
 #include "vtkIOADIOS2Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkDataArray;
 class vtkDataObject;
@@ -50,6 +50,7 @@ class vtkDataSetAttributes;
 class vtkFieldData;
 class vtkImageData;
 class vtkMultiBlockDataSet;
+class vtkMultiProcessController;
 class vtkStringArray;
 
 //----------------------------------------------------------------------------
@@ -65,7 +66,7 @@ public:
   using Params = std::map<std::string, std::string>;
   using StringToParams = std::map<std::string, Params>;
   using InquireVariablesType = std::vector<std::pair<std::string, VarType>>;
-  static vtkADIOS2CoreImageReader* New(void);
+  static vtkADIOS2CoreImageReader* New();
   vtkTypeMacro(vtkADIOS2CoreImageReader, vtkDataObjectAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
@@ -73,39 +74,39 @@ public:
    * Test whether or not a given file should even be attempted for use with this
    * reader.
    */
-  int CanReadFile(const std::string& name);
+  int CanReadFile(VTK_FILEPATH const std::string& name);
 
-  virtual int CanReadFile(const char* filename);
+  virtual int CanReadFile(VTK_FILEPATH const char* filename);
 
-  //@{
+  ///@{
   /**
    * Get/Set the input filename
    */
   vtkSetMacro(FileName, std::string);
   vtkGetMacro(FileName, std::string);
-  //@}
+  ///@}
 
-  void SetFileName(const char* filename);
+  void SetFileName(VTK_FILEPATH const char* filename);
 
-  //@{
+  ///@{
   /**
    * Get/Set the origin of output vtkImageData.
    * Default to be the origin point.
    */
   vtkSetVector3Macro(Origin, double);
   vtkGetVector3Macro(Origin, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the spacing of output vtkImageData
    * Default to be 1.0, 1.0, 1.0.
    */
   vtkSetVector3Macro(Spacing, double);
   vtkGetVector3Macro(Spacing, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the name of the array to deduce the dimension
    * of vtkImageData. You can toggle the DimensionArrayAsCell
@@ -114,9 +115,9 @@ public:
   vtkStringArray* GetAllDimensionArrays();
   vtkSetMacro(DimensionArray, std::string);
   vtkGetMacro(DimensionArray, std::string);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/Disable the assumption that the dimension array is cell data.
    * On by default.
@@ -124,19 +125,19 @@ public:
   vtkSetMacro(DimensionArrayAsCell, bool);
   vtkGetMacro(DimensionArrayAsCell, bool);
   vtkBooleanMacro(DimensionArrayAsCell, bool);
-  //@}
+  ///@}
 
   vtkStringArray* GetAllTimeStepArrays();
-  //@{
+  ///@{
   /**
    * Get/Set the name of the time step array. Once it's set, vtk will try to populate the
    * time step info from this array.
    */
   vtkSetMacro(TimeStepArray, std::string);
   vtkGetMacro(TimeStepArray, std::string);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get information about arrays. As is typical with readers this
    * is only valid after the filename is set and UpdateInformation() has been
@@ -149,16 +150,16 @@ public:
   int GetNumberOfArrays();
   const char* GetArrayName(int index);
 
-  //@{
+  ///@{
   /**
    * Set the array that should be read in. Based on the dimension info,
    * proper adios2 arrays will be read in as point or cell dota.
    */
   void SetArrayStatus(const char* name, int status);
   int GetArrayStatus(const char* name);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/Disable the assumption that the order of input data is column major.
    * Off by default.
@@ -169,9 +170,9 @@ public:
   vtkSetMacro(IsColumnMajor, bool);
   vtkGetMacro(IsColumnMajor, bool);
   vtkBooleanMacro(IsColumnMajor, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the active scalar on each image block
    */
@@ -179,26 +180,26 @@ public:
   std::pair<std::string, VarType>& GetActiveScalar();
   const std::pair<std::string, VarType>& GetActiveScalar() const;
 
-  //@{
+  ///@{
   /**
    * Get the available variables. Call this function after calling RequestInformation
    */
   StringToParams& GetAvilableVariables();
   const StringToParams& GetAvilableVariables() const;
 
-  //@{
+  ///@{
   /**
    * Get the available attributes. Call this function after calling RequestInformation
    */
   StringToParams& GetAvailableAttributes();
   const StringToParams& GetAvailableAttributes() const;
 
-  //@{
+  ///@{
   /**
    * Set the MPI controller
    */
   void SetController(vtkMultiProcessController*);
-  //@}
+  ///@}
 
   /**
    * The main interface which triggers the reader to start
@@ -271,4 +272,5 @@ private:
   vtkADIOS2CoreImageReader(const vtkADIOS2CoreImageReader&) = delete;
   void operator=(const vtkADIOS2CoreImageReader&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 #endif
