@@ -34,9 +34,13 @@
 // forward declaring to keep it private
 namespace vtx
 {
+VTK_ABI_NAMESPACE_BEGIN
 class VTXSchemaManager;
+VTK_ABI_NAMESPACE_END
 }
 
+VTK_ABI_NAMESPACE_BEGIN
+
 class vtkIndent;
 class vtkInformation;
 class vtkInformationvector;
@@ -44,30 +48,31 @@ class vtkInformationvector;
 class VTKIOADIOS2_EXPORT vtkADIOS2VTXReader : public vtkMultiBlockDataSetAlgorithm
 {
 public:
-    static vtkADIOS2VTXReader *New();
-    vtkTypeMacro(vtkADIOS2VTXReader, vtkMultiBlockDataSetAlgorithm);
-    void PrintSelf(ostream &os, vtkIndent index) override;
+  static vtkADIOS2VTXReader* New();
+  vtkTypeMacro(vtkADIOS2VTXReader, vtkMultiBlockDataSetAlgorithm);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-    vtkSetStringMacro(FileName);
-    vtkGetStringMacro(FileName);
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
 
 protected:
-    vtkADIOS2VTXReader();
-    ~vtkADIOS2VTXReader() = default;
+  vtkADIOS2VTXReader();
+  ~vtkADIOS2VTXReader();
 
-    vtkADIOS2VTXReader(const vtkADIOS2VTXReader &) = delete;
-    void operator=(const vtkADIOS2VTXReader &) = delete;
+  vtkADIOS2VTXReader(const vtkADIOS2VTXReader&) = delete;
+  void operator=(const vtkADIOS2VTXReader&) = delete;
 
-    int RequestInformation(vtkInformation *, vtkInformationVector **,
-                           vtkInformationVector *outputVector);
-    int RequestUpdateExtent(vtkInformation *, vtkInformationVector **,
-                            vtkInformationVector *outputVector);
-    int RequestData(vtkInformation *, vtkInformationVector **,
-                    vtkInformationVector *outputVector);
+  int RequestInformation(
+    vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector) override;
+  int RequestUpdateExtent(
+    vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector) override;
+  int RequestData(
+    vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector) override;
 
 private:
-    char *FileName;
-    std::unique_ptr<vtx::VTXSchemaManager> SchemaManager;
+  char* FileName;
+  std::unique_ptr<vtx::VTXSchemaManager> SchemaManager;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* vtkADIOS2VTXReader_h */
