@@ -39,6 +39,7 @@
 // Description:
 // Finds the block index (blockIndx) within the HDF5 file associated with
 // the given file index.
+VTK_ABI_NAMESPACE_BEGIN
 static bool FindBlockIndex(hid_t fileIndx, const int blockIdx, hid_t& rootIndx)
 {
   // retrieve the contents of the root directory to look for a group
@@ -107,7 +108,7 @@ static void GetDoubleArrayByName(const hid_t rootIdx, const char* name, std::vec
   int numbPnts = dimValus[0];
 
   array.resize(numbPnts);
-  H5Dread(arrayIdx, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, &array[0]);
+  H5Dread(arrayIdx, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, array.data());
 
   //  H5Dclose( spaceIdx );
   //  H5Dclose( arrayIdx );
@@ -347,7 +348,7 @@ vtkPolyData* vtkAMREnzoParticlesReader::GetParticles(const char* file, const int
 //------------------------------------------------------------------------------
 void vtkAMREnzoParticlesReader::SetupParticleDataSelections()
 {
-  assert("pre: Intenal reader is nullptr" && (this->Internal != nullptr));
+  assert("pre: Internal reader is nullptr" && (this->Internal != nullptr));
 
   unsigned int N = static_cast<unsigned int>(this->Internal->ParticleAttributeNames.size());
   for (unsigned int i = 0; i < N; ++i)
@@ -399,3 +400,4 @@ vtkPolyData* vtkAMREnzoParticlesReader::ReadParticles(const int blkidx)
   vtkPolyData* particles = this->GetParticles(pfile.c_str(), blkidx);
   return (particles);
 }
+VTK_ABI_NAMESPACE_END
