@@ -12,6 +12,7 @@
 #define amrNode 1
 #define amrLeaf 2
 #define amrFullLeaf 3
+VTK_ABI_NAMESPACE_BEGIN
 vtkAMRVelodyneReaderInternal::vtkAMRVelodyneReaderInternal()
 {
   this->Init();
@@ -24,7 +25,6 @@ vtkAMRVelodyneReaderInternal::~vtkAMRVelodyneReaderInternal()
 
 void vtkAMRVelodyneReaderInternal::Init()
 {
-  this->FileName = nullptr;
   this->nLevels = 0;
   this->nBlocks = 0;
   this->nLeaves = 0;
@@ -40,9 +40,9 @@ void vtkAMRVelodyneReaderInternal::Init()
   this->arrayMap.clear();
 }
 
-void vtkAMRVelodyneReaderInternal::SetFileName(char* fileName)
+void vtkAMRVelodyneReaderInternal::SetFileName(VTK_FUTURE_CONST char* fileName)
 {
-  this->FileName = fileName;
+  this->FileName = fileName ? fileName : "";
   if (this->file_id > 0)
   {
     herr_t ierr = this->CloseFile(this->file_id);
@@ -56,7 +56,7 @@ void vtkAMRVelodyneReaderInternal::SetFileName(char* fileName)
 
 void vtkAMRVelodyneReaderInternal::ReadMetaData()
 {
-  if (this->FileName == nullptr || !strcmp(this->FileName, ""))
+  if (this->FileName.empty())
   {
     return;
   }
@@ -64,7 +64,7 @@ void vtkAMRVelodyneReaderInternal::ReadMetaData()
   {
     return;
   }
-  this->file_id = H5Fopen(this->FileName, H5F_ACC_RDONLY, H5P_DEFAULT);
+  this->file_id = H5Fopen(this->FileName.c_str(), H5F_ACC_RDONLY, H5P_DEFAULT);
   if (this->file_id < 0)
   {
     vtkGenericWarningMacro("Failed to open file " << this->FileName << endl);
@@ -167,7 +167,7 @@ void vtkAMRVelodyneReaderInternal::ReadMetaData()
   hid_t atype = H5Aget_type(att_id);
   size_t att_size = H5Tget_size(atype);
   size_t total_size = att_size * nVars;
-  char* stringout = NULL;
+  char* stringout = nullptr;
   stringout = new char[total_size + 1];
   ierr = H5Aread(att_id, atype, stringout);
   if (ierr < 0)
@@ -176,7 +176,7 @@ void vtkAMRVelodyneReaderInternal::ReadMetaData()
   }
   stringout[total_size] = '\0';
   std::string tmp(stringout);
-  delete stringout;
+  delete[] stringout;
   stringout = nullptr;
   for (int i = 0; i < nVars; i++)
   {
@@ -261,8 +261,8 @@ void vtkAMRVelodyneReaderInternal::ReadBlocks()
   std::vector<int> nodeLevels;
   std::vector<double> nodeX0;
   herr_t status;
-  status = H5Eset_auto(NULL, NULL);
-  status = H5Gget_objinfo(grp_amr, "NonLeafNodes", 0, NULL);
+  status = H5Eset_auto(nullptr, nullptr);
+  status = H5Gget_objinfo(grp_amr, "NonLeafNodes", false, nullptr);
   if (status == 0)
   {
     grp_sub = H5Gopen(grp_amr, nodeName.c_str());
@@ -272,8 +272,8 @@ void vtkAMRVelodyneReaderInternal::ReadBlocks()
 
   std::vector<int> leafLevels;
   std::vector<double> leafX0;
-  status = H5Eset_auto(NULL, NULL);
-  status = H5Gget_objinfo(grp_amr, "Leaves", 0, NULL);
+  status = H5Eset_auto(nullptr, nullptr);
+  status = H5Gget_objinfo(grp_amr, "Leaves", false, nullptr);
   if (status == 0)
   {
     grp_sub = H5Gopen(grp_amr, leafName.c_str());
@@ -283,8 +283,8 @@ void vtkAMRVelodyneReaderInternal::ReadBlocks()
 
   std::vector<int> fullLeafLevels;
   std::vector<double> fullLeafX0;
-  status = H5Eset_auto(NULL, NULL);
-  status = H5Gget_objinfo(grp_amr, "FullLeaves", 0, NULL);
+  status = H5Eset_auto(nullptr, nullptr);
+  status = H5Gget_objinfo(grp_amr, "FullLeaves", false, nullptr);
   if (status == 0)
   {
     grp_sub = H5Gopen(grp_amr, fullLeafName.c_str());
@@ -1039,3 +1039,4 @@ vtkDataArray* vtkAMRVelodyneReaderInternal::GetTypeAndArray(const int type, hid_
   }
   return dataArray;
 }
+VTK_ABI_NAMESPACE_END
