@@ -32,6 +32,7 @@
 #include <unordered_map>
 #include <vector>
 
+#include "vtkABINamespace.h"
 #include "vtkByteSwap.h"
 #include "vtkCellData.h"
 #include "vtkDataArray.h"
@@ -48,27 +49,24 @@
 //================================================================================
 //                          INTERNAL VELODYNE READER
 //================================================================================
-typedef struct tagVelodyneSimParameters
-{
-  double Time;
-  int CycleTime;
-} VelodneSimParameters;
+VTK_ABI_NAMESPACE_BEGIN
 
-typedef struct tagBlock
-{
-  int Index;
-  int dSetLoc;
-  int Level;
-  double Origin[3];
-  bool isFull;
-  bool isLeaf;
-} Block;
 class vtkAMRVelodyneReaderInternal
 {
 public:
+  typedef struct tagVelodyneBlock
+  {
+    int Index;
+    int dSetLoc;
+    int Level;
+    double Origin[3];
+    bool isFull;
+    bool isLeaf;
+  } Block;
+
   vtkAMRVelodyneReaderInternal();
   ~vtkAMRVelodyneReaderInternal();
-  void SetFileName(char* fileName);
+  void SetFileName(VTK_FILEPATH VTK_FUTURE_CONST char* fileName);
   void ReadMetaData();
   void GetBlockAttribute(const char* attribute, int blockIdx, vtkUniformGrid* pDataSet);
 
@@ -95,11 +93,13 @@ private:
   herr_t CloseFile(hid_t& fid);
   vtkDataArray* GetTypeAndArray(const int, hid_t&);
 
-  char* FileName;
+  std::string FileName;
   int nLeaves;
   int nFullLeaves;
   int nNodes;
   std::unordered_map<std::string, int> typeMap;
   std::unordered_map<std::string, int> arrayMap;
 };
+VTK_ABI_NAMESPACE_END
 #endif
+// VTK-HeaderTest-Exclude: vtkAMRVelodyneReaderInternal.h
