@@ -22,13 +22,15 @@
 
 #ifndef vtkAMReXGridReaderInternal_h
 #define vtkAMReXGridReaderInternal_h
-#ifndef __VTK_WRAP__
 
+#include <map>
 #include <string>
 #include <vector>
 
 #include "vtkDataSet.h"
+#include "vtkSOADataArrayTemplate.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIndent;
 
 //==============================================================================
@@ -69,7 +71,7 @@ public:
   const std::vector<long>& formatarray() const&;
   const int* order() const&;
   const std::vector<int>& orderarray() const&;
-  int numBytes() const;
+  long numBytes() const;
   bool operator==(const RealDescriptor& rd) const;
 
 private:
@@ -78,7 +80,7 @@ private:
 };
 
 // ----------------------------------------------------------------------------
-//                     Class  RealDecriptor ( end )
+//                     Class  RealDescriptor ( end )
 // ----------------------------------------------------------------------------
 
 // ----------------------------------------------------------------------------
@@ -91,6 +93,21 @@ public:
   std::string versionName;
   int variableNamesSize;
   std::vector<std::string> variableNames;
+
+  // prefix string indicating a variable is a vector component
+  // Note: this prefix will be removed from any variable name
+  // whether or not the variable name is a properly formed
+  // vector variable name (contains a proper postfix)
+  std::string vectorNamePrefix = "amrexvec";
+
+  // delimiter must be the same after prefix and before postfix
+  char nameDelim = '_';
+
+  // variableNames map to (potentially a collection of) variableNames indices
+  std::map<std::string, std::vector<int>> parsedVariableNames;
+  std::map<std::string, std::vector<int>> extraMultiFabParsedVarNames;
+  std::map<std::string, int> extraMultiFabParsedVarMap;
+
   int dim;
   double time;
   int finestLevel;
@@ -106,6 +123,17 @@ public:
   std::vector<std::vector<std::vector<std::vector<double>>>> levelCells;
   std::vector<std::string> levelPrefix;
   std::vector<std::string> multiFabPrefix;
+
+  // use this to store the prefixes for extra multifabs appended to the end of the main header
+  int extraMultiFabCount;
+  // only allow one topology per multifab. 0 == vertex data, 3 == cell data
+  // edge and face data not supported
+  std::vector<int> extraMultiFabVarTopology;
+  // prefix for each multifab on each level [fab][level]
+  std::vector<std::vector<std::string>> extraMultiFabPrefixes;
+  // vector of variables stored on each fab [fab][variable]
+  std::vector<std::vector<std::string>> extraMultiFabVariables;
+
   bool debugHeader;
 
   vtkAMReXGridHeader();
@@ -114,6 +142,21 @@ public:
   void PrintSelfGenericHeader(std::ostream& os, vtkIndent indent);
   bool Parse(const std::string& headerData);
   bool ParseGenericHeader(const std::string& headerData);
+
+  void SetVectorNamePrefix(const std::string& prefix);
+  void SetNameDelimiter(const char delim);
+
+private:
+  // if the vectorNamePrefix is detected at the beginning of the name,
+  // remove it along with the expected x/y/z postfix. Otherwise, return
+  // the original string
+  std::string GetBaseVariableName(const std::string& name);
+
+  // returns 0 if postfix is x, 1 for y and 2 for z. returns -1 otherwise
+  int CheckComponent(const std::string& name);
+
+  // check if name has the vectorNamePrefix
+  bool HasVectorPrefix(const std::string& name);
 };
 
 // ----------------------------------------------------------------------------
@@ -194,12 +237,16 @@ public:
   void ReadMetaData();
   bool ReadHeader();
   bool ReadLevelHeader();
+  bool ReadExtraFabHeader();
   int GetNumberOfLevels();
   int GetBlockLevel(const int blockIdx);
   int GetNumberOfBlocks();
   int GetBlockIndexWithinLevel(int blockIdx, int level);
   void GetBlockAttribute(const char* attribute, int blockIdx, vtkDataSet* pDataSet);
+  void GetExtraMultiFabBlockAttribute(const char* attribute, int blockIdx, vtkDataSet* pDataSet);
   int GetOffsetOfAttribute(const char* attribute);
+  int GetAttributeOffsetExtraMultiFab(const char* attribute, const int fabIndex);
+  int GetExtraMultiFabIndex(const char* attribute);
   void ReadFAB(std::istream& is);
   int ReadVersion(std::istream& is);
   void ReadOrder(std::istream& is, std::vector<int>& ar);
@@ -207,27 +254,66 @@ public:
   void ReadFormat(std::istream& is, std::vector<long>& ar);
   void PrintFormat(std::vector<long>& ar);
   RealDescriptor* ReadRealDescriptor(std::istream& is);
-  int ReadBoxArray(std::istream& is, int* boxArray, int* boxArrayDim);
+  long ReadBoxArray(std::istream& is, int* boxArray, int* boxArrayDim);
   void PrintBoxArray(int* boxArray);
   int ReadNumberOfAttributes(std::istream& is);
-  void ReadBlockAttribute(std::istream& is, int numberOfPoints, int size, char* buffer);
+  void ReadBlockAttribute(std::istream& is, long numberOfPoints, long size, char* buffer);
   void Convert(
     void* out, const void* in, long nitems, const RealDescriptor& ord, const RealDescriptor& ird);
   void PermuteOrder(
     void* out, const void* in, long nitems, const int* outord, const int* inord, int REALSIZE);
 
+  template <typename T>
+  void CreateVTKAttributeArray(vtkAOSDataArrayTemplate<T>* dataArray, const RealDescriptor* ord,
+    const RealDescriptor* ird, const std::vector<std::vector<char>>& buffers,
+    const int numberOfPoints, const std::string& attribute);
+
   bool headersAreRead;
+  bool extraMultiFabHeadersAreRead;
   bool debugReader;
   std::string FileName;
   vtkAMReXGridHeader* Header;
   friend class vtkAMReXGridHeader;
   std::vector<vtkAMReXGridLevelHeader*> LevelHeader;
+  std::vector<std::vector<vtkAMReXGridLevelHeader*>> ExtraMultiFabHeader;
   friend class vtkAMReXGridLeveHeader;
 };
 
+template <typename T>
+void vtkAMReXGridReaderInternal::CreateVTKAttributeArray(vtkAOSDataArrayTemplate<T>* dataArray,
+  const RealDescriptor* ord, const RealDescriptor* ird,
+  const std::vector<std::vector<char>>& buffers, const int numberOfPoints,
+  const std::string& attribute)
+{
+  int nComps = static_cast<int>(this->Header->parsedVariableNames[attribute].size());
+  if (nComps == 0) // check if the variable is in an extra fab
+  {
+    nComps = static_cast<int>(this->Header->extraMultiFabParsedVarNames[attribute].size());
+  }
+  if (nComps == 0)
+  {
+    return;
+  }
+  dataArray->SetName(attribute.c_str());
+  dataArray->SetNumberOfComponents(nComps);
+  dataArray->SetNumberOfTuples(numberOfPoints);
+  T* arrayPtr = new T[numberOfPoints];
+  for (int j = 0; j < nComps; ++j)
+  {
+    this->Convert(arrayPtr, buffers[j].data(), numberOfPoints, *ord, *ird);
+
+    // Copy to data array component
+    for (int i = 0; i < numberOfPoints; ++i)
+    {
+      dataArray->SetTypedComponent(i, j, arrayPtr[i]);
+    }
+  }
+  delete[] arrayPtr;
+}
+
 // ----------------------------------------------------------------------------
 //                     Class  vtkAMReXGridReaderInternal ( end )
 // ----------------------------------------------------------------------------
-#endif
+VTK_ABI_NAMESPACE_END
 #endif /* vtkAMReXGridReaderInternal_h */
 // VTK-HeaderTest-Exclude: vtkAMReXGridReaderInternal.h
