@@ -24,6 +24,7 @@
 
 namespace CGNSRead
 {
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 int setUpRind(const int cgioNum, const double rindId, int* rind)
 {
@@ -91,12 +92,12 @@ int getFirstNodeId(
       return 1;
     }
 
-    if (name != NULL && cgio_get_name(cgioNum, idList[n], nodeName))
+    if (name != nullptr && cgio_get_name(cgioNum, idList[n], nodeName))
     {
       return 1;
     }
 
-    if (0 == strcmp(nodeLabel, label) && (name == NULL || 0 == strcmp(nodeName, name)))
+    if (0 == strcmp(nodeLabel, label) && (name == nullptr || 0 == strcmp(nodeName, name)))
     {
       *id = idList[n];
       nId = 1;
@@ -176,7 +177,7 @@ int get_section_connectivity(const int cgioNum, const double cgioSectionId, cons
     if (sizeOfCnt == sizeof(int))
     {
       int* data = new int[nn];
-      if (data == 0)
+      if (data == nullptr)
       {
         std::cerr << "Allocation failed for temporary connectivity array\n";
       }
@@ -199,7 +200,7 @@ int get_section_connectivity(const int cgioNum, const double cgioSectionId, cons
     else if (sizeOfCnt == sizeof(cglong_t))
     {
       cglong_t* data = new cglong_t[nn];
-      if (data == 0)
+      if (data == nullptr)
       {
         std::cerr << "Allocation failed for temporary connectivity array\n";
         return 1;
@@ -278,7 +279,7 @@ int get_section_start_offset(const int cgioNum, const double cgioSectionId, cons
     if (sizeOfCnt == sizeof(int))
     {
       int* data = new int[nn];
-      if (data == 0)
+      if (data == nullptr)
       {
         std::cerr << "Allocation failed for temporary connectivity offset array\n";
       }
@@ -301,7 +302,7 @@ int get_section_start_offset(const int cgioNum, const double cgioSectionId, cons
     else if (sizeOfCnt == sizeof(cglong_t))
     {
       cglong_t* data = new cglong_t[nn];
-      if (data == 0)
+      if (data == nullptr)
       {
         std::cerr << "Allocation failed for temporary connectivity array\n";
         return 1;
@@ -326,6 +327,105 @@ int get_section_start_offset(const int cgioNum, const double cgioSectionId, cons
   return 0;
 }
 
+//------------------------------------------------------------------------------
+int get_section_parent_elements(const int cgioNum, const double cgioSectionId, const int dim,
+  const cgsize_t* srcStart, const cgsize_t* srcEnd, const cgsize_t* srcStride,
+  const cgsize_t* memStart, const cgsize_t* memEnd, const cgsize_t* memStride,
+  const cgsize_t* memDim, vtkIdType* localPE)
+{
+  const char* PEPath = "ParentElements";
+  double cgioPEId;
+  char dataType[3];
+  std::size_t sizeOfCnt = 0;
+
+  if (cgio_get_node_id(cgioNum, cgioSectionId, PEPath, &cgioPEId) != CG_OK)
+  {
+    return 1; // ParentElements not found
+  }
+
+  cgio_get_data_type(cgioNum, cgioPEId, dataType);
+
+  if (strcmp(dataType, "I4") == 0)
+  {
+    sizeOfCnt = sizeof(int);
+  }
+  else if (strcmp(dataType, "I8") == 0)
+  {
+    sizeOfCnt = sizeof(cglong_t);
+  }
+  else
+  {
+    std::cerr << "ParentElements data_type unknown\n";
+  }
+  if (sizeOfCnt == sizeof(vtkIdType))
+  {
+
+    if (cgio_read_data_type(cgioNum, cgioPEId, srcStart, srcEnd, srcStride, dataType, dim, memDim,
+          memStart, memEnd, memStride, (void*)localPE) != CG_OK)
+    {
+      char message[81];
+      cgio_error_message(message);
+      std::cerr << "cgio_read_data_type :" << message;
+      return 1;
+    }
+  }
+  else
+  {
+    // Need to read into temp array to convert data
+    cgsize_t nn = 1;
+    for (int ii = 0; ii < dim; ii++)
+    {
+      nn *= memDim[ii];
+    }
+    if (sizeOfCnt == sizeof(int))
+    {
+      int* data = new int[nn];
+      if (data == nullptr)
+      {
+        std::cerr << "Allocation failed for temporary ParentElements array\n";
+      }
+      if (cgio_read_data_type(cgioNum, cgioPEId, srcStart, srcEnd, srcStride, "I4", dim, memDim,
+            memStart, memEnd, memStride, (void*)data) != CG_OK)
+      {
+        delete[] data;
+        char message[81];
+        cgio_error_message(message);
+        std::cerr << "cgio_read_data_type :" << message;
+        return 1;
+      }
+      for (cgsize_t n = 0; n < nn; n++)
+      {
+        localPE[n] = static_cast<vtkIdType>(data[n]);
+      }
+      delete[] data;
+    }
+    else if (sizeOfCnt == sizeof(cglong_t))
+    {
+      cglong_t* data = new cglong_t[nn];
+      if (data == nullptr)
+      {
+        std::cerr << "Allocation failed for temporary ParentElements array\n";
+        return 1;
+      }
+      if (cgio_read_data_type(cgioNum, cgioPEId, srcStart, srcEnd, srcStride, "I8", dim, memDim,
+            memStart, memEnd, memStride, (void*)data) != CG_OK)
+      {
+        delete[] data;
+        char message[81];
+        cgio_error_message(message);
+        std::cerr << "cgio_read_data_type :" << message;
+        return 1;
+      }
+      for (cgsize_t n = 0; n < nn; n++)
+      {
+        localPE[n] = static_cast<vtkIdType>(data[n]);
+      }
+      delete[] data;
+    }
+  }
+  cgio_release_id(cgioNum, cgioPEId);
+  return 0;
+}
 //------------------------------------------------------------------------------
 int GetVTKElemType(
   CGNS_ENUMT(ElementType_t) elemType, bool& higherOrderWarning, bool& cgnsOrderFlag)
@@ -522,13 +622,13 @@ inline const int* getTranslator(const int cellType)
     case VTK_PYRAMID:
     case VTK_QUADRATIC_PYRAMID:
     case VTK_WEDGE:
-      return NULL;
+      return nullptr;
     case VTK_QUADRATIC_WEDGE:
       return CGNSRead::PENTA_15_ToVTK;
     case VTK_BIQUADRATIC_QUADRATIC_WEDGE:
       return CGNSRead::PENTA_18_ToVTK;
     case VTK_HEXAHEDRON:
-      return NULL;
+      return nullptr;
     case VTK_QUADRATIC_HEXAHEDRON:
       return CGNSRead::HEXA_20_ToVTK;
     case VTK_TRIQUADRATIC_HEXAHEDRON:
@@ -544,7 +644,7 @@ inline const int* getTranslator(const int cellType)
     case VTK_LAGRANGE_PYRAMID:
       return CGNSRead::PYRA_30_ToVTK;
     default:
-      return NULL;
+      return nullptr;
   }
 }
 
@@ -560,7 +660,7 @@ void CGNS2VTKorder(const vtkIdType size, const int* cells_types, vtkIdType* elem
     translator = getTranslator(cells_types[icell]);
     vtkIdType numPointsPerCell = elements[pos];
     pos++;
-    if (translator != NULL)
+    if (translator != nullptr)
     {
       for (vtkIdType ip = 0; ip < numPointsPerCell; ++ip)
       {
@@ -583,7 +683,7 @@ void CGNS2VTKorderMonoElem(const vtkIdType size, const int cell_type, vtkIdType*
   int tmp[maxPointsPerCells];
   const int* translator;
   translator = getTranslator(cell_type);
-  if (translator == NULL)
+  if (translator == nullptr)
   {
     return;
   }
@@ -630,6 +730,8 @@ void fillVectorsFromVars(std::vector<CGNSRead::CGNSVariable>& vars,
   for (std::size_t n = 0; n < nvar; ++n)
   {
     len = strlen(vars[n].name) - 1;
+    // CGNS convention uses CamelCase for vector naming (VectorX)
+    // For added convenience, snake_case is supported (vector_x)
     switch (vars[n].name[len])
     {
       case 'X':
@@ -644,8 +746,32 @@ void fillVectorsFromVars(std::vector<CGNSRead::CGNSVariable>& vars,
         vars[n].xyzIndex = 3;
         vars[n].isComponent = true;
         break;
+      case 'x':
+        if (len > 0 && vars[n].name[len - 1] == '_')
+        {
+          vars[n].xyzIndex = 1;
+          vars[n].isComponent = true;
+          len -= 1;
+        }
+        break;
+      case 'y':
+        if (len > 0 && vars[n].name[len - 1] == '_')
+        {
+          vars[n].xyzIndex = 2;
+          vars[n].isComponent = true;
+          len -= 1;
+        }
+        break;
+      case 'z':
+        if (len > 0 && vars[n].name[len - 1] == '_')
+        {
+          vars[n].xyzIndex = 3;
+          vars[n].isComponent = true;
+          len -= 1;
+        }
+        break;
     }
-    if (vars[n].isComponent == true)
+    if (vars[n].isComponent)
     {
       strcpy(name, vars[n].name);
       name[len] = '\0';
@@ -671,62 +797,60 @@ void fillVectorsFromVars(std::vector<CGNSRead::CGNSVariable>& vars,
 
   // Detect and tag invalid vector :
   bool invalid = false;
-  for (std::vector<CGNSRead::CGNSVector>::iterator iter = vectors.begin(); iter != vectors.end();
-       ++iter)
+  for (auto& iter : vectors)
   {
     // Check if number of component agrees with phys_dim
-    if (((physicalDim == 3) && (iter->numComp != 6)) ||
-      ((physicalDim == 2) && (iter->numComp != 3)))
+    if (((physicalDim == 3) && (iter.numComp != 6)) || ((physicalDim == 2) && (iter.numComp != 3)))
     {
       for (int index = 0; index < physicalDim; index++)
       {
-        int nv = iter->xyzIndex[index];
+        int nv = iter.xyzIndex[index];
         if (nv >= 0)
         {
           vars[nv].isComponent = false;
         }
       }
-      iter->numComp = 0;
+      iter.numComp = 0;
       invalid = true;
     }
     // Check if a variable is present with a similar
     // name as the vector being built
-    if (CGNSRead::isACGNSVariable(vars, iter->name) == true)
+    if (CGNSRead::isACGNSVariable(vars, iter.name))
     {
       // vtkWarningMacro ( "Warning, vector " << iter->name
       //                  << " can't be assembled." << std::endl );
       for (int index = 0; index < physicalDim; index++)
       {
-        int n = iter->xyzIndex[index];
+        int n = iter.xyzIndex[index];
         if (n >= 0)
         {
           vars[n].isComponent = false;
         }
       }
-      iter->numComp = 0;
+      iter.numComp = 0;
       invalid = true;
     }
-    if (iter->numComp > 0)
+    if (iter.numComp > 0)
     {
       // Check if DataType_t are identical for all components
-      if ((vars[iter->xyzIndex[0]].dt != vars[iter->xyzIndex[1]].dt) ||
-        (vars[iter->xyzIndex[0]].dt != vars[iter->xyzIndex[physicalDim - 1]].dt))
+      if ((vars[iter.xyzIndex[0]].dt != vars[iter.xyzIndex[1]].dt) ||
+        (vars[iter.xyzIndex[0]].dt != vars[iter.xyzIndex[physicalDim - 1]].dt))
       {
         for (int index = 0; index < physicalDim; index++)
         {
-          int n = iter->xyzIndex[index];
+          int n = iter.xyzIndex[index];
           if (n >= 0)
           {
             vars[n].isComponent = false;
           }
         }
-        iter->numComp = 0;
+        iter.numComp = 0;
         invalid = true;
       }
     }
   }
   // Remove invalid vectors
-  if (invalid == true)
+  if (invalid)
   {
     vectors.erase(
       std::remove_if(vectors.begin(), vectors.end(), CGNSRead::testValidVector), vectors.end());
@@ -736,7 +860,6 @@ void fillVectorsFromVars(std::vector<CGNSRead::CGNSVariable>& vars,
 //------------------------------------------------------------------------------
 bool vtkCGNSMetaData::Parse(const char* cgnsFileName)
 {
-
   if (!cgnsFileName)
   {
     return false;
@@ -770,7 +893,7 @@ bool vtkCGNSMetaData::Parse(const char* cgnsFileName)
     return false;
   }
 
-  if (this->baseList.size() > 0)
+  if (!this->baseList.empty())
   {
     this->baseList.clear();
   }
@@ -802,7 +925,7 @@ bool vtkCGNSMetaData::Parse(const char* cgnsFileName)
         }
         nzones++;
 
-        this->baseList[numBase].zones.push_back(CGNSRead::ZoneInformation());
+        this->baseList[numBase].zones.emplace_back();
         if (readZoneInfo(cgioNum, baseChildId[nn], this->baseList[numBase].zones.back()) != CG_OK)
         {
           this->baseList[numBase].zones.pop_back();
@@ -827,7 +950,7 @@ bool vtkCGNSMetaData::Parse(const char* cgnsFileName)
     }
     this->baseList[numBase].nzones = static_cast<int>(nzones);
 
-    if (this->baseList[numBase].times.size() < 1)
+    if (this->baseList[numBase].times.empty())
     {
       // If no time information were found
       // just put default values
@@ -837,10 +960,10 @@ bool vtkCGNSMetaData::Parse(const char* cgnsFileName)
       this->baseList[numBase].times.push_back(0.0);
     }
 
-    if (nzones > 0)
+    // Read variable name and more from each zone
+    for (nn = 0; nn < nzones; ++nn)
     {
-      // variable name and more, based on first zone only
-      readZoneInfo(cgioNum, baseChildId[0], this->baseList[numBase]);
+      readZoneInfo(cgioNum, baseChildId[nn], this->baseList[numBase]);
     }
   }
 
@@ -896,21 +1019,23 @@ void vtkCGNSMetaData::PrintSelf(std::ostream& os)
       os << "      Cell :: ";
       os << this->baseList[b].CellDataArraySelection.GetArrayName(i) << std::endl;
     }
+    for (int i = 0; i < this->baseList[b].FaceDataArraySelection.GetNumberOfArrays(); ++i)
+    {
+      os << "      Face :: ";
+      os << this->baseList[b].FaceDataArraySelection.GetArrayName(i) << std::endl;
+    }
 
     os << "    Family Number: " << this->baseList[b].family.size() << std::endl;
-    for (std::size_t fam = 0; fam < this->baseList[b].family.size(); fam++)
+    for (const auto& fam : this->baseList[b].family)
     {
-      os << "      Family: " << this->baseList[b].family[fam].name
-         << " is BC: " << this->baseList[b].family[fam].isBC << std::endl;
+      os << "      Family: " << fam.name << " is BC: " << fam.isBC << std::endl;
     }
 
     os << "    Reference State:" << std::endl;
-    std::map<std::string, double>::iterator iter;
-    for (iter = this->baseList[b].referenceState.begin();
-         iter != this->baseList[b].referenceState.end(); iter++)
+    for (const auto& iter : this->baseList[b].referenceState)
     {
-      os << "  Variable: " << iter->first;
-      os << "  Value: " << iter->second << std::endl;
+      os << "  Variable: " << iter.first;
+      os << "  Value: " << iter.second << std::endl;
     }
   }
 }
@@ -934,13 +1059,14 @@ static void BroadcastString(vtkMultiProcessController* controller, std::string&
     {
       std::vector<char> tmp;
       tmp.resize(len);
-      controller->Broadcast(&(tmp[0]), len, 0);
-      str = &tmp[0];
+      controller->Broadcast(tmp.data(), len, 0);
+      str = tmp.data();
     }
     else
     {
       const char* start = str.c_str();
       std::vector<char> tmp(start, start + len);
+      // NOLINTNEXTLINE(readability-container-data-pointer): needs C++17
       controller->Broadcast(&tmp[0], len, 0);
     }
   }
@@ -957,7 +1083,7 @@ static void BroadcastDoubleVector(
   }
   if (len)
   {
-    controller->Broadcast(&dvec[0], len, 0);
+    controller->Broadcast(dvec.data(), len, 0);
   }
 }
 //------------------------------------------------------------------------------
@@ -972,7 +1098,7 @@ static void BroadcastIntVector(
   }
   if (len)
   {
-    controller->Broadcast(&ivec[0], len, 0);
+    controller->Broadcast(ivec.data(), len, 0);
   }
 }
 //------------------------------------------------------------------------------
@@ -983,19 +1109,18 @@ static void BroadcastSelection(
   controller->Broadcast(&len, 1, 0);
   if (rank == 0)
   {
-    std::map<std::string, bool>::iterator ite;
     int tmp;
-    for (ite = selection.begin(); ite != selection.end(); ++ite)
+    for (auto& ite : selection)
     {
-      unsigned long len2 = static_cast<unsigned long>(ite->first.size()) + 1;
+      unsigned long len2 = static_cast<unsigned long>(ite.first.size()) + 1;
       controller->Broadcast(&len2, 1, 0);
       if (len2)
       {
-        const char* start = ite->first.c_str();
+        const char* start = ite.first.c_str();
         std::vector<char> tmpVector(start, start + len2);
-        controller->Broadcast(&tmpVector[0], len2, 0);
+        controller->Broadcast(tmpVector.data(), len2, 0);
       }
-      tmp = (int)ite->second;
+      tmp = (int)ite.second;
       controller->Broadcast(&tmp, 1, 0);
     }
   }
@@ -1022,18 +1147,17 @@ static void BroadcastRefState(
   controller->Broadcast(&len, 1, 0);
   if (rank == 0)
   {
-    std::map<std::string, double>::iterator ite;
-    for (ite = refInfo.begin(); ite != refInfo.end(); ++ite)
+    for (auto& ite : refInfo)
     {
-      unsigned long len2 = static_cast<unsigned long>(ite->first.size()) + 1;
+      unsigned long len2 = static_cast<unsigned long>(ite.first.size()) + 1;
       controller->Broadcast(&len2, 1, 0);
       if (len2)
       {
-        const char* start = ite->first.c_str();
+        const char* start = ite.first.c_str();
         std::vector<char> tmp(start, start + len2);
-        controller->Broadcast(&tmp[0], len2, 0);
+        controller->Broadcast(tmp.data(), len2, 0);
       }
-      controller->Broadcast(&ite->second, 1, 0);
+      controller->Broadcast(&ite.second, 1, 0);
     }
   }
   else
@@ -1058,14 +1182,13 @@ static void BroadcastFamilies(vtkMultiProcessController* controller,
   {
     famInfo.resize(len);
   }
-  std::vector<CGNSRead::FamilyInformation>::iterator ite;
-  for (ite = famInfo.begin(); ite != famInfo.end(); ++ite)
+  for (auto& ite : famInfo)
   {
-    BroadcastString(controller, ite->name, rank);
+    BroadcastString(controller, ite.name, rank);
     int flags = 0;
     if (rank == 0)
     {
-      if (ite->isBC == true)
+      if (ite.isBC)
       {
         flags = 1;
       }
@@ -1076,7 +1199,7 @@ static void BroadcastFamilies(vtkMultiProcessController* controller,
       controller->Broadcast(&flags, 1, 0);
       if ((flags & 1) != 0)
       {
-        ite->isBC = true;
+        ite.isBC = true;
       }
     }
   }
@@ -1136,23 +1259,22 @@ void vtkCGNSMetaData::Broadcast(vtkMultiProcessController* controller, int rank)
   {
     this->baseList.resize(len);
   }
-  std::vector<CGNSRead::BaseInformation>::iterator ite;
-  for (ite = this->baseList.begin(); ite != baseList.end(); ++ite)
+  for (auto& ite : this->baseList)
   {
-    CGNSRead::BroadcastCGNSString(controller, ite->name);
-    controller->Broadcast(&ite->cellDim, 1, 0);
-    controller->Broadcast(&ite->physicalDim, 1, 0);
-    controller->Broadcast(&ite->baseNumber, 1, 0);
-    controller->Broadcast(&ite->nzones, 1, 0);
+    CGNSRead::BroadcastCGNSString(controller, ite.name);
+    controller->Broadcast(&ite.cellDim, 1, 0);
+    controller->Broadcast(&ite.physicalDim, 1, 0);
+    controller->Broadcast(&ite.baseNumber, 1, 0);
+    controller->Broadcast(&ite.nzones, 1, 0);
 
     int flags = 0;
     if (rank == 0)
     {
-      if (ite->useGridPointers == true)
+      if (ite.useGridPointers)
       {
         flags = 1;
       }
-      if (ite->useFlowPointers == true)
+      if (ite.useFlowPointers)
       {
         flags = (flags | 2);
       }
@@ -1163,23 +1285,24 @@ void vtkCGNSMetaData::Broadcast(vtkMultiProcessController* controller, int rank)
       controller->Broadcast(&flags, 1, 0);
       if ((flags & 1) != 0)
       {
-        ite->useGridPointers = true;
+        ite.useGridPointers = true;
       }
       if ((flags & 2) != 0)
       {
-        ite->useFlowPointers = true;
+        ite.useFlowPointers = true;
       }
     }
 
-    CGNSRead::BroadcastRefState(controller, ite->referenceState, rank);
-    CGNSRead::BroadcastFamilies(controller, ite->family, rank);
-    CGNSRead::BroadcastZones(controller, ite->zones, rank);
+    CGNSRead::BroadcastRefState(controller, ite.referenceState, rank);
+    CGNSRead::BroadcastFamilies(controller, ite.family, rank);
+    CGNSRead::BroadcastZones(controller, ite.zones, rank);
 
-    CGNSRead::BroadcastSelection(controller, ite->PointDataArraySelection, rank);
-    CGNSRead::BroadcastSelection(controller, ite->CellDataArraySelection, rank);
+    CGNSRead::BroadcastSelection(controller, ite.PointDataArraySelection, rank);
+    CGNSRead::BroadcastSelection(controller, ite.CellDataArraySelection, rank);
+    CGNSRead::BroadcastSelection(controller, ite.FaceDataArraySelection, rank);
 
-    BroadcastIntVector(controller, ite->steps, rank);
-    BroadcastDoubleVector(controller, ite->times, rank);
+    BroadcastIntVector(controller, ite.steps, rank);
+    BroadcastDoubleVector(controller, ite.times, rank);
   }
   CGNSRead::BroadcastString(controller, this->LastReadFilename, rank);
   BroadcastDoubleVector(controller, this->GlobalTime, rank);
@@ -1251,4 +1374,5 @@ bool ReadPatch(vtkCGNSReader* reader, const BaseInformation&, const ZoneInformat
   return true;
 }
 
+VTK_ABI_NAMESPACE_END
 } // end of namespace
