@@ -20,10 +20,7 @@
  *     parse a file in "CGNS" format
  *
  * @warning
- *     Only Cell/Vertex data are supported.
- *
- * @par Thanks:
- * Thanks to .
+ *     Only Cell/Face/Vertex data are supported.
  */
 
 #ifndef vtkCGNSReaderInternal_h
@@ -41,13 +38,18 @@
 #include "vtkMultiProcessController.h"
 #include "vtkNew.h"
 #include "vtkPoints.h"
+
+// .clang-format off
 #include "vtk_cgns.h"
+#include VTK_CGNS(cgnslib.h)
+#include VTK_CGNS(cgns_io.h)
+// .clang-format on
 
 namespace CGNSRead
 {
-
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 template <typename T>
 struct is_double
 {
@@ -71,10 +73,12 @@ struct is_float<float>
 {
   static const bool value = true;
 };
+VTK_ABI_NAMESPACE_END
 }
 
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 template <typename T>
 constexpr const char* cgns_type_name() noexcept
 {
@@ -104,8 +108,10 @@ constexpr const char* cgns_type_name<vtkTypeInt64>() noexcept
 {
   return "I8";
 }
+VTK_ABI_NAMESPACE_END
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 typedef char char_33[33];
 
 //------------------------------------------------------------------------------
@@ -157,7 +163,7 @@ public:
       }
       cc++;
     }
-    return NULL;
+    return nullptr;
   }
 
   int GetNumberOfArrays() { return static_cast<int>(this->size()); }
@@ -280,11 +286,12 @@ public:
   // std::vector<CGNSRead::zone> zone;
   vtkCGNSArraySelection PointDataArraySelection;
   vtkCGNSArraySelection CellDataArraySelection;
+  vtkCGNSArraySelection FaceDataArraySelection;
 };
 
 //==============================================================================
 
-//@{
+///@{
 /**
  * Helpers to encapsulate all logic to read various nodes (zones, bc patches
  * etc.).
@@ -295,7 +302,7 @@ bool ReadGridForZone(
 bool ReadPatchesForBase(vtkCGNSReader* reader, const BaseInformation&);
 bool ReadPatch(vtkCGNSReader* reader, const BaseInformation&, const ZoneInformation& zoneInfo,
   const std::string& patchFamilyname);
-//@}
+///@}
 
 //==============================================================================
 class vtkCGNSMetaData
@@ -329,13 +336,13 @@ public:
 
   void Broadcast(vtkMultiProcessController* controller, int rank);
 
-  //@{
+  ///@{
   /**
    * Constructor/Destructor
    */
   vtkCGNSMetaData() = default;
   ~vtkCGNSMetaData() = default;
-  //@}
+  ///@}
 
 private:
   vtkCGNSMetaData(const vtkCGNSMetaData&) = delete;
@@ -408,8 +415,8 @@ int setUpRind(const int cgioNum, const double rindId, int* rind);
  * Find the first node with the given `label`. If `name` is non-NULL, then the
  * first node with given `label` that has the given `name` as well.
  */
-int getFirstNodeId(
-  const int cgioNum, const double parentId, const char* label, double* id, const char* name = NULL);
+int getFirstNodeId(const int cgioNum, const double parentId, const char* label, double* id,
+  const char* name = nullptr);
 //------------------------------------------------------------------------------
 int get_section_connectivity(const int cgioNum, const double cgioSectionId, const int dim,
   const cgsize_t* srcStart, const cgsize_t* srcEnd, const cgsize_t* srcStride,
@@ -421,6 +428,11 @@ int get_section_start_offset(const int cgioNum, const double cgioSectionId, cons
   const cgsize_t* memStart, const cgsize_t* memEnd, const cgsize_t* memStride,
   const cgsize_t* memDim, vtkIdType* localElementsIdx);
 //------------------------------------------------------------------------------
+int get_section_parent_elements(const int cgioNum, const double cgioSectionId, const int dim,
+  const cgsize_t* srcStart, const cgsize_t* srcEnd, const cgsize_t* srcStride,
+  const cgsize_t* memStart, const cgsize_t* memEnd, const cgsize_t* memStride,
+  const cgsize_t* memDim, vtkIdType* localElementsIdx);
+//------------------------------------------------------------------------------
 int GetVTKElemType(
   CGNS_ENUMT(ElementType_t) elemType, bool& higherOrderWarning, bool& cgnsOrderFlag);
 //------------------------------------------------------------------------------
@@ -510,12 +522,12 @@ int get_XYZ_mesh(const int cgioNum, const std::vector<double>& gridChildId,
     else
     {
       constexpr const char* dtNameY = detail::cgns_type_name<Y>();
-      Y* dataArray = 0;
+      Y* dataArray = nullptr;
       const cgsize_t memNoStride[3] = { 1, 1, 1 };
 
       // need to read into temp array to convert data
       dataArray = new Y[nPts];
-      if (dataArray == 0)
+      if (dataArray == nullptr)
       {
         std::cerr << "Error allocating buffer array\n";
         break;
@@ -538,6 +550,7 @@ int get_XYZ_mesh(const int cgioNum, const std::vector<double>& gridChildId,
   }
   return 0;
 }
+VTK_ABI_NAMESPACE_END
 }
 
 #endif // vtkCGNSReaderInternal_h
