@@ -43,56 +43,14 @@
 #define H5_USE_16_API
 #include "vtk_hdf5.h"
 
+#include "vtkHDF5ScopedHandle.h"
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCONVERGECFDReader);
 
 namespace
 {
 
-//----------------------------------------------------------------------------
-/**
- * RAII class for automatically closing H5 handles.
- */
-#define DefineScopedHandle(name)                                                                   \
-  class ScopedH5##name##Handle                                                                     \
-  {                                                                                                \
-  public:                                                                                          \
-    ScopedH5##name##Handle(const ScopedH5##name##Handle& other) { this->Handle = other.Handle; }   \
-    ScopedH5##name##Handle(hid_t handle)                                                           \
-      : Handle(handle)                                                                             \
-    {                                                                                              \
-    }                                                                                              \
-    virtual ~ScopedH5##name##Handle()                                                              \
-    {                                                                                              \
-      if (this->Handle >= 0)                                                                       \
-      {                                                                                            \
-        H5##name##close(this->Handle);                                                             \
-      }                                                                                            \
-    }                                                                                              \
-                                                                                                   \
-    operator hid_t() const { return this->Handle; }                                                \
-                                                                                                   \
-  private:                                                                                         \
-    hid_t Handle;                                                                                  \
-  };
-
-// Defines ScopedH5AHandle closed with H5Aclose
-DefineScopedHandle(A);
-
-// Defines ScopedH5DHandle closed with H5Dclose
-DefineScopedHandle(D);
-
-// Defines ScopedH5FHandle closed with H5Fclose
-DefineScopedHandle(F);
-
-// Defines ScopedH5GHandle closed with H5Gclose
-DefineScopedHandle(G);
-
-// Defines ScopedH5SHandle closed with H5Sclose
-DefineScopedHandle(S);
-
-// Defines ScopedH5THandle closed with H5Tclose
-DefineScopedHandle(T);
-
 //----------------------------------------------------------------------------
 /**
  *  Check existence of array defined by pathName relative to fileId.
@@ -118,14 +76,14 @@ bool GroupExists(hid_t fileId, const char* groupName)
  */
 hsize_t GetDataLength(hid_t fileId, const char* pathName)
 {
-  ScopedH5DHandle arrayId = H5Dopen(fileId, pathName);
+  vtkHDF::ScopedH5DHandle arrayId = H5Dopen(fileId, pathName);
   if (arrayId < 0)
   {
     vtkGenericWarningMacro("No array named " << pathName << " available");
     return 0;
   }
 
-  ScopedH5DHandle dataspace = H5Dget_space(arrayId);
+  vtkHDF::ScopedH5DHandle dataspace = H5Dget_space(arrayId);
   if (H5Sget_simple_extent_ndims(dataspace) != 1)
   {
     vtkGenericWarningMacro("Array " << pathName << " dimensionality is not 1");
@@ -154,15 +112,15 @@ hsize_t GetDataLength(hid_t fileId, const char* pathName)
 template <typename T>
 bool ReadArray(hid_t fileId, const char* pathName, T* data, hsize_t n)
 {
-  ScopedH5DHandle arrayId = H5Dopen(fileId, pathName);
+  vtkHDF::ScopedH5DHandle arrayId = H5Dopen(fileId, pathName);
   if (arrayId < 0)
   {
     return false;
   }
 
-  ScopedH5DHandle rawType = H5Dget_type(arrayId);
-  ScopedH5THandle dataType = H5Tget_native_type(rawType, H5T_DIR_ASCEND);
-  ScopedH5DHandle dataspace = H5Dget_space(arrayId);
+  vtkHDF::ScopedH5DHandle rawType = H5Dget_type(arrayId);
+  vtkHDF::ScopedH5THandle dataType = H5Tget_native_type(rawType, H5T_DIR_ASCEND);
+  vtkHDF::ScopedH5DHandle dataspace = H5Dget_space(arrayId);
   if (H5Sget_simple_extent_ndims(dataspace) != 1)
   {
     vtkGenericWarningMacro("Array " << pathName << " dimensionality is not 1");
@@ -200,18 +158,18 @@ bool ReadArray(hid_t fileId, const char* pathName, T* data, hsize_t n)
  */
 bool ReadStrings(hid_t fileId, const char* path, std::vector<std::string>& strings)
 {
-  ScopedH5DHandle stringsId = H5Dopen(fileId, path);
+  vtkHDF::ScopedH5DHandle stringsId = H5Dopen(fileId, path);
   if (stringsId < 0)
   {
     vtkGenericWarningMacro("Could not read " << path);
     return false;
   }
 
-  ScopedH5THandle filetype = H5Dget_type(stringsId);
+  vtkHDF::ScopedH5THandle filetype = H5Dget_type(stringsId);
   size_t sdim = H5Tget_size(filetype);
   sdim++; /* Make room for null terminator */
 
-  ScopedH5SHandle space = H5Dget_space(stringsId);
+  vtkHDF::ScopedH5SHandle space = H5Dget_space(stringsId);
   hsize_t dim;
   int ndims = H5Sget_simple_extent_dims(space, &dim, nullptr);
   if (ndims != 1)
@@ -227,7 +185,7 @@ bool ReadStrings(hid_t fileId, const char* path, std::vector<std::string>& strin
     rdata[i] = rdata[0] + i * sdim;
   }
 
-  ScopedH5THandle memtype = H5Tcopy(H5T_C_S1);
+  vtkHDF::ScopedH5THandle memtype = H5Tcopy(H5T_C_S1);
   H5Tset_size(memtype, sdim);
   if (H5Dread(stringsId, memtype, H5S_ALL, H5S_ALL, H5P_DEFAULT, rdata[0]) < 0)
   {
@@ -481,7 +439,7 @@ int vtkCONVERGECFDReader::RequestInformation(
   // Reset internal information
   this->Internal->Reset();
 
-  ScopedH5FHandle fileId = H5Fopen(this->FileName, H5F_ACC_RDONLY, H5P_DEFAULT);
+  vtkHDF::ScopedH5FHandle fileId = H5Fopen(this->FileName, H5F_ACC_RDONLY, H5P_DEFAULT);
   if (fileId < 0)
   {
     vtkErrorMacro("Could not open HDF5 file '" << this->FileName << "'");
@@ -505,7 +463,7 @@ int vtkCONVERGECFDReader::RequestInformation(
     }
 
     // Open the group
-    ScopedH5GHandle streamId = H5Gopen(fileId, streamName.str().c_str());
+    vtkHDF::ScopedH5GHandle streamId = H5Gopen(fileId, streamName.str().c_str());
     if (streamId < 0)
     {
       // Group exists, but could not be opened
@@ -545,7 +503,7 @@ int vtkCONVERGECFDReader::RequestInformation(
     else
     {
       // 3.1 and later format
-      ScopedH5GHandle varNamesHandle = H5Gopen(streamId, "VARIABLE_NAMES");
+      vtkHDF::ScopedH5GHandle varNamesHandle = H5Gopen(streamId, "VARIABLE_NAMES");
       if (varNamesHandle < 0)
       {
         vtkErrorMacro("Cannot open /" << streamId << "/VARIABLE_NAMES");
@@ -709,14 +667,14 @@ int vtkCONVERGECFDReader::RequestData(
   hierarchy->Initialize();
   outputPDC->SetDataAssembly(hierarchy);
 
-  ScopedH5FHandle fileId = H5Fopen(fileName.c_str(), H5F_ACC_RDONLY, H5P_DEFAULT);
+  vtkHDF::ScopedH5FHandle fileId = H5Fopen(fileName.c_str(), H5F_ACC_RDONLY, H5P_DEFAULT);
   if (fileId < 0)
   {
     vtkErrorMacro("Could not open HDF5 file '" << fileName << "'");
     return 0;
   }
 
-  ScopedH5GHandle boundaryHandle = H5Gopen(fileId, "/BOUNDARIES");
+  vtkHDF::ScopedH5GHandle boundaryHandle = H5Gopen(fileId, "/BOUNDARIES");
   if (boundaryHandle < 0)
   {
     vtkErrorMacro("Cannot open group/BOUNDARIES");
@@ -746,7 +704,7 @@ int vtkCONVERGECFDReader::RequestData(
     }
 
     // Open the group
-    ScopedH5GHandle streamId = H5Gopen(fileId, streamName.str().c_str());
+    vtkHDF::ScopedH5GHandle streamId = H5Gopen(fileId, streamName.str().c_str());
     if (streamId < 0)
     {
       vtkErrorMacro("Could not open stream " << streamName.str());
@@ -963,7 +921,7 @@ int vtkCONVERGECFDReader::RequestData(
         vtkIdType ptId = polygons[polygonOffsets[polyId] + id];
         ptIds[id] = blocksOriginalToBlockPointId[boundaryIndex][ptId];
       }
-      polyData->GetPolys()->InsertNextCell(numCellPts, &ptIds[0]);
+      polyData->GetPolys()->InsertNextCell(numCellPts, ptIds.data());
     }
 
     // Clear some memory
@@ -1164,7 +1122,7 @@ int vtkCONVERGECFDReader::RequestData(
         // Handle 3.1 or above version
 
         // Get parcel data type names
-        ScopedH5GHandle parcelDataTypesHandle = H5Gopen(streamId, "PARCEL_DATA");
+        vtkHDF::ScopedH5GHandle parcelDataTypesHandle = H5Gopen(streamId, "PARCEL_DATA");
         // We already checked that the group exists, so no need to check again.
 
         hsize_t numParcelDataTypes = 0;
@@ -1195,7 +1153,7 @@ int vtkCONVERGECFDReader::RequestData(
           std::string dataType(groupName);
           std::string dataTypeGroupName("PARCEL_DATA/");
           dataTypeGroupName += dataType;
-          ScopedH5GHandle dataTypeHandle = H5Gopen(streamId, dataTypeGroupName.c_str());
+          vtkHDF::ScopedH5GHandle dataTypeHandle = H5Gopen(streamId, dataTypeGroupName.c_str());
           if (dataTypeHandle < 0)
           {
             vtkErrorMacro("Cannot open group " << dataTypeGroupName);
@@ -1305,8 +1263,8 @@ void vtkCONVERGECFDReader::ReadTimeSteps(vtkInformation* outInfo)
   vtkNew<vtkDirectory> dir;
   if (!dir->Open(path.c_str()))
   {
-    vtkWarningMacro(<< "Could not open directory " << originalFile.c_str()
-                    << " is supposed to be from (" << path.c_str() << ")");
+    vtkWarningMacro(<< "Could not open directory " << originalFile << " is supposed to be from ("
+                    << path << ")");
     fileNames.emplace_back(originalFile);
     return;
   }
@@ -1356,7 +1314,7 @@ void vtkCONVERGECFDReader::ReadTimeSteps(vtkInformation* outInfo)
     double timeRange[2] = { times[0], times[times.size() - 1] };
     outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), timeRange, 2);
     outInfo->Set(
-      vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &times[0], static_cast<int>(times.size()));
+      vtkStreamingDemandDrivenPipeline::TIME_STEPS(), times.data(), static_cast<int>(times.size()));
   }
 }
 
@@ -1368,7 +1326,7 @@ bool vtkCONVERGECFDReader::ReadOutputTime(const std::string& filePath, double& t
     return false;
   }
 
-  ScopedH5FHandle fileId = H5Fopen(filePath.c_str(), H5F_ACC_RDONLY, H5P_DEFAULT);
+  vtkHDF::ScopedH5FHandle fileId = H5Fopen(filePath.c_str(), H5F_ACC_RDONLY, H5P_DEFAULT);
   if (fileId < 0)
   {
     return false;
@@ -1376,10 +1334,10 @@ bool vtkCONVERGECFDReader::ReadOutputTime(const std::string& filePath, double& t
 
   if (H5Aexists(fileId, "OUTPUT_TIME"))
   {
-    ScopedH5AHandle outputTimeId =
+    vtkHDF::ScopedH5AHandle outputTimeId =
       H5Aopen_by_name(fileId, ".", "OUTPUT_TIME", H5P_DEFAULT, H5P_DEFAULT);
-    ScopedH5THandle rawType = H5Aget_type(outputTimeId);
-    ScopedH5THandle dataType = H5Tget_native_type(rawType, H5T_DIR_ASCEND);
+    vtkHDF::ScopedH5THandle rawType = H5Aget_type(outputTimeId);
+    vtkHDF::ScopedH5THandle dataType = H5Tget_native_type(rawType, H5T_DIR_ASCEND);
 
     double outputTime = 0.0;
     if (H5Aread(outputTimeId, dataType, &outputTime) >= 0)
@@ -1428,7 +1386,7 @@ int vtkCONVERGECFDReader::CanReadFile(const char* fname)
     return 0;
   }
 
-  ScopedH5FHandle fileId = H5Fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT);
+  vtkHDF::ScopedH5FHandle fileId = H5Fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT);
   if (fileId < 0)
   {
     return 0;
@@ -1444,3 +1402,4 @@ int vtkCONVERGECFDReader::CanReadFile(const char* fname)
   // Everything succeeded
   return 1;
 }
+VTK_ABI_NAMESPACE_END
