@@ -52,6 +52,7 @@
 #include <unordered_map>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCityGMLReader::Implementation
 {
 public:
@@ -62,7 +63,6 @@ public:
     MATERIAL
   };
 
-public:
   Implementation(vtkCityGMLReader* reader, int lod, int useTransparencyAsOpacity)
   {
     this->Initialize(reader, lod, useTransparencyAsOpacity);
@@ -127,7 +127,7 @@ public:
       {
         const char* value = node.child_value();
         std::istringstream iss(value);
-        std::array<float, 3> color;
+        std::array<double, 3> color;
         for (size_t i = 0; i < color.size(); ++i)
         {
           iss >> color[i];
@@ -142,9 +142,14 @@ public:
         }
         else if (std::string(node.name()) == "app:transparency")
         {
-          float transparency = this->UseTransparencyAsOpacity ? 1 - color[0] : color[0];
+          double transparency = this->UseTransparencyAsOpacity ? 1 - color[0] : color[0];
           material.Transparency = transparency;
         }
+        else if (std::string(node.name()) == "app:shininess")
+        {
+          double shininess = color[0];
+          material.Shininess = shininess;
+        }
       }
       this->Materials.push_back(material);
       size_t indexMaterial = this->Materials.size() - 1;
@@ -235,7 +240,7 @@ public:
     transformFilter->SetInputDataObject(it->second);
     transformFilter->Update();
     vtkDataObject* obj = transformFilter->GetOutputDataObject(0);
-    this->SetField(obj, "element", element);
+    vtkCityGMLReader::Implementation::SetField(obj, "element", element);
     output->SetBlock(output->GetNumberOfBlocks(), obj);
   }
 
@@ -243,7 +248,7 @@ public:
     const char* gmlNamespace, const char* feature)
   {
     vtkNew<vtkMultiBlockDataSet> b;
-    this->SetField(b, "element", "grp:CityObjectGroup");
+    vtkCityGMLReader::Implementation::SetField(b, "element", "grp:CityObjectGroup");
     auto ximplicitGeometry =
       doc.select_nodes((std::string("//") + gmlNamespace + ":" + feature + "/" + gmlNamespace +
         ":" + "lod" + std::to_string(this->LOD) + "ImplicitRepresentation/core:ImplicitGeometry")
@@ -419,7 +424,7 @@ public:
           ++i;
         }
       } while (validPoint);
-      // gml:posList repeates the last point in a
+      // gml:posList repeats the last point in a
       // polygon (there are n points). We only need the first n - 1.
       polyPointIds->SetNumberOfIds(polyPointIds->GetNumberOfIds() - 1);
       points->SetNumberOfPoints(points->GetNumberOfPoints() - 1);
@@ -432,7 +437,7 @@ public:
       // go over all gml:pos children
       for (pugi::xml_node pos : nodeRing.children())
       {
-        // Part-1-Terrain-WaterBody-Vegetation-V2.gml repeates the last point in a
+        // Part-1-Terrain-WaterBody-Vegetation-V2.gml repeats the last point in a
         // polygon (there are n points). We only read the first n - 1.
         if (i == n - 1)
         {
@@ -515,7 +520,7 @@ public:
     else
     {
       std::array<double, 3> p;
-      // Part-1-Terrain-WaterBody-Vegetation-V2.gml repeates the first point at the end
+      // Part-1-Terrain-WaterBody-Vegetation-V2.gml repeats the first point at the end
       vtkIdType n = std::distance(nodeRing.begin(), nodeRing.end());
 
       auto it = nodeRing.begin();
@@ -526,7 +531,7 @@ public:
           iss >> p[j];
         }
       }
-      points->InsertNextPoint(&p[0]);
+      points->InsertNextPoint(p.data());
       vtkIdType firstPointIndex = points->GetNumberOfPoints() - 1;
       vtkIdType i = 1;
       for (++it; it != nodeRing.end(); ++it, ++i)
@@ -544,7 +549,7 @@ public:
         line->GetPointIds()->SetId(0, points->GetNumberOfPoints() - 1);
         if (i < n - 1)
         {
-          points->InsertNextPoint(&p[0]);
+          points->InsertNextPoint(p.data());
           line->GetPointIds()->SetId(1, points->GetNumberOfPoints() - 1);
         }
         else
@@ -590,7 +595,7 @@ public:
     fd->AddArray(sa);
   }
 
-  static void SetField(vtkDataObject* obj, const char* name, float* value, vtkIdType size)
+  static void SetField(vtkDataObject* obj, const char* name, double* value, vtkIdType components)
   {
     vtkFieldData* fd = obj->GetFieldData();
     if (!fd)
@@ -598,12 +603,10 @@ public:
       vtkNew<vtkFieldData> newfd;
       obj->SetFieldData(newfd);
     }
-    vtkNew<vtkFloatArray> da;
-    da->SetNumberOfTuples(size);
-    for (vtkIdType i = 0; i < size; ++i)
-    {
-      da->SetValue(i, value[i]);
-    }
+    vtkNew<vtkDoubleArray> da;
+    da->SetNumberOfTuples(1);
+    da->SetNumberOfComponents(components);
+    da->SetTypedTuple(0, value);
     da->SetName(name);
     fd->AddArray(da);
   }
@@ -650,21 +653,26 @@ public:
         vtkNew<vtkCellArray> cells;
         if (gmlIdAttribute)
         {
-          this->SetField(polyData, "gml_id", exteriorId);
+          vtkCityGMLReader::Implementation::SetField(polyData, "gml_id", exteriorId);
         }
         polyData->SetPoints(points);
         nodeInterior ? polyData->SetLines(cells) : polyData->SetPolys(cells);
         switch (polygonType)
         {
           case PolygonType::TEXTURE:
-            this->SetField(polyData, "texture_uri", imageURI.c_str());
+            vtkCityGMLReader::Implementation::SetField(polyData, "texture_uri", imageURI.c_str());
             break;
           case PolygonType::MATERIAL:
           {
             Material material = this->Materials[materialIndex];
-            this->SetField(polyData, "diffuse_color", &material.Diffuse[0], 3);
-            this->SetField(polyData, "specular_color", &material.Specular[0], 3);
-            this->SetField(polyData, "transparency", &material.Transparency, 1);
+            vtkCityGMLReader::Implementation::SetField(
+              polyData, "diffuse_color", material.Diffuse.data(), 3);
+            vtkCityGMLReader::Implementation::SetField(
+              polyData, "specular_color", material.Specular.data(), 3);
+            vtkCityGMLReader::Implementation::SetField(
+              polyData, "transparency", &material.Transparency, 1);
+            vtkCityGMLReader::Implementation::SetField(
+              polyData, "shininess", &material.Shininess, 1);
             break;
           }
           case PolygonType::NONE:
@@ -881,16 +889,23 @@ public:
 
   void ReadMultiSurfaceGroup(pugi::xml_document& doc, vtkMultiBlockDataSet* output,
     const char* gmlNamespace, const char* feature, float progressStart, float progressEnd,
-    int maximumNumberOfNodes = std::numeric_limits<int>::max())
+    size_t beginNodeIndex = 0, size_t endNodeIndex = std::numeric_limits<int>::max())
   {
     std::ostringstream ostr;
     std::string element = std::string(gmlNamespace) + ":" + feature;
     ostr << "//" << element;
     auto nodes = doc.select_nodes(ostr.str().c_str());
     int size = std::distance(nodes.begin(), nodes.end());
-    int i = 0;
-    for (auto featureNode : nodes)
+
+    endNodeIndex = std::min(endNodeIndex, nodes.size());
+    for (size_t i = beginNodeIndex; i < endNodeIndex; ++i)
     {
+      auto featureNode = nodes[i];
+      if (i % 1024 == 0)
+      {
+        this->Reader->UpdateProgress(progressStart + (progressEnd - progressStart) * i / size);
+      }
+
       vtkNew<vtkMultiBlockDataSet> groupBlock;
       ostr.str("");
       ostr << "descendant::" << gmlNamespace
@@ -907,23 +922,14 @@ public:
       if (groupBlock->GetNumberOfBlocks())
       {
         output->SetBlock(output->GetNumberOfBlocks(), groupBlock);
-        this->SetField(groupBlock, "element", element.c_str());
+        vtkCityGMLReader::Implementation::SetField(groupBlock, "element", element.c_str());
         pugi::xml_attribute gmlIdAttribute = featureNode.node().attribute("gml:id");
         auto gmlId = gmlIdAttribute.value();
         if (gmlId)
         {
-          this->SetField(groupBlock, "gml_id", gmlId);
+          vtkCityGMLReader::Implementation::SetField(groupBlock, "gml_id", gmlId);
         }
       }
-      ++i;
-      if (i >= maximumNumberOfNodes)
-      {
-        break;
-      }
-      if (i % 1024 == 0)
-      {
-        this->Reader->UpdateProgress(progressStart + (progressEnd - progressStart) * i / size);
-      }
     }
   }
 
@@ -947,7 +953,7 @@ public:
       {
         pugi::xml_node node = it->node();
         std::istringstream iss(node.child_value());
-        // Part-1-Terrain-WaterBody-Vegetation-V2.gml repeates the last point in a
+        // Part-1-Terrain-WaterBody-Vegetation-V2.gml repeats the last point in a
         // triangle (there are 4 points). We only read the first 3.
         for (vtkIdType i = 0; i < 3; ++i)
         {
@@ -967,7 +973,7 @@ public:
         vtkNew<vtkPolyData> polyData;
         polyData->SetPoints(points);
         polyData->SetPolys(polys);
-        this->SetField(polyData, "element", "dem:ReliefFeature");
+        vtkCityGMLReader::Implementation::SetField(polyData, "element", "dem:ReliefFeature");
         output->SetBlock(output->GetNumberOfBlocks(), polyData);
       }
     }
@@ -976,7 +982,7 @@ public:
   void ReadWaterBody(pugi::xml_document& doc, vtkMultiBlockDataSet* output)
   {
     vtkNew<vtkMultiBlockDataSet> b;
-    this->SetField(b, "element", "wtr:WaterBody");
+    vtkCityGMLReader::Implementation::SetField(b, "element", "wtr:WaterBody");
     auto xWaterSurface = doc.select_nodes(("//wtr:WaterBody//wtr:WaterSurface/wtr:lod" +
       std::to_string(this->LOD) + "Surface/gml:CompositeSurface")
                                             .c_str());
@@ -1007,12 +1013,12 @@ private:
       std::fill(this->Specular.begin(), this->Specular.end(), 1.0);
       this->Transparency = 1.0;
     }
-    std::array<float, 3> Diffuse;
-    std::array<float, 3> Specular;
-    float Transparency;
+    std::array<double, 3> Diffuse;
+    std::array<double, 3> Specular;
+    double Transparency;
+    double Shininess;
   };
 
-private:
   vtkCityGMLReader* Reader;
   int LOD;
   int UseTransparencyAsOpacity;
@@ -1035,7 +1041,8 @@ vtkCityGMLReader::vtkCityGMLReader()
   this->UseTransparencyAsOpacity = false;
   this->Impl = new Implementation(this, this->LOD, this->UseTransparencyAsOpacity);
   this->SetNumberOfInputPorts(0);
-  this->NumberOfBuildings = std::numeric_limits<int>::max();
+  this->NumberOfBuildings = this->EndBuildingIndex = std::numeric_limits<int>::max();
+  this->BeginBuildingIndex = 0;
 }
 
 //------------------------------------------------------------------------------
@@ -1049,6 +1056,23 @@ vtkCityGMLReader::~vtkCityGMLReader()
 int vtkCityGMLReader::RequestData(
   vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector)
 {
+  int beginBuildingIndex = 0, endBuildingIndex = std::numeric_limits<int>::max();
+  if (this->NumberOfBuildings != std::numeric_limits<int>::max())
+  {
+    beginBuildingIndex = 0;
+    endBuildingIndex = this->NumberOfBuildings;
+  }
+  if (this->BeginBuildingIndex != 0 || this->EndBuildingIndex != std::numeric_limits<int>::max())
+  {
+    if (this->NumberOfBuildings != std::numeric_limits<int>::max())
+    {
+      vtkWarningMacro("Both NumberOfBuildings and (BeginBuildingIndex, EndBuildingIndex)"
+                      " are set. Using the latter form.");
+    }
+    beginBuildingIndex = this->BeginBuildingIndex;
+    endBuildingIndex = this->EndBuildingIndex;
+  }
+
   this->Impl->Initialize(this, this->LOD, this->UseTransparencyAsOpacity);
   pugi::xml_document doc;
   pugi::xml_parse_result result = doc.load_file(this->FileName);
@@ -1084,7 +1108,7 @@ int vtkCityGMLReader::RequestData(
     this->Impl->ReadMultiSurfaceGroup(doc, output, "tran", "Road", 0.475, 0.5);
     this->UpdateProgress(0.5);
     this->Impl->ReadMultiSurfaceGroup(
-      doc, output, "bldg", "Building", 0.5, 0.875, this->NumberOfBuildings);
+      doc, output, "bldg", "Building", 0.5, 0.875, beginBuildingIndex, endBuildingIndex);
     this->Impl->ReadMultiSurfaceGroup(doc, output, "frn", "CityFurniture", 0.875, 0.9);
     this->UpdateProgress(0.9);
     this->Impl->CacheImplicitGeometry(doc, "frn", "CityFurniture");
@@ -1092,6 +1116,10 @@ int vtkCityGMLReader::RequestData(
     this->Impl->InitializeImplicitGeometry();
     this->Impl->ReadMultiSurfaceGroup(doc, output, "gen", "GenericCityObject", 0.9, 0.95);
     this->Impl->ReadMultiSurfaceGroup(doc, output, "luse", "LandUse", 0.95, 1.0);
+    if (!output->GetNumberOfBlocks())
+    {
+      vtkWarningMacro("There is no data on LOD " << this->LOD << ". Try a different LOD.");
+    }
   }
   catch (pugi::xpath_exception& e)
   {
@@ -1111,3 +1139,4 @@ void vtkCityGMLReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
