@@ -16,8 +16,8 @@
 // vtkOBJReader vtkPLYReader vtkSTLReader
 #include "vtkAbstractPolyDataReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkAbstractPolyDataReader::vtkAbstractPolyDataReader()
-  : vtkPolyDataAlgorithm()
 {
   this->FileName = nullptr;
   this->SetNumberOfInputPorts(0);
@@ -30,7 +30,7 @@ vtkAbstractPolyDataReader::~vtkAbstractPolyDataReader()
 
 void vtkAbstractPolyDataReader::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
-  os << indent << "FileName: " <<
-    (this->FileName ? this->FileName : "NONE") << endl;
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "FileName: " << (this->FileName ? this->FileName : "NONE") << endl;
 }
+VTK_ABI_NAMESPACE_END
