@@ -18,9 +18,6 @@
   the U.S. Government retains certain rights in this software.
 -------------------------------------------------------------------------*/
 
-// Hide VTK_DEPRECATED_IN_9_1_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkArrayReader.h"
 
 #include "vtkArrayData.h"
@@ -29,13 +26,13 @@
 #include "vtkObjectFactory.h"
 #include "vtkSmartPointer.h"
 #include "vtkSparseArray.h"
-#include "vtkUnicodeString.h"
 #include "vtksys/FStream.hxx"
 
 #include <sstream>
 #include <stdexcept>
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkArrayReader);
 
 namespace
@@ -60,21 +57,6 @@ void ExtractValue(istream& stream, vtkStdString& value)
   value = value.substr(begin, end);
 }
 
-void ExtractValue(istream& stream, vtkUnicodeString& value)
-{
-  std::string buffer;
-  std::getline(stream, buffer);
-  vtkStdString::size_type begin, end;
-  begin = 0;
-  end = buffer.size();
-  while ((begin < end) && isspace(buffer[begin]))
-    begin++;
-  while ((begin < end) && isspace(buffer[end - 1]))
-    end--;
-  buffer = buffer.substr(begin, end);
-  value = vtkUnicodeString::from_utf8(buffer);
-}
-
 void ReadHeader(
   istream& stream, vtkArrayExtents& extents, vtkArrayExtents::SizeT& non_null_size, vtkArray* array)
 {
@@ -226,64 +208,6 @@ vtkSparseArray<vtkStdString>* ReadSparseArrayBinary<vtkStdString>(istream& strea
   return array;
 }
 
-template <>
-vtkSparseArray<vtkUnicodeString>* ReadSparseArrayBinary<vtkUnicodeString>(istream& stream)
-{
-  // Create the array ...
-  vtkSmartPointer<vtkSparseArray<vtkUnicodeString>> array =
-    vtkSmartPointer<vtkSparseArray<vtkUnicodeString>>::New();
-
-  // Read the file header ...
-  vtkArrayExtents extents;
-  vtkArrayExtents::SizeT non_null_size = 0;
-  bool swap_endian = false;
-  ReadHeader(stream, extents, non_null_size, array);
-  ReadEndianOrderMark(stream, swap_endian);
-
-  // Read the array nullptr value ...
-  std::string null_value;
-  for (int character = stream.get(); stream; character = stream.get())
-  {
-    if (character == 0)
-    {
-      array->SetNullValue(vtkUnicodeString::from_utf8(null_value));
-      break;
-    }
-    else
-    {
-      null_value += static_cast<char>(character);
-    }
-  }
-
-  // Read array coordinates ...
-  array->ReserveStorage(non_null_size);
-
-  for (vtkArray::DimensionT i = 0; i != array->GetDimensions(); ++i)
-  {
-    stream.read(reinterpret_cast<char*>(array->GetCoordinateStorage(i)),
-      non_null_size * sizeof(vtkArray::CoordinateT));
-  }
-
-  // Read array values ...
-  std::string buffer;
-  vtkArray::SizeT n = 0;
-  for (int character = stream.get(); stream; character = stream.get())
-  {
-    if (character == 0)
-    {
-      array->SetValueN(n++, vtkUnicodeString::from_utf8(buffer));
-      buffer.resize(0);
-    }
-    else
-    {
-      buffer += static_cast<char>(character);
-    }
-  }
-
-  array->Register(nullptr);
-  return array;
-}
-
 template <typename ValueT>
 vtkDenseArray<ValueT>* ReadDenseArrayBinary(istream& stream)
 {
@@ -343,40 +267,6 @@ vtkDenseArray<vtkStdString>* ReadDenseArrayBinary<vtkStdString>(istream& stream)
   return array;
 }
 
-template <>
-vtkDenseArray<vtkUnicodeString>* ReadDenseArrayBinary<vtkUnicodeString>(istream& stream)
-{
-  // Create the array ...
-  vtkSmartPointer<vtkDenseArray<vtkUnicodeString>> array =
-    vtkSmartPointer<vtkDenseArray<vtkUnicodeString>>::New();
-
-  // Read the file header ...
-  vtkArrayExtents extents;
-  vtkArrayExtents::SizeT non_null_size = 0;
-  bool swap_endian = false;
-  ReadHeader(stream, extents, non_null_size, array);
-  ReadEndianOrderMark(stream, swap_endian);
-
-  // Read array values ...
-  std::string buffer;
-  vtkArray::SizeT n = 0;
-  for (int character = stream.get(); stream; character = stream.get())
-  {
-    if (character == 0)
-    {
-      array->SetValueN(n++, vtkUnicodeString::from_utf8(buffer));
-      buffer.resize(0);
-    }
-    else
-    {
-      buffer += static_cast<char>(character);
-    }
-  }
-
-  array->Register(nullptr);
-  return array;
-}
-
 template <typename ValueT>
 vtkSparseArray<ValueT>* ReadSparseArrayAscii(istream& stream)
 {
@@ -604,16 +494,11 @@ vtkArray* vtkArrayReader::Read(istream& stream)
         return (read_binary ? ReadSparseArrayBinary<double>(stream)
                             : ReadSparseArrayAscii<double>(stream));
       }
-      else if (header_type == "string")
+      else if ((header_type == "string") || header_type == "unicode-string")
       {
         return (read_binary ? ReadSparseArrayBinary<vtkStdString>(stream)
                             : ReadSparseArrayAscii<vtkStdString>(stream));
       }
-      else if (header_type == "unicode-string")
-      {
-        return (read_binary ? ReadSparseArrayBinary<vtkUnicodeString>(stream)
-                            : ReadSparseArrayAscii<vtkUnicodeString>(stream));
-      }
       else
       {
         throw std::runtime_error("Unknown array type: " + header_type);
@@ -631,16 +516,11 @@ vtkArray* vtkArrayReader::Read(istream& stream)
         return (
           read_binary ? ReadDenseArrayBinary<double>(stream) : ReadDenseArrayAscii<double>(stream));
       }
-      else if (header_type == "string")
+      else if ((header_type == "string") || (header_type == "unicode-string"))
       {
         return (read_binary ? ReadDenseArrayBinary<vtkStdString>(stream)
                             : ReadDenseArrayAscii<vtkStdString>(stream));
       }
-      else if (header_type == "unicode-string")
-      {
-        return (read_binary ? ReadDenseArrayBinary<vtkUnicodeString>(stream)
-                            : ReadDenseArrayAscii<vtkUnicodeString>(stream));
-      }
       else
       {
         throw std::runtime_error("Unknown array type: " + header_type);
@@ -658,3 +538,4 @@ vtkArray* vtkArrayReader::Read(istream& stream)
 
   return nullptr;
 }
+VTK_ABI_NAMESPACE_END
