@@ -50,13 +50,14 @@
 #define VTK_STAT_FUNC stat64
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkEnSight6BinaryReader);
 
 //------------------------------------------------------------------------------
 vtkEnSight6BinaryReader::vtkEnSight6BinaryReader()
 {
   this->NumberOfUnstructuredPoints = 0;
-  this->UnstructuredPoints = vtkPoints::New();
+  this->UnstructuredPoints = nullptr;
   this->UnstructuredNodeIds = nullptr;
 
   this->BinaryIFile = nullptr;
@@ -69,13 +70,7 @@ vtkEnSight6BinaryReader::vtkEnSight6BinaryReader()
 //------------------------------------------------------------------------------
 vtkEnSight6BinaryReader::~vtkEnSight6BinaryReader()
 {
-  if (this->UnstructuredNodeIds)
-  {
-    this->UnstructuredNodeIds->Delete();
-    this->UnstructuredNodeIds = nullptr;
-  }
-  this->UnstructuredPoints->Delete();
-  this->UnstructuredPoints = nullptr;
+  this->CleanUpCache();
 
   if (this->BinaryIFile)
   {
@@ -151,7 +146,7 @@ int vtkEnSight6BinaryReader::ReadGeometryFile(
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to geometry file: " << sfilename.c_str());
+    vtkDebugMacro("full path to geometry file: " << sfilename);
   }
   else
   {
@@ -160,7 +155,7 @@ int vtkEnSight6BinaryReader::ReadGeometryFile(
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -193,6 +188,8 @@ int vtkEnSight6BinaryReader::ReadGeometryFile(
   this->ReadLine(line);
   this->ReadLine(line);
 
+  this->CleanUpCache();
+
   // Read the node id and element id lines.
   this->ReadLine(line); // node id *
   sscanf(line, " %*s %*s %s", subLine);
@@ -230,6 +227,7 @@ int vtkEnSight6BinaryReader::ReadGeometryFile(
     return 0;
   }
 
+  this->UnstructuredPoints = vtkPoints::New();
   this->UnstructuredPoints->SetNumberOfPoints(this->NumberOfUnstructuredPoints);
 
   if (pointIdsListed)
@@ -737,7 +735,7 @@ int vtkEnSight6BinaryReader::ReadMeasuredGeometryFile(
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to measured geometry file: " << sfilename.c_str());
+    vtkDebugMacro("full path to measured geometry file: " << sfilename);
   }
   else
   {
@@ -746,7 +744,7 @@ int vtkEnSight6BinaryReader::ReadMeasuredGeometryFile(
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     points->Delete();
     pd->Delete();
     return 0;
@@ -890,7 +888,7 @@ int vtkEnSight6BinaryReader::ReadScalarsPerNode(const char* fileName, const char
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to scalar per node file: " << sfilename.c_str());
+    vtkDebugMacro("full path to scalar per node file: " << sfilename);
   }
   else
   {
@@ -899,7 +897,7 @@ int vtkEnSight6BinaryReader::ReadScalarsPerNode(const char* fileName, const char
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -1017,18 +1015,21 @@ int vtkEnSight6BinaryReader::ReadScalarsPerNode(const char* fileName, const char
       {
         partId = this->UnstructuredPartIds->GetId(i);
         output = this->GetDataSetFromBlock(compositeOutput, partId);
-        if (component == 0)
+        if (output)
         {
-          scalars->SetName(description);
-          output->GetPointData()->AddArray(scalars);
-          if (!output->GetPointData()->GetScalars())
+          if (component == 0)
           {
-            output->GetPointData()->SetScalars(scalars);
+            scalars->SetName(description);
+            output->GetPointData()->AddArray(scalars);
+            if (!output->GetPointData()->GetScalars())
+            {
+              output->GetPointData()->SetScalars(scalars);
+            }
+          }
+          else
+          {
+            output->GetPointData()->AddArray(scalars);
           }
-        }
-        else
-        {
-          output->GetPointData()->AddArray(scalars);
         }
       }
     }
@@ -1036,10 +1037,13 @@ int vtkEnSight6BinaryReader::ReadScalarsPerNode(const char* fileName, const char
     {
       scalars->SetName(description);
       output = this->GetDataSetFromBlock(compositeOutput, this->NumberOfGeometryParts);
-      output->GetPointData()->AddArray(scalars);
-      if (!output->GetPointData()->GetScalars())
+      if (output)
       {
-        output->GetPointData()->SetScalars(scalars);
+        output->GetPointData()->AddArray(scalars);
+        if (!output->GetPointData()->GetScalars())
+        {
+          output->GetPointData()->SetScalars(scalars);
+        }
       }
     }
     delete[] scalarsRead;
@@ -1140,7 +1144,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerNode(const char* fileName, const char
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to vector per node file: " << sfilename.c_str());
+    vtkDebugMacro("full path to vector per node file: " << sfilename);
   }
   else
   {
@@ -1149,7 +1153,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerNode(const char* fileName, const char
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -1227,6 +1231,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerNode(const char* fileName, const char
     vectors = vtkFloatArray::New();
     vectors->SetNumberOfTuples(numPts);
     vectors->SetNumberOfComponents(3);
+    vectors->SetName(description);
     vectors->Allocate(numPts * 3);
     vectorsRead = new float[numPts * 3];
     this->ReadFloatArray(vectorsRead, numPts * 3);
@@ -1244,17 +1249,18 @@ int vtkEnSight6BinaryReader::ReadVectorsPerNode(const char* fileName, const char
       {
         partId = this->UnstructuredPartIds->GetId(i);
         output = this->GetDataSetFromBlock(compositeOutput, partId);
-        vectors->SetName(description);
-        output->GetPointData()->AddArray(vectors);
-        if (!output->GetPointData()->GetVectors())
+        if (output)
         {
-          output->GetPointData()->SetVectors(vectors);
+          output->GetPointData()->AddArray(vectors);
+          if (!output->GetPointData()->GetVectors())
+          {
+            output->GetPointData()->SetVectors(vectors);
+          }
         }
       }
     }
     else
     {
-      vectors->SetName(description);
       output = this->GetDataSetFromBlock(compositeOutput, this->NumberOfGeometryParts);
       output->GetPointData()->AddArray(vectors);
       if (!output->GetPointData()->GetVectors())
@@ -1279,6 +1285,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerNode(const char* fileName, const char
     vectors = vtkFloatArray::New();
     vectors->SetNumberOfTuples(numPts);
     vectors->SetNumberOfComponents(3);
+    vectors->SetName(description);
     vectors->Allocate(numPts * 3);
     vectorsRead = new float[numPts * 3];
 
@@ -1291,7 +1298,6 @@ int vtkEnSight6BinaryReader::ReadVectorsPerNode(const char* fileName, const char
       vectors->InsertTuple(i, vector);
     }
 
-    vectors->SetName(description);
     output->GetPointData()->AddArray(vectors);
     if (!output->GetPointData()->GetVectors())
     {
@@ -1346,7 +1352,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerNode(const char* fileName, const char
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to tensor symm per node file: " << sfilename.c_str());
+    vtkDebugMacro("full path to tensor symm per node file: " << sfilename);
   }
   else
   {
@@ -1355,7 +1361,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerNode(const char* fileName, const char
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -1416,6 +1422,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerNode(const char* fileName, const char
     tensors = vtkFloatArray::New();
     tensors->SetNumberOfTuples(numPts);
     tensors->SetNumberOfComponents(6);
+    tensors->SetName(description);
     tensors->Allocate(numPts * 6);
     tensorsRead = new float[numPts * 6];
     this->ReadFloatArray(tensorsRead, numPts * 6);
@@ -1433,8 +1440,11 @@ int vtkEnSight6BinaryReader::ReadTensorsPerNode(const char* fileName, const char
     for (i = 0; i < this->UnstructuredPartIds->GetNumberOfIds(); i++)
     {
       partId = this->UnstructuredPartIds->GetId(i);
-      tensors->SetName(description);
-      this->GetDataSetFromBlock(compositeOutput, partId)->GetPointData()->AddArray(tensors);
+      output = this->GetDataSetFromBlock(compositeOutput, partId);
+      if (output)
+      {
+        output->GetPointData()->AddArray(tensors);
+      }
     }
     tensors->Delete();
     delete[] tensorsRead;
@@ -1452,6 +1462,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerNode(const char* fileName, const char
     tensors = vtkFloatArray::New();
     tensors->SetNumberOfTuples(numPts);
     tensors->SetNumberOfComponents(6);
+    tensors->SetName(description);
     tensors->Allocate(numPts * 6);
     tensorsRead = new float[numPts * 6];
     this->ReadFloatArray(tensorsRead, numPts * 6);
@@ -1467,7 +1478,6 @@ int vtkEnSight6BinaryReader::ReadTensorsPerNode(const char* fileName, const char
       tensors->InsertTuple(i, tensor);
     }
 
-    tensors->SetName(description);
     output->GetPointData()->AddArray(tensors);
     tensors->Delete();
     delete[] tensorsRead;
@@ -1509,7 +1519,7 @@ int vtkEnSight6BinaryReader::ReadScalarsPerElement(const char* fileName, const c
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to scalar per element file: " << sfilename.c_str());
+    vtkDebugMacro("full path to scalar per element file: " << sfilename);
   }
   else
   {
@@ -1518,7 +1528,7 @@ int vtkEnSight6BinaryReader::ReadScalarsPerElement(const char* fileName, const c
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -1701,7 +1711,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerElement(const char* fileName, const c
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to vector per element file: " << sfilename.c_str());
+    vtkDebugMacro("full path to vector per element file: " << sfilename);
   }
   else
   {
@@ -1710,7 +1720,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerElement(const char* fileName, const c
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -1789,6 +1799,7 @@ int vtkEnSight6BinaryReader::ReadVectorsPerElement(const char* fileName, const c
     lineRead = this->ReadLine(line); // element type or "block"
     vectors->SetNumberOfTuples(numCells);
     vectors->SetNumberOfComponents(3);
+    vectors->SetName(description);
     vectors->Allocate(numCells * 3);
 
     // need to find out from CellIds how many cells we have of this element
@@ -1835,7 +1846,6 @@ int vtkEnSight6BinaryReader::ReadVectorsPerElement(const char* fileName, const c
       delete[] vectorsRead;
       lineRead = this->ReadLine(line);
     }
-    vectors->SetName(description);
     output->GetCellData()->AddArray(vectors);
     if (!output->GetCellData()->GetVectors())
     {
@@ -1888,7 +1898,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerElement(const char* fileName, const c
       sfilename += "/";
     }
     sfilename += fileName;
-    vtkDebugMacro("full path to tensor per element file: " << sfilename.c_str());
+    vtkDebugMacro("full path to tensor per element file: " << sfilename);
   }
   else
   {
@@ -1897,7 +1907,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerElement(const char* fileName, const c
 
   if (this->OpenFile(sfilename.c_str()) == 0)
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     return 0;
   }
 
@@ -1978,6 +1988,7 @@ int vtkEnSight6BinaryReader::ReadTensorsPerElement(const char* fileName, const c
     lineRead = this->ReadLine(line); // element type or "block"
     tensors->SetNumberOfTuples(numCells);
     tensors->SetNumberOfComponents(6);
+    tensors->SetName(description);
     tensors->Allocate(numCells * 6);
 
     // need to find out from CellIds how many cells we have of this element
@@ -2032,7 +2043,6 @@ int vtkEnSight6BinaryReader::ReadTensorsPerElement(const char* fileName, const c
       delete[] tensorsRead;
       lineRead = this->ReadLine(line);
     }
-    tensors->SetName(description);
     output->GetCellData()->AddArray(tensors);
     tensors->Delete();
   }
@@ -2050,7 +2060,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
   int lineRead = 1;
   int i, j;
   int* nodeIdList;
-  vtkIdType* nodeIds;
   int numElements;
   int idx, cellType;
   vtkIdType cellId;
@@ -2093,7 +2102,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of point cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[1];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2105,15 +2113,14 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
 
       for (i = 0; i < numElements; i++)
       {
-        nodeIds[0] = nodeIdList[i] - 1;
+        vtkIdType nodeIds = nodeIdList[i] - 1;
         if (this->UnstructuredNodeIds)
         {
-          nodeIds[0] = this->UnstructuredNodeIds->GetValue(nodeIds[0]);
+          nodeIds = this->UnstructuredNodeIds->GetValue(nodeIds);
         }
-        cellId = output->InsertNextCell(VTK_VERTEX, 1, nodeIds);
+        cellId = output->InsertNextCell(VTK_VERTEX, 1, &nodeIds);
         this->GetCellIds(idx, vtkEnSightReader::POINT)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "bar2", 4) == 0)
@@ -2126,7 +2133,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of bar2 cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[2];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2136,6 +2142,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
       nodeIdList = new int[numElements * 2];
       this->ReadIntArray(nodeIdList, numElements * 2);
 
+      vtkIdType nodeIds[2];
       for (i = 0; i < numElements; i++)
       {
         for (j = 0; j < 2; j++)
@@ -2153,7 +2160,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_LINE, 2, nodeIds);
         this->GetCellIds(idx, vtkEnSightReader::BAR2)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "bar3", 4) == 0)
@@ -2167,7 +2173,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of bar3 cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[2];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2177,6 +2182,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
       nodeIdList = new int[numElements * 3];
       this->ReadIntArray(nodeIdList, numElements * 3);
 
+      vtkIdType nodeIds[2];
       for (i = 0; i < numElements; i++)
       {
         for (j = 0; j < 2; j++)
@@ -2194,7 +2200,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_LINE, 2, nodeIds);
         this->GetCellIds(idx, vtkEnSightReader::BAR3)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "tria3", 5) == 0 || strncmp(line, "tria6", 5) == 0)
@@ -2217,7 +2222,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of triangle cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[3];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2235,6 +2239,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         this->ReadIntArray(nodeIdList, numElements * 6);
       }
 
+      vtkIdType nodeIds[3];
       for (i = 0; i < numElements; i++)
       {
         if (cellType == vtkEnSightReader::TRIA3)
@@ -2261,7 +2266,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_TRIANGLE, 3, nodeIds);
         this->GetCellIds(idx, cellType)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "quad4", 5) == 0 || strncmp(line, "quad8", 5) == 0)
@@ -2284,7 +2288,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of quad cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[4];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2302,6 +2305,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         this->ReadIntArray(nodeIdList, numElements * 8);
       }
 
+      vtkIdType nodeIds[4];
       for (i = 0; i < numElements; i++)
       {
         if (cellType == vtkEnSightReader::QUAD4)
@@ -2328,7 +2332,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_QUAD, 4, nodeIds);
         this->GetCellIds(idx, cellType)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "tetra4", 6) == 0 || strncmp(line, "tetra10", 7) == 0)
@@ -2352,7 +2355,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
           "Invalid number of tetrahedral cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[4];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2370,6 +2372,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         this->ReadIntArray(nodeIdList, numElements * 10);
       }
 
+      vtkIdType nodeIds[4];
       for (i = 0; i < numElements; i++)
       {
         if (cellType == vtkEnSightReader::TETRA4)
@@ -2396,7 +2399,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_TETRA, 4, nodeIds);
         this->GetCellIds(idx, cellType)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "pyramid5", 8) == 0 || strncmp(line, "pyramid13", 9) == 0)
@@ -2419,7 +2421,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of pyramid cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[5];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2437,6 +2438,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         this->ReadIntArray(nodeIdList, numElements * 13);
       }
 
+      vtkIdType nodeIds[5];
       for (i = 0; i < numElements; i++)
       {
         if (cellType == vtkEnSightReader::PYRAMID5)
@@ -2463,7 +2465,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_PYRAMID, 5, nodeIds);
         this->GetCellIds(idx, cellType)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "hexa8", 5) == 0 || strncmp(line, "hexa20", 6) == 0)
@@ -2486,7 +2487,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of hexahedral cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[8];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2504,6 +2504,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         this->ReadIntArray(nodeIdList, numElements * 20);
       }
 
+      vtkIdType nodeIds[8];
       for (i = 0; i < numElements; i++)
       {
         if (cellType == vtkEnSightReader::HEXA8)
@@ -2530,7 +2531,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_HEXAHEDRON, 8, nodeIds);
         this->GetCellIds(idx, cellType)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     else if (strncmp(line, "penta6", 6) == 0 || strncmp(line, "penta15", 7) == 0)
@@ -2553,7 +2553,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         vtkErrorMacro("Invalid number of pentagonal cells; check that ByteOrder is set correctly.");
         return 0;
       }
-      nodeIds = new vtkIdType[6];
       if (this->ElementIdsListed)
       {
         // skip element ids
@@ -2571,6 +2570,7 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         this->ReadIntArray(nodeIdList, numElements * 15);
       }
 
+      vtkIdType nodeIds[6];
       const unsigned char wedgeMap[6] = { 0, 2, 1, 3, 5, 4 };
       for (i = 0; i < numElements; i++)
       {
@@ -2598,7 +2598,6 @@ int vtkEnSight6BinaryReader::CreateUnstructuredGridOutput(
         cellId = output->InsertNextCell(VTK_WEDGE, 6, nodeIds);
         this->GetCellIds(idx, cellType)->InsertNextId(cellId);
       }
-      delete[] nodeIds;
       delete[] nodeIdList;
     }
     lineRead = this->ReadLine(line);
@@ -2849,3 +2848,21 @@ void vtkEnSight6BinaryReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+
+//------------------------------------------------------------------------------
+void vtkEnSight6BinaryReader::CleanUpCache()
+{
+  if (this->UnstructuredPoints)
+  {
+    this->NumberOfUnstructuredPoints = 0;
+    this->UnstructuredPoints->Delete();
+    this->UnstructuredPoints = nullptr;
+  }
+  if (this->UnstructuredNodeIds)
+  {
+    this->UnstructuredNodeIds->Delete();
+    this->UnstructuredNodeIds = nullptr;
+  }
+}
+
+VTK_ABI_NAMESPACE_END
