@@ -36,6 +36,7 @@
 
 //------------------------------------------------------------------------------
 typedef std::vector<vtkSmartPointer<vtkIdList>> vtkEnSightReaderCellIdsTypeBase;
+VTK_ABI_NAMESPACE_BEGIN
 class vtkEnSightReaderCellIdsType : public vtkEnSightReaderCellIdsTypeBase
 {
 };
@@ -251,7 +252,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             filenameNum = filenameNumbers->GetId(timeStep - 1);
             if (!this->UseFileSets)
             {
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -285,7 +286,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             {
               filenameNumbers = this->FileSetFileNameNumbers->GetItem(collectionNum);
               filenameNum = filenameNumbers->GetId(fileNum - 1);
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -334,7 +335,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             filenameNum = filenameNumbers->GetId(timeStep - 1);
             if (!this->UseFileSets)
             {
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -368,7 +369,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             {
               filenameNumbers = this->FileSetFileNameNumbers->GetItem(fileSet);
               filenameNum = filenameNumbers->GetId(fileNum - 1);
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -430,7 +431,7 @@ int vtkEnSightReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     {
       vtkInformation* outInfo = outputVector->GetInformationObject(0);
       outInfo->Set(
-        vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &uniqueTimeValues[0], numTimeValues);
+        vtkStreamingDemandDrivenPipeline::TIME_STEPS(), uniqueTimeValues.data(), numTimeValues);
       double timeRange[2];
       timeRange[0] = uniqueTimeValues[0];
       timeRange[1] = uniqueTimeValues[numTimeValues - 1];
@@ -997,7 +998,7 @@ int vtkEnSightReader::ReadCaseFileTime(char* line)
     // --- to obtain a sequence of filenameNum(s) which might span multiple lines
     if (this->ReadNextDataLine(line) == 0)
     {
-      vtkErrorMacro("Error with vtkEnSightReader: 'filename ......' not found!!!");
+      vtkErrorMacro("Error with vtkEnSightReader: 'filename ......' entry not found!!!");
       return 0;
     }
 
@@ -1291,7 +1292,7 @@ int vtkEnSightReader::ReadCaseFile()
       sfilename += "/";
     }
     sfilename += this->CaseFileName;
-    vtkDebugMacro("full path to case file: " << sfilename.c_str());
+    vtkDebugMacro("full path to case file: " << sfilename);
   }
   else
   {
@@ -1301,7 +1302,7 @@ int vtkEnSightReader::ReadCaseFile()
   this->IS = new vtksys::ifstream(sfilename.c_str(), ios::in);
   if (this->IS->fail())
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     delete this->IS;
     this->IS = nullptr;
     return 0;
@@ -1501,10 +1502,9 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
         {
           filenameNumbers = this->TimeSetFileNameNumbers->GetItem(collectionNum);
           filenameNum = filenameNumbers->GetId(timeStep - 1);
-          // this->ReplaceWildcards(fileName, filenameNum);
           if (!this->UseFileSets)
           {
-            this->ReplaceWildcards(fileName, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
           }
         }
       }
@@ -1540,7 +1540,7 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
           {
             filenameNumbers = this->FileSetFileNameNumbers->GetItem(collectionNum);
             filenameNum = filenameNumbers->GetId(fileNum);
-            this->ReplaceWildcards(fileName, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
           }
         }
       }
@@ -1650,8 +1650,8 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
         {
           filenameNumbers = this->TimeSetFileNameNumbers->GetItem(collectionNum);
           filenameNum = filenameNumbers->GetId(timeStep - 1);
-          this->ReplaceWildcards(fileName, filenameNum);
-          this->ReplaceWildcards(fileName2, filenameNum);
+          vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
+          vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName2, filenameNum);
         }
       }
 
@@ -1686,8 +1686,8 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
           {
             filenameNumbers = this->FileSetFileNameNumbers->GetItem(collectionNum);
             filenameNum = filenameNumbers->GetId(timeStep - 1);
-            this->ReplaceWildcards(fileName, filenameNum);
-            this->ReplaceWildcards(fileName2, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName2, filenameNum);
           }
         }
       }
@@ -2049,46 +2049,6 @@ int vtkEnSightReader::GetElementType(const char* line)
   }
 }
 
-void vtkEnSightReader::ReplaceWildcards(char* filename, int num)
-{
-  int wildcardPos, numWildcards, i, j;
-  char pattern[32];
-  char numStr[32];
-  char filenameTmp[2048];
-  int len, cnt, numStrLen;
-  int foundWildcard = 0;
-
-  wildcardPos = static_cast<int>(strcspn(filename, "*"));
-  numWildcards = static_cast<int>(strspn(filename + wildcardPos, "*"));
-
-  if (numWildcards < 1)
-    return;
-  else if (numWildcards == 1)
-    strcpy(pattern, "%d");
-  else
-    snprintf(pattern, sizeof(pattern), "%%0%dd", numWildcards);
-  snprintf(numStr, sizeof(numStr), pattern, num);
-  numStrLen = static_cast<int>(strlen(numStr));
-  len = static_cast<int>(strlen(filename));
-  cnt = 0;
-  for (i = 0; i < len; i++)
-  {
-    if (filename[i] == '*')
-    {
-      if (foundWildcard == 0)
-      {
-        for (j = 0; j < numStrLen; j++)
-          filenameTmp[cnt++] = numStr[j];
-        foundWildcard = 1;
-      }
-    }
-    else
-      filenameTmp[cnt++] = filename[i];
-  }
-  filenameTmp[cnt] = '\0';
-  strcpy(filename, filenameTmp);
-}
-
 //------------------------------------------------------------------------------
 void vtkEnSightReader::RemoveLeadingBlanks(char* line)
 {
@@ -2209,3 +2169,4 @@ void vtkEnSightReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "UseTimeSets: " << this->UseTimeSets << endl;
   os << indent << "UseFileSets: " << this->UseFileSets << endl;
 }
+VTK_ABI_NAMESPACE_END
