@@ -18,6 +18,7 @@
 #include "vtkCompositeDataPipeline.h"
 #include "vtkDataArrayCollection.h"
 #include "vtkDataArraySelection.h"
+#include "vtkDataSetTriangleFilter.h"
 #include "vtkEnSight6BinaryReader.h"
 #include "vtkEnSight6Reader.h"
 #include "vtkEnSightGoldBinaryReader.h"
@@ -35,6 +36,7 @@
 #include <map>
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGenericEnSightReader);
 
 vtkCxxSetObjectMacro(vtkGenericEnSightReader, TimeSets, vtkDataArrayCollection);
@@ -280,6 +282,16 @@ int vtkGenericEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
     this->NumberOfComplexVariables++;
   }
 
+  // Apply a Tetrahedralize filter to prevent non manifold triangle
+  if (this->ApplyTetrahedralize)
+  {
+    vtkNew<vtkDataSetTriangleFilter> tetrahedralizeFilter;
+    tetrahedralizeFilter->SetInputData(output);
+    tetrahedralizeFilter->Update();
+    output->CompositeShallowCopy(
+      vtkMultiBlockDataSet::SafeDownCast(tetrahedralizeFilter->GetOutputDataObject(0)));
+  }
+
   return 1;
 }
 
@@ -320,7 +332,7 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
       sfilename += "/";
     }
     sfilename += this->CaseFileName;
-    vtkDebugMacro("full path to case file: " << sfilename.c_str());
+    vtkDebugMacro("full path to case file: " << sfilename);
   }
   else
   {
@@ -331,7 +343,7 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
   if (this->IS->fail())
   {
     if (!quiet)
-      vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+      vtkErrorMacro("Unable to open file: " << sfilename);
     delete this->IS;
     this->IS = nullptr;
     return -1;
@@ -424,7 +436,7 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
                 sfilename += "/";
               }
               sfilename += fileName;
-              vtkDebugMacro("full path to geometry file: " << sfilename.c_str());
+              vtkDebugMacro("full path to geometry file: " << sfilename);
             }
             else
             {
@@ -438,7 +450,7 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
             {
               if (!quiet)
               {
-                vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+                vtkErrorMacro("Unable to open file: " << sfilename);
                 vtkWarningMacro("Assuming binary file.");
               }
               this->IFile = nullptr;
@@ -538,7 +550,7 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
             sfilename += "/";
           }
           sfilename += fileName;
-          vtkDebugMacro("full path to geometry file: " << sfilename.c_str());
+          vtkDebugMacro("full path to geometry file: " << sfilename);
         }
         else
         {
@@ -552,7 +564,7 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
         {
           if (!quiet)
           {
-            vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+            vtkErrorMacro("Unable to open file: " << sfilename);
             vtkWarningMacro("Assuming binary file.");
           }
           this->IFile = nullptr;
@@ -679,6 +691,16 @@ int vtkGenericEnSightReader::ReadBinaryLine(char result[80])
   return 1;
 }
 
+//------------------------------------------------------------------------------
+// Determines whether a non-comment line should be skipped.
+// Currently skips:
+//  'maximum time steps:'
+//
+bool vtkGenericEnSightReader::SkipDataLine(char line[256])
+{
+  return (strncmp(line, "maximum time steps:", 19) == 0);
+}
+
 //------------------------------------------------------------------------------
 // Internal function that skips blank lines and comment lines
 // and reads the next line it finds (up to 256 characters).
@@ -691,7 +713,7 @@ int vtkGenericEnSightReader::ReadNextDataLine(char result[256])
   while (isComment && value)
   {
     value = this->ReadLine(result);
-    if (*result && result[0] != '#')
+    if (*result && result[0] != '#' && !this->SkipDataLine(result))
     {
       size_t len = strlen(result);
       unsigned int i = 0;
@@ -1112,7 +1134,7 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet, int f
       sfilename += "/";
     }
     sfilename += this->CaseFileName;
-    vtkDebugMacro("full path to case file: " << sfilename.c_str());
+    vtkDebugMacro("full path to case file: " << sfilename);
   }
   else
   {
@@ -1268,7 +1290,7 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet, int f
   }
 
   // So far we have got a file name index
-  this->ReplaceWildcardsHelper(fileName, fileNameNum);
+  vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, fileNameNum);
   delete this->IS;
   this->IS = nullptr;
 
@@ -1276,75 +1298,58 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet, int f
 }
 
 //------------------------------------------------------------------------------
-void vtkGenericEnSightReader::ReplaceWildcardsHelper(char* fileName, int num)
+void vtkGenericEnSightReader::ReplaceWildcardsHelper(char* filename, int num)
 {
-  int wildcardPos, numWildcards, numDigits = 1, i;
-  int tmpNum = num, multTen = 1;
-  char newChar;
-  int newNum;
+  // TODO Rewrite using std::regex and std::string
 
-  wildcardPos = static_cast<int>(strcspn(fileName, "*"));
-  numWildcards = static_cast<int>(strspn(fileName + wildcardPos, "*"));
+  size_t wildcardPos = strcspn(filename, "*");
 
-  tmpNum /= 10;
-  while (tmpNum >= 1)
+  // Check if no wildcard
+  if (strlen(filename) == wildcardPos)
   {
-    numDigits++;
-    multTen *= 10;
-    tmpNum /= 10;
+    return;
   }
 
-  for (i = 0; i < numWildcards - numDigits; i++)
+  size_t numWildcards = strspn(filename + wildcardPos, "*");
+
+  char pattern[32];
+  if (numWildcards == 1)
   {
-    fileName[i + wildcardPos] = '0';
+    strcpy(pattern, "%d");
+  }
+  else
+  {
+    snprintf(pattern, sizeof(pattern), "%%0%dd", static_cast<int>(numWildcards));
   }
 
-  tmpNum = num;
-  for (i = numWildcards - numDigits; i < numWildcards; i++)
+  char numStr[32];
+  snprintf(numStr, sizeof(numStr), pattern, num);
+
+  int numStrLen = static_cast<int>(strlen(numStr));
+  int len = static_cast<int>(strlen(filename));
+  int cnt = 0;
+  bool foundWildcard = false;
+  char filenameTmp[2048];
+  for (int i = 0; i < len; i++)
   {
-    newNum = tmpNum / multTen;
-    switch (newNum)
+    if (filename[i] == '*')
     {
-      case 0:
-        newChar = '0';
-        break;
-      case 1:
-        newChar = '1';
-        break;
-      case 2:
-        newChar = '2';
-        break;
-      case 3:
-        newChar = '3';
-        break;
-      case 4:
-        newChar = '4';
-        break;
-      case 5:
-        newChar = '5';
-        break;
-      case 6:
-        newChar = '6';
-        break;
-      case 7:
-        newChar = '7';
-        break;
-      case 8:
-        newChar = '8';
-        break;
-      case 9:
-        newChar = '9';
-        break;
-      default:
-        // This case should never be reached.
-        return;
+      if (!foundWildcard)
+      {
+        for (int j = 0; j < numStrLen; j++)
+        {
+          filenameTmp[cnt++] = numStr[j];
+        }
+        foundWildcard = true;
+      }
+    }
+    else
+    {
+      filenameTmp[cnt++] = filename[i];
     }
-    assert(newChar == ('0' + newNum));
-
-    fileName[i + wildcardPos] = newChar;
-    tmpNum -= multTen * newNum;
-    multTen /= 10;
   }
+  filenameTmp[cnt] = '\0';
+  strcpy(filename, filenameTmp);
 }
 
 //------------------------------------------------------------------------------
@@ -1615,3 +1620,4 @@ int vtkGenericEnSightReader::FillOutputPortInformation(int vtkNotUsed(port), vtk
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkMultiBlockDataSet");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
