@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkCPExodusIIElementBlock.h
+  Module:    vtkCPExodusIIElementBlock.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -25,6 +25,7 @@
 #include <algorithm>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCPExodusIIElementBlock);
 vtkStandardNewMacro(vtkCPExodusIIElementBlockImpl);
 
@@ -118,6 +119,14 @@ void vtkCPExodusIIElementBlockImpl::GetCellPoints(vtkIdType cellId, vtkIdList* p
     this->GetElementStart(cellId), this->GetElementEnd(cellId), ptIds->GetPointer(0), NodeToPoint);
 }
 
+//------------------------------------------------------------------------------
+void vtkCPExodusIIElementBlockImpl::GetFaceStream(
+  vtkIdType vtkNotUsed(cellId), vtkIdList* vtkNotUsed(ptIds))
+{
+  // vtkCPExodusIIElementBlockImpl does not support polyhedra
+  vtkErrorMacro(<< __FUNCTION__ << " is not implemented");
+}
+
 //------------------------------------------------------------------------------
 void vtkCPExodusIIElementBlockImpl::GetPointCells(vtkIdType ptId, vtkIdList* cellIds)
 {
@@ -210,3 +219,4 @@ vtkCPExodusIIElementBlockImpl::~vtkCPExodusIIElementBlockImpl()
 {
   delete[] this->Elements;
 }
+VTK_ABI_NAMESPACE_END
