@@ -22,24 +22,22 @@
 
 #include <algorithm>
 
-vtkStandardNewMacro(vtkCPExodusIIElementBlockCellIterator)
+VTK_ABI_NAMESPACE_BEGIN
+vtkStandardNewMacro(vtkCPExodusIIElementBlockCellIterator);
 
 //------------------------------------------------------------------------------
-void vtkCPExodusIIElementBlockCellIterator::PrintSelf(ostream &os,
-                                                      vtkIndent indent)
+void vtkCPExodusIIElementBlockCellIterator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Storage: " << this->Storage << endl;
-  os << indent << "DataSetPoints: "
-     << this->DataSetPoints << endl;
-  os << indent << "CellId: "  << this->CellId << endl;
+  os << indent << "DataSetPoints: " << this->DataSetPoints << endl;
+  os << indent << "CellId: " << this->CellId << endl;
 }
 
 //------------------------------------------------------------------------------
 bool vtkCPExodusIIElementBlockCellIterator::IsValid()
 {
-  return this->Storage
-      && this->CellId < this->Storage->NumberOfCells;
+  return this->Storage && this->CellId < this->Storage->NumberOfCells;
 }
 
 //------------------------------------------------------------------------------
@@ -50,16 +48,14 @@ vtkIdType vtkCPExodusIIElementBlockCellIterator::GetCellId()
 
 //------------------------------------------------------------------------------
 vtkCPExodusIIElementBlockCellIterator::vtkCPExodusIIElementBlockCellIterator()
-    : Storage(nullptr),
-      DataSetPoints(nullptr),
-      CellId(0)
+  : Storage(nullptr)
+  , DataSetPoints(nullptr)
+  , CellId(0)
 {
 }
 
 //------------------------------------------------------------------------------
-vtkCPExodusIIElementBlockCellIterator::~vtkCPExodusIIElementBlockCellIterator()
-{
-}
+vtkCPExodusIIElementBlockCellIterator::~vtkCPExodusIIElementBlockCellIterator() {}
 
 //------------------------------------------------------------------------------
 void vtkCPExodusIIElementBlockCellIterator::ResetToFirstCell()
@@ -85,8 +81,8 @@ void vtkCPExodusIIElementBlockCellIterator::FetchPointIds()
   this->PointIds->SetNumberOfIds(this->Storage->CellSize);
 
   std::transform(this->Storage->GetElementStart(this->CellId),
-                 this->Storage->GetElementEnd(this->CellId),
-                 this->PointIds->GetPointer(0), StorageType::NodeToPoint);
+    this->Storage->GetElementEnd(this->CellId), this->PointIds->GetPointer(0),
+    StorageType::NodeToPoint);
 }
 
 //------------------------------------------------------------------------------
@@ -96,14 +92,13 @@ void vtkCPExodusIIElementBlockCellIterator::FetchPoints()
 }
 
 //------------------------------------------------------------------------------
-void vtkCPExodusIIElementBlockCellIterator::SetStorage(
-    vtkCPExodusIIElementBlock *eb)
+void vtkCPExodusIIElementBlockCellIterator::SetStorage(vtkCPExodusIIElementBlock* eb)
 {
   if (eb != nullptr)
   {
     this->Storage = eb->GetInternals();
-    this->DataSetPoints= eb->GetPoints();
-    if(this->DataSetPoints)
+    this->DataSetPoints = eb->GetPoints();
+    if (this->DataSetPoints)
     {
       this->Points->SetDataType(this->DataSetPoints->GetDataType());
     }
@@ -115,3 +110,4 @@ void vtkCPExodusIIElementBlockCellIterator::SetStorage(
   }
   this->CellId = 0;
 }
+VTK_ABI_NAMESPACE_END
