@@ -4,7 +4,6 @@
 // Do not include this file directly. It is only for use
 // from inside the ExodusII reader and its descendants.
 
-#include "vtkDeprecation.h"    // for deprecation macros
 #include "vtkExodusIICache.h"  // for vtkExodusIICacheKey
 #include "vtkExodusIIReader.h" // for vtkExodusIIReader
 #include "vtkObject.h"
@@ -16,6 +15,7 @@
 
 #include "vtkIOExodusModule.h" // For export macro
 #include "vtk_exodusII.h"      // for exodus APIs
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataArray;
 class vtkExodusIIReaderParser;
 class vtkIdTypeArray;
@@ -31,8 +31,6 @@ class VTKIOEXODUS_EXPORT vtkExodusIIReaderPrivate : public vtkObject
 {
 public:
   static vtkExodusIIReaderPrivate* New();
-  VTK_DEPRECATED_IN_9_1_0("Renamed to PrintSelf")
-  void PrintData(ostream& os, vtkIndent indent) { this->PrintSelf(os, indent); }
   void PrintSelf(ostream& os, vtkIndent indent) override;
   vtkTypeMacro(vtkExodusIIReaderPrivate, vtkObject);
   // virtual void Modified();
@@ -865,4 +863,5 @@ private:
   void operator=(const vtkExodusIIReaderPrivate&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkExodusIIReaderPrivate_h
