@@ -76,6 +76,7 @@
 #include <string> // STL Header
 #include <vector> // STL Header
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkModelMetadata;
 class vtkDoubleArray;
 class vtkIntArray;
@@ -108,8 +109,8 @@ public:
    * If not set, this class will make up a file name.
    */
 
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
 
   /**
    * If StoreDoubles is ON, the floating point fields in the Exodus file
@@ -369,4 +370,5 @@ private:
   void operator=(const vtkExodusIIWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
