@@ -41,6 +41,7 @@
 #include <string>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkJSONDataSetWriter);
 vtkCxxSetObjectMacro(vtkJSONDataSetWriter, Archiver, vtkArchiver);
 
@@ -59,24 +60,6 @@ vtkJSONDataSetWriter::~vtkJSONDataSetWriter()
 
 //------------------------------------------------------------------------------
 
-void vtkJSONDataSetWriter::SetFileName(const char* archiveName)
-{
-  VTK_LEGACY_REPLACED_BODY(
-    vtkJSONDataSetWriter::SetFileName, "VTK 9.0", vtkJSONDataSetWriter::SetArchiveName);
-  this->Archiver->SetArchiveName(archiveName);
-}
-
-//------------------------------------------------------------------------------
-
-char* vtkJSONDataSetWriter::GetFileName()
-{
-  VTK_LEGACY_REPLACED_BODY(
-    vtkJSONDataSetWriter::GetFileName, "VTK 9.0", vtkJSONDataSetWriter::GetArchiveName);
-  return this->Archiver->GetArchiveName();
-}
-
-//------------------------------------------------------------------------------
-
 vtkDataSet* vtkJSONDataSetWriter::GetInput()
 {
   return vtkDataSet::SafeDownCast(this->Superclass::GetInput());
@@ -162,7 +145,7 @@ std::string vtkJSONDataSetWriter::WriteArray(
   bool needConvert;
   std::string id = vtkJSONDataSetWriter::GetUID(array, needConvert);
   std::stringstream arrayPath;
-  arrayPath << "data/" << id.c_str();
+  arrayPath << "data/" << id;
   bool success = vtkJSONDataSetWriter::WriteArrayContents(array, arrayPath.str().c_str());
 
   if (!success)
@@ -182,7 +165,7 @@ std::string vtkJSONDataSetWriter::WriteArray(
      << INDENT << "  \"ref\": {\n"
      << INDENT << "     \"encode\": \"LittleEndian\",\n"
      << INDENT << "     \"basepath\": \"data\",\n"
-     << INDENT << "     \"id\": \"" << id.c_str() << "\"\n"
+     << INDENT << "     \"id\": \"" << id << "\"\n"
      << INDENT << "  },\n"
      << INDENT << "  \"size\": " << array->GetNumberOfValues() << "\n"
      << INDENT << "}";
@@ -236,39 +219,35 @@ void vtkJSONDataSetWriter::Write(vtkDataSet* dataset)
 
     vtkPoints* points = polyData->GetPoints();
     metaJsonFile << ",\n  \"points\": "
-                 << this->WriteArray(points->GetData(), "vtkPoints", "points").c_str();
+                 << this->WriteArray(points->GetData(), "vtkPoints", "points");
 
     // Verts
     vtkNew<vtkIdTypeArray> cells;
     polyData->GetVerts()->ExportLegacyFormat(cells);
     if (cells->GetNumberOfValues())
     {
-      metaJsonFile << ",\n  \"verts\": "
-                   << this->WriteArray(cells, "vtkCellArray", "verts").c_str();
+      metaJsonFile << ",\n  \"verts\": " << this->WriteArray(cells, "vtkCellArray", "verts");
     }
 
     // Lines
     polyData->GetLines()->ExportLegacyFormat(cells);
     if (cells->GetNumberOfValues())
     {
-      metaJsonFile << ",\n  \"lines\": "
-                   << this->WriteArray(cells, "vtkCellArray", "lines").c_str();
+      metaJsonFile << ",\n  \"lines\": " << this->WriteArray(cells, "vtkCellArray", "lines");
     }
 
     // Strips
     polyData->GetStrips()->ExportLegacyFormat(cells);
     if (cells->GetNumberOfValues())
     {
-      metaJsonFile << ",\n  \"strips\": "
-                   << this->WriteArray(cells, "vtkCellArray", "strips").c_str();
+      metaJsonFile << ",\n  \"strips\": " << this->WriteArray(cells, "vtkCellArray", "strips");
     }
 
     // Polys
     polyData->GetPolys()->ExportLegacyFormat(cells);
     if (cells->GetNumberOfValues())
     {
-      metaJsonFile << ",\n  \"polys\": "
-                   << this->WriteArray(cells, "vtkCellArray", "polys").c_str();
+      metaJsonFile << ",\n  \"polys\": " << this->WriteArray(cells, "vtkCellArray", "polys");
     }
   }
 
@@ -278,7 +257,7 @@ void vtkJSONDataSetWriter::Write(vtkDataSet* dataset)
   if (!fieldJSON.empty())
   {
     isEmpty = false;
-    metaJsonFile << ",\n" << fieldJSON.c_str();
+    metaJsonFile << ",\n" << fieldJSON;
   }
 
   // CellData
@@ -286,7 +265,7 @@ void vtkJSONDataSetWriter::Write(vtkDataSet* dataset)
   if (!fieldJSON.empty())
   {
     isEmpty = false;
-    metaJsonFile << ",\n" << fieldJSON.c_str();
+    metaJsonFile << ",\n" << fieldJSON;
   }
 
   metaJsonFile << "}\n";
@@ -319,7 +298,7 @@ bool vtkJSONDataSetWriter::WriteArrayContents(vtkDataArray* input, const char* f
   }
 
   // Check if we need to convert the (u)int64 to (u)int32
-  vtkSmartPointer<vtkDataArray> arrayToWrite;
+  vtkSmartPointer<vtkDataArray> arrayToWrite = input;
   vtkIdType arraySize = input->GetNumberOfTuples() * input->GetNumberOfComponents();
   switch (input->GetDataType())
   {
@@ -490,7 +469,6 @@ std::string vtkJSONDataSetWriter::GetShortType(vtkDataArray* input, bool& needCo
 
     case VTK_BIT:
     case VTK_STRING:
-    case VTK_UNICODE_STRING:
     case VTK_VARIANT:
     default:
       ss << "xxx";
@@ -511,7 +489,7 @@ std::string vtkJSONDataSetWriter::GetUID(vtkDataArray* input, bool& needConversi
 
   std::stringstream ss;
   ss << vtkJSONDataSetWriter::GetShortType(input, needConversion) << "_"
-     << input->GetNumberOfValues() << "-" << hash.c_str();
+     << input->GetNumberOfValues() << "-" << hash;
 
   return ss.str();
 }
@@ -529,3 +507,4 @@ std::string vtkJSONDataSetWriter::GetValidString(const char* name)
 
   return ss.str();
 }
+VTK_ABI_NAMESPACE_END
