@@ -40,11 +40,11 @@
 
 #include "vtkIOExportModule.h" // For export macro
 
-#include "vtkDeprecation.h" // For VTK_DEPRECATED_IN_9_0_0
 #include "vtkWriter.h"
 
 #include <string> // std::string used as parameters in a few methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkDataArray;
 class vtkDataSetAttributes;
@@ -55,15 +55,15 @@ class VTKIOEXPORT_EXPORT vtkJSONDataSetWriter : public vtkWriter
 public:
   using vtkWriter::Write;
 
-  //@{
+  ///@{
   /**
    * Compute a MD5 digest of a void/(const unsigned char) pointer to compute a
    *  string hash
    */
   static void ComputeMD5(const unsigned char* content, int size, std::string& hash);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Compute the target JavaScript typed array name for the given vtkDataArray
    * (Uin8, Uint16, Uin32, Int8, Int16, Int32, Float32, Float64) or
@@ -73,24 +73,24 @@ public:
    * argument will be set to true and Uint32/Int32 will be returned instead.
    */
   static std::string GetShortType(vtkDataArray* input, bool& needConversion);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return a Unique identifier for that array
    * (i.e.: Float32_356_13f880891af7b77262c49cae09a41e28 )
    */
   static std::string GetUID(vtkDataArray*, bool& needConversion);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return a Unique identifier for any invalid string
    */
   std::string GetValidString(const char*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Write the contents of the vtkDataArray to disk based on the filePath
    * provided without any extra information. Just the raw data will be
@@ -99,48 +99,36 @@ public:
    * If vtkDataArray is a Uint64 or Int64, the data will be converted
    * to Uint32 or Int32 before being written.
    */
-  bool WriteArrayContents(vtkDataArray*, const char* relativeFilePath);
-  //@}
+  bool WriteArrayContents(vtkDataArray*, VTK_FILEPATH const char* relativeFilePath);
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * For backwards compatiblity, this static method writes a data array's
+   * For backwards compatibility, this static method writes a data array's
    * contents directly to a file.
    */
-  static bool WriteArrayAsRAW(vtkDataArray*, const char* filePath);
-  //@}
+  static bool WriteArrayAsRAW(vtkDataArray*, VTK_FILEPATH const char* filePath);
+  ///@}
 
   static vtkJSONDataSetWriter* New();
   vtkTypeMacro(vtkJSONDataSetWriter, vtkWriter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
-  /**
-   * Specify file name of vtk data file to write.
-   * This correspond to the root directory of the data to write.
-   * DEPRECATED: use the Archive's API instead.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Use vtkJSONDataSetWriter::SetArchiveName")
-  void SetFileName(const char*);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkJSONDataSetWriter::GetArchiveName")
-  virtual char* GetFileName();
-  //@}
-
-  //@{
+  ///@{
   /**
    * Get the input to this writer.
    */
   vtkDataSet* GetInput();
   vtkDataSet* GetInput(int port);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the Scene Archiver object
    */
   virtual void SetArchiver(vtkArchiver*);
   vtkGetObjectMacro(Archiver, vtkArchiver);
-  //@}
+  ///@}
 
   void Write(vtkDataSet*);
 
@@ -165,4 +153,5 @@ private:
   void operator=(const vtkJSONDataSetWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
