@@ -25,21 +25,23 @@
 #include "vtkImageFlip.h"
 #include "vtkMapper.h"
 #include "vtkNew.h"
+#include "vtkNumberToString.h"
 #include "vtkObjectFactory.h"
 #include "vtkPNGWriter.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkProperty.h"
-#include "vtkRendererCollection.h"
 #include "vtkRenderWindow.h"
+#include "vtkRendererCollection.h"
 #include "vtkTexture.h"
 #include "vtkTransform.h"
-#include "vtkNumberToString.h"
 
+#include "vtksys/FStream.hxx"
 #include "vtksys/SystemTools.hxx"
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOBJExporter);
 
 vtkOBJExporter::vtkOBJExporter()
@@ -54,21 +56,21 @@ vtkOBJExporter::vtkOBJExporter()
 
 vtkOBJExporter::~vtkOBJExporter()
 {
-  delete [] this->OBJFileComment;
-  delete [] this->MTLFileComment;
-  delete [] this->FilePrefix;
+  delete[] this->OBJFileComment;
+  delete[] this->MTLFileComment;
+  delete[] this->FilePrefix;
 }
 
 void vtkOBJExporter::WriteData()
 {
   // make sure the user specified a filename
-  if ( this->FilePrefix == nullptr)
+  if (this->FilePrefix == nullptr)
   {
     vtkErrorMacro(<< "Please specify file prefix to use");
     return;
   }
 
-  vtkRenderer *ren = this->ActiveRenderer;
+  vtkRenderer* ren = this->ActiveRenderer;
   if (!ren)
   {
     ren = this->RenderWindow->GetRenderers()->GetFirstRenderer();
@@ -86,23 +88,23 @@ void vtkOBJExporter::WriteData()
   std::string filePrefix(this->FilePrefix);
   // get the model name which isthe last component of the FilePrefix
   std::string modelName;
-  if (filePrefix.find_last_of("/") != std::string::npos)
+  if (filePrefix.find_last_of('/') != std::string::npos)
   {
-    modelName = filePrefix.substr(filePrefix.find_last_of("/") + 1);
+    modelName = filePrefix.substr(filePrefix.find_last_of('/') + 1);
   }
   else
   {
     modelName = filePrefix;
   }
 
-  std::ofstream fpObj(objFilePath, ios::out);
+  vtksys::ofstream fpObj(objFilePath.c_str(), ios::out);
   if (!fpObj)
   {
     vtkErrorMacro(<< "unable to open " << objFilePath);
     return;
   }
   std::string mtlFilePath = std::string(this->FilePrefix) + ".mtl";
-  std::ofstream fpMtl(mtlFilePath, ios::out);
+  vtksys::ofstream fpMtl(mtlFilePath.c_str(), ios::out);
   if (!fpMtl)
   {
     fpMtl.close();
@@ -126,16 +128,16 @@ void vtkOBJExporter::WriteData()
     fpMtl << "# " << this->GetMTLFileComment() << "\n\n";
   }
 
-  vtkActorCollection *allActors = ren->GetActors();
+  vtkActorCollection* allActors = ren->GetActors();
   vtkCollectionSimpleIterator actorsIt;
-  vtkActor *anActor;
+  vtkActor* anActor;
   int idStart = 1;
-  for (allActors->InitTraversal(actorsIt); (anActor = allActors->GetNextActor(actorsIt)); )
+  for (allActors->InitTraversal(actorsIt); (anActor = allActors->GetNextActor(actorsIt));)
   {
-    vtkAssemblyPath *aPath;
-    for (anActor->InitPathTraversal(); (aPath = anActor->GetNextPath()); )
+    vtkAssemblyPath* aPath;
+    for (anActor->InitPathTraversal(); (aPath = anActor->GetNextPath());)
     {
-      vtkActor *aPart = vtkActor::SafeDownCast(aPath->GetLastNode()->GetViewProp());
+      vtkActor* aPart = vtkActor::SafeDownCast(aPath->GetLastNode()->GetViewProp());
       this->WriteAnActor(aPart, fpObj, fpMtl, modelName, idStart);
     }
   }
@@ -144,12 +146,10 @@ void vtkOBJExporter::WriteData()
   {
     std::stringstream fullFileName;
     fullFileName << this->FilePrefix << t.first;
-    auto writeTexture =
-      vtkSmartPointer<vtkPNGWriter>::New();
+    auto writeTexture = vtkSmartPointer<vtkPNGWriter>::New();
     if (this->FlipTexture)
     {
-      auto flip =
-        vtkSmartPointer<vtkImageFlip>::New();
+      auto flip = vtkSmartPointer<vtkImageFlip>::New();
       flip->SetInputData(t.second->GetInput());
       flip->SetFilteredAxis(1);
       flip->Update();
@@ -166,25 +166,22 @@ void vtkOBJExporter::WriteData()
   fpMtl.close();
 }
 
-void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
-                                  std::ofstream &fpObj,
-                                  std::ofstream &fpMtl,
-                                  std::string &modelName,
-                                  int &idStart)
+void vtkOBJExporter::WriteAnActor(
+  vtkActor* anActor, std::ostream& fpObj, std::ostream& fpMtl, std::string& modelName, int& idStart)
 {
-  vtkDataSet *ds;
+  vtkDataSet* ds;
   vtkNew<vtkPolyData> pd;
-  vtkPointData *pntData;
-  vtkPoints *points;
-  vtkDataArray *tcoords;
+  vtkPointData* pntData;
+  vtkPoints* points;
+  vtkDataArray* tcoords;
   int i, i1, i2, idNext;
-  vtkProperty *prop;
-  double *tempd;
-  double *p;
-  vtkCellArray *cells;
+  vtkProperty* prop;
+  double* tempd;
+  double* p;
+  vtkCellArray* cells;
   vtkNew<vtkTransform> trans;
   vtkIdType npts = 0;
-  vtkIdType *indx = nullptr;
+  const vtkIdType* indx = nullptr;
 
   // see if the actor has a mapper. it could be an assembly
   if (anActor->GetMapper() == nullptr)
@@ -202,31 +199,22 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   fpMtl << "newmtl mtl" << idStart << "\n";
   tempd = prop->GetAmbientColor();
   temp = prop->GetAmbient();
-  fpMtl << "Ka "
-        << convert(temp * tempd[0]) << " "
-        << convert(temp * tempd[1]) << " "
-        << convert(temp * tempd[2])
-        << "\n";
+  fpMtl << "Ka " << convert(temp * tempd[0]) << " " << convert(temp * tempd[1]) << " "
+        << convert(temp * tempd[2]) << "\n";
   tempd = prop->GetDiffuseColor();
   temp = prop->GetDiffuse();
-  fpMtl << "Kd "
-        << convert(temp * tempd[0]) << " "
-        << convert(temp * tempd[1]) << " "
-        << convert(temp * tempd[2])
-        << "\n";
+  fpMtl << "Kd " << convert(temp * tempd[0]) << " " << convert(temp * tempd[1]) << " "
+        << convert(temp * tempd[2]) << "\n";
   tempd = prop->GetSpecularColor();
   temp = prop->GetSpecular();
-  fpMtl << "Ks "
-        << convert(temp * tempd[0]) << " "
-        << convert(temp * tempd[1]) << " "
-        << convert(temp * tempd[2])
-        << "\n";
+  fpMtl << "Ks " << convert(temp * tempd[0]) << " " << convert(temp * tempd[1]) << " "
+        << convert(temp * tempd[2]) << "\n";
   fpMtl << "Ns " << convert(prop->GetSpecularPower()) << "\n";
-  fpMtl << "Tr " <<convert(prop->GetOpacity()) << "\n";
+  fpMtl << "Tr " << convert(prop->GetOpacity()) << "\n";
   fpMtl << "illum 3\n";
 
   // Actor has the texture
-  bool hasTexture = anActor->GetTexture() != nullptr;;
+  bool hasTexture = anActor->GetTexture() != nullptr;
 
   // Actor's property has the texture. We choose the albedo texture
   // since it seems to be similar to the texture we expect
@@ -242,7 +230,8 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   else if (hasTextureProp)
   {
     std::stringstream textureFileName;
-    textureFileName << "albedoTex" << "_" << idStart << ".png";
+    textureFileName << "albedoTex"
+                    << "_" << idStart << ".png";
     fpMtl << "map_Kd " << modelName << textureFileName.str() << "\n\n";
     auto albedoTexture = allTextures.find("albedoTex");
     this->TextureFileMap[textureFileName.str()] = albedoTexture->second;
@@ -260,11 +249,10 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   trans->SetMatrix(anActor->vtkProp3D::GetMatrix());
 
   // we really want polydata
-  if ( ds->GetDataObjectType() != VTK_POLY_DATA )
+  if (ds->GetDataObjectType() != VTK_POLY_DATA)
   {
     vtkNew<vtkGeometryFilter> gf;
-    gf->SetInputConnection(
-      anActor->GetMapper()->GetInputConnection(0, 0));
+    gf->SetInputConnection(anActor->GetMapper()->GetInputConnection(0, 0));
     gf->Update();
     pd->DeepCopy(gf->GetOutput());
   }
@@ -275,14 +263,11 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
 
   // write out the points
   points = vtkPoints::New();
-  trans->TransformPoints(pd->GetPoints(),points);
+  trans->TransformPoints(pd->GetPoints(), points);
   for (i = 0; i < points->GetNumberOfPoints(); i++)
   {
     p = points->GetPoint(i);
-    fpObj << "v "
-          << convert(p[0]) << " "
-          << convert(p[1]) << " "
-          << convert(p[2]) << "\n";
+    fpObj << "v " << convert(p[0]) << " " << convert(p[1]) << " " << convert(p[2]) << "\n";
   }
   idNext = idStart + static_cast<int>(points->GetNumberOfPoints());
   points->Delete();
@@ -293,14 +278,11 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   {
     vtkNew<vtkFloatArray> normals;
     normals->SetNumberOfComponents(3);
-    trans->TransformNormals(pntData->GetNormals(),normals);
+    trans->TransformNormals(pntData->GetNormals(), normals);
     for (i = 0; i < normals->GetNumberOfTuples(); i++)
     {
       p = normals->GetTuple(i);
-      fpObj << "vn "
-            << convert(p[0]) << " "
-            << convert(p[1]) << " "
-            << convert(p[2]) << "\n";
+      fpObj << "vn " << convert(p[0]) << " " << convert(p[1]) << " " << convert(p[2]) << "\n";
     }
   }
 
@@ -310,10 +292,7 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
     for (i = 0; i < tcoords->GetNumberOfTuples(); i++)
     {
       p = tcoords->GetTuple(i);
-      fpObj << "vt "
-            << convert(p[0]) << " "
-            << convert(p[1]) << " "
-            << 0.0 << "\n";
+      fpObj << "vt " << convert(p[0]) << " " << convert(p[1]) << " " << 0.0 << "\n";
     }
   }
 
@@ -324,7 +303,7 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   if (pd->GetNumberOfVerts() > 0)
   {
     cells = pd->GetVerts();
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); )
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx);)
     {
       fpObj << "p ";
       for (i = 0; i < npts; i++)
@@ -340,7 +319,7 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   if (pd->GetNumberOfLines() > 0)
   {
     cells = pd->GetLines();
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); )
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx);)
     {
       fpObj << "l ";
       if (tcoords)
@@ -350,24 +329,24 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
           // treating vtkIdType as int
           fpObj << static_cast<int>(indx[i]) + idStart << "/"
                 << static_cast<int>(indx[i]) + idStart;
+        }
       }
-    }
-    else
-    {
-      for (i = 0; i < npts; i++)
+      else
       {
-        // treating vtkIdType as int
-        fpObj << static_cast<int>(indx[i]) + idStart << " ";
+        for (i = 0; i < npts; i++)
+        {
+          // treating vtkIdType as int
+          fpObj << static_cast<int>(indx[i]) + idStart << " ";
+        }
       }
-    }
-    fpObj << "\n";
+      fpObj << "\n";
     }
   }
   // write out polys if any
   if (pd->GetNumberOfPolys() > 0)
   {
     cells = pd->GetPolys();
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); )
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx);)
     {
       fpObj << "f ";
       for (i = 0; i < npts; i++)
@@ -411,11 +390,11 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
   if (pd->GetNumberOfStrips() > 0)
   {
     cells = pd->GetStrips();
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); )
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx);)
     {
       for (i = 2; i < npts; i++)
       {
-        if (i%2 == 0)
+        if (i % 2 == 0)
         {
           i1 = i - 2;
           i2 = i - 1;
@@ -430,8 +409,7 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
           if (tcoords)
           {
             // treating vtkIdType as int
-            fpObj << "f "
-                  << static_cast<int>(indx[i1]) + idStart << "/"
+            fpObj << "f " << static_cast<int>(indx[i1]) + idStart << "/"
                   << static_cast<int>(indx[i1]) + idStart << "/"
                   << static_cast<int>(indx[i1]) + idStart << " ";
             fpObj << static_cast<int>(indx[i2]) + idStart << "/"
@@ -444,6 +422,8 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
           else
           {
             // treating vtkIdType as int
+            fpObj << "f " << static_cast<int>(indx[i1]) + idStart << "//"
+                  << static_cast<int>(indx[i1]) + idStart << " ";
             fpObj << static_cast<int>(indx[i2]) + idStart << "//"
                   << static_cast<int>(indx[i2]) + idStart << " ";
             fpObj << static_cast<int>(indx[i]) + idStart << "//"
@@ -455,8 +435,7 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
           if (tcoords)
           {
             // treating vtkIdType as int
-            fpObj << "f "
-                  << static_cast<int>(indx[i1]) + idStart << "/"
+            fpObj << "f " << static_cast<int>(indx[i1]) + idStart << "/"
                   << static_cast<int>(indx[i1]) + idStart << " ";
             fpObj << static_cast<int>(indx[i2]) + idStart << "/"
                   << static_cast<int>(indx[i2]) + idStart << " ";
@@ -466,8 +445,7 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
           else
           {
             // treating vtkIdType as int
-            fpObj << "f "
-                  << static_cast<int>(indx[i1]) + idStart << " "
+            fpObj << "f " << static_cast<int>(indx[i1]) + idStart << " "
                   << static_cast<int>(indx[i2]) + idStart << " "
                   << static_cast<int>(indx[i]) + idStart << "\n";
           }
@@ -481,9 +459,12 @@ void vtkOBJExporter::WriteAnActor(vtkActor *anActor,
 
 void vtkOBJExporter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "FilePrefix: " << (this->FilePrefix ? this->FilePrefix : "(null)") << "\n";
-  os << indent << "OBJFileComment: " << (this->OBJFileComment ? this->OBJFileComment : "(null)") << "\n";
-  os << indent << "MTLFileComment: " << (this->MTLFileComment ? this->MTLFileComment : "(null)") << "\n";
+  os << indent << "OBJFileComment: " << (this->OBJFileComment ? this->OBJFileComment : "(null)")
+     << "\n";
+  os << indent << "MTLFileComment: " << (this->MTLFileComment ? this->MTLFileComment : "(null)")
+     << "\n";
 }
+VTK_ABI_NAMESPACE_END
