@@ -15,13 +15,14 @@
 #include "vtkRIBLight.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRIBLight);
 
-vtkRIBLight::vtkRIBLight ()
+vtkRIBLight::vtkRIBLight()
 {
   this->Shadows = 0;
   // create a vtkLight that can be rendered
-  this->Light = vtkLight::New ();
+  this->Light = vtkLight::New();
 }
 
 vtkRIBLight::~vtkRIBLight()
@@ -32,25 +33,20 @@ vtkRIBLight::~vtkRIBLight()
   }
 }
 
-void vtkRIBLight::Render(vtkRenderer *ren, int index)
+void vtkRIBLight::Render(vtkRenderer* ren, int index)
 {
-  int ref;
-
   // Copy this light's ivars into the light to be rendered
-  ref = this->Light->GetReferenceCount();
   this->Light->DeepCopy(this);
-  //this->Light->SetDeleteMethod(nullptr);
-  this->Light->SetReferenceCount(ref);
+  // this->Light->SetDeleteMethod(nullptr);
 
   // Render the light
-  this->Light->Render (ren, index);
+  this->Light->Render(ren, index);
 }
 
 void vtkRIBLight::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
-
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Shadows: " << (this->Shadows ? "On\n" : "Off\n");
 }
-
+VTK_ABI_NAMESPACE_END
