@@ -14,8 +14,8 @@
 =========================================================================*/
 #include "vtkX3DExporter.h"
 
-#include "vtkActor2DCollection.h"
 #include "vtkActor2D.h"
+#include "vtkActor2DCollection.h"
 #include "vtkAssemblyPath.h"
 #include "vtkCamera.h"
 #include "vtkCellArray.h"
@@ -25,64 +25,53 @@
 #include "vtkGeometryFilter.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
-#include "vtkLightCollection.h"
 #include "vtkLight.h"
+#include "vtkLightCollection.h"
 #include "vtkMath.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
-#include "vtkPolyDataMapper2D.h"
 #include "vtkPolyDataMapper.h"
+#include "vtkPolyDataMapper2D.h"
 #include "vtkProperty.h"
-#include "vtkRendererCollection.h"
 #include "vtkRenderWindow.h"
+#include "vtkRendererCollection.h"
 #include "vtkSmartPointer.h"
 #include "vtkTextActor.h"
 #include "vtkTextProperty.h"
 #include "vtkTexture.h"
 #include "vtkTransform.h"
+#include "vtkUnsignedCharArray.h"
+#include "vtkX3D.h"
 #include "vtkX3DExporterFIWriter.h"
 #include "vtkX3DExporterXMLWriter.h"
-#include "vtkX3D.h"
 
-#include <sstream>
 #include <cassert>
+#include <sstream>
 
 using namespace vtkX3D;
 
 // forward declarations
-static bool vtkX3DExporterWriterUsingCellColors(vtkMapper* anActor);
-static bool vtkX3DExporterWriterRenderFaceSet(
-  int cellType,
-  int representation,
-  vtkPoints* points,
-  vtkIdType cellOffset,
-  vtkCellArray* cells,
-  vtkUnsignedCharArray* colors, bool cell_colors,
-  vtkDataArray* normals, bool cell_normals,
-  vtkDataArray* tcoords,
-  bool common_data_written, int index, vtkX3DExporterWriter* writer);
-static void vtkX3DExporterWriteData(vtkPoints *points,
-  vtkDataArray *normals,
-  vtkDataArray *tcoords,
-  vtkUnsignedCharArray *colors,
+VTK_ABI_NAMESPACE_BEGIN
+static bool vtkX3DExporterWriterUsingCellColors(vtkMapper* mapper);
+static bool vtkX3DExporterWriterRenderFaceSet(int cellType, int representation, vtkPoints* points,
+  vtkIdType cellOffset, vtkCellArray* cells, vtkUnsignedCharArray* colors, bool cell_colors,
+  vtkDataArray* normals, bool cell_normals, vtkDataArray* tcoords, bool common_data_written,
   int index, vtkX3DExporterWriter* writer);
-static void vtkX3DExporterUseData(bool normals, bool tcoords, bool colors, int index,
-  vtkX3DExporterWriter* writer);
-static bool vtkX3DExporterWriterRenderVerts(
-  vtkPoints* points, vtkCellArray* cells,
-  vtkUnsignedCharArray* colors, bool cell_colors,  vtkX3DExporterWriter* writer);
+static void vtkX3DExporterWriteData(vtkPoints* points, vtkDataArray* normals, vtkDataArray* tcoords,
+  vtkUnsignedCharArray* colors, int index, vtkX3DExporterWriter* writer);
+static void vtkX3DExporterUseData(
+  bool normals, bool tcoords, bool colors, int index, vtkX3DExporterWriter* writer);
+static bool vtkX3DExporterWriterRenderVerts(vtkPoints* points, vtkCellArray* cells,
+  vtkUnsignedCharArray* colors, bool cell_colors, vtkX3DExporterWriter* writer);
 static bool vtkX3DExporterWriterRenderPoints(
-  vtkPolyData* pd,
-  vtkUnsignedCharArray* colors,
-  bool cell_colors,
-  vtkX3DExporterWriter* writer);
+  vtkPolyData* pd, vtkUnsignedCharArray* colors, bool cell_colors, vtkX3DExporterWriter* writer);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkX3DExporter);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkX3DExporter::vtkX3DExporter()
 {
   this->Speed = 4.0;
@@ -94,24 +83,24 @@ vtkX3DExporter::vtkX3DExporter()
   this->OutputStringLength = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkX3DExporter::~vtkX3DExporter()
 {
   this->SetFileName(nullptr);
-  delete [] this->OutputString;
+  delete[] this->OutputString;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporter::WriteData()
 {
   vtkSmartPointer<vtkX3DExporterWriter> writer;
-  vtkActorCollection *ac;
-  vtkActor2DCollection *a2Dc;
+  vtkActorCollection* ac;
+  vtkActor2DCollection* a2Dc;
   vtkActor *anActor, *aPart;
   vtkActor2D *anTextActor2D, *aPart2D;
-  vtkLightCollection *lc;
-  vtkLight *aLight;
-  vtkCamera *cam;
+  vtkLightCollection* lc;
+  vtkLight* aLight;
+  vtkCamera* cam;
 
   // make sure the user specified a FileName or FilePointer
   if (this->FileName == nullptr && (!this->WriteToOutputString))
@@ -121,7 +110,7 @@ void vtkX3DExporter::WriteData()
   }
 
   // get the renderer
-  vtkRenderer *ren = this->ActiveRenderer;
+  vtkRenderer* ren = this->ActiveRenderer;
   if (!ren)
   {
     ren = this->RenderWindow->GetRenderers()->GetFirstRenderer();
@@ -146,8 +135,7 @@ void vtkX3DExporter::WriteData()
     writer = vtkSmartPointer<vtkX3DExporterXMLWriter>::New();
   }
 
-
-  if(this->WriteToOutputString)
+  if (this->WriteToOutputString)
   {
     if (!writer->OpenStream())
     {
@@ -207,7 +195,8 @@ void vtkX3DExporter::WriteData()
   // Start write the Camera
   cam = ren->GetActiveCamera();
   writer->StartNode(Viewpoint);
-  writer->SetField( fieldOfView,static_cast<float>( vtkMath::RadiansFromDegrees( cam->GetViewAngle() ) ) );
+  writer->SetField(
+    fieldOfView, static_cast<float>(vtkMath::RadiansFromDegrees(cam->GetViewAngle())));
   writer->SetField(position, SFVEC3F, cam->GetPosition());
   writer->SetField(description, "Default View");
   writer->SetField(orientation, SFROTATION, cam->GetOrientationWXYZ());
@@ -218,8 +207,8 @@ void vtkX3DExporter::WriteData()
   // do the lights first the ambient then the others
   writer->StartNode(NavigationInfo);
   writer->SetField(type, "\"EXAMINE\" \"FLY\" \"ANY\"", true);
-  writer->SetField(speed,static_cast<float>(this->Speed));
-  writer->SetField(headlight, this->HasHeadLight(ren) ? true : false);
+  writer->SetField(speed, static_cast<float>(this->Speed));
+  writer->SetField(headlight, this->HasHeadLight(ren) != 0);
   writer->EndNode();
 
   writer->StartNode(DirectionalLight);
@@ -228,9 +217,8 @@ void vtkX3DExporter::WriteData()
   writer->SetField(color, SFCOLOR, ren->GetAmbient());
   writer->EndNode();
 
-
   // label ROOT
-  static double n[] = {0.0, 0.0, 0.0};
+  static double n[] = { 0.0, 0.0, 0.0 };
   writer->StartNode(Transform);
   writer->SetField(DEF, "ROOT");
   writer->SetField(translation, SFVEC3F, n);
@@ -239,7 +227,7 @@ void vtkX3DExporter::WriteData()
   // if we don't then use a headlight
   lc = ren->GetLights();
   vtkCollectionSimpleIterator lsit;
-  for (lc->InitTraversal(lsit); (aLight = lc->GetNextLight(lsit)); )
+  for (lc->InitTraversal(lsit); (aLight = lc->GetNextLight(lsit));)
   {
     if (!aLight->LightTypeIsHeadlight())
     {
@@ -249,16 +237,16 @@ void vtkX3DExporter::WriteData()
 
   // do the actors now
   ac = ren->GetActors();
-  vtkAssemblyPath *apath;
+  vtkAssemblyPath* apath;
   vtkCollectionSimpleIterator ait;
-  int index=0;
-  for (ac->InitTraversal(ait); (anActor = ac->GetNextActor(ait)); )
+  int index = 0;
+  for (ac->InitTraversal(ait); (anActor = ac->GetNextActor(ait));)
   {
-    for (anActor->InitPathTraversal(); (apath=anActor->GetNextPath()); )
+    for (anActor->InitPathTraversal(); (apath = anActor->GetNextPath());)
     {
-      if(anActor->GetVisibility()!=0)
+      if (anActor->GetVisibility() != 0)
       {
-        aPart=static_cast<vtkActor *>(apath->GetLastNode()->GetViewProp());
+        aPart = static_cast<vtkActor*>(apath->GetLastNode()->GetViewProp());
         this->WriteAnActor(aPart, writer, index);
         index++;
       }
@@ -266,38 +254,34 @@ void vtkX3DExporter::WriteData()
   }
   writer->EndNode(); // ROOT Transform
 
-
   //////////////////////////////////////////////
   // do the 2D actors now
   a2Dc = ren->GetActors2D();
 
-  if(a2Dc->GetNumberOfItems()!=0)
+  if (a2Dc->GetNumberOfItems() != 0)
   {
-    static double s[] = {1000000.0, 1000000.0, 1000000.0};
+    static double s[] = { 1000000.0, 1000000.0, 1000000.0 };
     writer->StartNode(ProximitySensor);
     writer->SetField(DEF, "PROX_LABEL");
     writer->SetField(size, SFVEC3F, s);
     writer->EndNode();
 
-    //disable collision for the text annotations
+    // disable collision for the text annotations
     writer->StartNode(Collision);
     writer->SetField(enabled, false);
 
-    //add a Label TRANS_LABEL for the text annotations and the sensor
+    // add a Label TRANS_LABEL for the text annotations and the sensor
     writer->StartNode(Transform);
     writer->SetField(DEF, "TRANS_LABEL");
 
-    vtkAssemblyPath *apath2D;
+    vtkAssemblyPath* apath2D;
     vtkCollectionSimpleIterator ait2D;
-    for (a2Dc->InitTraversal(ait2D);
-      (anTextActor2D = a2Dc->GetNextActor2D(ait2D)); )
+    for (a2Dc->InitTraversal(ait2D); (anTextActor2D = a2Dc->GetNextActor2D(ait2D));)
     {
 
-      for (anTextActor2D->InitPathTraversal();
-        (apath2D=anTextActor2D->GetNextPath()); )
+      for (anTextActor2D->InitPathTraversal(); (apath2D = anTextActor2D->GetNextPath());)
       {
-        aPart2D=
-              static_cast<vtkActor2D *>(apath2D->GetLastNode()->GetViewProp());
+        aPart2D = static_cast<vtkActor2D*>(apath2D->GetLastNode()->GetViewProp());
         this->WriteATextActor2D(aPart2D, writer);
       }
     }
@@ -328,16 +312,15 @@ void vtkX3DExporter::WriteData()
   writer->EndDocument();
   writer->CloseFile();
 
-  if(this->WriteToOutputString)
+  if (this->WriteToOutputString)
   {
     this->OutputStringLength = writer->GetOutputStringLength();
     this->OutputString = writer->RegisterAndGetOutputString();
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkX3DExporter::WriteALight(vtkLight *aLight,
-  vtkX3DExporterWriter* writer)
+//------------------------------------------------------------------------------
+void vtkX3DExporter::WriteALight(vtkLight* aLight, vtkX3DExporterWriter* writer)
 {
   double *pos, *focus, *colord;
   double dir[3];
@@ -361,11 +344,10 @@ void vtkX3DExporter::WriteALight(vtkLight *aLight,
     {
       writer->StartNode(SpotLight);
       writer->SetField(direction, SFVEC3F, dir);
-      writer->SetField(cutOffAngle,static_cast<float>(aLight->GetConeAngle()));
+      writer->SetField(cutOffAngle, static_cast<float>(aLight->GetConeAngle()));
     }
     writer->SetField(location, SFVEC3F, pos);
     writer->SetField(attenuation, SFVEC3F, aLight->GetAttenuationValues());
-
   }
   else
   {
@@ -376,14 +358,13 @@ void vtkX3DExporter::WriteALight(vtkLight *aLight,
   // TODO: Check correct color
   writer->SetField(color, SFCOLOR, colord);
   writer->SetField(intensity, static_cast<float>(aLight->GetIntensity()));
-  writer->SetField(on, aLight->GetSwitch() ? true : false);
+  writer->SetField(on, aLight->GetSwitch() != 0);
   writer->EndNode();
   writer->Flush();
 }
 
-//----------------------------------------------------------------------------
-void vtkX3DExporter::WriteAnActor(vtkActor *anActor,
-  vtkX3DExporterWriter* writer, int index)
+//------------------------------------------------------------------------------
+void vtkX3DExporter::WriteAnActor(vtkActor* anActor, vtkX3DExporterWriter* writer, int index)
 {
   // see if the actor has a mapper. it could be an assembly
   vtkMapper* mapper = anActor->GetMapper();
@@ -421,7 +402,8 @@ void vtkX3DExporter::WriteAnActor(vtkActor *anActor,
       if (vtkPolyData* currentPD = vtkPolyData::SafeDownCast(iter->GetCurrentDataObject()))
       {
         writer->StartNode(Group);
-        if (iter->HasCurrentMetaData() && iter->GetCurrentMetaData()->Has(vtkCompositeDataSet::NAME()))
+        if (iter->HasCurrentMetaData() &&
+          iter->GetCurrentMetaData()->Has(vtkCompositeDataSet::NAME()))
         {
           if (const char* aname = iter->GetCurrentMetaData()->Get(vtkCompositeDataSet::NAME()))
           {
@@ -445,17 +427,17 @@ void vtkX3DExporter::WriteAnActor(vtkActor *anActor,
   writer->EndNode();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporter::WriteAPiece(
-  vtkPolyData* pd, vtkActor *anActor, vtkX3DExporterWriter* writer, int index)
+  vtkPolyData* pd, vtkActor* anActor, vtkX3DExporterWriter* writer, int index)
 {
-  vtkPointData *pntData;
-  vtkCellData *cellData;
-  vtkPoints *points;
-  vtkDataArray *normals = nullptr;
-  vtkDataArray *tcoords = nullptr;
-  vtkProperty *prop;
-  vtkUnsignedCharArray *colors;
+  vtkPointData* pntData;
+  vtkCellData* cellData;
+  vtkPoints* points;
+  vtkDataArray* normals = nullptr;
+  vtkDataArray* tcoords = nullptr;
+  vtkProperty* prop;
+  vtkUnsignedCharArray* colors;
   vtkSmartPointer<vtkTransform> trans;
 
   // see if the actor has a mapper. it could be an assembly
@@ -470,8 +452,7 @@ void vtkX3DExporter::WriteAPiece(
   }
 
   // Create a temporary poly-data mapper that we use.
-  vtkSmartPointer<vtkPolyDataMapper> mapper =
-    vtkSmartPointer<vtkPolyDataMapper>::New();
+  vtkSmartPointer<vtkPolyDataMapper> mapper = vtkSmartPointer<vtkPolyDataMapper>::New();
 
   mapper->SetInputData(pd);
   mapper->SetScalarRange(anActor->GetMapper()->GetScalarRange());
@@ -482,18 +463,18 @@ void vtkX3DExporter::WriteAPiece(
   // Essential to turn of interpolate scalars otherwise GetScalars() may return
   // nullptr. We restore value before returning.
   mapper->SetInterpolateScalarsBeforeMapping(0);
-  if ( mapper->GetScalarMode() == VTK_SCALAR_MODE_USE_POINT_FIELD_DATA ||
-    mapper->GetScalarMode() == VTK_SCALAR_MODE_USE_CELL_FIELD_DATA )
+  if (mapper->GetScalarMode() == VTK_SCALAR_MODE_USE_POINT_FIELD_DATA ||
+    mapper->GetScalarMode() == VTK_SCALAR_MODE_USE_CELL_FIELD_DATA)
   {
-    if ( anActor->GetMapper()->GetArrayAccessMode() == VTK_GET_ARRAY_BY_ID )
+    if (anActor->GetMapper()->GetArrayAccessMode() == VTK_GET_ARRAY_BY_ID)
     {
-      mapper->ColorByArrayComponent(anActor->GetMapper()->GetArrayId(),
-        anActor->GetMapper()->GetArrayComponent());
+      mapper->ColorByArrayComponent(
+        anActor->GetMapper()->GetArrayId(), anActor->GetMapper()->GetArrayComponent());
     }
     else
     {
-      mapper->ColorByArrayComponent(anActor->GetMapper()->GetArrayName(),
-        anActor->GetMapper()->GetArrayComponent());
+      mapper->ColorByArrayComponent(
+        anActor->GetMapper()->GetArrayName(), anActor->GetMapper()->GetArrayComponent());
     }
   }
 
@@ -503,7 +484,7 @@ void vtkX3DExporter::WriteAPiece(
   tcoords = pntData->GetTCoords();
   cellData = pd->GetCellData();
 
-  colors  = mapper->MapScalars(255.0);
+  colors = mapper->MapScalars(255.0);
 
   // Are we using cell colors? Pass the temporary mapper we created here since
   // we're assured that that mapper only has vtkPolyData as input and hence
@@ -521,11 +502,10 @@ void vtkX3DExporter::WriteAPiece(
     cell_normals = true;
   }
 
-
   // if we don't have colors and we have only lines & points
   // use emissive to color them
-  bool writeEmissiveColor = !(normals || colors || pd->GetNumberOfPolys() ||
-    pd->GetNumberOfStrips());
+  bool writeEmissiveColor =
+    !(normals || colors || pd->GetNumberOfPolys() || pd->GetNumberOfStrips());
 
   // write out the material properties to the mat file
   int representation = prop->GetRepresentation();
@@ -534,7 +514,6 @@ void vtkX3DExporter::WriteAPiece(
   {
     // If representation is points, then we don't have to render different cell
     // types in separate shapes, since the cells type no longer matter.
-    if (true)
     {
       writer->StartNode(Shape);
       this->WriteAnAppearance(anActor, writeEmissiveColor, writer);
@@ -564,11 +543,10 @@ void vtkX3DExporter::WriteAPiece(
       // Write Appearance
       this->WriteAnAppearance(anActor, writeEmissiveColor, writer);
       // Write Geometry
-      vtkX3DExporterWriterRenderFaceSet(VTK_POLYGON, representation, points,
-        (numVerts+numLines), polys,
-        colors, cell_colors, normals, cell_normals,
-        tcoords, common_data_written, index, writer);
-      writer->EndNode();  // close the  Shape
+      vtkX3DExporterWriterRenderFaceSet(VTK_POLYGON, representation, points, (numVerts + numLines),
+        polys, colors, cell_colors, normals, cell_normals, tcoords, common_data_written, index,
+        writer);
+      writer->EndNode(); // close the  Shape
       common_data_written = true;
     }
 
@@ -578,12 +556,10 @@ void vtkX3DExporter::WriteAPiece(
       // Write Appearance
       this->WriteAnAppearance(anActor, writeEmissiveColor, writer);
       // Write Geometry
-      vtkX3DExporterWriterRenderFaceSet(VTK_TRIANGLE_STRIP,
-        representation, points,
-        (numVerts+numLines+numPolys), tstrips,
-        colors, cell_colors, normals, cell_normals,
+      vtkX3DExporterWriterRenderFaceSet(VTK_TRIANGLE_STRIP, representation, points,
+        (numVerts + numLines + numPolys), tstrips, colors, cell_colors, normals, cell_normals,
         tcoords, common_data_written, index, writer);
-      writer->EndNode();  // close the  Shape
+      writer->EndNode(); // close the  Shape
       common_data_written = true;
     }
 
@@ -594,11 +570,9 @@ void vtkX3DExporter::WriteAPiece(
       this->WriteAnAppearance(anActor, writeEmissiveColor, writer);
       // Write Geometry
       vtkX3DExporterWriterRenderFaceSet(VTK_POLY_LINE,
-        (representation==VTK_SURFACE? VTK_WIREFRAME:representation),
-        points, (numVerts), lines,
-        colors, cell_colors, normals, cell_normals,
-        tcoords, common_data_written, index, writer);
-      writer->EndNode();  // close the  Shape
+        (representation == VTK_SURFACE ? VTK_WIREFRAME : representation), points, (numVerts), lines,
+        colors, cell_colors, normals, cell_normals, tcoords, common_data_written, index, writer);
+      writer->EndNode(); // close the  Shape
       common_data_written = true;
     }
 
@@ -606,18 +580,16 @@ void vtkX3DExporter::WriteAPiece(
     {
       writer->StartNode(Shape);
       this->WriteAnAppearance(anActor, writeEmissiveColor, writer);
-      vtkX3DExporterWriterRenderVerts(
-        points, verts,
-        colors, cell_normals, writer);
-      writer->EndNode();  // close the  Shape
+      vtkX3DExporterWriterRenderVerts(points, verts, colors, cell_normals, writer);
+      writer->EndNode(); // close the  Shape
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   if (this->FileName)
   {
@@ -631,8 +603,8 @@ void vtkX3DExporter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Binary: " << this->Binary << "\n";
   os << indent << "Fastest: " << this->Fastest << endl;
 
-  os << indent << "WriteToOutputString: "
-     << (this->WriteToOutputString ? "On" : "Off") << std::endl;
+  os << indent << "WriteToOutputString: " << (this->WriteToOutputString ? "On" : "Off")
+     << std::endl;
   os << indent << "OutputStringLength: " << this->OutputStringLength << std::endl;
   if (this->OutputString)
   {
@@ -640,16 +612,12 @@ void vtkX3DExporter::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-
-
-
-//----------------------------------------------------------------------------
-void vtkX3DExporter::WriteATextActor2D(vtkActor2D *anTextActor2D,
-  vtkX3DExporterWriter* writer)
+//------------------------------------------------------------------------------
+void vtkX3DExporter::WriteATextActor2D(vtkActor2D* anTextActor2D, vtkX3DExporterWriter* writer)
 {
-  char *ds;
-  vtkTextActor *ta;
-  vtkTextProperty *tp;
+  char* ds;
+  vtkTextActor* ta;
+  vtkTextProperty* tp;
 
   if (!anTextActor2D->IsA("vtkTextActor"))
   {
@@ -660,7 +628,7 @@ void vtkX3DExporter::WriteATextActor2D(vtkActor2D *anTextActor2D,
   tp = ta->GetTextProperty();
   ds = ta->GetInput();
 
-  if (ds==nullptr)
+  if (ds == nullptr)
   {
     return;
   }
@@ -668,8 +636,8 @@ void vtkX3DExporter::WriteATextActor2D(vtkActor2D *anTextActor2D,
   double temp[3];
 
   writer->StartNode(Transform);
-  temp[0] = ((ta->GetPosition()[0])/(this->RenderWindow->GetSize()[0])) - 0.5;
-  temp[1] = ((ta->GetPosition()[1])/(this->RenderWindow->GetSize()[1])) - 0.5;
+  temp[0] = ((ta->GetPosition()[0]) / (this->RenderWindow->GetSize()[0])) - 0.5;
+  temp[1] = ((ta->GetPosition()[1]) / (this->RenderWindow->GetSize()[1])) - 0.5;
   temp[2] = -2.0;
   writer->SetField(translation, SFVEC3F, temp);
   temp[0] = temp[1] = temp[2] = 0.002;
@@ -680,7 +648,9 @@ void vtkX3DExporter::WriteATextActor2D(vtkActor2D *anTextActor2D,
   writer->StartNode(Appearance);
 
   writer->StartNode(Material);
-  temp[0] = 0.0; temp[1] = 0.0; temp[2] = 1.0;
+  temp[0] = 0.0;
+  temp[1] = 0.0;
+  temp[2] = 1.0;
   writer->SetField(diffuseColor, SFCOLOR, temp);
   tp->GetColor(temp);
   writer->SetField(emissiveColor, SFCOLOR, temp);
@@ -692,30 +662,30 @@ void vtkX3DExporter::WriteATextActor2D(vtkActor2D *anTextActor2D,
   writer->SetField(vtkX3D::string, ds);
 
   std::string familyStr;
-  switch(tp->GetFontFamily())
+  switch (tp->GetFontFamily())
   {
-  case 0:
-  default:
-    familyStr = "\"SANS\"";
-    break;
-  case 1:
-    familyStr = "\"TYPEWRITER\"";
-    break;
-  case 2:
-    familyStr = "\"SERIF\"";
-    break;
+    case 0:
+    default:
+      familyStr = "\"SANS\"";
+      break;
+    case 1:
+      familyStr = "\"TYPEWRITER\"";
+      break;
+    case 2:
+      familyStr = "\"SERIF\"";
+      break;
   }
 
   std::string justifyStr;
-  switch  (tp->GetJustification())
+  switch (tp->GetJustification())
   {
-  case 0:
-  default:
-    justifyStr += "\"BEGIN\"";
-    break;
-  case 2:
-    justifyStr += "\"END\"";
-    break;
+    case 0:
+    default:
+      justifyStr += "\"BEGIN\"";
+      break;
+    case 2:
+      justifyStr += "\"END\"";
+      break;
   }
 
   justifyStr += " \"BEGIN\"";
@@ -731,8 +701,8 @@ void vtkX3DExporter::WriteATextActor2D(vtkActor2D *anTextActor2D,
   writer->EndNode(); // Transform
 }
 
-void vtkX3DExporter::WriteAnAppearance(vtkActor *anActor, bool emissive,
-  vtkX3DExporterWriter* writer)
+void vtkX3DExporter::WriteAnAppearance(
+  vtkActor* anActor, bool emissive, vtkX3DExporterWriter* writer)
 {
   double tempd[3];
   double tempf2;
@@ -741,15 +711,15 @@ void vtkX3DExporter::WriteAnAppearance(vtkActor *anActor, bool emissive,
 
   writer->StartNode(Appearance);
   writer->StartNode(Material);
-  writer->SetField(ambientIntensity,static_cast<float>(prop->GetAmbient()));
+  writer->SetField(ambientIntensity, static_cast<float>(prop->GetAmbient()));
 
   if (emissive)
   {
     tempf2 = prop->GetAmbient();
     prop->GetAmbientColor(tempd);
-    tempd[0]*=tempf2;
-    tempd[1]*=tempf2;
-    tempd[2]*=tempf2;
+    tempd[0] *= tempf2;
+    tempd[1] *= tempf2;
+    tempd[2] *= tempf2;
   }
   else
   {
@@ -760,23 +730,23 @@ void vtkX3DExporter::WriteAnAppearance(vtkActor *anActor, bool emissive,
   // Set diffuse color
   tempf2 = prop->GetDiffuse();
   prop->GetDiffuseColor(tempd);
-  tempd[0]*=tempf2;
-  tempd[1]*=tempf2;
-  tempd[2]*=tempf2;
+  tempd[0] *= tempf2;
+  tempd[1] *= tempf2;
+  tempd[2] *= tempf2;
   writer->SetField(diffuseColor, SFCOLOR, tempd);
 
   // Set specular color
   tempf2 = prop->GetSpecular();
   prop->GetSpecularColor(tempd);
-  tempd[0]*=tempf2;
-  tempd[1]*=tempf2;
-  tempd[2]*=tempf2;
+  tempd[0] *= tempf2;
+  tempd[1] *= tempf2;
+  tempd[2] *= tempf2;
   writer->SetField(specularColor, SFCOLOR, tempd);
 
   // Material shininess
-  writer->SetField(shininess,static_cast<float>(prop->GetSpecularPower()/128.0));
+  writer->SetField(shininess, static_cast<float>(prop->GetSpecularPower() / 128.0));
   // Material transparency
-  writer->SetField(transparency,static_cast<float>(1.0 - prop->GetOpacity()));
+  writer->SetField(transparency, static_cast<float>(1.0 - prop->GetOpacity()));
   writer->EndNode(); // close material
 
   // is there a texture map
@@ -787,17 +757,15 @@ void vtkX3DExporter::WriteAnAppearance(vtkActor *anActor, bool emissive,
   writer->EndNode(); // close appearance
 }
 
-void vtkX3DExporter::WriteATexture(vtkActor *anActor,
-  vtkX3DExporterWriter* writer)
+void vtkX3DExporter::WriteATexture(vtkActor* anActor, vtkX3DExporterWriter* writer)
 {
-  vtkTexture *aTexture = anActor->GetTexture();
+  vtkTexture* aTexture = anActor->GetTexture();
   int *size, xsize, ysize;
-  vtkDataArray *scalars;
-  vtkDataArray *mappedScalars;
-  unsigned char *txtrData;
+  vtkDataArray* scalars;
+  vtkDataArray* mappedScalars;
+  unsigned char* txtrData;
   int totalValues;
 
-
   // make sure it is updated and then get some info
   if (aTexture->GetInput() == nullptr)
   {
@@ -817,9 +785,9 @@ void vtkX3DExporter::WriteATexture(vtkActor *anActor,
 
   // make sure using unsigned char data of color scalars type
   if (aTexture->GetColorMode() == VTK_COLOR_MODE_MAP_SCALARS ||
-    (scalars->GetDataType() != VTK_UNSIGNED_CHAR) )
+    (scalars->GetDataType() != VTK_UNSIGNED_CHAR))
   {
-    mappedScalars = aTexture->GetMappedScalars ();
+    mappedScalars = aTexture->GetMappedScalars();
   }
   else
   {
@@ -831,7 +799,8 @@ void vtkX3DExporter::WriteATexture(vtkActor *anActor,
   // could be any of them, so lets find it
   if (size[0] == 1)
   {
-    xsize = size[1]; ysize = size[2];
+    xsize = size[1];
+    ysize = size[2];
   }
   else
   {
@@ -856,13 +825,12 @@ void vtkX3DExporter::WriteATexture(vtkActor *anActor,
   imageDataVec.push_back(ysize);
   imageDataVec.push_back(mappedScalars->GetNumberOfComponents());
 
-  totalValues = xsize*ysize;
-  txtrData = static_cast<vtkUnsignedCharArray*>(mappedScalars)->
-    GetPointer(0);
+  totalValues = xsize * ysize;
+  txtrData = static_cast<vtkUnsignedCharArray*>(mappedScalars)->GetPointer(0);
   for (int i = 0; i < totalValues; i++)
   {
     int result = 0;
-    for(int j = 0; j < imageDataVec[2]; j++)
+    for (int j = 0; j < imageDataVec[2]; j++)
     {
       result = result << 8;
       result += *txtrData;
@@ -871,9 +839,6 @@ void vtkX3DExporter::WriteATexture(vtkActor *anActor,
     imageDataVec.push_back(result);
   }
 
-
-
-
   writer->StartNode(PixelTexture);
   writer->SetField(image, &(imageDataVec.front()), imageDataVec.size(), true);
   if (!(aTexture->GetRepeat()))
@@ -884,15 +849,15 @@ void vtkX3DExporter::WriteATexture(vtkActor *anActor,
   writer->EndNode();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkX3DExporter::HasHeadLight(vtkRenderer* ren)
 {
   // make sure we have a default light
   // if we don't then use a headlight
   vtkLightCollection* lc = ren->GetLights();
   vtkCollectionSimpleIterator lsit;
-  vtkLight* aLight=nullptr;
-  for (lc->InitTraversal(lsit); (aLight = lc->GetNextLight(lsit)); )
+  vtkLight* aLight = nullptr;
+  for (lc->InitTraversal(lsit); (aLight = lc->GetNextLight(lsit));)
   {
     if (aLight->LightTypeIsHeadlight())
     {
@@ -907,43 +872,33 @@ int vtkX3DExporter::HasHeadLight(vtkRenderer* ren)
 static bool vtkX3DExporterWriterUsingCellColors(vtkMapper* mapper)
 {
   int cellFlag = 0;
-  vtkAbstractMapper::GetScalars(
-    mapper->GetInput(),
-    mapper->GetScalarMode(),
-    mapper->GetArrayAccessMode(),
-    mapper->GetArrayId(),
-    mapper->GetArrayName(), cellFlag);
+  vtkAbstractMapper::GetScalars(mapper->GetInput(), mapper->GetScalarMode(),
+    mapper->GetArrayAccessMode(), mapper->GetArrayId(), mapper->GetArrayName(), cellFlag);
   return (cellFlag == 1);
 }
 
-//----------------------------------------------------------------------------
-static bool vtkX3DExporterWriterRenderFaceSet(
-  int cellType,
-  int representation,
-  vtkPoints* points,
-  vtkIdType cellOffset,
-  vtkCellArray* cells,
-  vtkUnsignedCharArray* colors, bool cell_colors,
-  vtkDataArray* normals, bool cell_normals,
-  vtkDataArray* tcoords,
-  bool common_data_written, int index, vtkX3DExporterWriter* writer)
+//------------------------------------------------------------------------------
+static bool vtkX3DExporterWriterRenderFaceSet(int cellType, int representation, vtkPoints* points,
+  vtkIdType cellOffset, vtkCellArray* cells, vtkUnsignedCharArray* colors, bool cell_colors,
+  vtkDataArray* normals, bool cell_normals, vtkDataArray* tcoords, bool common_data_written,
+  int index, vtkX3DExporterWriter* writer)
 {
   std::vector<int> coordIndexVector;
   std::vector<int> cellIndexVector;
 
   vtkIdType npts = 0;
-  vtkIdType *indx = nullptr;
+  const vtkIdType* indx = nullptr;
 
   if (cellType == VTK_POLYGON || cellType == VTK_POLY_LINE)
   {
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); cellOffset++)
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx); cellOffset++)
     {
-      for (vtkIdType cc=0; cc < npts; cc++)
+      for (vtkIdType cc = 0; cc < npts; cc++)
       {
         coordIndexVector.push_back(static_cast<int>(indx[cc]));
       }
 
-      if (representation == VTK_WIREFRAME && npts>2 && cellType == VTK_POLYGON)
+      if (representation == VTK_WIREFRAME && npts > 2 && cellType == VTK_POLYGON)
       {
         // close the polygon.
         coordIndexVector.push_back(static_cast<int>(indx[0]));
@@ -956,13 +911,13 @@ static bool vtkX3DExporterWriterRenderFaceSet(
   }
   else // cellType == VTK_TRIANGLE_STRIP
   {
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); cellOffset++)
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx); cellOffset++)
     {
-      for (vtkIdType cc=2; cc < npts; cc++)
+      for (vtkIdType cc = 2; cc < npts; cc++)
       {
         vtkIdType i1;
         vtkIdType i2;
-        if (cc%2)
+        if (cc % 2)
         {
           i1 = cc - 1;
           i2 = cc - 2;
@@ -979,7 +934,7 @@ static bool vtkX3DExporterWriterRenderFaceSet(
         if (representation == VTK_WIREFRAME)
         {
           // close the polygon when drawing lines
-            coordIndexVector.push_back(static_cast<int>(indx[i1]));
+          coordIndexVector.push_back(static_cast<int>(indx[i1]));
         }
         coordIndexVector.push_back(-1);
 
@@ -1026,19 +981,16 @@ static bool vtkX3DExporterWriterRenderFaceSet(
   }
   else
   {
-    vtkX3DExporterUseData((normals != nullptr), (tcoords != nullptr), (colors!= nullptr), index, writer);
+    vtkX3DExporterUseData(
+      (normals != nullptr), (tcoords != nullptr), (colors != nullptr), index, writer);
   }
 
   writer->EndNode(); // end IndexedFaceSet or IndexedLineSet
   return true;
 }
 
-static void vtkX3DExporterWriteData(vtkPoints *points,
-  vtkDataArray *normals,
-  vtkDataArray *tcoords,
-  vtkUnsignedCharArray *colors,
-  int index,
-  vtkX3DExporterWriter* writer)
+static void vtkX3DExporterWriteData(vtkPoints* points, vtkDataArray* normals, vtkDataArray* tcoords,
+  vtkUnsignedCharArray* colors, int index, vtkX3DExporterWriter* writer)
 {
   char indexString[100];
   snprintf(indexString, sizeof(indexString), "%04d", index);
@@ -1053,7 +1005,7 @@ static void vtkX3DExporterWriteData(vtkPoints *points,
   // write out the point data
   if (normals)
   {
-    defString="VTKnormals";
+    defString = "VTKnormals";
     writer->StartNode(Normal);
     writer->SetField(DEF, defString.append(indexString).c_str());
     writer->SetField(vtkX3D::vector, MFVEC3F, normals);
@@ -1063,7 +1015,7 @@ static void vtkX3DExporterWriteData(vtkPoints *points,
   // write out the point data
   if (tcoords)
   {
-    defString="VTKtcoords";
+    defString = "VTKtcoords";
     writer->StartNode(TextureCoordinate);
     writer->SetField(DEF, defString.append(indexString).c_str());
     writer->SetField(point, MFVEC2F, tcoords);
@@ -1073,7 +1025,7 @@ static void vtkX3DExporterWriteData(vtkPoints *points,
   // write out the point data
   if (colors)
   {
-    defString="VTKcolors";
+    defString = "VTKcolors";
     writer->StartNode(Color);
     writer->SetField(DEF, defString.append(indexString).c_str());
 
@@ -1081,18 +1033,18 @@ static void vtkX3DExporterWriteData(vtkPoints *points,
     unsigned char c[4];
     for (int i = 0; i < colors->GetNumberOfTuples(); i++)
     {
-      colors->GetTypedTuple(i,c);
-      colorVec.push_back(c[0]/255.0);
-      colorVec.push_back(c[1]/255.0);
-      colorVec.push_back(c[2]/255.0);
+      colors->GetTypedTuple(i, c);
+      colorVec.push_back(c[0] / 255.0);
+      colorVec.push_back(c[1] / 255.0);
+      colorVec.push_back(c[2] / 255.0);
     }
     writer->SetField(color, &(colorVec.front()), colorVec.size());
     writer->EndNode();
   }
 }
 
-static void vtkX3DExporterUseData(bool normals, bool tcoords, bool colors, int index,
-  vtkX3DExporterWriter* writer)
+static void vtkX3DExporterUseData(
+  bool normals, bool tcoords, bool colors, int index, vtkX3DExporterWriter* writer)
 {
   char indexString[100];
   snprintf(indexString, sizeof(indexString), "%04d", index);
@@ -1129,9 +1081,8 @@ static void vtkX3DExporterUseData(bool normals, bool tcoords, bool colors, int i
   }
 }
 
-static bool vtkX3DExporterWriterRenderVerts(
-  vtkPoints* points, vtkCellArray* cells,
-  vtkUnsignedCharArray* colors, bool cell_colors,  vtkX3DExporterWriter* writer)
+static bool vtkX3DExporterWriterRenderVerts(vtkPoints* points, vtkCellArray* cells,
+  vtkUnsignedCharArray* colors, bool cell_colors, vtkX3DExporterWriter* writer)
 {
   std::vector<double> colorVector;
 
@@ -1139,10 +1090,10 @@ static bool vtkX3DExporterWriterRenderVerts(
   {
     vtkIdType cellId = 0;
     vtkIdType npts = 0;
-    vtkIdType *indx = nullptr;
-    for (cells->InitTraversal(); cells->GetNextCell(npts,indx); cellId++)
+    const vtkIdType* indx = nullptr;
+    for (cells->InitTraversal(); cells->GetNextCell(npts, indx); cellId++)
     {
-      for (vtkIdType cc=0; cc < npts; cc++)
+      for (vtkIdType cc = 0; cc < npts; cc++)
       {
         unsigned char color[4];
         if (cell_colors)
@@ -1154,9 +1105,9 @@ static bool vtkX3DExporterWriterRenderVerts(
           colors->GetTypedTuple(indx[cc], color);
         }
 
-        colorVector.push_back(color[0]/255.0);
-        colorVector.push_back(color[1]/255.0);
-        colorVector.push_back(color[2]/255.0);
+        colorVector.push_back(color[0] / 255.0);
+        colorVector.push_back(color[1] / 255.0);
+        colorVector.push_back(color[2] / 255.0);
       }
     }
   }
@@ -1175,10 +1126,7 @@ static bool vtkX3DExporterWriterRenderVerts(
 }
 
 static bool vtkX3DExporterWriterRenderPoints(
-  vtkPolyData* pd,
-  vtkUnsignedCharArray* colors,
-  bool cell_colors
-  ,  vtkX3DExporterWriter* writer)
+  vtkPolyData* pd, vtkUnsignedCharArray* colors, bool cell_colors, vtkX3DExporterWriter* writer)
 {
   if (pd->GetNumberOfCells() == 0)
   {
@@ -1193,7 +1141,7 @@ static bool vtkX3DExporterWriterRenderPoints(
   // We render as cells so that even when coloring with cell data, the points
   // are assigned colors correctly.
 
-  if ( (colors !=nullptr) && cell_colors)
+  if ((colors != nullptr) && cell_colors)
   {
     // Cell colors are used, however PointSet element can only have point
     // colors, hence we use this method. Although here we end up with duplicate
@@ -1201,7 +1149,7 @@ static bool vtkX3DExporterWriterRenderPoints(
     // okay.
     vtkIdType numCells = pd->GetNumberOfCells();
     vtkSmartPointer<vtkIdList> pointIds = vtkSmartPointer<vtkIdList>::New();
-    for (vtkIdType cid =0; cid < numCells; cid++)
+    for (vtkIdType cid = 0; cid < numCells; cid++)
     {
       pointIds->Reset();
       pd->GetCellPoints(cid, pointIds);
@@ -1210,12 +1158,11 @@ static bool vtkX3DExporterWriterRenderPoints(
       unsigned char color[4];
       colors->GetTypedTuple(cid, color);
       double dcolor[3];
-      dcolor[0] = color[0]/255.0;
-      dcolor[1] = color[1]/255.0;
-      dcolor[2] = color[2]/255.0;
+      dcolor[0] = color[0] / 255.0;
+      dcolor[1] = color[1] / 255.0;
+      dcolor[2] = color[2] / 255.0;
 
-
-      for (vtkIdType cc=0; cc < pointIds->GetNumberOfIds(); cc++)
+      for (vtkIdType cc = 0; cc < pointIds->GetNumberOfIds(); cc++)
       {
         vtkIdType pid = pointIds->GetId(cc);
         double* point = points->GetPoint(pid);
@@ -1233,7 +1180,7 @@ static bool vtkX3DExporterWriterRenderPoints(
     // Colors are point colors, simply render all the points and corresponding
     // colors.
     vtkIdType numPoints = points->GetNumberOfPoints();
-    for (vtkIdType pid=0; pid < numPoints; pid++)
+    for (vtkIdType pid = 0; pid < numPoints; pid++)
     {
       double* point = points->GetPoint(pid);
       coordinateVec.push_back(point[0]);
@@ -1244,9 +1191,9 @@ static bool vtkX3DExporterWriterRenderPoints(
       {
         unsigned char color[4];
         colors->GetTypedTuple(pid, color);
-        colorVec.push_back(color[0]/255.0);
-        colorVec.push_back(color[1]/255.0);
-        colorVec.push_back(color[2]/255.0);
+        colorVec.push_back(color[0] / 255.0);
+        colorVec.push_back(color[1] / 255.0);
+        colorVec.push_back(color[2] / 255.0);
       }
     }
   }
@@ -1264,13 +1211,14 @@ static bool vtkX3DExporterWriterRenderPoints(
   writer->EndNode(); // PointSet
   return true;
 }
-//----------------------------------------------------------------------------
-char *vtkX3DExporter::RegisterAndGetOutputString()
+//------------------------------------------------------------------------------
+char* vtkX3DExporter::RegisterAndGetOutputString()
 {
-  char *tmp = this->OutputString;
+  char* tmp = this->OutputString;
 
   this->OutputString = nullptr;
   this->OutputStringLength = 0;
 
   return tmp;
 }
+VTK_ABI_NAMESPACE_END
