@@ -32,6 +32,7 @@
 using namespace vtkX3D;
 
 /*======================================================================== */
+VTK_ABI_NAMESPACE_BEGIN
 struct NodeInfo
 {
   NodeInfo(int _nodeId)
@@ -143,7 +144,7 @@ std::string vtkX3DExporterFIByteWriter::GetStringStream(vtkIdType& size)
   }
 
   size = 0;
-  return nullptr;
+  return std::string();
 }
 
 //------------------------------------------------------------------------------
@@ -152,7 +153,12 @@ void vtkX3DExporterFIByteWriter::TryFlush()
   if (this->CurrentBytePos == 8)
   {
     this->Stream->write((char*)(&(this->CurrentByte)), 1);
+#if defined(__GNUC__) && (__GNUC__ >= 7) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstringop-overflow"
     this->CurrentByte = 0;
+#pragma GCC diagnostic pop
+#endif
     this->CurrentBytePos = 0;
   }
 }
@@ -235,9 +241,11 @@ void vtkX3DExporterFIByteWriter::PutBits(const std::string& bitstring)
   }
 }
 
+VTK_ABI_NAMESPACE_END
 #include "vtkX3DExporterFIWriterHelper.h"
 
 /* ------------------------------------------------------------------------- */
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkX3DExporterFIWriter);
 //------------------------------------------------------------------------------
 vtkX3DExporterFIWriter::~vtkX3DExporterFIWriter()
@@ -426,7 +434,7 @@ void vtkX3DExporterFIWriter::StartAttribute(int attributeID, bool literal, bool
   // then the bit '0' (discriminant) is appended
   // ITU C.14.4: If the alternative string-index is present,
   // then the bit '1' (discriminant) is appended
-  this->Writer->PutBit(literal ? false : true);
+  this->Writer->PutBit(!literal);
   if (literal)
   {
     // ITU C.14.3.1 If the value of the component add-to-table is TRUE,
@@ -692,3 +700,4 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, const char* value, bool v
 
 //------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::Flush() {}
+VTK_ABI_NAMESPACE_END
