@@ -40,7 +40,6 @@
 #include "vtkTextProperty.h"
 #include "vtkTextRenderer.h"
 #include "vtkTransform.h"
-#include "vtkUnicodeString.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkVectorOperators.h"
 
@@ -56,11 +55,11 @@
 #include <utility>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
-static void GetPointBounds(
-  float* points, int numPoints, HPDF_REAL bbox[4], const float radius = 0.f)
+void GetPointBounds(float* points, int numPoints, HPDF_REAL bbox[4], const float radius = 0.f)
 {
   bbox[0] = static_cast<HPDF_REAL>(points[0]);
   bbox[1] = static_cast<HPDF_REAL>(points[0]);
@@ -81,7 +80,7 @@ static void GetPointBounds(
   bbox[3] += radius;
 }
 
-static void PolygonToShading(
+void PolygonToShading(
   float* points, int numPoints, unsigned char* colors, int nc_comps, HPDF_Shading shading)
 {
   assert(numPoints >= 3);
@@ -105,7 +104,7 @@ static void PolygonToShading(
   }
 }
 
-static void LineSegmentToShading(const float p1[2], const unsigned char rgb1[3], const float p2[2],
+void LineSegmentToShading(const float p1[2], const unsigned char rgb1[3], const float p2[2],
   const unsigned char rgb2[3], float radius, HPDF_Shading shading)
 {
   float pDy = p2[1] - p1[1];
@@ -129,8 +128,8 @@ static void LineSegmentToShading(const float p1[2], const unsigned char rgb1[3],
   PolygonToShading(quad, 4, color, 3, shading);
 }
 
-static void PolyLineToShading(const float* points, int numPoints, const unsigned char* color,
-  int nc_comps, float radius, HPDF_Shading shading)
+void PolyLineToShading(const float* points, int numPoints, const unsigned char* color, int nc_comps,
+  float radius, HPDF_Shading shading)
 {
   for (int i = 0; i < numPoints - 1; ++i)
   {
@@ -1305,18 +1304,6 @@ void vtkPDFContextDevice2D::ComputeStringBounds(const vtkStdString& string, floa
   bounds[3] = helper.BBoxHeight;
 }
 
-//------------------------------------------------------------------------------
-void vtkPDFContextDevice2D::DrawString(float* point, const vtkUnicodeString& string)
-{
-  this->DrawString(point, std::string(string.utf8_str()));
-}
-
-//------------------------------------------------------------------------------
-void vtkPDFContextDevice2D::ComputeStringBounds(const vtkUnicodeString& string, float bounds[4])
-{
-  this->ComputeStringBounds(string.utf8_str(), bounds);
-}
-
 //------------------------------------------------------------------------------
 void vtkPDFContextDevice2D::ComputeJustifiedStringBounds(const char* string, float bounds[4])
 {
@@ -1631,21 +1618,21 @@ void vtkPDFContextDevice2D::ApplyLineWidth(float width)
 void vtkPDFContextDevice2D::ApplyLineType(int type)
 {
   // These match the OpenGL2 implementation:
-  static const HPDF_UINT16 noPen[] = { 0, 10 };
+  static const HPDF_REAL noPen[] = { 0.f, 10.f };
   static const HPDF_UINT noPenLen = 2;
 
-  static const HPDF_UINT16 dash[] = { 8 };
+  static const HPDF_REAL dash[] = { 8.f };
   static const HPDF_UINT dashLen = 1;
 
-  static const HPDF_UINT16 dot[] = { 1, 7 };
-  static const HPDF_UINT16 denseDot[] = { 1, 3 };
+  static const HPDF_REAL dot[] = { 1.f, 7.f };
+  static const HPDF_REAL denseDot[] = { 1.f, 3.f };
   static const HPDF_UINT dotLen = 2;
 
-  static const HPDF_UINT16 dashDot[] = { 4, 6, 2, 4 };
+  static const HPDF_REAL dashDot[] = { 4.f, 6.f, 2.f, 4.f };
   static const HPDF_UINT dashDotLen = 4;
 
   // This is dash-dot-dash, but eh. It matches the OpenGL2 0x1C47 pattern.
-  static const HPDF_UINT16 dashDotDot[] = { 3, 3, 1, 3, 3, 3 };
+  static const HPDF_REAL dashDotDot[] = { 3.f, 3.f, 1.f, 3.f, 3.f, 3.f };
   static const HPDF_UINT dashDotDotLen = 6;
 
   switch (type)
@@ -2398,3 +2385,4 @@ void vtkPDFContextDevice2D::HPDFTransformToMatrix3(
   mat3[7] = 0.;
   mat3[8] = 1.;
 }
+VTK_ABI_NAMESPACE_END
