@@ -65,10 +65,11 @@ extern "C"
 //
 /////////////////////////////////////////////////////////////////////////
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFFMPEGVideoSourceInternal
 {
 public:
-  vtkFFMPEGVideoSourceInternal() {}
+  vtkFFMPEGVideoSourceInternal() = default;
   void ReleaseSystemResources()
   {
     if (this->Frame)
@@ -112,12 +113,25 @@ public:
   int AudioStreamIndex = -1;
   AVFrame* Frame = nullptr;
   AVFrame* AudioFrame = nullptr;
-  AVPacket Packet;
+  AVPacket* Packet = nullptr;
   struct SwsContext* RGBContext = nullptr;
 };
 
 vtkStandardNewMacro(vtkFFMPEGVideoSource);
 
+//------------------------------------------------------------------------------
+void vtkFFMPEGVideoSource::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "DecodingThreads: " << this->DecodingThreads << endl;
+  os << indent << "DrainAudioThreadId: " << this->DrainAudioThreadId << endl;
+  os << indent << "DrainThreadId: " << this->DrainThreadId << endl;
+  os << indent << "EndOfFile: " << this->EndOfFile << endl;
+  os << indent << "FeedThreadId: " << this->FeedThreadId << endl;
+  os << indent << "FileName: " << (this->FileName ? this->FileName : "(null)") << endl;
+  os << indent << "Stereo3D: " << this->Stereo3D << endl;
+}
+
 //------------------------------------------------------------------------------
 vtkFFMPEGVideoSource::vtkFFMPEGVideoSource()
   : AudioCallback(nullptr)
@@ -143,8 +157,10 @@ vtkFFMPEGVideoSource::vtkFFMPEGVideoSource()
 //------------------------------------------------------------------------------
 vtkFFMPEGVideoSource::~vtkFFMPEGVideoSource()
 {
+  this->Stop();
   this->vtkFFMPEGVideoSource::ReleaseSystemResources();
   delete[] this->FileName;
+  av_packet_free(&this->Internal->Packet);
   delete this->Internal;
 }
 
@@ -191,7 +207,7 @@ void vtkFFMPEGVideoSource::Initialize()
 
   this->Internal->VideoStream = fcontext->streams[this->Internal->VideoStreamIndex];
 
-  AVCodec* dec = avcodec_find_decoder(this->Internal->VideoStream->codecpar->codec_id);
+  const AVCodec* dec = avcodec_find_decoder(this->Internal->VideoStream->codecpar->codec_id);
   if (!dec)
   {
     vtkErrorMacro("Failed to find codec for video");
@@ -257,7 +273,7 @@ void vtkFFMPEGVideoSource::Initialize()
   {
     this->Internal->AudioStream = fcontext->streams[this->Internal->AudioStreamIndex];
 
-    AVCodec* adec = avcodec_find_decoder(this->Internal->AudioStream->codecpar->codec_id);
+    const AVCodec* adec = avcodec_find_decoder(this->Internal->AudioStream->codecpar->codec_id);
     if (!adec)
     {
       vtkErrorMacro("Failed to find codec for audio");
@@ -296,9 +312,9 @@ void vtkFFMPEGVideoSource::Initialize()
   }
 
   /* initialize packet, set data to nullptr, let the demuxer fill it */
-  av_init_packet(&this->Internal->Packet);
-  this->Internal->Packet.data = nullptr;
-  this->Internal->Packet.size = 0;
+  this->Internal->Packet = av_packet_alloc();
+  this->Internal->Packet->data = nullptr;
+  this->Internal->Packet->size = 0;
 
   // update framebuffer again to reflect any changes which
   // might have occurred
@@ -331,17 +347,17 @@ void* vtkFFMPEGVideoSource::Feed(vtkMultiThreader::ThreadInfo* data)
     // read in the packet
     if (!retryPacket)
     {
-      av_packet_unref(&this->Internal->Packet);
-      fret = av_read_frame(this->Internal->FormatContext, &this->Internal->Packet);
+      av_packet_unref(this->Internal->Packet);
+      fret = av_read_frame(this->Internal->FormatContext, this->Internal->Packet);
     }
     retryPacket = false;
     // feed video
-    if (fret >= 0 && this->Internal->Packet.stream_index == this->Internal->VideoStreamIndex)
+    if (fret >= 0 && this->Internal->Packet->stream_index == this->Internal->VideoStreamIndex)
     {
       // lock the decoder
       this->FeedMutex.lock();
 
-      int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, &this->Internal->Packet);
+      int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, this->Internal->Packet);
       if (sret == 0) // good decode
       {
         this->FeedCondition.notify_one();
@@ -364,12 +380,12 @@ void* vtkFFMPEGVideoSource::Feed(vtkMultiThreader::ThreadInfo* data)
     }
 
     // feed audio
-    if (fret >= 0 && this->Internal->Packet.stream_index == this->Internal->AudioStreamIndex)
+    if (fret >= 0 && this->Internal->Packet->stream_index == this->Internal->AudioStreamIndex)
     {
       // lock the decoder
       this->FeedAudioMutex.lock();
 
-      int sret = avcodec_send_packet(this->Internal->AudioDecodeContext, &this->Internal->Packet);
+      int sret = avcodec_send_packet(this->Internal->AudioDecodeContext, this->Internal->Packet);
       if (sret == 0) // good decode
       {
         this->FeedAudioCondition.notify_one();
@@ -400,7 +416,7 @@ void* vtkFFMPEGVideoSource::Feed(vtkMultiThreader::ThreadInfo* data)
     // check to see if we are being told to quit every so often
     if (count == 10)
     {
-      std::lock_guard<std::mutex>(*data->ActiveFlagLock);
+      std::lock_guard<std::mutex> guard(*data->ActiveFlagLock);
       done = done || (*(data->ActiveFlag) == 0);
       count = 0;
     }
@@ -502,6 +518,7 @@ void* vtkFFMPEGVideoSource::Drain(vtkMultiThreader::ThreadInfo* data)
     }
     else if (ret == AVERROR_EOF)
     {
+      this->FeedMutex.unlock();
       return nullptr;
     }
     else if (ret < 0) // error code
@@ -541,7 +558,7 @@ void* vtkFFMPEGVideoSource::Drain(vtkMultiThreader::ThreadInfo* data)
     // check to see if we are being told to quit every so often
     if (count == 10)
     {
-      std::lock_guard<std::mutex>(*data->ActiveFlagLock);
+      std::lock_guard<std::mutex> guard(*data->ActiveFlagLock);
       done = done || (*(data->ActiveFlag) == 0);
       count = 0;
     }
@@ -582,6 +599,7 @@ void* vtkFFMPEGVideoSource::DrainAudio(vtkMultiThreader::ThreadInfo* data)
     }
     else if (ret == AVERROR_EOF)
     {
+      this->FeedAudioMutex.unlock();
       return nullptr;
     }
     else if (ret < 0) // error code
@@ -646,7 +664,14 @@ void* vtkFFMPEGVideoSource::DrainAudio(vtkMultiThreader::ThreadInfo* data)
         cbd.NumberOfSamples = this->Internal->AudioFrame->nb_samples;
         cbd.BytesPerSample =
           av_get_bytes_per_sample(this->Internal->AudioDecodeContext->sample_fmt);
+#if defined(LIBAVCODEC_VERSION_MAJOR) &&                                                           \
+  (LIBAVCODEC_VERSION_MAJOR > 59 ||                                                                \
+    (LIBAVCODEC_VERSION_MAJOR == 59 && defined(LIBAVCODEC_VERSION_MINOR) &&                        \
+      LIBAVCODEC_VERSION_MINOR >= 24))
+        cbd.NumberOfChannels = this->Internal->AudioDecodeContext->ch_layout.nb_channels;
+#else
         cbd.NumberOfChannels = this->Internal->AudioDecodeContext->channels;
+#endif
         cbd.SampleRate = this->Internal->AudioDecodeContext->sample_rate;
         cbd.DataType = sampleFormat;
         cbd.Data = this->Internal->AudioFrame->extended_data;
@@ -661,7 +686,7 @@ void* vtkFFMPEGVideoSource::DrainAudio(vtkMultiThreader::ThreadInfo* data)
     // check to see if we are being told to quit every so often
     if (count == 10)
     {
-      std::lock_guard<std::mutex>(*data->ActiveFlagLock);
+      std::lock_guard<std::mutex> guard(*data->ActiveFlagLock);
       done = done || (*(data->ActiveFlag) == 0);
       count = 0;
     }
@@ -675,10 +700,10 @@ void vtkFFMPEGVideoSource::ReadFrame()
 {
   // first try to grab a frame from data we already have
   bool gotFrame = false;
-  while (!gotFrame && (!this->EndOfFile || this->Internal->Packet.size > 0))
+  while (!gotFrame && (!this->EndOfFile || this->Internal->Packet->size > 0))
   {
     int ret = AVERROR(EAGAIN);
-    if (this->Internal->Packet.size > 0)
+    if (this->Internal->Packet->size > 0)
     {
       ret = avcodec_receive_frame(this->Internal->VideoDecodeContext, this->Internal->Frame);
       if (ret < 0 && ret != AVERROR(EAGAIN) && ret != AVERROR_EOF)
@@ -701,11 +726,11 @@ void vtkFFMPEGVideoSource::ReadFrame()
     if (ret == AVERROR(EAGAIN) && !this->EndOfFile)
     {
       // if the packet is empty read more data from the file
-      av_packet_unref(&this->Internal->Packet);
-      int fret = av_read_frame(this->Internal->FormatContext, &this->Internal->Packet);
-      if (fret >= 0 && this->Internal->Packet.stream_index == this->Internal->VideoStreamIndex)
+      av_packet_unref(this->Internal->Packet);
+      int fret = av_read_frame(this->Internal->FormatContext, this->Internal->Packet);
+      if (fret >= 0 && this->Internal->Packet->stream_index == this->Internal->VideoStreamIndex)
       {
-        int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, &this->Internal->Packet);
+        int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, this->Internal->Packet);
         if (sret < 0 && sret != AVERROR(EAGAIN) && sret != AVERROR_EOF)
         {
           vtkErrorMacro("codec did not send packet");
@@ -937,3 +962,4 @@ void vtkFFMPEGVideoSource::SetOutputFormat(int format)
 
   this->Modified();
 }
+VTK_ABI_NAMESPACE_END
