@@ -21,10 +21,17 @@
 
 extern "C"
 {
+#include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
 #include <libswscale/swscale.h>
 }
 
+#if LIBAVFORMAT_VERSION_MAJOR < 59
+#define vtk_ff_const59
+#else
+#define vtk_ff_const59 const
+#endif
+
 #if defined(LIBAVFORMAT_VERSION_MAJOR) && LIBAVFORMAT_VERSION_MAJOR >= 57
 extern "C"
 {
@@ -32,6 +39,8 @@ extern "C"
 }
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
+
 //------------------------------------------------------------------------------
 class vtkFFMPEGWriterInternal
 {
@@ -51,7 +60,7 @@ private:
 
   AVFormatContext* avFormatContext;
 
-  AVOutputFormat* avOutputFormat;
+  vtk_ff_const59 AVOutputFormat* avOutputFormat;
 
   AVStream* avStream;
 
@@ -115,15 +124,9 @@ int vtkFFMPEGWriterInternal::Start()
     return 0;
   }
 
-  if (this->Writer->GetCompression())
-  {
-    // choose a codec that is easily playable on windows
-    this->avOutputFormat->video_codec = AV_CODEC_ID_MJPEG;
-  }
-  else
-  {
-    this->avOutputFormat->video_codec = AV_CODEC_ID_RAWVIDEO;
-  }
+  enum AVCodecID video_codec = this->Writer->GetCompression()
+    ? AV_CODEC_ID_MJPEG // choose a codec that is easily playable on windows
+    : AV_CODEC_ID_RAWVIDEO;
 
   // create the format context that wraps all of the media output structures
   if (avformat_alloc_output_context2(
@@ -133,8 +136,8 @@ int vtkFFMPEGWriterInternal::Start()
     return 0;
   }
 
-  AVCodec* codec;
-  if (!(codec = avcodec_find_encoder(this->avOutputFormat->video_codec)))
+  vtk_ff_const59 AVCodec* codec;
+  if (!(codec = avcodec_find_encoder(video_codec)))
   {
     vtkGenericWarningMacro(<< "Failed to get video codec.");
     return 0;
@@ -155,7 +158,7 @@ int vtkFFMPEGWriterInternal::Start()
     return 0;
   }
 
-  this->avStream->codecpar->codec_id = static_cast<AVCodecID>(this->avOutputFormat->video_codec);
+  this->avStream->codecpar->codec_id = video_codec;
   this->avStream->codecpar->codec_type = AVMEDIA_TYPE_VIDEO;
   this->avStream->codecpar->width = this->Dim[0];
   this->avStream->codecpar->height = this->Dim[1];
@@ -310,19 +313,18 @@ int vtkFFMPEGWriterInternal::Write(vtkImageData* id)
   }
 
   // run the encoder
-  AVPacket pkt;
-  av_init_packet(&pkt);
-  pkt.data = nullptr;
-  pkt.size = 0;
+  AVPacket* pkt = av_packet_alloc();
+  pkt->data = nullptr;
+  pkt->size = 0;
 
   while (!ret)
   {
     // dump the compressed result to file
-    ret = avcodec_receive_packet(this->avCodecContext, &pkt);
+    ret = avcodec_receive_packet(this->avCodecContext, pkt);
     if (!ret)
     {
-      pkt.stream_index = this->avStream->index;
-      int wret = av_write_frame(this->avFormatContext, &pkt);
+      pkt->stream_index = this->avStream->index;
+      int wret = av_write_frame(this->avFormatContext, pkt);
       if (wret < 0)
       {
         vtkGenericWarningMacro(<< "Problem encoding frame.");
@@ -330,6 +332,7 @@ int vtkFFMPEGWriterInternal::Write(vtkImageData* id)
       }
     }
   }
+  av_packet_free(&pkt);
 
   return 1;
 }
@@ -359,7 +362,7 @@ void vtkFFMPEGWriterInternal::End()
     }
 
     avformat_free_context(this->avFormatContext);
-    this->avFormatContext = 0;
+    this->avFormatContext = nullptr;
   }
 
   if (this->avOutputFormat)
@@ -367,7 +370,7 @@ void vtkFFMPEGWriterInternal::End()
     // Next line was done inside av_free(this->avFormatContext).
     // av_free(this->avOutputFormat);
 
-    this->avOutputFormat = 0;
+    this->avOutputFormat = nullptr;
   }
 
   if (this->avCodecContext)
@@ -664,7 +667,7 @@ vtkStandardNewMacro(vtkFFMPEGWriter);
 //------------------------------------------------------------------------------
 vtkFFMPEGWriter::vtkFFMPEGWriter()
 {
-  this->Internals = 0;
+  this->Internals = nullptr;
   this->Quality = 2;
   this->Compression = true;
   this->Rate = 25;
@@ -772,7 +775,7 @@ void vtkFFMPEGWriter::End()
   this->Internals->End();
 
   delete this->Internals;
-  this->Internals = 0;
+  this->Internals = nullptr;
 }
 
 //------------------------------------------------------------------------------
@@ -785,3 +788,4 @@ void vtkFFMPEGWriter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "BitRate: " << this->BitRate << endl;
   os << indent << "BitRateTolerance: " << this->BitRateTolerance << endl;
 }
+VTK_ABI_NAMESPACE_END
