@@ -51,6 +51,7 @@
 #include <sstream>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGDALRasterReader);
 
 //------------------------------------------------------------------------------
@@ -157,7 +158,7 @@ vtkGDALRasterReader::vtkGDALRasterReaderInternal::~vtkGDALRasterReaderInternal()
 //------------------------------------------------------------------------------
 void vtkGDALRasterReader::vtkGDALRasterReaderInternal::ReadMetaData(const std::string& fileName)
 {
-  if (fileName.compare(this->PrevReadFileName) == 0)
+  if (fileName == this->PrevReadFileName)
   {
     return;
   }
@@ -198,7 +199,7 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::ReadMetaData(const std::s
     {
       for (int i = 0; papszMetaData[i] != nullptr; ++i)
       {
-        this->Reader->MetaData.push_back(papszMetaData[i]);
+        this->Reader->MetaData.emplace_back(papszMetaData[i]);
       }
     }
   }
@@ -427,19 +428,19 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::GenericReadData()
         rawUniformGridData.resize(4 * destWidth * destHeight * pixelSpace);
 
         err = redBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 0 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 0 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         err = greenBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 1 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 1 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         err = blueBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 2 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 2 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         err = alphaBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 3 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 3 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         completedBand = 4.0;
@@ -450,15 +451,15 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::GenericReadData()
         rawUniformGridData.resize(3 * destWidth * destHeight * pixelSpace);
 
         err = redBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 0 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 0 * bandSpace),
           destWidth, destHeight, this->TargetDataType, 0, 0);
         assert(err == CE_None);
         err = greenBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 1 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 1 * bandSpace),
           destWidth, destHeight, this->TargetDataType, 0, 0);
         assert(err == CE_None);
         err = blueBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 2 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 2 * bandSpace),
           destWidth, destHeight, this->TargetDataType, 0, 0);
         assert(err == CE_None);
         completedBand = 3.0;
@@ -477,11 +478,11 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::GenericReadData()
         rawUniformGridData.resize(2 * destWidth * destHeight * pixelSpace);
 
         err = grayBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 0 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 0 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         err = alphaBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 1 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 1 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         completedBand = 2.0;
@@ -492,7 +493,7 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::GenericReadData()
         this->Reader->SetNumberOfScalarComponents(1);
         rawUniformGridData.resize(destWidth * destHeight * pixelSpace);
         err = grayBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-          static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 0 * bandSpace),
+          static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 0 * bandSpace),
           destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
         assert(err == CE_None);
         completedBand = 1.0;
@@ -506,7 +507,7 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::GenericReadData()
       this->Reader->SetNumberOfScalarComponents(1);
       rawUniformGridData.resize(destWidth * destHeight * pixelSpace);
       err = paletteBand->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-        static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 0 * bandSpace),
+        static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 0 * bandSpace),
         destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
       assert(err == CE_None);
 
@@ -528,7 +529,7 @@ void vtkGDALRasterReader::vtkGDALRasterReaderInternal::GenericReadData()
     {
       groupIndex[0] = i;
       err = allBands[i]->RasterIO(GF_Read, windowX, windowY, windowWidth, windowHeight,
-        static_cast<void*>(reinterpret_cast<GByte*>(&rawUniformGridData[0]) + 0 * bandSpace),
+        static_cast<void*>(reinterpret_cast<GByte*>(rawUniformGridData.data()) + 0 * bandSpace),
         destWidth, destHeight, this->TargetDataType, pixelSpace, lineSpace);
       assert(err == CE_None);
       this->Convert<VTK_TYPE, RAW_TYPE>(rawUniformGridData, destWidth, destHeight, groupIndex,
@@ -819,7 +820,6 @@ void vtkGDALRasterReader::PrintSelf(std::ostream& os, vtkIndent indent)
 
 //------------------------------------------------------------------------------
 vtkGDALRasterReader::vtkGDALRasterReader()
-  : vtkImageReader2()
 {
   this->Impl = new vtkGDALRasterReaderInternal(this);
 
@@ -854,7 +854,7 @@ vtkGDALRasterReader::~vtkGDALRasterReader()
 
   if (this->FileName)
   {
-    this->SetFileName(0);
+    this->SetFileName(nullptr);
   }
 }
 
@@ -896,7 +896,7 @@ std::vector<std::string> vtkGDALRasterReader::GetDomainMetaData(const std::strin
   {
     for (int i = 0; papszMetadata[i] != nullptr; ++i)
     {
-      domainMetaData.push_back(papszMetadata[i]);
+      domainMetaData.emplace_back(papszMetadata[i]);
     }
   }
 
@@ -958,7 +958,7 @@ int vtkGDALRasterReader::RequestData(vtkInformation* vtkNotUsed(request),
   this->Impl->UniformGridData->GetFieldData()->AddArray(projectionData);
 
   // Add NoDataValue as field data
-  // GDALDatset can have 1 value for each raster band
+  // GDALDataset can have 1 value for each raster band
   // Use NaN for undefined values
   vtkSmartPointer<vtkDoubleArray> noDataArray = vtkSmartPointer<vtkDoubleArray>::New();
   noDataArray->SetName("NO_DATA_VALUE");
@@ -1141,3 +1141,4 @@ void vtkGDALRasterReader::EnableAllCellArrays()
 {
   this->Impl->CellArraySelection->EnableAllArrays();
 }
+VTK_ABI_NAMESPACE_END
