@@ -35,6 +35,7 @@
 // C++ includes
 #include <vector> // Requires STL vector
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGDALVectorReader);
 
 int vtkGDALVectorReader::OGRRegistered = 0;
@@ -262,7 +263,7 @@ public:
       case wkbPoint25D:
         gpt = (OGRPoint*)geom;
         ptIds.push_back(pts->InsertNextPoint(gpt->getX(), gpt->getY(), gpt->getZ()));
-        verts->InsertNextCell(1, &(ptIds[0]));
+        verts->InsertNextCell(1, ptIds.data());
         ++nCells;
         break;
 
@@ -277,7 +278,7 @@ public:
           ptIds.push_back(pts->InsertNextPoint(gls->getX(p), gls->getY(p), gls->getZ(p)));
         }
         // insert ring line segments
-        lines->InsertNextCell((int)ptIds.size(), &(ptIds[0]));
+        lines->InsertNextCell((int)ptIds.size(), ptIds.data());
         ++nCells;
         break;
 
@@ -685,3 +686,4 @@ int vtkGDALVectorReader::InitializeInternal()
 
   return VTK_OK;
 }
+VTK_ABI_NAMESPACE_END
