@@ -38,6 +38,7 @@
 #include <iostream>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGeoJSONReader);
 
 //------------------------------------------------------------------------------
@@ -144,7 +145,7 @@ void vtkGeoJSONReader::GeoJSONReaderInternal::ParseRoot(const Json::Value& root,
   }
 
   // Check type
-  Json::Value rootType = root["type"];
+  Json::Value const& rootType = root["type"];
   if (rootType.isNull())
   {
     vtkGenericWarningMacro(<< "ParseRoot: Missing type node");
@@ -281,7 +282,7 @@ void vtkGeoJSONReader::GeoJSONReaderInternal::ParseFeatureProperties(
     spec = *iter;
     property.Name = spec.Name;
 
-    Json::Value propertyNode = propertiesNode[spec.Name];
+    Json::Value const& propertyNode = propertiesNode[spec.Name];
     if (propertyNode.isNull())
     {
       property.Value = spec.Value;
@@ -473,3 +474,4 @@ void vtkGeoJSONReader::PrintSelf(ostream& os, vtkIndent indent)
   os << "vtkGeoJSONReader" << std::endl;
   os << "Filename: " << this->FileName << std::endl;
 }
+VTK_ABI_NAMESPACE_END
