@@ -63,6 +63,7 @@
 #define GL_NEAREST 0x2600
 #define GL_LINEAR 0x2601
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 //------------------------------------------------------------------------------
@@ -149,9 +150,8 @@ void GenerateIndicesForPrimitive(vtkGLTFDocumentLoader::Primitive& primitive)
 }
 
 //------------------------------------------------------------------------------
-const std::vector<std::string> vtkGLTFDocumentLoader::SupportedExtensions = {
-  "KHR_lights_punctual"
-};
+const std::vector<std::string> vtkGLTFDocumentLoader::SupportedExtensions = { "KHR_lights_punctual",
+  "KHR_materials_unlit" };
 
 //------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkGLTFDocumentLoader);
@@ -174,11 +174,7 @@ bool vtkGLTFDocumentLoader::LoadModelMetaDataFromFile(std::string fileName)
   fileName = vtksys::SystemTools::CollapseFullPath(fileName);
   this->InternalModel->FileName = fileName;
 
-  if (!impl.LoadModelMetaDataFromFile(fileName, this->UsedExtensions))
-  {
-    return false;
-  }
-  return true;
+  return impl.LoadModelMetaDataFromFile(fileName, this->UsedExtensions);
 }
 
 /** Data loading **/
@@ -747,7 +743,8 @@ bool vtkGLTFDocumentLoader::LoadAnimationData()
       // Get actual tuple size when loading morphing weights
       unsigned int numberOfComponents = sampler.OutputData->GetNumberOfComponents();
       // If we're loading T/R/S, tuple size is already set (to 3 or 4) in outputdata.
-      if (numberOfComponents == this->GetNumberOfComponentsForType(AccessorType::SCALAR))
+      if (numberOfComponents ==
+        vtkGLTFDocumentLoader::GetNumberOfComponentsForType(AccessorType::SCALAR))
       {
         unsigned int nInput = sampler.InputData->GetNumberOfValues();
         unsigned int nOutput = sampler.OutputData->GetNumberOfValues();
@@ -885,7 +882,7 @@ bool vtkGLTFDocumentLoader::LoadSkinMatrixData()
     vtkArrayDispatch::DispatchByArray<AttributeArrayTypes>::Execute(matrixValues, worker);
 
     size_t totalNumberOfComponents =
-      skin.Joints.size() * this->GetNumberOfComponentsForType(AccessorType::MAT4);
+      skin.Joints.size() * vtkGLTFDocumentLoader::GetNumberOfComponentsForType(AccessorType::MAT4);
     if (!worker.Result ||
       static_cast<size_t>(matrixValues->GetNumberOfValues()) != totalNumberOfComponents)
     {
@@ -963,15 +960,18 @@ bool vtkGLTFDocumentLoader::ApplyAnimation(float t, int animationId, bool forceS
     switch (channel.TargetPath)
     {
       case Animation::Channel::PathType::ROTATION:
-        numberOfComponents = this->GetNumberOfComponentsForType(AccessorType::VEC4);
+        numberOfComponents =
+          vtkGLTFDocumentLoader::GetNumberOfComponentsForType(AccessorType::VEC4);
         target = &(node.Rotation);
         break;
       case Animation::Channel::PathType::TRANSLATION:
-        numberOfComponents = this->GetNumberOfComponentsForType(AccessorType::VEC3);
+        numberOfComponents =
+          vtkGLTFDocumentLoader::GetNumberOfComponentsForType(AccessorType::VEC3);
         target = &(node.Translation);
         break;
       case Animation::Channel::PathType::SCALE:
-        numberOfComponents = this->GetNumberOfComponentsForType(AccessorType::VEC3);
+        numberOfComponents =
+          vtkGLTFDocumentLoader::GetNumberOfComponentsForType(AccessorType::VEC3);
         target = &(node.Scale);
         break;
       case Animation::Channel::PathType::WEIGHTS:
@@ -1440,7 +1440,6 @@ void vtkGLTFDocumentLoader::BuildGlobalTransforms(
   {
     this->BuildGlobalTransforms(childId, node.GlobalTransform);
   }
-  return;
 }
 
 //------------------------------------------------------------------------------
@@ -1541,3 +1540,4 @@ void vtkGLTFDocumentLoader::ComputeJointMatrices(const Model& model, const Skin&
     jointMats.emplace_back(jointMat);
   }
 }
+VTK_ABI_NAMESPACE_END
