@@ -46,6 +46,7 @@
 #include <string> // For std::string
 #include <vector> // For std::vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkDataArray;
 class vtkFloatArray;
@@ -322,6 +323,9 @@ public:
     bool DoubleSided;
 
     std::string Name;
+
+    // extension KHR_materials_unlit
+    bool Unlit;
   };
 
   /**
@@ -536,7 +540,7 @@ public:
    * Load the binary part of a binary glTF (.glb) file. Returns false if no valid binary part was
    * found.
    */
-  bool LoadFileBuffer(const std::string& fileName, std::vector<char>& glbBuffer);
+  bool LoadFileBuffer(VTK_FILEPATH const std::string& fileName, std::vector<char>& glbBuffer);
 
   /**
    * Reset internal Model struct, and serialize glTF metadata (all json information) into it.
@@ -649,4 +653,5 @@ private:
   std::vector<std::string> UsedExtensions;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
