@@ -18,6 +18,7 @@
 #include "vtkCommand.h"
 #include "vtkDataArraySelection.h"
 #include "vtkDoubleArray.h"
+#include "vtkEventForwarderCommand.h"
 #include "vtkFieldData.h"
 #include "vtkFloatArray.h"
 #include "vtkGLTFDocumentLoader.h"
@@ -36,11 +37,12 @@
 #include <array>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Replacement for std::to_string as it is not supported by certain compilers
-template<typename T>
+template <typename T>
 std::string value_to_string(const T& val)
 {
   std::ostringstream ss;
@@ -48,7 +50,7 @@ std::string value_to_string(const T& val)
   return ss.str();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string MakeUniqueNonEmptyName(
   const std::string& name, std::map<std::string, unsigned int>& duplicateCounters)
 {
@@ -70,7 +72,7 @@ std::string MakeUniqueNonEmptyName(
   return newName;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddIntegerToFieldData(
   std::string arrayName, int value, vtkSmartPointer<vtkFieldData> fieldData)
 {
@@ -82,7 +84,7 @@ void AddIntegerToFieldData(
   fieldData->AddArray(array);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddFloatToFieldData(
   std::string arrayName, float value, vtkSmartPointer<vtkFieldData> fieldData)
 {
@@ -94,7 +96,7 @@ void AddFloatToFieldData(
   fieldData->AddArray(array);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddVecNfToFieldData(const std::string& arrayName, const std::vector<float>& multiplier,
   vtkSmartPointer<vtkFieldData> fieldData)
 {
@@ -106,7 +108,7 @@ void AddVecNfToFieldData(const std::string& arrayName, const std::vector<float>&
   fieldData->AddArray(array);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddTextureInfoToFieldData(const std::string& prefix, int textureIndex, int textureCoordIndex,
   vtkSmartPointer<vtkFieldData> fieldData, std::vector<float> multiplier = std::vector<float>())
 {
@@ -118,7 +120,7 @@ void AddTextureInfoToFieldData(const std::string& prefix, int textureIndex, int
   AddIntegerToFieldData(prefix + "TexCoordIndex", textureCoordIndex, fieldData);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddMaterialToFieldData(int materialId, vtkSmartPointer<vtkFieldData> fieldData,
   const vtkGLTFDocumentLoader::Model& model)
 {
@@ -185,9 +187,9 @@ void AddMaterialToFieldData(int materialId, vtkSmartPointer<vtkFieldData> fieldD
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSmartPointer<vtkDataArray> ApplyMorphingToDataArray(vtkSmartPointer<vtkDataArray> origin,
-  const std::vector<float>& weights, const std::vector<vtkSmartPointer<vtkFloatArray> >& targets)
+  const std::vector<float>& weights, const std::vector<vtkSmartPointer<vtkFloatArray>>& targets)
 {
   if (origin == nullptr)
   {
@@ -220,9 +222,9 @@ vtkSmartPointer<vtkDataArray> ApplyMorphingToDataArray(vtkSmartPointer<vtkDataAr
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void SetupWeightedTransformFilterForGLTFSkinning(vtkSmartPointer<vtkWeightedTransformFilter> filter,
-  const std::vector<vtkSmartPointer<vtkTransform> >& jointMats,
+  const std::vector<vtkSmartPointer<vtkMatrix4x4>>& jointMats,
   const vtkSmartPointer<vtkPolyData> poly)
 {
   filter->SetInputData(poly);
@@ -233,14 +235,15 @@ void SetupWeightedTransformFilterForGLTFSkinning(vtkSmartPointer<vtkWeightedTran
   filter->SetNumberOfTransforms(static_cast<int>(nbTransforms));
   for (unsigned int i = 0; i < nbTransforms; i++)
   {
+    vtkNew<vtkTransform> transform;
     if (i >= jointMats.size())
     {
-      vtkNew<vtkTransform> transform;
       filter->SetTransform(transform, i);
     }
     else
     {
-      filter->SetTransform(jointMats[i], i);
+      transform->SetMatrix(jointMats[i]);
+      filter->SetTransform(transform, i);
     }
   }
 
@@ -249,8 +252,8 @@ void SetupWeightedTransformFilterForGLTFSkinning(vtkSmartPointer<vtkWeightedTran
   filter->SetWeightArray("WEIGHTS_0");
 }
 
-//----------------------------------------------------------------------------
-void AddTransformToFieldData(const vtkSmartPointer<vtkTransform> transform,
+//------------------------------------------------------------------------------
+void AddTransformToFieldData(const vtkSmartPointer<vtkMatrix4x4> transform,
   vtkSmartPointer<vtkFieldData> fieldData, const std::string& name)
 {
   vtkSmartPointer<vtkDoubleArray> matrixArray;
@@ -268,12 +271,12 @@ void AddTransformToFieldData(const vtkSmartPointer<vtkTransform> transform,
   // Create array to store the matrix's values
   for (int i = 0; i < 16; i++)
   {
-    matrixArray->InsertNextValue(transform->GetMatrix()->GetElement(i / 4, i % 4));
+    matrixArray->InsertNextValue(transform->GetElement(i / 4, i % 4));
   }
 }
 
-//----------------------------------------------------------------------------
-void AddJointMatricesToFieldData(const std::vector<vtkSmartPointer<vtkTransform> >& jointMats,
+//------------------------------------------------------------------------------
+void AddJointMatricesToFieldData(const std::vector<vtkSmartPointer<vtkMatrix4x4>>& jointMats,
   vtkSmartPointer<vtkFieldData> fieldData)
 {
   for (unsigned int matId = 0; matId < jointMats.size(); matId++)
@@ -282,15 +285,15 @@ void AddJointMatricesToFieldData(const std::vector<vtkSmartPointer<vtkTransform>
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddGlobalTransformToFieldData(
-  const vtkSmartPointer<vtkTransform> globalTransform, vtkSmartPointer<vtkFieldData> fieldData)
+  const vtkSmartPointer<vtkMatrix4x4> globalTransform, vtkSmartPointer<vtkFieldData> fieldData)
 {
   // Create array to store the matrix's values
   AddTransformToFieldData(globalTransform, fieldData, "globalTransform");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddMorphingWeightsToFieldData(
   const std::vector<float>& weights, vtkSmartPointer<vtkFieldData> fieldData)
 {
@@ -304,10 +307,10 @@ void AddMorphingWeightsToFieldData(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void AddInfoToFieldData(const std::vector<float>* morphingWeights,
-  const std::vector<vtkSmartPointer<vtkTransform> >& jointMats,
-  vtkSmartPointer<vtkTransform> globalTransform, vtkSmartPointer<vtkFieldData> fieldData)
+  const std::vector<vtkSmartPointer<vtkMatrix4x4>>& jointMats,
+  vtkSmartPointer<vtkMatrix4x4> globalTransform, vtkSmartPointer<vtkFieldData> fieldData)
 {
   if (morphingWeights != nullptr && !morphingWeights->empty())
   {
@@ -322,10 +325,10 @@ void AddInfoToFieldData(const std::vector<float>* morphingWeights,
   AddGlobalTransformToFieldData(globalTransform, fieldData);
 }
 
-//----------------------------------------------------------------------------
-void PrepareMorphingTargetArrays(std::vector<vtkSmartPointer<vtkFloatArray> >& positionArrays,
-  std::vector<vtkSmartPointer<vtkFloatArray> >& normalArrays,
-  std::vector<vtkSmartPointer<vtkFloatArray> >& tangentArrays,
+//------------------------------------------------------------------------------
+void PrepareMorphingTargetArrays(std::vector<vtkSmartPointer<vtkFloatArray>>& positionArrays,
+  std::vector<vtkSmartPointer<vtkFloatArray>>& normalArrays,
+  std::vector<vtkSmartPointer<vtkFloatArray>>& tangentArrays,
   std::vector<vtkGLTFDocumentLoader::MorphTarget>& targets)
 {
   for (auto& target : targets)
@@ -345,15 +348,15 @@ void PrepareMorphingTargetArrays(std::vector<vtkSmartPointer<vtkFloatArray> >& p
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void ApplyMorphingToPolyData(std::vector<vtkGLTFDocumentLoader::MorphTarget>& targets,
   std::vector<float>* morphingWeights, vtkSmartPointer<vtkPolyData> inputPolyData,
   vtkSmartPointer<vtkPolyData> outputPolyData)
 {
   // Prepare target arrays
-  std::vector<vtkSmartPointer<vtkFloatArray> > positionArrays;
-  std::vector<vtkSmartPointer<vtkFloatArray> > normalArrays;
-  std::vector<vtkSmartPointer<vtkFloatArray> > tangentArrays;
+  std::vector<vtkSmartPointer<vtkFloatArray>> positionArrays;
+  std::vector<vtkSmartPointer<vtkFloatArray>> normalArrays;
+  std::vector<vtkSmartPointer<vtkFloatArray>> tangentArrays;
   PrepareMorphingTargetArrays(positionArrays, normalArrays, tangentArrays, targets);
 
   // Apply morphing with all targets
@@ -380,12 +383,12 @@ void ApplyMorphingToPolyData(std::vector<vtkGLTFDocumentLoader::MorphTarget>& ta
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool BuildMultiBlockDatasetFromMesh(vtkGLTFDocumentLoader::Model& m, unsigned int meshId,
   vtkSmartPointer<vtkMultiBlockDataSet> parentDataSet,
   vtkSmartPointer<vtkMultiBlockDataSet> meshDataSet, std::string& dataSetName,
-  vtkSmartPointer<vtkTransform> globalTransform,
-  const std::vector<vtkSmartPointer<vtkTransform> >& jointMats, bool applyDeformations,
+  vtkSmartPointer<vtkMatrix4x4> globalTransform,
+  const std::vector<vtkSmartPointer<vtkMatrix4x4>>& jointMats, bool applyDeformations,
   std::vector<float>* morphingWeights)
 {
   if (meshId >= m.Meshes.size())
@@ -455,7 +458,9 @@ bool BuildMultiBlockDatasetFromMesh(vtkGLTFDocumentLoader::Model& m, unsigned in
       }
 
       // Node transform
-      filter->SetTransform(globalTransform);
+      vtkNew<vtkTransform> transform;
+      transform->SetMatrix(globalTransform);
+      filter->SetTransform(transform);
       if (createNewPolyData)
       {
         meshDataSet->SetBlock(meshDataSet->GetNumberOfBlocks(), (filter->GetOutputDataObject(0)));
@@ -487,50 +492,7 @@ bool BuildMultiBlockDatasetFromMesh(vtkGLTFDocumentLoader::Model& m, unsigned in
   return true;
 }
 
-//----------------------------------------------------------------------------
-void ComputeJointMatrices(const vtkGLTFDocumentLoader::Model& m,
-  const vtkGLTFDocumentLoader::Skin& skin, vtkGLTFDocumentLoader::Node& node,
-  std::vector<vtkSmartPointer<vtkTransform> >& jointMats)
-{
-  jointMats.clear();
-  jointMats.reserve(skin.Joints.size());
-
-  for (unsigned int jointId = 0; jointId < skin.Joints.size(); jointId++)
-  {
-    const vtkGLTFDocumentLoader::Node& jointNode = m.Nodes[skin.Joints[jointId]];
-
-    vtkNew<vtkTransform> jointGlobalTransform;
-    vtkNew<vtkTransform> inverseMeshGlobalTransform;
-    vtkNew<vtkTransform> inverseBindTransform;
-    vtkNew<vtkTransform> jointTransform;
-
-    /**
-     * Joint matrices:
-     * jointMatrix(j) =
-     * globalTransformOfNodeThatTheMeshIsAttachedTo^-1 *
-     * globalTransformOfJointNode(j) *
-     * inverseBindMatrixForJoint(j);
-     * The mesh will be transformed (using vtkWeightedTransformFilter) using this matrix:
-     * mat4 skinMat =
-     * weight.x * jointMatrix[joint.x] +
-     * weight.y * jointMatrix[joint.y] +
-     * weight.z * jointMatrix[joint.z] +
-     * weight.w * jointMatrix[joint.w];
-     */
-    inverseMeshGlobalTransform->SetInput(node.GlobalTransform);
-    inverseMeshGlobalTransform->Inverse();
-    inverseBindTransform->SetMatrix(skin.InverseBindMatrices[jointId]);
-    jointGlobalTransform->SetInput(jointNode.GlobalTransform);
-    jointTransform->PostMultiply();
-    jointTransform->Concatenate(inverseBindTransform);
-    jointTransform->Concatenate(jointGlobalTransform);
-    jointTransform->Concatenate(inverseMeshGlobalTransform);
-
-    jointMats.push_back(jointTransform);
-  }
-}
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool BuildMultiBlockDataSetFromNode(vtkGLTFDocumentLoader::Model& m, unsigned int nodeId,
   vtkSmartPointer<vtkMultiBlockDataSet> parentDataSet,
   vtkSmartPointer<vtkMultiBlockDataSet> nodeDataset, std::string nodeName, bool applyDeformations)
@@ -555,13 +517,13 @@ bool BuildMultiBlockDataSetFromNode(vtkGLTFDocumentLoader::Model& m, unsigned in
   int blockId = 0;
   if (node.Mesh >= 0)
   {
-    std::vector<vtkSmartPointer<vtkTransform> > jointMats;
+    std::vector<vtkSmartPointer<vtkMatrix4x4>> jointMats;
 
     if (node.Skin >= 0)
     {
       // Compute skinning matrices
       const vtkGLTFDocumentLoader::Skin& skin = m.Skins[node.Skin];
-      ComputeJointMatrices(m, skin, node, jointMats);
+      vtkGLTFDocumentLoader::ComputeJointMatrices(m, skin, node, jointMats);
     }
 
     std::vector<float>* morphingWeights = nullptr;
@@ -611,7 +573,7 @@ bool BuildMultiBlockDataSetFromNode(vtkGLTFDocumentLoader::Model& m, unsigned in
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool BuildMultiBlockDataSetFromScene(vtkGLTFDocumentLoader::Model& m, vtkIdType sceneId,
   vtkSmartPointer<vtkMultiBlockDataSet> dataSet, bool applyDeformations)
 {
@@ -647,22 +609,22 @@ bool BuildMultiBlockDataSetFromScene(vtkGLTFDocumentLoader::Model& m, vtkIdType
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkGLTFReader);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGLTFReader::vtkGLTFReader()
 {
   this->SetNumberOfInputPorts(0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGLTFReader::~vtkGLTFReader()
 {
   this->SetFileName(nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -674,7 +636,7 @@ void vtkGLTFReader::PrintSelf(ostream& os, vtkIndent indent)
      << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::StoreTextureData()
 {
   if (!this->Textures.empty())
@@ -690,7 +652,7 @@ void vtkGLTFReader::StoreTextureData()
   int nbSamplers = static_cast<int>(model->Samplers.size());
 
   this->Textures.reserve(this->Loader->GetInternalModel()->Textures.size());
-  for (auto loaderTexture : this->Loader->GetInternalModel()->Textures)
+  for (const auto& loaderTexture : this->Loader->GetInternalModel()->Textures)
   {
     vtkGLTFReader::GLTFTexture readerTexture;
     if (loaderTexture.Source >= 0 && loaderTexture.Source < nbTextures)
@@ -714,7 +676,7 @@ void vtkGLTFReader::StoreTextureData()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGLTFReader::RequestInformation(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -731,9 +693,9 @@ int vtkGLTFReader::RequestInformation(
     return 0;
   }
 
-  std::string fileNameAsString (this->FileName);
+  std::string fileNameAsString(this->FileName);
 
-  if(fileNameAsString.find('\\') != std::string::npos)
+  if (fileNameAsString.find('\\') != std::string::npos)
   {
     vtksys::SystemTools::ConvertToUnixSlashes(fileNameAsString);
   }
@@ -743,7 +705,7 @@ int vtkGLTFReader::RequestInformation(
     fileNameAsString = vtksys::SystemTools::CollapseFullPath(fileNameAsString);
   }
 
-  if(this->FileName != fileNameAsString)
+  if (this->FileName != fileNameAsString)
   {
     this->SetFileName(fileNameAsString.c_str());
   }
@@ -765,6 +727,11 @@ int vtkGLTFReader::RequestInformation(
       vtkErrorMacro("Error loading model metadata from file " << this->FileName);
       return 0;
     }
+
+    vtkNew<vtkEventForwarderCommand> forwarder;
+    forwarder->SetTarget(this);
+    this->Loader->AddObserver(vtkCommand::ProgressEvent, forwarder);
+
     this->CreateAnimationSelection();
     this->CreateSceneNamesArray();
     this->SetCurrentScene(this->Loader->GetInternalModel()->DefaultScene);
@@ -828,7 +795,7 @@ int vtkGLTFReader::RequestInformation(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGLTFReader::RequestData(
   vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector)
 {
@@ -896,6 +863,7 @@ int vtkGLTFReader::RequestData(
         this->Loader->ResetAnimation(i);
       }
     }
+    this->Loader->BuildGlobalTransforms();
   }
 
   vtkIdType selectedScene = this->CurrentScene;
@@ -914,11 +882,11 @@ int vtkGLTFReader::RequestData(
   // Save current animations
   this->PreviousAnimationSelection->CopySelections(this->AnimationSelection);
 
-  output->ShallowCopy(this->OutputDataSet);
+  output->CompositeShallowCopy(this->OutputDataSet);
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::EnableAnimation(vtkIdType animationIndex)
 {
   if (this->AnimationSelection == nullptr)
@@ -936,7 +904,7 @@ void vtkGLTFReader::EnableAnimation(vtkIdType animationIndex)
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::DisableAnimation(vtkIdType animationIndex)
 {
   if (this->AnimationSelection == nullptr)
@@ -954,7 +922,7 @@ void vtkGLTFReader::DisableAnimation(vtkIdType animationIndex)
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkGLTFReader::IsAnimationEnabled(vtkIdType animationIndex)
 {
   if (this->AnimationSelection == nullptr)
@@ -971,7 +939,7 @@ bool vtkGLTFReader::IsAnimationEnabled(vtkIdType animationIndex)
   return this->AnimationSelection->ArrayIsEnabled(name) != 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string vtkGLTFReader::GetAnimationName(vtkIdType animationIndex)
 {
   if (this->Loader == nullptr || this->Loader->GetInternalModel() == nullptr)
@@ -988,7 +956,7 @@ std::string vtkGLTFReader::GetAnimationName(vtkIdType animationIndex)
   return this->Loader->GetInternalModel()->Animations[animationIndex].Name;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 float vtkGLTFReader::GetAnimationDuration(vtkIdType animationIndex)
 {
   if (this->Loader == nullptr || this->Loader->GetInternalModel() == nullptr)
@@ -1005,7 +973,7 @@ float vtkGLTFReader::GetAnimationDuration(vtkIdType animationIndex)
   return this->Loader->GetInternalModel()->Animations[animationIndex].Duration;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string vtkGLTFReader::GetSceneName(vtkIdType sceneIndex)
 {
   if (this->Loader == nullptr || this->Loader->GetInternalModel() == nullptr)
@@ -1022,13 +990,13 @@ std::string vtkGLTFReader::GetSceneName(vtkIdType sceneIndex)
   return this->Loader->GetInternalModel()->Scenes[sceneIndex].Name;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkGLTFReader::GetNumberOfTextures()
 {
   return static_cast<vtkIdType>(this->Textures.size());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGLTFReader::GLTFTexture vtkGLTFReader::GetGLTFTexture(vtkIdType textureIndex)
 {
   if (textureIndex < 0 || textureIndex >= static_cast<vtkIdType>(this->Textures.size()))
@@ -1039,7 +1007,7 @@ vtkGLTFReader::GLTFTexture vtkGLTFReader::GetGLTFTexture(vtkIdType textureIndex)
   return this->Textures[textureIndex];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::SetScene(const std::string& scene)
 {
   if (this->SceneNames == nullptr)
@@ -1059,7 +1027,7 @@ void vtkGLTFReader::SetScene(const std::string& scene)
   vtkWarningMacro("Scene '" << scene << "' does not exist.");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::CreateSceneNamesArray()
 {
   if (this->Loader == nullptr || this->Loader->GetInternalModel() == nullptr)
@@ -1078,7 +1046,7 @@ void vtkGLTFReader::CreateSceneNamesArray()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStringArray* vtkGLTFReader::GetAllSceneNames()
 {
   if (this->Loader == nullptr || this->Loader->GetInternalModel() == nullptr)
@@ -1089,13 +1057,13 @@ vtkStringArray* vtkGLTFReader::GetAllSceneNames()
   return this->SceneNames;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArraySelection* vtkGLTFReader::GetAnimationSelection()
 {
   return this->AnimationSelection;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::CreateAnimationSelection()
 {
   if (this->Loader == nullptr || this->Loader->GetInternalModel() == nullptr)
@@ -1115,7 +1083,7 @@ void vtkGLTFReader::CreateAnimationSelection()
   this->AnimationSelection->AddObserver(vtkCommand::ModifiedEvent, this, &vtkGLTFReader::Modified);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFReader::SetApplyDeformationsToGeometry(bool flag)
 {
   if (this->ApplyDeformationsToGeometry != flag)
@@ -1125,3 +1093,4 @@ void vtkGLTFReader::SetApplyDeformationsToGeometry(bool flag)
   }
   this->ApplyDeformationsToGeometry = flag;
 }
+VTK_ABI_NAMESPACE_END
