@@ -16,7 +16,7 @@
 #include "vtkGLTFUtils.h"
 
 #include "vtkBase64Utilities.h"
-#include "vtk_jsoncpp.h"
+#include "vtksys/FStream.hxx"
 #include "vtksys/RegularExpression.hxx"
 #include "vtksys/SystemTools.hxx"
 
@@ -24,68 +24,76 @@
 #include <iostream>
 
 #define MIN_GLTF_VERSION "2.0"
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetBoolValue(const Json::Value& root, bool& value)
+namespace vtkGLTFUtils
 {
-  if (root.empty() || !root.isBool())
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
+bool GetBoolValue(const nlohmann::json& root, const std::string& key, bool& value)
+{
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_boolean())
   {
     return false;
   }
-  value = root.asBool();
+  value = it.value();
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetIntValue(const Json::Value& root, int& value)
+//------------------------------------------------------------------------------
+bool GetIntValue(const nlohmann::json& root, const std::string& key, int& value)
 {
-  if (root.empty() || !root.isInt())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_number_integer())
   {
     return false;
   }
-  value = root.asInt();
+  value = it.value();
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetUIntValue(const Json::Value& root, unsigned int& value)
+//------------------------------------------------------------------------------
+bool GetUIntValue(const nlohmann::json& root, const std::string& key, unsigned int& value)
 {
-  if (root.empty() || !root.isUInt())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_number_unsigned())
   {
     return false;
   }
-  value = root.asUInt();
+  value = it.value();
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetDoubleValue(const Json::Value& root, double& value)
+//------------------------------------------------------------------------------
+bool GetDoubleValue(const nlohmann::json& root, const std::string& key, double& value)
 {
-  if (root.empty() || !root.isDouble())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_number())
   {
     return false;
   }
-  value = root.asDouble();
+  value = it.value();
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetIntArray(const Json::Value& root, std::vector<int>& value)
+//------------------------------------------------------------------------------
+bool GetIntArray(const nlohmann::json& root, const std::string& key, std::vector<int>& value)
 {
-  if (root.empty() || !root.isArray())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_array())
   {
     return false;
   }
-  value.reserve(root.size());
-  for (const auto& intValue : root)
+  value.reserve(it.value().size());
+  for (const auto& intValue : it.value())
   {
-    if (intValue.empty() && !intValue.isInt())
+    if (intValue.empty() && !intValue.is_number_integer())
     {
       value.clear();
       return false;
     }
-    value.push_back(intValue.asInt());
+    value.push_back(intValue);
   }
-  if (value.size() == 0)
+  if (value.empty())
   {
     value.clear();
     return false;
@@ -93,24 +101,26 @@ bool vtkGLTFUtils::GetIntArray(const Json::Value& root, std::vector<int>& value)
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetUIntArray(const Json::Value& root, std::vector<unsigned int>& value)
+//------------------------------------------------------------------------------
+bool GetUIntArray(
+  const nlohmann::json& root, const std::string& key, std::vector<unsigned int>& value)
 {
-  if (root.empty() || !root.isArray())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_array())
   {
     return false;
   }
-  value.reserve(root.size());
-  for (const auto& uIntValue : root)
+  value.reserve(it.value().size());
+  for (const auto& uIntValue : it.value())
   {
-    if (uIntValue.empty() && !uIntValue.isUInt())
+    if (uIntValue.empty() && !uIntValue.is_number_unsigned())
     {
       value.clear();
       return false;
     }
-    value.push_back(uIntValue.asUInt());
+    value.push_back(uIntValue);
   }
-  if (value.size() == 0)
+  if (value.empty())
   {
     value.clear();
     return false;
@@ -118,24 +128,25 @@ bool vtkGLTFUtils::GetUIntArray(const Json::Value& root, std::vector<unsigned in
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetFloatArray(const Json::Value& root, std::vector<float>& value)
+//------------------------------------------------------------------------------
+bool GetFloatArray(const nlohmann::json& root, const std::string& key, std::vector<float>& value)
 {
-  if (root.empty() || !root.isArray())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_array())
   {
     return false;
   }
-  value.reserve(root.size());
-  for (const auto& floatValue : root)
+  value.reserve(it.value().size());
+  for (const auto& floatValue : it.value())
   {
-    if (floatValue.empty() && !floatValue.isDouble())
+    if (floatValue.empty() && !floatValue.is_number())
     {
       value.clear();
       return false;
     }
-    value.push_back(floatValue.asDouble());
+    value.push_back(floatValue);
   }
-  if (value.size() == 0)
+  if (value.empty())
   {
     value.clear();
     return false;
@@ -143,24 +154,25 @@ bool vtkGLTFUtils::GetFloatArray(const Json::Value& root, std::vector<float>& va
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetDoubleArray(const Json::Value& root, std::vector<double>& value)
+//------------------------------------------------------------------------------
+bool GetDoubleArray(const nlohmann::json& root, const std::string& key, std::vector<double>& value)
 {
-  if (root.empty() || !root.isArray())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_array())
   {
     return false;
   }
-  value.reserve(root.size());
-  for (const auto& doubleValue : root)
+  value.reserve(it.value().size());
+  for (const auto& doubleValue : it.value())
   {
-    if (doubleValue.empty() && !doubleValue.isDouble())
+    if (doubleValue.empty() && !doubleValue.is_number())
     {
       value.clear();
       return false;
     }
-    value.push_back(doubleValue.asDouble());
+    value.push_back(doubleValue);
   }
-  if (value.size() == 0)
+  if (value.empty())
   {
     value.clear();
     return false;
@@ -168,34 +180,34 @@ bool vtkGLTFUtils::GetDoubleArray(const Json::Value& root, std::vector<double>&
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetStringValue(const Json::Value& root, std::string& value)
+//------------------------------------------------------------------------------
+bool GetStringValue(const nlohmann::json& root, const std::string& key, std::string& value)
 {
-  if (root.empty() || !root.isString())
+  auto it = root.find(key);
+  if (it == root.end() || !it.value().is_string())
   {
     return false;
   }
-  value = root.asString();
+  value = it.value();
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::CheckVersion(const Json::Value& glTFAsset)
+//------------------------------------------------------------------------------
+bool CheckVersion(const nlohmann::json& glTFAsset)
 {
-  Json::Value assetMinVersion = glTFAsset["minVersion"];
-  Json::Value assetVersion = glTFAsset["version"];
+  auto assetMinVersionIt = glTFAsset.find("minVersion");
+  auto assetVersionIt = glTFAsset.find("version");
 
-  if (!assetMinVersion.empty())
+  if (assetMinVersionIt != glTFAsset.end())
   {
-    if (assetMinVersion != MIN_GLTF_VERSION)
+    if (assetMinVersionIt.value() != MIN_GLTF_VERSION)
     {
       return false;
     }
   }
-  else if (!assetVersion.empty())
+  else if (assetVersionIt != glTFAsset.end())
   {
-    std::string assetVersionStr = glTFAsset["version"].asString();
-    if (assetVersionStr != MIN_GLTF_VERSION)
+    if (assetVersionIt.value() != MIN_GLTF_VERSION)
     {
       return false;
     }
@@ -207,9 +219,8 @@ bool vtkGLTFUtils::CheckVersion(const Json::Value& glTFAsset)
   return true;
 }
 
-//----------------------------------------------------------------------------
-std::string vtkGLTFUtils::GetResourceFullPath(
-  const std::string& resourcePath, const std::string& glTFFilePath)
+//------------------------------------------------------------------------------
+std::string GetResourceFullPath(const std::string& resourcePath, const std::string& glTFFilePath)
 {
   // Check for relative path
   if (!vtksys::SystemTools::FileIsFullPath(resourcePath.c_str()))
@@ -221,8 +232,8 @@ std::string vtkGLTFUtils::GetResourceFullPath(
   return resourcePath;
 }
 
-//----------------------------------------------------------------------------
-std::string vtkGLTFUtils::GetDataUriMimeType(const std::string& uri)
+//------------------------------------------------------------------------------
+std::string GetDataUriMimeType(const std::string& uri)
 {
   vtksys::RegularExpression regex("^data:.*;");
   if (regex.find(uri))
@@ -235,8 +246,8 @@ std::string vtkGLTFUtils::GetDataUriMimeType(const std::string& uri)
   return std::string();
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::GetBinaryBufferFromUri(const std::string& uri, const std::string& glTFFilePath,
+//------------------------------------------------------------------------------
+bool GetBinaryBufferFromUri(const std::string& uri, const std::string& glTFFilePath,
   std::vector<char>& buffer, size_t bufferSize)
 {
   // Check for data-uri
@@ -253,12 +264,12 @@ bool vtkGLTFUtils::GetBinaryBufferFromUri(const std::string& uri, const std::str
   // Load buffer from file
   else
   {
-    ifstream fin;
+    vtksys::ifstream fin;
 
     std::string bufferPath = GetResourceFullPath(uri, glTFFilePath);
 
     // Open file
-    fin.open(bufferPath, ios::binary);
+    fin.open(bufferPath.c_str(), ios::binary);
     if (!fin.is_open())
     {
       return false;
@@ -278,12 +289,12 @@ bool vtkGLTFUtils::GetBinaryBufferFromUri(const std::string& uri, const std::str
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::ExtractGLBFileInformation(const std::string& fileName, std::string& magic,
-  uint32_t& version, uint32_t& fileLength, std::vector<vtkGLTFUtils::ChunkInfoType>& chunkInfo)
+//------------------------------------------------------------------------------
+bool ExtractGLBFileInformation(const std::string& fileName, std::string& magic, uint32_t& version,
+  uint32_t& fileLength, std::vector<vtkGLTFUtils::ChunkInfoType>& chunkInfo)
 {
-  std::ifstream fin;
-  fin.open(fileName, std::ios::binary | std::ios::in);
+  vtksys::ifstream fin;
+  fin.open(fileName.c_str(), std::ios::binary | std::ios::in);
   if (!fin.is_open())
   {
     return false;
@@ -316,15 +327,15 @@ bool vtkGLTFUtils::ExtractGLBFileInformation(const std::string& fileName, std::s
     char chunkTypeBuffer[vtkGLTFUtils::GLBWordSize];
     fin.read(chunkTypeBuffer, vtkGLTFUtils::GLBWordSize);
     std::string chunkType(chunkTypeBuffer, chunkTypeBuffer + vtkGLTFUtils::GLBWordSize);
-    chunkInfo.push_back(vtkGLTFUtils::ChunkInfoType(chunkType, chunkDataSize));
+    chunkInfo.emplace_back(chunkType, chunkDataSize);
     // Jump to next chunk
     fin.seekg(chunkDataSize, std::ios::cur);
   }
   return true;
 }
 
-//----------------------------------------------------------------------------
-bool vtkGLTFUtils::ValidateGLBFile(const std::string& magic, uint32_t version, uint32_t fileLength,
+//------------------------------------------------------------------------------
+bool ValidateGLBFile(const std::string& magic, uint32_t version, uint32_t fileLength,
   std::vector<vtkGLTFUtils::ChunkInfoType> chunkInfo)
 {
   // Check header
@@ -332,7 +343,7 @@ bool vtkGLTFUtils::ValidateGLBFile(const std::string& magic, uint32_t version, u
   {
     return false;
   }
-  if (chunkInfo.size() == 0)
+  if (chunkInfo.empty())
   {
     return false;
   }
@@ -354,3 +365,5 @@ bool vtkGLTFUtils::ValidateGLBFile(const std::string& magic, uint32_t version, u
   // Check for inconsistent chunk sizes
   return fileLength == lengthSum;
 }
+VTK_ABI_NAMESPACE_END
+}
