@@ -52,6 +52,7 @@
 
 #include <cctype> // for isspace(), isalnum()
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTecplotReader);
 
 // ============================================================================
@@ -87,7 +88,6 @@ FileStreamReader::FileStreamReader()
   , Eof(true)
   , Pos(BUFF_SIZE)
   , BuffEnd(BUFF_SIZE)
-  , FileName()
 {
 }
 
@@ -139,7 +139,7 @@ int FileStreamReader::get()
   {
     this->Pos = 0;
     // read the first buffer
-    this->BuffEnd = gzread(this->file, this->buff, this->BUFF_SIZE);
+    this->BuffEnd = gzread(this->file, this->buff, FileStreamReader::BUFF_SIZE);
     // assign EOF to what gzread returned
     this->Eof = (this->BuffEnd <= 0);
     if (this->Eof)
@@ -171,8 +171,8 @@ void FileStreamReader::close()
   {
     this->Open = false;
     this->Eof = false;
-    this->Pos = this->BUFF_SIZE;
-    this->BuffEnd = this->BUFF_SIZE;
+    this->Pos = FileStreamReader::BUFF_SIZE;
+    this->BuffEnd = FileStreamReader::BUFF_SIZE;
     this->FileName = std::string();
 
     gzclose(this->file);
@@ -207,7 +207,6 @@ public:
   FileStreamReader ASCIIStream;
   std::string TokenBackup;
 
-public:
   void Init()
   {
     this->Completed = 0;
@@ -620,7 +619,7 @@ int vtkTecplotReader::IsDataAttributeCellBased(const char* attrName)
   {
     for (unsigned int i = 0; i < this->Variables.size(); i++)
     {
-      if (strcmp(this->Variables[i].c_str(), attrName) == 0)
+      if (this->Variables[i] == attrName)
       {
         varIndex = i;
         break;
@@ -958,7 +957,8 @@ void vtkTecplotReader::GetStructuredGridFromBlockPackingZone(int iDimSize, int j
   pntCords = nullptr;
 
   if ((this->Internal->TopologyDim == 2 || this->Internal->TopologyDim == 3) ||
-    (this->Internal->TopologyDim == 0 && this->Internal->GeometryDim > 1))
+    ((this->Internal->TopologyDim == 0 || this->Internal->TopologyDim == 1) &&
+      this->Internal->GeometryDim > 1))
   {
     multZone->SetBlock(zoneIndx, strcGrid);
     multZone->GetMetaData(zoneIndx)->Set(vtkCompositeDataSet::NAME(), zoneName);
@@ -2062,7 +2062,7 @@ void vtkTecplotReader::ReadFile(vtkMultiBlockDataSet* multZone)
         else
         {
           // UNKNOWN FORMAT
-          vtkErrorMacro(<< this->FileName << ": The format " << format.c_str()
+          vtkErrorMacro(<< this->FileName << ": The format " << format
                         << " found in the file is unknown.");
           return;
         }
@@ -2153,8 +2153,7 @@ void vtkTecplotReader::ReadFile(vtkMultiBlockDataSet* multZone)
               if (pos != std::string::npos)
               {
                 exprDef.replace(pos, 1, "}");
-                vtkDebugMacro(
-                  "Expr name = " << exprName.c_str() << ", Expr def = " << exprDef.c_str());
+                vtkDebugMacro("Expr name = " << exprName << ", Expr def = " << exprDef);
               }
             }
           }
@@ -2175,7 +2174,7 @@ void vtkTecplotReader::ReadFile(vtkMultiBlockDataSet* multZone)
     else
     {
       // UNKNOWN RECORD TYPE
-      vtkErrorMacro(<< this->FileName << ": The record type " << tok.c_str()
+      vtkErrorMacro(<< this->FileName << ": The record type " << tok
                     << " found in the file is unknown.");
       return;
     }
@@ -2195,3 +2194,4 @@ void vtkTecplotReader::ReadFile(vtkMultiBlockDataSet* multZone)
 
   this->Internal->Completed = 1;
 }
+VTK_ABI_NAMESPACE_END
