@@ -62,18 +62,9 @@
 #include <vtksys/RegularExpression.hxx>
 #include <vtksys/SystemTools.hxx>
 //
-#include "vtkCharArray.h"
-#include "vtkDoubleArray.h"
-#include "vtkFloatArray.h"
-#include "vtkIntArray.h"
-#include "vtkLongArray.h"
-#include "vtkShortArray.h"
 #include "vtkSmartPointer.h"
-#include "vtkUnsignedCharArray.h"
-#include "vtkUnsignedShortArray.h"
 
 #include <algorithm>
-#include <functional>
 
 #include "vtk_h5part.h"
 // clang-format off
@@ -92,6 +83,7 @@
 
   \return  \c an hdf5 handle to the native type of the data
 */
+VTK_ABI_NAMESPACE_BEGIN
 static hid_t H5PartGetNativeDatasetType(H5PartFile* f, const char* name)
 {
   hid_t dataset, datatype, datatypen;
@@ -200,7 +192,7 @@ vtkH5PartReader::~vtkH5PartReader()
   this->Zarray = nullptr;
 
   this->PointDataArraySelection->Delete();
-  this->PointDataArraySelection = 0;
+  this->PointDataArraySelection = nullptr;
 }
 
 //------------------------------------------------------------------------------
@@ -369,7 +361,7 @@ int vtkH5PartReader::RequestInformation(vtkInformation* vtkNotUsed(request),
         this->TimeStepValues[i] = i;
       }
     }
-    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &this->TimeStepValues[0],
+    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), this->TimeStepValues.data(),
       static_cast<int>(this->TimeStepValues.size()));
     double timeRange[2];
     timeRange[0] = this->TimeStepValues.front();
@@ -480,17 +472,13 @@ int GetVTKDataType(hid_t datatype)
     H5Dclose(dataset);                                                                             \
   }
 
-class H5PartToleranceCheck : public std::binary_function<double, double, bool>
+class H5PartToleranceCheck
 {
 public:
   H5PartToleranceCheck(double tol) { this->tolerance = tol; }
   double tolerance;
   //
-  result_type operator()(first_argument_type a, second_argument_type b) const
-  {
-    bool result = (fabs(a - b) <= (this->tolerance));
-    return (result_type)result;
-  }
+  bool operator()(double a, double b) const { return (fabs(a - b) <= (this->tolerance)); }
 };
 //------------------------------------------------------------------------------
 int vtkH5PartReader::RequestData(vtkInformation* vtkNotUsed(request),
@@ -605,9 +593,11 @@ int vtkH5PartReader::RequestData(vtkInformation* vtkNotUsed(request),
   if (outInfo->Has(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP()))
   {
     double requestedTimeValue = outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP());
-    this->ActualTimeStep =
-      std::find_if(this->TimeStepValues.begin(), this->TimeStepValues.end(),
-        std::bind2nd(H5PartToleranceCheck(this->TimeStepTolerance), requestedTimeValue)) -
+    auto toleranceCheck = H5PartToleranceCheck(this->TimeStepTolerance);
+    this->ActualTimeStep = std::find_if(this->TimeStepValues.begin(), this->TimeStepValues.end(),
+                             [&toleranceCheck, &requestedTimeValue](double timeStepValue) {
+                               return toleranceCheck(timeStepValue, requestedTimeValue);
+                             }) -
       this->TimeStepValues.begin();
     //
     if (requestedTimeValue < this->TimeStepValues.front() ||
@@ -853,3 +843,4 @@ void vtkH5PartReader::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "NumberOfSteps: " << this->NumberOfTimeSteps << "\n";
 }
+VTK_ABI_NAMESPACE_END
