@@ -53,9 +53,14 @@
 #include <cassert>
 #include <set>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
+class vtkDataSet;
+VTK_ABI_NAMESPACE_END
+
 namespace vtkIOSSUtilities
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 enum DatabaseFormatType
 {
@@ -101,6 +106,27 @@ private:
   CacheInternals* Internals;
 };
 
+/**
+ * A helper to instantiate on stack to temporarily redirect non-critical messages
+ * emanating from IOSS. See paraview/paraview#21193
+ */
+class CaptureNonErrorMessages
+{
+public:
+  CaptureNonErrorMessages();
+  ~CaptureNonErrorMessages();
+
+  /**
+   * Provides access to the accumulated messages.
+   */
+  std::string GetMessages() const;
+
+private:
+  std::ostringstream Stream;
+  std::ostream* DebugStream;
+  std::ostream* WarningStream;
+};
+
 using EntityNameType = std::pair<vtkTypeUInt64, std::string>;
 
 /**
@@ -194,6 +220,15 @@ vtkSmartPointer<vtkDataArray> GetData(const Ioss::GroupingEntity* entity,
  */
 int GetCellType(const Ioss::ElementTopology* topology);
 
+/**
+ * Returns an Ioss topology element, if possible, given a VTK cell type.
+ *
+ * This is inverse of GetCellType.
+ *
+ * Throws `std::runtime_error` for unknown and unsupported element types.
+ */
+const Ioss::ElementTopology* GetElementTopology(int vtk_cell_type);
+
 /**
  * Read connectivity information from the group_entity.
  *
@@ -223,10 +258,13 @@ vtkSmartPointer<vtkPoints> GetMeshModelCoordinates(
  */
 bool IsFieldTransient(Ioss::GroupingEntity* entity, const std::string& fieldname);
 
+///@{
 /**
  * Finds a displacement field name. Returns empty string if none can be found.
  */
 std::string GetDisplacementFieldName(Ioss::GroupingEntity* nodeblock);
+std::string GetDisplacementFieldName(vtkDataSet* dataset);
+///@}
 
 /**
  * Must be called before using any Ioss library functions. Necessary to
@@ -255,7 +293,9 @@ DatabaseFormatType GetFormat(const Ioss::GroupingEntity* entity);
  */
 std::vector<Ioss::StructuredBlock*> GetMatchingStructuredBlocks(
   Ioss::Region* region, const std::string& blockname);
-};
+
+VTK_ABI_NAMESPACE_END
+}
 
 #endif
 // VTK-HeaderTest-Exclude: vtkIOSSUtilities.h
