@@ -23,12 +23,14 @@
 
 #include <vtksys/SystemTools.hxx>
 
+#include <cmath>
 #include <string>
 #include <vector>
 
 #include "DICOMAppHelper.h"
 #include "DICOMParser.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkDICOMImageReader);
 
 class vtkDICOMImageReaderVector : public std::vector<std::string>
@@ -166,12 +168,12 @@ void vtkDICOMImageReader::ExecuteInformation()
 
       if (val == 1)
       {
-        vtkDebugMacro(<< "Adding " << fileString.c_str() << " to DICOMFileNames.");
+        vtkDebugMacro(<< "Adding " << fileString << " to DICOMFileNames.");
         this->DICOMFileNames->push_back(fileString);
       }
       else
       {
-        vtkDebugMacro(<< fileString.c_str() << " - DICOMParser CanReadFile returned : " << val);
+        vtkDebugMacro(<< fileString << " - DICOMParser CanReadFile returned : " << val);
       }
     }
     std::vector<std::string>::iterator iter;
@@ -212,9 +214,8 @@ void vtkDICOMImageReader::ExecuteInformation()
       std::vector<std::pair<float, std::string>>::iterator siter;
       for (siter = sortedFiles.begin(); siter != sortedFiles.end(); ++siter)
       {
-        vtkDebugMacro(<< "Sorted filename : " << (*siter).second.c_str());
-        vtkDebugMacro(<< "Adding file " << (*siter).second.c_str()
-                      << " at slice : " << (*siter).first);
+        vtkDebugMacro(<< "Sorted filename : " << (*siter).second);
+        vtkDebugMacro(<< "Adding file " << (*siter).second << " at slice : " << (*siter).first);
         this->DICOMFileNames->push_back((*siter).second);
       }
     }
@@ -344,11 +345,7 @@ void vtkDICOMImageReader::ExecuteDataWithInformation(vtkDataObject* output, vtkI
       buffer = ((char*)buffer) + imageDataLengthInBytes;
 
       this->UpdateProgress(float(count) / float(numFiles));
-      int len = static_cast<int>(strlen((const char*)(*fiter).c_str()));
-      char* filename = new char[len + 1];
-      strcpy(filename, (const char*)(*fiter).c_str());
-      this->SetProgressText(filename);
-      delete[] filename;
+      this->SetProgressText(fiter->c_str());
     }
   }
 }
@@ -578,3 +575,4 @@ const char* vtkDICOMImageReader::GetDICOMFileName(int index)
   }
   return nullptr;
 }
+VTK_ABI_NAMESPACE_END
