@@ -35,6 +35,7 @@
 #include "vtkIOImageModule.h" // For export macro
 #include "vtkMedicalImageReader2.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOIMAGE_EXPORT vtkGESignaReader : public vtkMedicalImageReader2
 {
 public:
@@ -45,7 +46,7 @@ public:
   /**
    * Is the given file a GESigna file?
    */
-  int CanReadFile(const char* fname) override;
+  int CanReadFile(VTK_FILEPATH const char* fname) override;
 
   /**
    * Valid extentsions
@@ -68,4 +69,5 @@ private:
   vtkGESignaReader(const vtkGESignaReader&) = delete;
   void operator=(const vtkGESignaReader&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 #endif
