@@ -21,10 +21,12 @@
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
+#include "vtksys/FStream.hxx"
 #include "vtksys/SystemTools.hxx"
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHDRReader);
 
 #define HDR_DATA_SIZE 3
@@ -110,7 +112,7 @@ void vtkHDRReader::ExecuteInformation()
 int vtkHDRReader::CanReadFile(const char* fname)
 {
   // get the magic number by reading in a file
-  std::ifstream ifs(fname, std::ifstream::in);
+  vtksys::ifstream ifs(fname, vtksys::ifstream::in);
 
   if (ifs.fail())
   {
@@ -213,7 +215,7 @@ void vtkHDRReader::ConvertAllDataFromRGBToXYZ(float* outPtr, int size)
 {
   for (int i = 0; i < size; i += HDR_DATA_SIZE)
   {
-    this->XYZ2RGB(matrixXYZ2RGB, outPtr[i], outPtr[i + 1], outPtr[i + 2]);
+    vtkHDRReader::XYZ2RGB(matrixXYZ2RGB, outPtr[i], outPtr[i + 1], outPtr[i + 2]);
   }
 }
 
@@ -656,3 +658,4 @@ void vtkHDRReader::XYZ2RGB(const float convertMatrix[3][3], float& r, float& g,
   g = convertMatrix[1][0] * x + convertMatrix[1][1] * y + convertMatrix[1][2] * z;
   b = convertMatrix[2][0] * x + convertMatrix[2][1] * y + convertMatrix[2][2] * z;
 }
+VTK_ABI_NAMESPACE_END
