@@ -24,8 +24,15 @@
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageImportExecutive);
 
+//------------------------------------------------------------------------------
+void vtkImageImportExecutive::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 vtkTypeBool vtkImageImportExecutive::ProcessRequest(
   vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
@@ -39,3 +46,4 @@ vtkTypeBool vtkImageImportExecutive::ProcessRequest(
 
   return this->Superclass::ProcessRequest(request, inInfoVec, outInfoVec);
 }
+VTK_ABI_NAMESPACE_END
