@@ -29,6 +29,7 @@
 #include <vtksys/FStream.hxx>
 #include <vtksys/SystemTools.hxx>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkJSONImageWriter);
 
 //------------------------------------------------------------------------------
@@ -44,6 +45,7 @@ vtkJSONImageWriter::vtkJSONImageWriter()
 vtkJSONImageWriter::~vtkJSONImageWriter()
 {
   this->SetFileName(nullptr);
+  this->SetArrayName(nullptr);
 }
 
 //------------------------------------------------------------------------------
@@ -158,3 +160,4 @@ void vtkJSONImageWriter::Write()
   this->Modified();
   this->UpdateWholeExtent();
 }
+VTK_ABI_NAMESPACE_END
