@@ -26,6 +26,7 @@
 #include "vtkIOImageModule.h" // For export macro
 #include "vtkImageAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOIMAGE_EXPORT vtkJSONImageWriter : public vtkImageAlgorithm
 {
 public:
@@ -33,29 +34,29 @@ public:
   vtkTypeMacro(vtkJSONImageWriter, vtkImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify file name for the image file.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify ArrayName to export. By default nullptr which will dump ALL arrays.
    */
   vtkSetStringMacro(ArrayName);
   vtkGetStringMacro(ArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify Slice in Z to export. By default -1 which will dump the full 3D domain.
    */
   vtkSetMacro(Slice, int);
   vtkGetMacro(Slice, int);
-  //@}
+  ///@}
 
   /**
    * The main interface which triggers the writer to start.
@@ -78,4 +79,5 @@ private:
   void operator=(const vtkJSONImageWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
