@@ -34,11 +34,13 @@
 #include "vtkmetaio/metaObject.h"
 #include "vtkmetaio/metaTypes.h"
 #include "vtkmetaio/metaUtils.h"
+#include <cmath>
 #include <string>
 
 #include <sys/stat.h>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMetaImageReader);
 
 //------------------------------------------------------------------------------
@@ -379,3 +381,4 @@ void vtkMetaImageReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "DistanceUnits: " << this->DistanceUnits << endl;
   os << indent << "AnatomicalOrientation: " << this->AnatomicalOrientation << endl;
 }
+VTK_ABI_NAMESPACE_END
