@@ -42,6 +42,7 @@
 
 #include "vtkTIFFReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOIMAGE_EXPORT vtkOMETIFFReader : public vtkTIFFReader
 {
 public:
@@ -49,11 +50,11 @@ public:
   vtkTypeMacro(vtkOMETIFFReader, vtkTIFFReader);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
-  int CanReadFile(const char* fname) override;
+  ///@{
+  int CanReadFile(VTK_FILEPATH const char* fname) override;
   const char* GetFileExtensions() override { return ".ome.tif .ome.tiff"; }
   const char* GetDescriptiveName() override { return "OME TIFF"; }
-  //@}
+  ///@}
 
 protected:
   vtkOMETIFFReader();
@@ -72,4 +73,5 @@ private:
   vtkOMEInternals* OMEInternals;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
