@@ -15,6 +15,7 @@
 #include "vtkPNGReader.h"
 
 #include "vtkDataArray.h"
+#include "vtkEndian.h"
 #include "vtkImageData.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
@@ -24,76 +25,74 @@
 #include <algorithm>
 #include <vector>
 
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPNGReader);
 
 #ifdef _MSC_VER
 // Let us get rid of this funny warning on /W4:
 // warning C4611: interaction between '_setjmp' and C++ object
 // destruction is non-portable
-#pragma warning( disable : 4611 )
+#pragma warning(disable : 4611)
 #endif
 
 namespace
 {
-  class CompareFirst
+class CompareFirst
+{
+public:
+  bool operator()(const std::pair<std::string, std::string>& left,
+    const std::pair<std::string, std::string>& right)
   {
-  public:
-    bool operator() (const std::pair<std::string,std::string>& left,
-                     const std::pair<std::string,std::string>& right)
-    {
-      return left.first < right.first;
-    }
-
-  };
-
-  /**
-   * When reading an image from memory, libpng needs to be passed a pointer to a custom
-   * read callback function, as well as a pointer to its input data.
-   * This callback function has to behave like fread(), so we use a custom stream object as input.
-   */
-  struct MemoryBufferStream
-  {
-    const unsigned char* buffer = nullptr;
-    size_t len = 0;
-    size_t position = 0;
-  };
-
-  // To be used by libpng instead of fread when reading data from memory.
-  void PNGReadCallback(png_structp pngPtr, png_bytep output, png_size_t length)
-  {
-    if (output == nullptr)
-    {
-      png_error(pngPtr, "Invalid output buffer");
-    }
-    // Get pointer to input buffer
-    png_voidp inputVoidP = png_get_io_ptr(pngPtr);
-    if (inputVoidP == nullptr)
-    {
-      png_error(pngPtr, "Invalid input stream");
-    }
-    // Cast it to MemoryBufferStream
-    MemoryBufferStream* input = static_cast<MemoryBufferStream*>(inputVoidP);
-    // Check for overflow
-    if (input->position + length > input->len)
-    {
-      png_error(pngPtr, "Attempt to read out of buffer");
-    }
-    // Copy it
-    auto begin = input->buffer + input->position;
-    auto end = begin + length;
-    std::copy(begin, end, output);
-    // Advance cursor
-    input->position += length;
+    return left.first < right.first;
   }
 };
 
+/**
+ * When reading an image from memory, libpng needs to be passed a pointer to a custom
+ * read callback function, as well as a pointer to its input data.
+ * This callback function has to behave like fread(), so we use a custom stream object as input.
+ */
+struct MemoryBufferStream
+{
+  const unsigned char* buffer = nullptr;
+  size_t len = 0;
+  size_t position = 0;
+};
+
+// To be used by libpng instead of fread when reading data from memory.
+void PNGReadCallback(png_structp pngPtr, png_bytep output, png_size_t length)
+{
+  if (output == nullptr)
+  {
+    png_error(pngPtr, "Invalid output buffer");
+  }
+  // Get pointer to input buffer
+  png_voidp inputVoidP = png_get_io_ptr(pngPtr);
+  if (inputVoidP == nullptr)
+  {
+    png_error(pngPtr, "Invalid input stream");
+  }
+  // Cast it to MemoryBufferStream
+  MemoryBufferStream* input = static_cast<MemoryBufferStream*>(inputVoidP);
+  // Check for overflow
+  if (input->position + length > input->len)
+  {
+    png_error(pngPtr, "Attempt to read out of buffer");
+  }
+  // Copy it
+  auto begin = input->buffer + input->position;
+  auto end = begin + length;
+  std::copy(begin, end, output);
+  // Advance cursor
+  input->position += length;
+}
+};
+
 class vtkPNGReader::vtkInternals
 {
 public:
-  std::vector<std::pair<std::string, std::string> > TextKeyValue;
-  typedef std::vector<std::pair<std::string, std::string> >::iterator
-  TextKeyValueIterator;
+  std::vector<std::pair<std::string, std::string>> TextKeyValue;
+  typedef std::vector<std::pair<std::string, std::string>>::iterator TextKeyValueIterator;
   void ReadTextChunks(png_structp png_ptr, png_infop info_ptr)
   {
     png_textp text_ptr;
@@ -103,27 +102,24 @@ public:
     for (int i = 0; i < num_text; ++i)
     {
       if (
-        // we don't deal with compressed text yet
-        text_ptr[i].compression != PNG_TEXT_COMPRESSION_NONE ||
+        // we only deal with uncompressed text or text with zTXt compression
+        (text_ptr[i].compression != PNG_TEXT_COMPRESSION_NONE &&
+          text_ptr[i].compression != PNG_TEXT_COMPRESSION_zTXt) ||
         // we don't deal with international text yet
-        text_ptr[i].text_length == 0
-          )
+        text_ptr[i].text_length == 0)
       {
         continue;
       }
-      this->TextKeyValue.push_back(std::pair<std::string, std::string>(
-                                     text_ptr[i].key, text_ptr[i].text));
+      this->TextKeyValue.emplace_back(text_ptr[i].key, text_ptr[i].text);
     }
-    std::sort(this->TextKeyValue.begin(), this->TextKeyValue.end(),
-              CompareFirst());
+    std::sort(this->TextKeyValue.begin(), this->TextKeyValue.end(), CompareFirst());
   }
 
   void GetTextChunks(const char* key, int beginEndIndex[2])
   {
     std::pair<TextKeyValueIterator, TextKeyValueIterator> it =
       std::equal_range(this->TextKeyValue.begin(), this->TextKeyValue.end(),
-                       std::pair<std::string,std::string>(key,std::string()),
-                       CompareFirst());
+        std::pair<std::string, std::string>(key, std::string()), CompareFirst());
     beginEndIndex[0] = it.first - this->TextKeyValue.begin();
     beginEndIndex[1] = it.second - this->TextKeyValue.begin();
   }
@@ -168,7 +164,7 @@ public:
 
   bool CreateLibPngStructs(png_structp& pngPtr, png_infop& infoPtr, png_infop& endInfo)
   {
-    pngPtr = png_create_read_struct(PNG_LIBPNG_VER_STRING, (png_voidp)nullptr, nullptr, nullptr);
+    pngPtr = png_create_read_struct(PNG_LIBPNG_VER_STRING, (png_voidp) nullptr, nullptr, nullptr);
     if (!pngPtr)
     {
       vtkErrorWithObjectMacro(nullptr, "Out of memory.");
@@ -177,14 +173,14 @@ public:
     infoPtr = png_create_info_struct(pngPtr);
     if (!infoPtr)
     {
-      png_destroy_read_struct(&pngPtr, (png_infopp)nullptr, (png_infopp)nullptr);
+      png_destroy_read_struct(&pngPtr, (png_infopp) nullptr, (png_infopp) nullptr);
       vtkErrorWithObjectMacro(nullptr, "Out of memory.");
       return false;
     }
     endInfo = png_create_info_struct(pngPtr);
     if (!endInfo)
     {
-      png_destroy_read_struct(&pngPtr, &infoPtr, (png_infopp)nullptr);
+      png_destroy_read_struct(&pngPtr, &infoPtr, (png_infopp) nullptr);
       vtkErrorWithObjectMacro(nullptr, "Unable to read PNG file!");
       return false;
     }
@@ -216,7 +212,7 @@ public:
   {
     if (setjmp(png_jmpbuf(pngPtr)))
     {
-      png_destroy_read_struct(&pngPtr, &infoPtr, (png_infopp)nullptr);
+      png_destroy_read_struct(&pngPtr, &infoPtr, (png_infopp) nullptr);
       if (fp)
       {
         fclose(fp);
@@ -225,20 +221,20 @@ public:
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPNGReader::vtkPNGReader()
 {
   this->Internals = new vtkInternals();
   this->ReadSpacingFromFile = false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPNGReader::~vtkPNGReader()
 {
   delete this->Internals;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPNGReader::ExecuteInformation()
 {
   vtkInternals* impl = this->Internals;
@@ -248,8 +244,7 @@ void vtkPNGReader::ExecuteInformation()
   if (this->GetMemoryBuffer())
   {
     // Read the header from MemoryBuffer
-    const unsigned char* memBuffer =
-      static_cast<const unsigned char*>(this->GetMemoryBuffer());
+    const unsigned char* memBuffer = static_cast<const unsigned char*>(this->GetMemoryBuffer());
     if (!impl->CheckBufferHeader(memBuffer, this->GetMemoryBufferLength()))
     {
       vtkErrorMacro("Invalid MemoryBuffer header: not a PNG file");
@@ -300,10 +295,8 @@ void vtkPNGReader::ExecuteInformation()
   int bit_depth, color_type, interlace_type;
   int compression_type, filter_method;
   // get size and bit-depth of the PNG-image
-  png_get_IHDR(png_ptr, info_ptr,
-               &width, &height,
-               &bit_depth, &color_type, &interlace_type,
-               &compression_type, &filter_method);
+  png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, &interlace_type,
+    &compression_type, &filter_method);
 
   impl->ReadTextChunks(png_ptr, info_ptr);
 
@@ -338,14 +331,14 @@ void vtkPNGReader::ExecuteInformation()
   this->DataExtent[2] = 0;
   this->DataExtent[3] = height - 1;
 
-  if(ReadSpacingFromFile)
+  if (ReadSpacingFromFile)
   {
     png_uint_32 x_pixels_per_meter, y_pixels_per_meter;
     x_pixels_per_meter = png_get_x_pixels_per_meter(png_ptr, info_ptr);
     y_pixels_per_meter = png_get_y_pixels_per_meter(png_ptr, info_ptr);
     if (x_pixels_per_meter > 0 && y_pixels_per_meter > 0)
     {
-      this->SetDataSpacing(1000.0/x_pixels_per_meter, 1000.0/y_pixels_per_meter, 1);
+      this->SetDataSpacing(1000.0 / x_pixels_per_meter, 1000.0 / y_pixels_per_meter, 1);
     }
   }
 
@@ -357,22 +350,20 @@ void vtkPNGReader::ExecuteInformation()
   {
     this->SetDataScalarTypeToUnsignedShort();
   }
-  this->SetNumberOfScalarComponents(
-    png_get_channels(png_ptr, info_ptr));
+  this->SetNumberOfScalarComponents(png_get_channels(png_ptr, info_ptr));
   this->vtkImageReader2::ExecuteInformation();
 
   png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
   // close the file if necessary
-  if(fp)
+  if (fp)
   {
     fclose(fp);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class OT>
-void vtkPNGReader::vtkPNGReaderUpdate2(
-  OT *outPtr, int *outExt, vtkIdType *outInc, long pixSize)
+void vtkPNGReader::vtkPNGReaderUpdate2(OT* outPtr, int* outExt, vtkIdType* outInc, long pixSize)
 {
   vtkPNGReader::vtkInternals* impl = this->Internals;
   unsigned int ui;
@@ -383,8 +374,7 @@ void vtkPNGReader::vtkPNGReaderUpdate2(
   if (this->GetMemoryBuffer())
   {
     // Read the header from MemoryBuffer
-    const unsigned char* memBuffer =
-      static_cast<const unsigned char*>(this->GetMemoryBuffer());
+    const unsigned char* memBuffer = static_cast<const unsigned char*>(this->GetMemoryBuffer());
     if (!impl->CheckBufferHeader(memBuffer, this->GetMemoryBufferLength()))
     {
       vtkErrorMacro("Invalid MemoryBuffer header: not a PNG file");
@@ -429,10 +419,8 @@ void vtkPNGReader::vtkPNGReaderUpdate2(
   int bit_depth, color_type, interlace_type;
   int compression_type, filter_method;
   // get size and bit-depth of the PNG-image
-  png_get_IHDR(png_ptr, info_ptr,
-               &width, &height,
-               &bit_depth, &color_type, &interlace_type,
-               &compression_type, &filter_method);
+  png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth, &color_type, &interlace_type,
+    &compression_type, &filter_method);
 
   impl->ReadTextChunks(png_ptr, info_ptr);
 
@@ -467,55 +455,52 @@ void vtkPNGReader::vtkPNGReaderUpdate2(
   }
 
   // have libpng handle interlacing
-  //int number_of_passes = png_set_interlace_handling(png_ptr);
+  // int number_of_passes = png_set_interlace_handling(png_ptr);
   // update the info now that we have defined the filters
   png_read_update_info(png_ptr, info_ptr);
 
   size_t rowbytes = png_get_rowbytes(png_ptr, info_ptr);
-  unsigned char *tempImage = new unsigned char [rowbytes*height];
-  png_bytep *row_pointers = new png_bytep [height];
+  std::vector<unsigned char> tempImage(rowbytes * height);
+  std::vector<png_bytep> row_pointers(height);
   for (ui = 0; ui < height; ++ui)
   {
-    row_pointers[ui] = tempImage + rowbytes*ui;
+    row_pointers[ui] = tempImage.data() + rowbytes * ui;
   }
-  png_read_image(png_ptr, row_pointers);
+  png_read_image(png_ptr, row_pointers.data());
 
   // copy the data into the outPtr
-  OT *outPtr2;
+  OT* outPtr2;
   outPtr2 = outPtr;
-  long outSize = pixSize*(outExt[1] - outExt[0] + 1);
+  long outSize = pixSize * (outExt[1] - outExt[0] + 1);
   for (i = outExt[2]; i <= outExt[3]; ++i)
   {
-    memcpy(outPtr2,row_pointers[height - i - 1] + outExt[0]*pixSize,outSize);
+    memcpy(outPtr2, row_pointers[height - i - 1] + outExt[0] * pixSize, outSize);
     outPtr2 += outInc[1];
   }
-  delete [] tempImage;
-  delete [] row_pointers;
 
   png_read_end(png_ptr, nullptr);
   png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
   // close the file if necessary
-  if(fp)
+  if (fp)
   {
     fclose(fp);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This function reads in one data of data.
 // templated to handle different data types.
 template <class OT>
-void vtkPNGReader::vtkPNGReaderUpdate(
-  vtkImageData *data, OT *outPtr)
+void vtkPNGReader::vtkPNGReaderUpdate(vtkImageData* data, OT* outPtr)
 {
   vtkIdType outIncr[3];
   int outExtent[6];
-  OT *outPtr2;
+  OT* outPtr2;
 
   data->GetExtent(outExtent);
   data->GetIncrements(outIncr);
 
-  long pixSize = data->GetNumberOfScalarComponents()*sizeof(OT);
+  long pixSize = data->GetNumberOfScalarComponents() * sizeof(OT);
 
   outPtr2 = outPtr;
   int idx2;
@@ -524,19 +509,17 @@ void vtkPNGReader::vtkPNGReaderUpdate(
     this->ComputeInternalFileName(idx2);
     // read in a PNG file
     this->vtkPNGReaderUpdate2(outPtr2, outExtent, outIncr, pixSize);
-    this->UpdateProgress((idx2 - outExtent[4])/
-                         (outExtent[5] - outExtent[4] + 1.0));
+    this->UpdateProgress((idx2 - outExtent[4]) / (outExtent[5] - outExtent[4] + 1.0));
     outPtr2 += outIncr[2];
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This function reads a data from a file.  The datas extent/axes
 // are assumed to be the same as the file extent/order.
-void vtkPNGReader::ExecuteDataWithInformation(vtkDataObject *output,
-                                              vtkInformation *outInfo)
+void vtkPNGReader::ExecuteDataWithInformation(vtkDataObject* output, vtkInformation* outInfo)
 {
-  vtkImageData *data = this->AllocateOutputData(output, outInfo);
+  vtkImageData* data = this->AllocateOutputData(output, outInfo);
 
   if (!this->GetMemoryBuffer() && this->InternalFileName == nullptr)
   {
@@ -549,24 +532,23 @@ void vtkPNGReader::ExecuteDataWithInformation(vtkDataObject *output,
   this->ComputeDataIncrements();
 
   // Call the correct templated function for the output
-  void *outPtr;
+  void* outPtr;
 
   // Call the correct templated function for the input
   outPtr = data->GetScalarPointer();
   switch (data->GetScalarType())
   {
-    vtkTemplateMacro(this->vtkPNGReaderUpdate(data, (VTK_TT *)(outPtr)));
+    vtkTemplateMacro(this->vtkPNGReaderUpdate(data, (VTK_TT*)(outPtr)));
     default:
       vtkErrorMacro(<< "UpdateFromFile: Unknown data type");
   }
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPNGReader::CanReadFile(const char* fname)
 {
   FILE* fp = vtksys::SystemTools::Fopen(fname, "rb");
-  if(!fp)
+  if (!fp)
   {
     return 0;
   }
@@ -577,14 +559,13 @@ int vtkPNGReader::CanReadFile(const char* fname)
     return 0;
   }
   int is_png = !png_sig_cmp(header, 0, 8);
-  if(!is_png)
+  if (!is_png)
   {
     fclose(fp);
     return 0;
   }
-  png_structp png_ptr = png_create_read_struct
-    (PNG_LIBPNG_VER_STRING, (png_voidp)nullptr,
-     nullptr, nullptr);
+  png_structp png_ptr =
+    png_create_read_struct(PNG_LIBPNG_VER_STRING, (png_voidp) nullptr, nullptr, nullptr);
   if (!png_ptr)
   {
     fclose(fp);
@@ -594,8 +575,7 @@ int vtkPNGReader::CanReadFile(const char* fname)
   png_infop info_ptr = png_create_info_struct(png_ptr);
   if (!info_ptr)
   {
-    png_destroy_read_struct(&png_ptr,
-                            (png_infopp)nullptr, (png_infopp)nullptr);
+    png_destroy_read_struct(&png_ptr, (png_infopp) nullptr, (png_infopp) nullptr);
     fclose(fp);
     return 0;
   }
@@ -603,8 +583,7 @@ int vtkPNGReader::CanReadFile(const char* fname)
   png_infop end_info = png_create_info_struct(png_ptr);
   if (!end_info)
   {
-    png_destroy_read_struct(&png_ptr, &info_ptr,
-                            (png_infopp)nullptr);
+    png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) nullptr);
     fclose(fp);
     return 0;
   }
@@ -615,37 +594,38 @@ int vtkPNGReader::CanReadFile(const char* fname)
 }
 #ifdef _MSC_VER
 // Put the warning back
-#pragma warning( default : 4611 )
+#pragma warning(default : 4611)
 #endif
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPNGReader::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Read Spacing From File: " <<
-    (this->ReadSpacingFromFile ? "On\n" : "Off\n");
+  os << indent << "Read Spacing From File: " << (this->ReadSpacingFromFile ? "On\n" : "Off\n");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPNGReader::GetTextChunks(const char* key, int beginEndIndex[2])
 {
   this->Internals->GetTextChunks(key, beginEndIndex);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkPNGReader::GetTextKey(int index)
 {
   return this->Internals->TextKeyValue[index].first.c_str();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkPNGReader::GetTextValue(int index)
 {
   return this->Internals->TextKeyValue[index].second.c_str();
 }
 
+//------------------------------------------------------------------------------
 size_t vtkPNGReader::GetNumberOfTextChunks()
 {
   return this->Internals->TextKeyValue.size();
 }
+VTK_ABI_NAMESPACE_END
