@@ -19,18 +19,18 @@
 #ifndef vtkSEPReader_h
 #define vtkSEPReader_h
 
-#include <vtkIOImageModule.h>
+#include "vtkIOImageModule.h" // For export macro
 
-#include <vtkExtentTranslator.h>
-#include <vtkImageAlgorithm.h>
-#include <vtkNew.h>
+#include "vtkExtentTranslator.h" // for vtkExtentTranslator
+#include "vtkImageAlgorithm.h"
+#include "vtkNew.h" // for ivars
 
-#include <array>
-#include <memory>
-#include <string>
+#include <array>  // for std::array
+#include <string> // for std::string
 
 namespace details
 {
+VTK_ABI_NAMESPACE_BEGIN
 enum class EndiannessType : std::uint8_t
 {
   SEP_LITTLE_ENDIAN = 0,
@@ -38,8 +38,10 @@ enum class EndiannessType : std::uint8_t
 };
 
 static constexpr int SEP_READER_MAX_DIMENSION = 32u;
+VTK_ABI_NAMESPACE_END
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkStringArray;
 
 class VTKIOIMAGE_EXPORT vtkSEPReader : public vtkImageAlgorithm
@@ -69,8 +71,8 @@ public:
   vtkSetMacro(ExtentSplitMode, int);
   vtkGetMacro(ExtentSplitMode, int);
 
-  vtkGetMacro(DataOrigin, double*);
-  vtkGetMacro(DataSpacing, double*);
+  vtkGetMacro(DataOrigin, VTK_FUTURE_CONST double*);
+  vtkGetMacro(DataSpacing, VTK_FUTURE_CONST double*);
 
   /**
    * Array containing the name of all dimensions.
@@ -99,7 +101,7 @@ public:
   vtkSetMacro(FixedDimensionValue2, int);
   vtkGetVector2Macro(FixedDimRange, int);
 
-  bool CanReadFile(const char*);
+  bool CanReadFile(VTK_FILEPATH const char*);
 
   std::array<std::int32_t, 6> ComputeExtent() const;
 
@@ -164,4 +166,5 @@ private:
   void operator=(const vtkSEPReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkSEPReader_h
