@@ -26,6 +26,7 @@
 #include <cassert>
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 struct FlipTrue
@@ -319,14 +320,8 @@ bool vtkTIFFReader::vtkTIFFReaderInternal::Initialize()
     // set for this image, but that's a required field so we set a warning flag.
     // (Because the "Photometrics" field is an enum, we can't rely on setting
     // this->Photometrics to some signal value.)
-    if (TIFFGetField(this->Image, TIFFTAG_PHOTOMETRIC, &this->Photometrics))
-    {
-      this->HasValidPhotometricInterpretation = true;
-    }
-    else
-    {
-      this->HasValidPhotometricInterpretation = false;
-    }
+    this->HasValidPhotometricInterpretation =
+      TIFFGetField(this->Image, TIFFTAG_PHOTOMETRIC, &this->Photometrics) != 0;
     if (!TIFFGetField(this->Image, TIFFTAG_TILEDEPTH, &this->TileDepth))
     {
       this->TileDepth = 0;
@@ -867,8 +862,8 @@ void vtkTIFFReader::ReadTiles(void* buffer)
   const unsigned int tileWidth = this->InternalImage->TileWidth;
   const unsigned int tileHeight = this->InternalImage->TileHeight;
   const unsigned int pixelSize = this->InternalImage->SamplesPerPixel;
-  const bool rowMultiple = (height % tileHeight == 0) ? true : false;
-  const bool colMultiple = (width % tileWidth == 0) ? true : false;
+  const bool rowMultiple = height % tileHeight == 0;
+  const bool colMultiple = width % tileWidth == 0;
   const bool flip = this->InternalImage->Orientation != ORIENTATION_TOPLEFT;
 
   for (unsigned int slice = 0; slice < this->InternalImage->NumberOfPages; ++slice)
@@ -1247,18 +1242,18 @@ void vtkTIFFReader::ReadImageInternal(T* outPtr)
   if (!this->InternalImage->CanRead())
   {
     // Why do we read the image for the ! CanRead case?
-    uint32* tempImage = reinterpret_cast<uint32*>(outPtr);
+    uint32_t* tempImage = reinterpret_cast<uint32_t*>(outPtr);
 
     if (this->OutputExtent[0] != 0 || this->OutputExtent[1] != width - 1 ||
       this->OutputExtent[2] != 0 || this->OutputExtent[3] != height - 1)
     {
-      tempImage = new uint32[width * height];
+      tempImage = new uint32_t[width * height];
     }
     // This should really be fixed to read only the rows necessary.
     if (!TIFFReadRGBAImage(this->InternalImage->Image, width, height, tempImage, 0))
     {
       vtkErrorMacro("Problem reading RGB image");
-      if (tempImage != reinterpret_cast<uint32*>(outPtr))
+      if (tempImage != reinterpret_cast<uint32_t*>(outPtr))
       {
         delete[] tempImage;
       }
@@ -1268,7 +1263,7 @@ void vtkTIFFReader::ReadImageInternal(T* outPtr)
     T* fimage = outPtr;
     for (int yy = 0; yy < height; ++yy)
     {
-      uint32* ssimage = flip ? (tempImage + yy * width) : (tempImage + (height - yy - 1) * width);
+      uint32_t* ssimage = flip ? (tempImage + yy * width) : (tempImage + (height - yy - 1) * width);
       for (int xx = 0; xx < width; ++xx)
       {
         if (xx >= this->OutputExtent[0] && xx <= this->OutputExtent[1] &&
@@ -1284,7 +1279,7 @@ void vtkTIFFReader::ReadImageInternal(T* outPtr)
       }
     }
 
-    if (tempImage != reinterpret_cast<uint32*>(outPtr))
+    if (tempImage != reinterpret_cast<uint32_t*>(outPtr))
     {
       delete[] tempImage;
     }
@@ -1392,3 +1387,4 @@ void vtkTIFFReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "SpacingSpecifiedFlag: " << this->SpacingSpecifiedFlag << endl;
   os << indent << "IgnoreColorMap: " << this->IgnoreColorMap << endl;
 }
+VTK_ABI_NAMESPACE_END
