@@ -65,6 +65,7 @@
 #include <map>    // For map
 #include <vector> // For vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkCamera;
 class vtkGLTFDocumentLoader;
@@ -78,13 +79,13 @@ public:
   vtkTypeMacro(vtkGLTFImporter, vtkImporter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the name of the file to read.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
   /**
    * glTF defines multiple camera objects, but no default behavior for which camera should be
@@ -93,11 +94,6 @@ public:
    */
   vtkSmartPointer<vtkCamera> GetCamera(unsigned int id);
 
-  /**
-   * Get the total number of cameras
-   */
-  size_t GetNumberOfCameras();
-
   /**
    * Get a printable string describing all outputs
    */
@@ -118,17 +114,33 @@ public:
    */
   std::string GetAnimationName(vtkIdType animationIndex) override;
 
-  //@{
+  ///@{
   /**
    * Enable/Disable/Get the status of specific animations
    */
   void EnableAnimation(vtkIdType animationIndex) override;
   void DisableAnimation(vtkIdType animationIndex) override;
   bool IsAnimationEnabled(vtkIdType animationIndex) override;
-  //@}
+  ///@}
 
   /**
-   * Get temporal informations for the currently enabled animations.
+   * Get the number of available cameras.
+   */
+  vtkIdType GetNumberOfCameras() override;
+
+  /**
+   * Get the name of a camera.
+   */
+  std::string GetCameraName(vtkIdType camIndex) override;
+
+  /**
+   * Enable a specific camera.
+   * If a negative index is provided, no camera from the importer is used.
+   */
+  void SetCamera(vtkIdType camIndex) override;
+
+  /**
+   * Get temporal information for the currently enabled animations.
    * frameRate is used to define the number of frames for one second of simulation.
    * the three return arguments are defined in this implementation.
    */
@@ -144,18 +156,22 @@ protected:
   void ImportCameras(vtkRenderer* renderer) override;
   void ImportLights(vtkRenderer* renderer) override;
 
+  void ApplySkinningMorphing();
+
   char* FileName = nullptr;
 
-  std::vector<vtkSmartPointer<vtkCamera>> Cameras;
+  std::map<int, vtkSmartPointer<vtkCamera>> Cameras;
   std::map<int, vtkSmartPointer<vtkTexture>> Textures;
   std::map<int, std::vector<vtkSmartPointer<vtkActor>>> Actors;
   vtkSmartPointer<vtkGLTFDocumentLoader> Loader;
   std::string OutputsDescription;
   std::vector<bool> EnabledAnimations;
+  vtkIdType EnabledCamera = -1;
 
 private:
   vtkGLTFImporter(const vtkGLTFImporter&) = delete;
   void operator=(const vtkGLTFImporter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
