@@ -37,6 +37,7 @@
 #include <set>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOBJImporter);
 vtkStandardNewMacro(vtkOBJPolyDataProcessor);
 
@@ -54,7 +55,7 @@ int CanReadFile(vtkObject* that, const std::string& fname)
   FILE* fileFD = vtksys::SystemTools::Fopen(fname, "rb");
   if (fileFD == nullptr)
   {
-    vtkErrorWithObjectMacro(that, << "Unable to open file: " << fname.c_str());
+    vtkErrorWithObjectMacro(that, << "Unable to open file: " << fname);
     return 0;
   }
   fclose(fileFD);
@@ -212,7 +213,7 @@ vtkOBJPolyDataProcessor::vtkOBJPolyDataProcessor()
   this->FileName = "";
   this->MTLFileName = "";
   this->DefaultMTLFileName = true;
-  this->TexturePath = ".";
+  this->TexturePath = "./";
   this->VertexScale = 1.0;
   this->SuccessParsingFiles = 1;
   this->SetNumberOfInputPorts(0);
@@ -261,6 +262,10 @@ std::string vtkOBJPolyDataProcessor::GetTextureFilename(int idx)
 
   if (mtl && !mtl->texture_filename.empty())
   {
+    if (vtksys::SystemTools::FileExists(mtl->texture_filename))
+    {
+      return mtl->texture_filename;
+    }
     std::vector<std::string> path_and_filename(2);
     path_and_filename[0] = this->TexturePath;
     path_and_filename[1] = mtl->texture_filename;
@@ -435,7 +440,9 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
 
   bool gotFirstUseMaterialTag = false;
 
+#ifndef NDEBUG
   int numPolysWithTCoords = 0;
+#endif
   bool hasTCoords = false;                 // has vt x y z
   bool hasPolysWithTextureIndices = false; // has f i/t/n or f i/t
   bool hasNormals = false;                 // has f i/t/n or f i//n
@@ -827,7 +834,9 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
         normal_polys->UpdateCellCount(nNormals);
 
         // also make a note of whether any cells have tcoords, and whether any have normals
+#ifndef NDEBUG
         numPolysWithTCoords += (int)(nTCoords) > 0;
+#endif
         if ((!hasTCoords) && (nTCoords > 0))
         {
           vtkDebugMacro("got texture coords in obj file! nTCoords = " << nTCoords);
@@ -913,7 +922,7 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
 
   if (everything_ok) // (otherwise just release allocated memory and return)
   {
-    // -- now turn this lot into a useable vtkPolyData --
+    // -- now turn this lot into a usable vtkPolyData --
     // loop over the materials found in the obj file
     for (size_t outputIndex = 0; outputIndex < poly_list.size(); ++outputIndex)
     {
@@ -928,12 +937,6 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
         << "tcoords same as verts!? " << tcoords_same_as_verts << " ... hasTCoords?" << hasTCoords
         << " ... numPolysWithTCoords = " << numPolysWithTCoords);
 
-      // assign the points color as point data
-      if (hasColors)
-      {
-        output->GetPointData()->SetScalars(colors);
-      }
-
       // if there are no tcoords or normals or they match exactly
       // then we can just copy the data into the output (easy!)
       if ((!hasTCoords || tcoords_same_as_verts) && (!hasNormals || normals_same_as_verts))
@@ -959,6 +962,12 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
         if (hasTCoords && tcoords_same_as_verts && hasPolysWithTextureIndices)
           output->GetPointData()->SetTCoords(tcoords);
 
+        // assign the points color as point data
+        if (hasColors)
+        {
+          output->GetPointData()->SetScalars(colors);
+        }
+
         // if there is an exact correspondence between normals and vertices then can simply
         // assign the normals as point data
         if (hasNormals && normals_same_as_verts)
@@ -971,12 +980,14 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
       else
       {
         vtkDebugMacro(<< "Duplicating vertices so that tcoords and normals are correct");
-        vtkPoints* new_points = vtkPoints::New();
-        vtkFloatArray* new_tcoords = vtkFloatArray::New();
+        vtkNew<vtkPoints> new_points;
+        vtkNew<vtkFloatArray> new_tcoords;
         new_tcoords->SetNumberOfComponents(2);
-        vtkFloatArray* new_normals = vtkFloatArray::New();
+        vtkNew<vtkFloatArray> new_normals;
         new_normals->SetNumberOfComponents(3);
-        vtkCellArray* new_polys = vtkCellArray::New();
+        vtkNew<vtkFloatArray> new_colors;
+        new_colors->SetNumberOfComponents(3);
+        vtkNew<vtkCellArray> new_polys;
 
         // for each poly, copy its vertices into new_points (and point at them)
         // also copy its tcoords into new_tcoords
@@ -996,6 +1007,7 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
 
         vtkIdType n_tcoords_tuples = tcoords->GetNumberOfTuples();
         vtkIdType n_normals_tuples = normals->GetNumberOfTuples();
+        vtkIdType n_colors_tuples = colors->GetNumberOfTuples();
 
         for (int i = 0; i < polys->GetNumberOfCells(); ++i)
         {
@@ -1040,6 +1052,15 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
                 }
                 new_normals->InsertNextTuple(n);
               }
+              if (hasColors)
+              {
+                float c[3] = { 0.f, 0.f, 0.f };
+                if (pts[j] < n_colors_tuples)
+                {
+                  colors->GetTypedTuple(pts[j], c);
+                }
+                new_colors->InsertNextTuple(c);
+              }
               // copy the vertex into the new structure and update
               // the vertex index in the polys structure (pts is a pointer into it)
               tmpCell->SetId(j, new_points->InsertNextPoint(points->GetPoint(pts[j])));
@@ -1061,19 +1082,21 @@ int vtkOBJPolyDataProcessor::RequestData(vtkInformation* vtkNotUsed(request),
           output->GetPointData()->SetTCoords(new_tcoords);
           vtkDebugMacro(" set new tcoords");
         }
+
         if (hasNormals)
         {
           output->GetPointData()->SetNormals(new_normals);
           vtkDebugMacro(" set new normals");
         }
 
+        if (hasColors)
+        {
+          output->GetPointData()->SetScalars(new_colors);
+          vtkDebugMacro(" set new colors");
+        }
+
         // TODO: fixup for pointElems and lineElems too
         output->Squeeze();
-
-        new_points->Delete();
-        new_polys->Delete();
-        new_tcoords->Delete();
-        new_normals->Delete();
       }
     }
   }
@@ -1110,3 +1133,4 @@ vtkPolyData* vtkOBJPolyDataProcessor::GetOutput(int idx)
     return nullptr;
   }
 }
+VTK_ABI_NAMESPACE_END
