@@ -39,6 +39,7 @@
 #include <new>
 
 // Use a user-managed heap to remove memory leaks
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkVRMLAllocator
 {
   static void Initialize()
@@ -49,10 +50,7 @@ struct vtkVRMLAllocator
     }
   }
 
-  static void* AllocateMemory(size_t n)
-  {
-    return Heap->AllocateMemory(n);
-  }
+  static void* AllocateMemory(size_t n) { return Heap->AllocateMemory(n); }
 
   static void CleanUp()
   {
@@ -63,19 +61,17 @@ struct vtkVRMLAllocator
     }
   }
 
-  static char* StrDup(const char *str)
-  {
-    return Heap->StringDup(str);
-  }
+  static char* StrDup(const char* str) { return Heap->StringDup(str); }
 
-  static vtkHeap *Heap;
+  static vtkHeap* Heap;
 };
 
 template <class T>
 class vtkVRMLVectorType
 {
 public:
-  vtkVRMLVectorType(int usenew = 0) : UseNew(usenew)
+  vtkVRMLVectorType(int usenew = 0)
+    : UseNew(usenew)
   {
     this->Init();
   }
@@ -95,7 +91,7 @@ public:
     {
       vtkVRMLAllocator::Initialize();
       void* mem = vtkVRMLAllocator::AllocateMemory(this->Allocated * sizeof(T));
-      this->Data = new(mem) T[this->Allocated];
+      this->Data = new (mem) T[this->Allocated];
     }
     else
     {
@@ -114,7 +110,7 @@ public:
       if (!this->UseNew)
       {
         void* mem = vtkVRMLAllocator::AllocateMemory(this->Allocated * sizeof(T));
-        this->Data = new(mem) T[this->Allocated];
+        this->Data = new (mem) T[this->Allocated];
       }
       else
       {
@@ -138,15 +134,11 @@ public:
     this->Used = newSize;
   }
 
-  int Count(void) const
-  {
-    return this->Used;
-  }
+  int Count(void) const { return this->Used; }
 
   T& Get(int index) const
   {
-    return (index > this->Used) ?
-      this->Data[this->Used - 1] : this->Data[index];
+    return (index > this->Used) ? this->Data[this->Used - 1] : this->Data[index];
   }
 
   T& operator[](int index)
@@ -158,10 +150,7 @@ public:
     return this->Data[index];
   }
 
-  operator T*() const
-  {
-    return this->Data;
-  }
+  operator T*() const { return this->Data; }
 
   vtkVRMLVectorType<T>& operator+=(T datum)
   {
@@ -184,29 +173,20 @@ public:
     return this->Data[this->Used];
   }
 
-  T& Top()
-  {
-    return this->Data[this->Used - 1];
-  }
+  T& Top() { return this->Data[this->Used - 1]; }
 
-  void* operator new(size_t n)
-  {
-    return vtkVRMLAllocator::AllocateMemory(n);
-  }
+  void* operator new(size_t n) { return vtkVRMLAllocator::AllocateMemory(n); }
 
-  void operator delete(void *)
-  {
-  }
+  void operator delete(void*) {}
 
 protected:
-  T *Data;
+  T* Data;
   int UseNew;
   int Allocated;
   int Used;
 };
 
-static const char standardNodes[][2042] = {
-  "#VRML V2.0 utf8 \n\
+static const char standardNodes[][2042] = { "#VRML V2.0 utf8 \n\
 # \n\
 # ************************************************** \n\
 # * VRML 2.0 Parser \n\
@@ -682,8 +662,9 @@ PROTO Viewpoint [ \n\
 PROTO WorldInfo [ \n\
   field MFString info  [] \n\
   field SFString title \"\" \n\
-] { }",""
-};
+] { }",
+  "" };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkVRML.h
