@@ -32,6 +32,7 @@
 #include <algorithm>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBiomTableReader);
 
 #ifdef read
@@ -229,15 +230,15 @@ void vtkBiomTableReader::ParseDataType()
 
   // element type lies between these quotes
   std::string data_type = this->FileContents.substr(pos3 + 1, pos4 - pos3 - 1);
-  if (strcmp(data_type.c_str(), "int") == 0)
+  if (data_type == "int")
   {
     this->DataType = VTK_INT;
   }
-  else if (strcmp(data_type.c_str(), "float") == 0)
+  else if (data_type == "float")
   {
     this->DataType = VTK_FLOAT;
   }
-  else if (strcmp(data_type.c_str(), "unicode") == 0)
+  else if (data_type == "unicode")
   {
     this->DataType = VTK_STRING;
   }
@@ -319,11 +320,11 @@ void vtkBiomTableReader::ParseSparseness()
 
   // We should find either 'sparse' or 'dense' between these quotes
   std::string matrix_type = this->FileContents.substr(pos2 + 1, pos3 - pos2 - 1);
-  if (matrix_type.compare("sparse") == 0)
+  if (matrix_type == "sparse")
   {
     this->Sparse = true;
   }
-  else if (matrix_type.compare("dense") == 0)
+  else if (matrix_type == "dense")
   {
     this->Sparse = false;
   }
@@ -393,7 +394,7 @@ void vtkBiomTableReader::ParseSparseData()
     this->InsertValue(row, column, value);
 
     pos_start = pos4 + 1;
-    if (strcmp(this->FileContents.substr(pos_start, 1).c_str(), ",") != 0)
+    if (this->FileContents.substr(pos_start, 1) != ",")
     {
       return;
     }
@@ -635,3 +636,4 @@ void vtkBiomTableReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
