@@ -19,29 +19,33 @@
 
 #include "vtkDIMACSGraphReader.h"
 
-#include "vtkExecutive.h"
 #include "vtkCellData.h"
-#include "vtkIntArray.h"
+#include "vtkExecutive.h"
 #include "vtkGraph.h"
-#include "vtkMutableUndirectedGraph.h"
+#include "vtkIntArray.h"
 #include "vtkMutableDirectedGraph.h"
-#include "vtksys/SystemTools.hxx"
+#include "vtkMutableUndirectedGraph.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkSmartPointer.h"
 #include "vtkStringArray.h"
-#include "vtkIntArray.h"
+#include "vtksys/SystemTools.hxx"
 
 #include <fstream>
-#include <sstream>
 #include <iostream>
-using std::ifstream;
+#include <sstream>
+#include <vtksys/FStream.hxx>
 using std::istringstream;
 
-#define VTK_CREATE(type, name) \
-  vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
+#define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
-typedef enum problemTypes { GENERIC, COLORING, MAXFLOW } problemTypes;
+VTK_ABI_NAMESPACE_BEGIN
+typedef enum problemTypes
+{
+  GENERIC,
+  COLORING,
+  MAXFLOW
+} problemTypes;
 
 vtkStandardNewMacro(vtkDIMACSGraphReader);
 
@@ -51,14 +55,13 @@ vtkDIMACSGraphReader::vtkDIMACSGraphReader()
   this->FileName = nullptr;
   this->SetNumberOfInputPorts(0);
   this->VertexAttributeArrayName = nullptr;
-  this->EdgeAttributeArrayName   = nullptr;
+  this->EdgeAttributeArrayName = nullptr;
   this->Directed = false;
-  this->fileOk   = false;
+  this->fileOk = false;
   this->numVerts = 0;
   this->numEdges = 0;
 }
 
-
 vtkDIMACSGraphReader::~vtkDIMACSGraphReader()
 {
   this->SetFileName(nullptr);
@@ -66,23 +69,17 @@ vtkDIMACSGraphReader::~vtkDIMACSGraphReader()
   this->SetEdgeAttributeArrayName(nullptr);
 }
 
-
 void vtkDIMACSGraphReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "FileName: "
-     << (this->FileName ? this->FileName : "(none)") << endl;
+  os << indent << "FileName: " << (this->FileName ? this->FileName : "(none)") << endl;
   os << indent << "Vertex Attribute Array Name: "
-     << (this->VertexAttributeArrayName ? this->VertexAttributeArrayName : "color")
-     << endl;
+     << (this->VertexAttributeArrayName ? this->VertexAttributeArrayName : "color") << endl;
   os << indent << "Edge Attribute Array Name  : "
-     << (this->EdgeAttributeArrayName ? this->EdgeAttributeArrayName : "color")
-     << endl;
+     << (this->EdgeAttributeArrayName ? this->EdgeAttributeArrayName : "color") << endl;
 }
 
-
-
 // ============================================================================
 // Generic DIMACS file format, which covers many 'DIMACS' style input files.
 // This is the default reader if we don't have a special case file.
@@ -96,11 +93,10 @@ void vtkDIMACSGraphReader::PrintSelf(ostream& os, vtkIndent indent)
 //         a u v wt
 //   alternatively, edges can also be:
 //         e u v wt
-int vtkDIMACSGraphReader::buildGenericGraph(vtkGraph     * output,
-                                            vtkStdString & defaultVertexAttrArrayName,
-                                            vtkStdString & defaultEdgeAttrArrayName)
+int vtkDIMACSGraphReader::buildGenericGraph(vtkGraph* output,
+  vtkStdString& defaultVertexAttrArrayName, vtkStdString& defaultEdgeAttrArrayName)
 {
-  vtkStdString S;
+  std::string S;
   int iEdgeU, iEdgeV, iVertexID;
   int currentEdgeId = 0;
 
@@ -112,24 +108,24 @@ int vtkDIMACSGraphReader::buildGenericGraph(vtkGraph     * output,
   VTK_CREATE(vtkIntArray, edgePedigreeIds);
 
   // Set up vertex attribute array for vertex-weights.
-  if(this->VertexAttributeArrayName)
+  if (this->VertexAttributeArrayName)
   {
     ArrayVertexAttributes->SetName(this->VertexAttributeArrayName);
   }
   else
   {
-    ArrayVertexAttributes->SetName(defaultVertexAttrArrayName);
+    ArrayVertexAttributes->SetName(defaultVertexAttrArrayName.c_str());
   }
   ArrayVertexAttributes->SetNumberOfTuples(this->numVerts);
 
   // Set up Edge attribute array for edge-weights.
-  if(this->EdgeAttributeArrayName)
+  if (this->EdgeAttributeArrayName)
   {
     ArrayEdgeAttributes->SetName(this->EdgeAttributeArrayName);
   }
   else
   {
-    ArrayEdgeAttributes->SetName(defaultEdgeAttrArrayName);
+    ArrayEdgeAttributes->SetName(defaultEdgeAttrArrayName.c_str());
   }
   ArrayEdgeAttributes->SetNumberOfTuples(this->numEdges);
 
@@ -140,59 +136,59 @@ int vtkDIMACSGraphReader::buildGenericGraph(vtkGraph     * output,
   edgePedigreeIds->SetNumberOfTuples(this->numEdges);
 
   // Allocate Vertices in the graph builder
-  for(int i=0; i<this->numVerts; i++)
+  for (int i = 0; i < this->numVerts; i++)
   {
     builder->AddVertex();
-    vertexPedigreeIds->SetValue(i, i+1);
+    vertexPedigreeIds->SetValue(i, i + 1);
   }
 
   // set starting edge id number.
   int baseEdgeId = 1;
 
-  ifstream IFP(this->FileName);
-  if(IFP.is_open())
+  vtksys::ifstream IFP(this->FileName);
+  if (IFP.is_open())
   {
-    while( vtksys::SystemTools::GetLineFromStream(IFP,S) )
+    while (vtksys::SystemTools::GetLineFromStream(IFP, S))
     {
       int value;
       istringstream iss(S);
       char lineType;
       iss >> lineType;
-      switch(lineType)
+      switch (lineType)
       {
-        case 'n':  /* vertex (node) definition */
-            iss >> iVertexID >> value;
-            ArrayVertexAttributes->SetValue(iVertexID-1, value);
-            vertexPedigreeIds->SetValue(iVertexID-1, iVertexID);
-            break;
-        case 'a':  /* edge arc */
+        case 'n': /* vertex (node) definition */
+          iss >> iVertexID >> value;
+          ArrayVertexAttributes->SetValue(iVertexID - 1, value);
+          vertexPedigreeIds->SetValue(iVertexID - 1, iVertexID);
+          break;
+        case 'a': /* edge arc */
         case 'e':
         {
-            iss >> iEdgeU >> iEdgeV >> value;
+          iss >> iEdgeU >> iEdgeV >> value;
 
-            if(iEdgeU==0 || iEdgeV==0)
-            {
-              vtkErrorMacro(<<"DIMACS graph vertices are numbered 1..n; 0 is not allowed");
-              return 0;
-            }
+          if (iEdgeU == 0 || iEdgeV == 0)
+          {
+            vtkErrorMacro(<< "DIMACS graph vertices are numbered 1..n; 0 is not allowed");
+            return 0;
+          }
 
-            vtkEdgeType edgeObj = builder->AddEdge(iEdgeU-1, iEdgeV-1);
-            ArrayEdgeAttributes->SetValue(edgeObj.Id, value);
-            edgePedigreeIds->SetValue(currentEdgeId, currentEdgeId+baseEdgeId);
-            currentEdgeId++;
+          vtkEdgeType edgeObj = builder->AddEdge(iEdgeU - 1, iEdgeV - 1);
+          ArrayEdgeAttributes->SetValue(edgeObj.Id, value);
+          edgePedigreeIds->SetValue(currentEdgeId, currentEdgeId + baseEdgeId);
+          currentEdgeId++;
         }
-            break;
+        break;
         case 'c': /* Comment line, ignore it! */
-            break;
+          break;
         default:
-            break;
-      };
+          break;
+      }
     }
   }
 
   // Add the pedigree ids to the graph
-  builder->GetVertexData()->SetPedigreeIds( vertexPedigreeIds );
-  builder->GetEdgeData()->SetPedigreeIds( edgePedigreeIds );
+  builder->GetVertexData()->SetPedigreeIds(vertexPedigreeIds);
+  builder->GetEdgeData()->SetPedigreeIds(edgePedigreeIds);
 
   // Add the attribute arrays to the graph
   builder->GetVertexData()->AddArray(ArrayVertexAttributes);
@@ -200,14 +196,12 @@ int vtkDIMACSGraphReader::buildGenericGraph(vtkGraph     * output,
 
   if (!output->CheckedShallowCopy(builder))
   {
-    vtkErrorMacro(<<"Invalid graph structure");
+    vtkErrorMacro(<< "Invalid graph structure");
     return 0;
   }
   return 1;
 }
 
-
-
 // ============================================================================
 // Build a graph from a max-flow problem.
 // * These are directed.
@@ -218,15 +212,15 @@ int vtkDIMACSGraphReader::buildGenericGraph(vtkGraph     * output,
 // * Format of edge lines is:
 //         a u v cap
 //   to create an edge u->v, and cap gives the edge capacity.
-int vtkDIMACSGraphReader::buildMaxflowGraph(vtkGraph * output)
+int vtkDIMACSGraphReader::buildMaxflowGraph(vtkGraph* output)
 {
-  vtkStdString S;
+  std::string S;
   int iEdgeU, iEdgeV, iVertexID;
   int currentEdgeId = 0;
   int numSrcs = 0;
   int numSinks = 0;
 
-  vtkStdString sAttribute;
+  std::string sAttribute;
   VTK_CREATE(vtkMutableDirectedGraph, builder);
 
   VTK_CREATE(vtkIntArray, vertexSourceArray);
@@ -244,15 +238,15 @@ int vtkDIMACSGraphReader::buildMaxflowGraph(vtkGraph * output)
   vertexSinkArray->SetNumberOfTuples(this->numVerts);
   edgeCapacityArray->SetNumberOfTuples(this->numEdges);
 
-  for(int i=0; i<this->numVerts; i++)
+  for (int i = 0; i < this->numVerts; i++)
   {
-    vertexSourceArray->SetValue(i,0);
-    vertexSinkArray->SetValue(i,0);
+    vertexSourceArray->SetValue(i, 0);
+    vertexSinkArray->SetValue(i, 0);
   }
 
-  for(int i=0; i<this->numEdges; i++)
+  for (int i = 0; i < this->numEdges; i++)
   {
-    edgeCapacityArray->SetValue(i,0);
+    edgeCapacityArray->SetValue(i, 0);
   }
 
   // Set up Pedigree-IDs arrays.
@@ -262,102 +256,97 @@ int vtkDIMACSGraphReader::buildMaxflowGraph(vtkGraph * output)
   edgePedigreeIds->SetNumberOfTuples(this->numEdges);
 
   // Allocate Vertices in the graph builder
-  for(int i=0; i<this->numVerts; i++)
+  for (int i = 0; i < this->numVerts; i++)
   {
     builder->AddVertex();
-    vertexPedigreeIds->SetValue(i, i+1);
+    vertexPedigreeIds->SetValue(i, i + 1);
   }
 
   // set starting edge id number.
   int baseEdgeId = 1;
 
-  ifstream IFP(this->FileName);
-  if(IFP.is_open())
+  vtksys::ifstream IFP(this->FileName);
+  if (IFP.is_open())
   {
-    while( vtksys::SystemTools::GetLineFromStream(IFP,S) )
+    while (vtksys::SystemTools::GetLineFromStream(IFP, S))
     {
       istringstream iss(S);
       char lineType;
       iss >> lineType;
-      switch(lineType)
+      switch (lineType)
       {
-        case 'n':  /* vertex (node) definition */
-            iss >> iVertexID >> sAttribute;
-            vertexPedigreeIds->SetValue(iVertexID-1, iVertexID);
+        case 'n': /* vertex (node) definition */
+          iss >> iVertexID >> sAttribute;
+          vertexPedigreeIds->SetValue(iVertexID - 1, iVertexID);
 
-            if(sAttribute == "s" && numSrcs==0)
-            {
-              numSrcs++;
-              vertexSourceArray->SetValue(iVertexID-1, 1);
-            }
-            else if(sAttribute == "t" && numSinks==0)
-            {
-              numSinks++;
-              vertexSinkArray->SetValue(iVertexID-1, 1);
-            }
-            else
-            {
-              vtkWarningMacro(<< "In DIMACS Max-Flow file: "
-                              << this->FileName
-                              << "  multiple sources or sinks specified!"
-                              << endl
-                              << "  Ignoring all but first source/sink found.");
-            }
-            break;
-        case 'a':  /* edge arc */
+          if (sAttribute == "s" && numSrcs == 0)
+          {
+            numSrcs++;
+            vertexSourceArray->SetValue(iVertexID - 1, 1);
+          }
+          else if (sAttribute == "t" && numSinks == 0)
+          {
+            numSinks++;
+            vertexSinkArray->SetValue(iVertexID - 1, 1);
+          }
+          else
+          {
+            vtkWarningMacro(<< "In DIMACS Max-Flow file: " << this->FileName
+                            << "  multiple sources or sinks specified!" << endl
+                            << "  Ignoring all but first source/sink found.");
+          }
+          break;
+        case 'a': /* edge arc */
         {
-            int edgeCapacity;
-            iss >> iEdgeU >> iEdgeV >> edgeCapacity;
+          int edgeCapacity;
+          iss >> iEdgeU >> iEdgeV >> edgeCapacity;
 
-            if(iEdgeU==0 || iEdgeV==0)
-            {
-              vtkErrorMacro(<<"DIMACS graph vertices are numbered 1..n; 0 is not allowed");
-              return 0;
-            }
+          if (iEdgeU == 0 || iEdgeV == 0)
+          {
+            vtkErrorMacro(<< "DIMACS graph vertices are numbered 1..n; 0 is not allowed");
+            return 0;
+          }
 
-            vtkEdgeType edgeObj = builder->AddEdge(iEdgeU-1, iEdgeV-1);
-            edgeCapacityArray->SetValue(edgeObj.Id, edgeCapacity);
-            edgePedigreeIds->SetValue(currentEdgeId, currentEdgeId+baseEdgeId);
-            currentEdgeId++;
+          vtkEdgeType edgeObj = builder->AddEdge(iEdgeU - 1, iEdgeV - 1);
+          edgeCapacityArray->SetValue(edgeObj.Id, edgeCapacity);
+          edgePedigreeIds->SetValue(currentEdgeId, currentEdgeId + baseEdgeId);
+          currentEdgeId++;
         }
-            break;
+        break;
         case 'c': /* Comment line, ignore it! */
-            break;
+          break;
         default:
-            break;
-      };
+          break;
+      }
     }
   }
 
   // Add the pedigree ids to the graph
-  builder->GetVertexData()->SetPedigreeIds( vertexPedigreeIds );
-  builder->GetEdgeData()->SetPedigreeIds( edgePedigreeIds );
+  builder->GetVertexData()->SetPedigreeIds(vertexPedigreeIds);
+  builder->GetEdgeData()->SetPedigreeIds(edgePedigreeIds);
 
   // Add the attribute arrays to the graph
   builder->GetVertexData()->AddArray(vertexSourceArray);
   builder->GetVertexData()->AddArray(vertexSinkArray);
   builder->GetEdgeData()->AddArray(edgeCapacityArray);
 
-
   if (!output->CheckedShallowCopy(builder))
   {
-    vtkErrorMacro(<<"Invalid graph structure");
+    vtkErrorMacro(<< "Invalid graph structure");
     return 0;
   }
   return 1;
 }
 
-
-
 // ============================================================================
 // Builder method for creating coloring problem graphs.
 // * These are undirected.
 // * nodes and edges have no weights associated with them.
 // * edges (u->v) are formatted as:
 //         e u v
-int vtkDIMACSGraphReader::buildColoringGraph(vtkGraph * output)
+int vtkDIMACSGraphReader::buildColoringGraph(vtkGraph* output)
 {
-  vtkStdString S;
+  std::string S;
   int iEdgeU, iEdgeV;
   int currentEdgeId = 0;
 
@@ -372,61 +361,59 @@ int vtkDIMACSGraphReader::buildColoringGraph(vtkGraph * output)
   edgePedigreeIds->SetNumberOfTuples(this->numEdges);
 
   // Allocate Vertices in the graph builder
-  for(int i=0; i<this->numVerts; i++)
+  for (int i = 0; i < this->numVerts; i++)
   {
     builder->AddVertex();
-    vertexPedigreeIds->SetValue(i, i+1);
+    vertexPedigreeIds->SetValue(i, i + 1);
   }
 
   // set starting edge id number.
   int baseEdgeId = 1;
 
-  ifstream IFP(this->FileName);
-  if(IFP.is_open())
+  vtksys::ifstream IFP(this->FileName);
+  if (IFP.is_open())
   {
-    while( vtksys::SystemTools::GetLineFromStream(IFP,S) )
+    while (vtksys::SystemTools::GetLineFromStream(IFP, S))
     {
       istringstream iss(S);
       char lineType;
       iss >> lineType;
-      switch(lineType)
+      switch (lineType)
       {
-        case 'e':  /* edge arc */
+        case 'e': /* edge arc */
         {
-            iss >> iEdgeU >> iEdgeV;
+          iss >> iEdgeU >> iEdgeV;
 
-            if(iEdgeU==0 || iEdgeV==0)
-            {
-              vtkErrorMacro(<<"DIMACS graph vertices are numbered 1..n; 0 is not allowed");
-              return 0;
-            }
+          if (iEdgeU == 0 || iEdgeV == 0)
+          {
+            vtkErrorMacro(<< "DIMACS graph vertices are numbered 1..n; 0 is not allowed");
+            return 0;
+          }
 
-            builder->AddEdge(iEdgeU-1, iEdgeV-1);
-            edgePedigreeIds->SetValue(currentEdgeId, currentEdgeId+baseEdgeId);
-            currentEdgeId++;
+          builder->AddEdge(iEdgeU - 1, iEdgeV - 1);
+          edgePedigreeIds->SetValue(currentEdgeId, currentEdgeId + baseEdgeId);
+          currentEdgeId++;
         }
-            break;
+        break;
         default:
-            break;
-      };
+          break;
+      }
     }
   }
 
   // Add the pedigree ids to the graph
-  builder->GetVertexData()->SetPedigreeIds( vertexPedigreeIds );
-  builder->GetEdgeData()->SetPedigreeIds( edgePedigreeIds );
+  builder->GetVertexData()->SetPedigreeIds(vertexPedigreeIds);
+  builder->GetEdgeData()->SetPedigreeIds(edgePedigreeIds);
 
   if (!output->CheckedShallowCopy(builder))
   {
-    vtkErrorMacro(<<"Invalid graph structure");
+    vtkErrorMacro(<< "Invalid graph structure");
     return 0;
   }
 
   return 1;
 }
 
-
-
 // ============================================================================
 // Searches for the problem line in a dimacs graph (starts with 'p')
 // and gets the problem type and the number of vertices and edges.
@@ -440,56 +427,54 @@ int vtkDIMACSGraphReader::ReadGraphMetaData()
     return 0;
   }
 
-  ifstream IFP(this->FileName);
-  if(!IFP.is_open())
+  vtksys::ifstream IFP(this->FileName);
+  if (!IFP.is_open())
   {
     vtkErrorMacro("Could not open file " << this->FileName << ".");
-    return(0);
+    return (0);
   }
-  vtkStdString S;
+  std::string S;
   bool foundProblemLine = false;
   bool foundMultipleProblemLines = false;
 
   // Look at lines until we find the problem line (this should always
   // be one of the first lines in a DIMACS graph)
-  while(!foundProblemLine && vtksys::SystemTools::GetLineFromStream(IFP,S))
+  while (!foundProblemLine && vtksys::SystemTools::GetLineFromStream(IFP, S))
   {
     istringstream iss(S);
     char lineType;
     iss >> lineType;
-    switch(lineType)
+    switch (lineType)
     {
       case 'p':
-        if( !foundProblemLine )
+        if (!foundProblemLine)
         {
           foundProblemLine = true;
-          iss >> this->dimacsProblemStr
-              >> this->numVerts
-              >> this->numEdges;
+          iss >> this->dimacsProblemStr >> this->numVerts >> this->numEdges;
         }
         else
         {
           foundMultipleProblemLines = true;
         }
-    };
+    }
   }
   IFP.close();
 
-  if(!foundProblemLine)
+  if (!foundProblemLine)
   {
     vtkErrorMacro(<< "Error in DIMACS file: " << this->FileName
                   << ", could not find a problem description line.");
     return 0;
   }
 
-  if(foundMultipleProblemLines)
+  if (foundMultipleProblemLines)
   {
-    vtkWarningMacro(<< "Found multiple problem lines in DIMACS file: "
-                    << this->FileName << "; using the first one found.");
+    vtkWarningMacro(<< "Found multiple problem lines in DIMACS file: " << this->FileName
+                    << "; using the first one found.");
   }
 
   // Set directed if necessary
-  if(this->dimacsProblemStr == "max")
+  if (this->dimacsProblemStr == "max")
   {
     this->Directed = true;
   }
@@ -499,27 +484,24 @@ int vtkDIMACSGraphReader::ReadGraphMetaData()
   return 1;
 }
 
-
-
 // ============================================================================
-int vtkDIMACSGraphReader::RequestData(vtkInformation       *  vtkNotUsed(request),
-                                      vtkInformationVector ** vtkNotUsed(inputVector),
-                                      vtkInformationVector *  outputVector)
+int vtkDIMACSGraphReader::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
-  int rval=0;
-  if( !this->fileOk )
+  int rval = 0;
+  if (!this->fileOk)
   {
     return 0;
   }
 
-  vtkGraph * output = vtkGraph::GetData(outputVector);
+  vtkGraph* output = vtkGraph::GetData(outputVector);
 
-  if(this->dimacsProblemStr == "edge")
+  if (this->dimacsProblemStr == "edge")
   {
     vtkDebugMacro("Loading DIMACS coloring problem graph.");
     rval = buildColoringGraph(output);
   }
-  else if(this->dimacsProblemStr == "max")
+  else if (this->dimacsProblemStr == "max")
   {
     vtkDebugMacro("Loading DIMACS max-flow problem graph.");
     rval = buildMaxflowGraph(output);
@@ -534,20 +516,17 @@ int vtkDIMACSGraphReader::RequestData(vtkInformation       *  vtkNotUsed(request
   return rval;
 }
 
-
-
-//----------------------------------------------------------------------------
-int vtkDIMACSGraphReader::RequestDataObject(vtkInformation*,
-                                            vtkInformationVector**,
-                                            vtkInformationVector* )
+//------------------------------------------------------------------------------
+int vtkDIMACSGraphReader::RequestDataObject(
+  vtkInformation*, vtkInformationVector**, vtkInformationVector*)
 {
   ReadGraphMetaData();
 
-  vtkDataObject *current = this->GetExecutive()->GetOutputData(0);
-  if (!current || (this->Directed && !vtkDirectedGraph::SafeDownCast(current))
-               || (!this->Directed && vtkDirectedGraph::SafeDownCast(current)))
+  vtkDataObject* current = this->GetExecutive()->GetOutputData(0);
+  if (!current || (this->Directed && !vtkDirectedGraph::SafeDownCast(current)) ||
+    (!this->Directed && vtkDirectedGraph::SafeDownCast(current)))
   {
-    vtkGraph *output = nullptr;
+    vtkGraph* output = nullptr;
     if (this->Directed)
     {
       output = vtkDirectedGraph::New();
@@ -561,3 +540,4 @@ int vtkDIMACSGraphReader::RequestDataObject(vtkInformation*,
   }
   return 1;
 }
+VTK_ABI_NAMESPACE_END
