@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkLSDynaSummaryParser.h
+  Module:    vtkLSDynaSummaryParser.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -19,11 +19,12 @@
 
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkLSDynaSummaryParser);
 
 namespace
 {
-static void vtkLSTrimWhitespace(std::string& line)
+void vtkLSTrimWhitespace(std::string& line)
 {
   std::string::size_type llen = line.length();
   while (llen &&
@@ -202,7 +203,7 @@ void vtkLSDynaSummaryParser::CharacterDataHandler(const char* data, int length)
   }
   // skip leading whitespace
   int i = 0;
-  while (this->PartName.empty() && i < length && this->IsSpace(data[i]))
+  while (this->PartName.empty() && i < length && vtkLSDynaSummaryParser::IsSpace(data[i]))
     ++i;
 
   if (i < length)
@@ -222,3 +223,4 @@ void vtkLSDynaSummaryParser::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "InDyna: " << this->InDyna << endl;
   os << indent << "InName: " << this->InName << endl;
 }
+VTK_ABI_NAMESPACE_END
