@@ -12,6 +12,7 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
 #include "vtkDataReader.h"
 
 #include "vtkBitArray.h"
@@ -51,7 +52,6 @@
 #include "vtkTable.h"
 #include "vtkTypeInt64Array.h"
 #include "vtkTypeUInt64Array.h"
-#include "vtkUnicodeStringArray.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
@@ -71,15 +71,18 @@
 // myself.
 // This function is also defined in Infovis/vtkDelimitedTextReader.cxx,
 // so it would be nice to put this in a common file.
-static int my_getline(istream& in, vtkStdString& output, char delim = '\n');
+VTK_ABI_NAMESPACE_BEGIN
+static int my_getline(istream& in, std::string& output, char delim = '\n');
 
 vtkStandardNewMacro(vtkDataReader);
 
 vtkCxxSetObjectMacro(vtkDataReader, InputArray, vtkCharArray);
 
+//------------------------------------------------------------------------------
 // Construct object.
 vtkDataReader::vtkDataReader()
 {
+  this->FileVersion = 0;
   this->FileType = VTK_ASCII;
   this->ScalarsName = nullptr;
   this->VectorsName = nullptr;
@@ -131,6 +134,7 @@ vtkDataReader::vtkDataReader()
   this->SetNumberOfOutputPorts(1);
 }
 
+//------------------------------------------------------------------------------
 vtkDataReader::~vtkDataReader()
 {
   delete[] this->ScalarsName;
@@ -149,6 +153,7 @@ vtkDataReader::~vtkDataReader()
   delete this->IS;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetFileName(const char* fname)
 {
   if (this->GetNumberOfFileNames() == 1 && this->GetFileName(0) && fname &&
@@ -164,6 +169,7 @@ void vtkDataReader::SetFileName(const char* fname)
   this->Modified();
 }
 
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetFileName() const
 {
   if (this->GetNumberOfFileNames() < 1)
@@ -173,6 +179,7 @@ const char* vtkDataReader::GetFileName() const
   return this->vtkSimpleReader::GetFileName(0);
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadTimeDependentMetaData(int timestep, vtkInformation* metadata)
 {
   if (this->ReadFromInputString)
@@ -183,6 +190,7 @@ int vtkDataReader::ReadTimeDependentMetaData(int timestep, vtkInformation* metad
   return this->Superclass::ReadTimeDependentMetaData(timestep, metadata);
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadMesh(
   int piece, int npieces, int nghosts, int timestep, vtkDataObject* output)
 {
@@ -201,6 +209,7 @@ int vtkDataReader::ReadMesh(
   return this->Superclass::ReadMesh(piece, npieces, nghosts, timestep, output);
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetInputString(const char* in)
 {
   int len = 0;
@@ -211,11 +220,13 @@ void vtkDataReader::SetInputString(const char* in)
   this->SetInputString(in, len);
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetBinaryInputString(const char* in, int len)
 {
   this->SetInputString(in, len);
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetInputString(const char* in, int len)
 {
   if (this->Debug)
@@ -250,6 +261,7 @@ void vtkDataReader::SetInputString(const char* in, int len)
   this->Modified();
 }
 
+//------------------------------------------------------------------------------
 // Internal function to read in a line up to 256 characters.
 // Returns zero if there was an error.
 int vtkDataReader::ReadLine(char result[256])
@@ -277,12 +289,16 @@ int vtkDataReader::ReadLine(char result[256])
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Internal function to read in a string up to 256 characters.
 // Returns zero if there was an error.
-int vtkDataReader::ReadString(char result[256])
+int vtkDataReader::ReadString(char (&result)[256])
 {
+  // Force the parameter to be seen as a 256-byte array rather than a decayed
+  // pointer.
+  char(&result_ref)[256] = *reinterpret_cast<char(*)[256]>(result);
   this->IS->width(256);
-  *this->IS >> result;
+  *this->IS >> result_ref;
   if (this->IS->fail())
   {
     return 0;
@@ -290,6 +306,7 @@ int vtkDataReader::ReadString(char result[256])
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Internal function to read in an integer value.
 // Returns zero if there was an error.
 int vtkDataReader::Read(char* result)
@@ -305,6 +322,7 @@ int vtkDataReader::Read(char* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned char* result)
 {
   int intData;
@@ -318,6 +336,7 @@ int vtkDataReader::Read(unsigned char* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(short* result)
 {
   *this->IS >> *result;
@@ -328,6 +347,7 @@ int vtkDataReader::Read(short* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned short* result)
 {
   *this->IS >> *result;
@@ -338,6 +358,7 @@ int vtkDataReader::Read(unsigned short* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(int* result)
 {
   *this->IS >> *result;
@@ -348,6 +369,7 @@ int vtkDataReader::Read(int* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned int* result)
 {
   *this->IS >> *result;
@@ -358,6 +380,7 @@ int vtkDataReader::Read(unsigned int* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(long* result)
 {
   *this->IS >> *result;
@@ -368,6 +391,7 @@ int vtkDataReader::Read(long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned long* result)
 {
   *this->IS >> *result;
@@ -378,6 +402,7 @@ int vtkDataReader::Read(unsigned long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(long long* result)
 {
   *this->IS >> *result;
@@ -388,6 +413,7 @@ int vtkDataReader::Read(long long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned long long* result)
 {
   *this->IS >> *result;
@@ -398,6 +424,7 @@ int vtkDataReader::Read(unsigned long long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(float* result)
 {
   *this->IS >> *result;
@@ -408,6 +435,7 @@ int vtkDataReader::Read(float* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(double* result)
 {
   *this->IS >> *result;
@@ -418,6 +446,7 @@ int vtkDataReader::Read(double* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 size_t vtkDataReader::Peek(char* str, size_t n)
 {
   if (n == 0)
@@ -438,6 +467,7 @@ size_t vtkDataReader::Peek(char* str, size_t n)
   return len;
 }
 
+//------------------------------------------------------------------------------
 // Open a vtk data file. Returns zero if error.
 int vtkDataReader::OpenVTKFile(const char* fname)
 {
@@ -510,6 +540,7 @@ int vtkDataReader::OpenVTKFile(const char* fname)
   return 0;
 }
 
+//------------------------------------------------------------------------------
 // Read the header of a vtk data file. Returns 0 if error.
 int vtkDataReader::ReadHeader(const char* fname)
 {
@@ -556,6 +587,8 @@ int vtkDataReader::ReadHeader(const char* fname)
                     << this->FileMinorVersion << " with older reader version "
                     << vtkLegacyReaderMajorVersion << "." << vtkLegacyReaderMinorVersion);
   }
+  // Compose FileVersion
+  this->FileVersion = 10 * this->FileMajorVersion + this->FileMinorVersion;
 
   //
   // read title
@@ -632,9 +665,10 @@ int vtkDataReader::ReadHeader(const char* fname)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::IsFileValid(const char* dstype)
 {
-  char line[1024];
+  char line[256];
 
   if (!dstype)
   {
@@ -678,6 +712,7 @@ int vtkDataReader::IsFileValid(const char* dstype)
   return 0;
 }
 
+//------------------------------------------------------------------------------
 // Read the cell data of a vtk data file. The number of cells (from the
 // dataset) must match the number of cells defined in cell attributes (unless
 // no geometry was defined).
@@ -836,6 +871,7 @@ int vtkDataReader::ReadCellData(vtkDataSet* ds, vtkIdType numCells)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the point data of a vtk data file. The number of points (from the
 // dataset) must match the number of points defined in point attributes (unless
 // no geometry was defined).
@@ -1004,6 +1040,7 @@ int vtkDataReader::ReadPointData(vtkDataSet* ds, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the vertex data of a vtk data file. The number of vertices (from the
 // graph) must match the number of vertices defined in vertex attributes (unless
 // no geometry was defined).
@@ -1162,6 +1199,7 @@ int vtkDataReader::ReadVertexData(vtkGraph* g, vtkIdType numVertices)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the edge data of a vtk data file. The number of edges (from the
 // graph) must match the number of edges defined in edge attributes (unless
 // no geometry was defined).
@@ -1320,6 +1358,7 @@ int vtkDataReader::ReadEdgeData(vtkGraph* g, vtkIdType numEdges)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the row data of a vtk data file.
 int vtkDataReader::ReadRowData(vtkTable* t, vtkIdType numEdges)
 {
@@ -1504,6 +1543,7 @@ int vtkReadASCIIData(vtkDataReader* self, T* data, vtkIdType numTuples, vtkIdTyp
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Description:
 // Read data array. Return pointer to array object if successful read;
 // otherwise return nullptr. Note: this method instantiates a reference counted
@@ -1787,7 +1827,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
     }
   }
 
-  else if (!strncmp(type, "string", 6))
+  else if (!strncmp(type, "string", 6) || !strncmp(type, "utf8_string", 11))
   {
     array = vtkStringArray::New();
     array->SetNumberOfComponents(numComp);
@@ -1804,7 +1844,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
         {
           vtkTypeUInt8 firstByte;
           vtkTypeUInt8 headerType;
-          vtkStdString::size_type stringLength;
+          std::string::size_type stringLength;
           firstByte = IS->peek();
           headerType = firstByte >> 6;
           if (headerType == 3)
@@ -1836,12 +1876,12 @@ vtkAbstractArray* vtkDataReader::ReadArray(
           {
             vtkTypeUInt64 length;
             IS->read(reinterpret_cast<char*>(&length), 8);
-            vtkByteSwap::Swap4BE(&length);
+            vtkByteSwap::Swap8BE(&length);
             stringLength = length;
           }
           std::vector<char> str(stringLength);
           IS->read(str.data(), stringLength);
-          vtkStdString s(str.data(), stringLength);
+          std::string s(str.data(), stringLength);
           ((vtkStringArray*)array)->InsertNextValue(s);
         }
       }
@@ -1849,7 +1889,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
     else
     {
       // read in newline
-      vtkStdString s;
+      std::string s;
       my_getline(*(this->IS), s);
 
       for (vtkIdType i = 0; i < numTuples; i++)
@@ -1860,92 +1900,12 @@ vtkAbstractArray* vtkDataReader::ReadArray(
           int length = static_cast<int>(s.length());
           std::vector<char> decoded(length + 1);
           int decodedLength = this->DecodeString(decoded.data(), s.c_str());
-          vtkStdString decodedStr(decoded.data(), decodedLength);
+          std::string decodedStr(decoded.data(), decodedLength);
           ((vtkStringArray*)array)->InsertNextValue(decodedStr);
         }
       }
     }
   }
-  else if (!strncmp(type, "utf8_string", 11))
-  {
-    array = vtkUnicodeStringArray::New();
-    array->SetNumberOfComponents(numComp);
-
-    if (this->FileType == VTK_BINARY)
-    {
-      // read in newline
-      char line[256];
-      IS->getline(line, 256);
-
-      for (vtkIdType i = 0; i < numTuples; i++)
-      {
-        for (vtkIdType j = 0; j < numComp; j++)
-        {
-          vtkTypeUInt8 firstByte;
-          vtkTypeUInt8 headerType;
-          vtkStdString::size_type stringLength;
-          firstByte = IS->peek();
-          headerType = firstByte >> 6;
-          if (headerType == 3)
-          {
-            vtkTypeUInt8 length = IS->get();
-            length <<= 2;
-            length >>= 2;
-            stringLength = length;
-          }
-          else if (headerType == 2)
-          {
-            vtkTypeUInt16 length;
-            IS->read(reinterpret_cast<char*>(&length), 2);
-            vtkByteSwap::Swap2BE(&length);
-            length <<= 2;
-            length >>= 2;
-            stringLength = length;
-          }
-          else if (headerType == 1)
-          {
-            vtkTypeUInt32 length;
-            IS->read(reinterpret_cast<char*>(&length), 4);
-            vtkByteSwap::Swap4BE(&length);
-            length <<= 2;
-            length >>= 2;
-            stringLength = length;
-          }
-          else
-          {
-            vtkTypeUInt64 length;
-            IS->read(reinterpret_cast<char*>(&length), 8);
-            vtkByteSwap::Swap4BE(&length);
-            stringLength = length;
-          }
-          std::vector<char> str(stringLength);
-          IS->read(str.data(), stringLength);
-          vtkUnicodeString s = vtkUnicodeString::from_utf8(str.data(), str.data() + stringLength);
-          ((vtkUnicodeStringArray*)array)->InsertNextValue(s);
-        }
-      }
-    }
-    else
-    {
-      // read in newline
-      vtkStdString s;
-      my_getline(*(this->IS), s);
-
-      for (vtkIdType i = 0; i < numTuples; i++)
-      {
-        for (vtkIdType j = 0; j < numComp; j++)
-        {
-          my_getline(*(this->IS), s);
-          int length = static_cast<int>(s.length());
-          std::vector<char> decoded(length + 1);
-          int decodedLength = this->DecodeString(decoded.data(), s.c_str());
-          vtkUnicodeString decodedStr =
-            vtkUnicodeString::from_utf8(decoded.data(), decoded.data() + decodedLength);
-          ((vtkUnicodeStringArray*)array)->InsertNextValue(decodedStr);
-        }
-      }
-    }
-  }
   else if (!strncmp(type, "variant", 7))
   {
     array = vtkVariantArray::New();
@@ -1955,11 +1915,11 @@ vtkAbstractArray* vtkDataReader::ReadArray(
       for (vtkIdType j = 0; j < numComp; j++)
       {
         int t;
-        vtkStdString str;
+        std::string str;
         *(this->IS) >> t >> str;
         std::vector<char> decoded(str.length() + 1);
         int decodedLength = this->DecodeString(decoded.data(), str.c_str());
-        vtkStdString decodedStr(decoded.data(), decodedLength);
+        std::string decodedStr(decoded.data(), decodedLength);
         vtkVariant sv(decodedStr);
         vtkVariant v;
         switch (t)
@@ -2135,6 +2095,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
   return array;
 }
 
+//------------------------------------------------------------------------------
 // Read point coordinates. Return 0 if error.
 int vtkDataReader::ReadPointCoordinates(vtkPointSet* ps, vtkIdType numPts)
 {
@@ -2170,6 +2131,7 @@ int vtkDataReader::ReadPointCoordinates(vtkPointSet* ps, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read point coordinates. Return 0 if error.
 int vtkDataReader::ReadPointCoordinates(vtkGraph* g, vtkIdType numPts)
 {
@@ -2205,6 +2167,7 @@ int vtkDataReader::ReadPointCoordinates(vtkGraph* g, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the coordinates for a rectilinear grid. The axes parameter specifies
 // which coordinate axes (0,1,2) is being read.
 int vtkDataReader::ReadCoordinates(vtkRectilinearGrid* rg, int axes, int numCoords)
@@ -2248,6 +2211,7 @@ int vtkDataReader::ReadCoordinates(vtkRectilinearGrid* rg, int axes, int numCoor
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read scalar point attributes. Return 0 if error.
 int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
@@ -2255,7 +2219,7 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   int skipScalar = 0;
   vtkDataArray* data;
   int numComp = 1;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2341,13 +2305,14 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read vector point attributes. Return 0 if error.
 int vtkDataReader::ReadVectorData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipVector = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2392,13 +2357,14 @@ int vtkDataReader::ReadVectorData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read normal point attributes. Return 0 if error.
 int vtkDataReader::ReadNormalData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipNormal = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2443,13 +2409,14 @@ int vtkDataReader::ReadNormalData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read tensor point attributes. Return 0 if error.
 int vtkDataReader::ReadTensorData(vtkDataSetAttributes* a, vtkIdType numPts, vtkIdType numComp)
 {
   int skipTensor = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2493,12 +2460,13 @@ int vtkDataReader::ReadTensorData(vtkDataSetAttributes* a, vtkIdType numPts, vtk
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read color scalar point attributes. Return 0 if error.
 int vtkDataReader::ReadCoScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int i, j, idx, numComp = 0, skipScalar = 0;
   char name[256];
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->Read(&numComp)))
   {
@@ -2589,6 +2557,7 @@ int vtkDataReader::ReadCoScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read texture coordinates point attributes. Return 0 if error.
 int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
@@ -2596,7 +2565,7 @@ int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
   int skipTCoord = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->Read(&dim) && this->ReadString(line)))
   {
@@ -2649,13 +2618,14 @@ int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read texture coordinates point attributes. Return 0 if error.
 int vtkDataReader::ReadGlobalIds(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipGlobalIds = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2695,13 +2665,14 @@ int vtkDataReader::ReadGlobalIds(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read pedigree ids. Return 0 if error.
 int vtkDataReader::ReadPedigreeIds(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipPedigreeIds = 0;
   char line[256], name[256];
   vtkAbstractArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2741,13 +2712,14 @@ int vtkDataReader::ReadPedigreeIds(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read edge flags. Return 0 if error.
 int vtkDataReader::ReadEdgeFlags(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipEdgeFlags = 0;
   char line[256], name[256];
   vtkAbstractArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2787,6 +2759,7 @@ int vtkDataReader::ReadEdgeFlags(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
 {
   // Assuming that the opening INFORMATION line has been read.
@@ -2872,7 +2845,7 @@ int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
         }
         if (values.size() == static_cast<size_t>(length))
         {
-          info->Set(dvKey, &values[0], length);
+          info->Set(dvKey, values.data(), length);
         }
 
         // Pop off the trailing newline:
@@ -2939,7 +2912,7 @@ int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
         }
         if (values.size() == static_cast<size_t>(length))
         {
-          info->Set(ivKey, &values[0], length);
+          info->Set(ivKey, values.data(), length);
         }
 
         // Pop off the trailing newline:
@@ -3044,6 +3017,7 @@ int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read lookup table. Return 0 if error.
 int vtkDataReader::ReadLutData(vtkDataSetAttributes* a)
 {
@@ -3114,6 +3088,7 @@ int vtkDataReader::ReadLutData(vtkDataSetAttributes* a)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadCells(vtkSmartPointer<vtkCellArray>& cellArray)
 {
   vtkIdType offsetsSize{ 0 };
@@ -3194,6 +3169,7 @@ int vtkDataReader::ReadCells(vtkSmartPointer<vtkCellArray>& cellArray)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read lookup table. Return 0 if error.
 int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data)
 {
@@ -3234,6 +3210,7 @@ int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data, int skip1, int read2, int skip3)
 {
   char line[256];
@@ -3346,6 +3323,7 @@ int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data, int skip1, int rea
   return 1;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::ConvertGhostLevelsToGhostType(FieldType fieldType, vtkAbstractArray* data) const
 {
   vtkUnsignedCharArray* ucData = vtkArrayDownCast<vtkUnsignedCharArray>(data);
@@ -3374,6 +3352,7 @@ void vtkDataReader::ConvertGhostLevelsToGhostType(FieldType fieldType, vtkAbstra
   }
 }
 
+//------------------------------------------------------------------------------
 vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
 {
   int i, numArrays = 0, skipField = 0;
@@ -3402,7 +3381,7 @@ vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
   // Read the number of arrays specified
   for (i = 0; i < numArrays; i++)
   {
-    char buffer[1024];
+    char buffer[256];
     this->ReadString(buffer);
     if (strcmp(buffer, "NULL_ARRAY") == 0)
     {
@@ -3441,6 +3420,7 @@ vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
   }
 }
 
+//------------------------------------------------------------------------------
 char* vtkDataReader::LowerCase(char* str, const size_t len)
 {
   size_t i;
@@ -3465,6 +3445,7 @@ void vtkDataReader::CloseVTKFile()
   this->IS = nullptr;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::InitializeCharacteristics()
 {
   int i;
@@ -3537,6 +3518,7 @@ void vtkDataReader::InitializeCharacteristics()
   }
 }
 
+//------------------------------------------------------------------------------
 // read entire file, storing important characteristics
 int vtkDataReader::CharacterizeFile()
 {
@@ -3576,6 +3558,7 @@ int vtkDataReader::CharacterizeFile()
   return 1;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::CheckFor(const char* name, char* line, int& num, char**& array, int& allocSize)
 {
   if (!strncmp(this->LowerCase(line, strlen(name)), name, strlen(name)))
@@ -3624,6 +3607,7 @@ void vtkDataReader::CheckFor(const char* name, char* line, int& num, char**& arr
   } // found one
 }
 
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetScalarsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3637,6 +3621,7 @@ const char* vtkDataReader::GetScalarsNameInFile(int i)
   }
 }
 
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetVectorsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3649,6 +3634,7 @@ const char* vtkDataReader::GetVectorsNameInFile(int i)
     return this->VectorsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetTensorsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3661,6 +3647,7 @@ const char* vtkDataReader::GetTensorsNameInFile(int i)
     return this->TensorsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetNormalsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3673,6 +3660,7 @@ const char* vtkDataReader::GetNormalsNameInFile(int i)
     return this->NormalsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetTCoordsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3685,6 +3673,7 @@ const char* vtkDataReader::GetTCoordsNameInFile(int i)
     return this->TCoordsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetFieldDataNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3698,33 +3687,13 @@ const char* vtkDataReader::GetFieldDataNameInFile(int i)
   }
 }
 
-vtkTypeBool vtkDataReader::ProcessRequest(
-  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
-{
-  // generate the data
-  if (request->Has(vtkDemandDrivenPipeline::REQUEST_DATA()))
-  {
-    return this->RequestData(request, inputVector, outputVector);
-  }
-
-  if (request->Has(vtkStreamingDemandDrivenPipeline::REQUEST_UPDATE_EXTENT()))
-  {
-    return this->RequestUpdateExtent(request, inputVector, outputVector);
-  }
-
-  // execute information
-  if (request->Has(vtkDemandDrivenPipeline::REQUEST_INFORMATION()))
-  {
-    return this->RequestInformation(request, inputVector, outputVector);
-  }
-
-  return this->Superclass::ProcessRequest(request, inputVector, outputVector);
-}
-
+//------------------------------------------------------------------------------
 void vtkDataReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
+  os << indent << "File Version: " << this->FileVersion << "\n";
+
   if (this->FileType == VTK_BINARY)
   {
     os << indent << "File Type: BINARY\n";
@@ -3839,11 +3808,13 @@ void vtkDataReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "InputStringLength: " << this->InputStringLength << endl;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadDataSetData(vtkDataSet* vtkNotUsed(ds))
 {
   return 0;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::DecodeString(char* resname, const char* name)
 {
   if (!resname || !name)
@@ -3883,9 +3854,9 @@ int vtkDataReader::DecodeString(char* resname, const char* name)
   return static_cast<int>(reslen);
 }
 
-static int my_getline(istream& in, vtkStdString& out, char delimiter)
+static int my_getline(istream& in, std::string& out, char delimiter)
 {
-  out = vtkStdString();
+  out = std::string();
   unsigned int numCharactersRead = 0;
   int nextValue = 0;
 
@@ -3932,3 +3903,4 @@ void vtkDataReader::SetScalarLut(const char* lut)
     } while (--n);
   }
 }
+VTK_ABI_NAMESPACE_END
