@@ -28,6 +28,7 @@
 #include "vtkDataWriter.h"
 #include "vtkIOLegacyModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkGraph;
 class vtkMolecule;
 
@@ -38,13 +39,13 @@ public:
   vtkTypeMacro(vtkGraphWriter, vtkDataWriter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get the input to this writer.
    */
   vtkGraph* GetInput();
   vtkGraph* GetInput(int port);
-  //@}
+  ///@}
 
 protected:
   vtkGraphWriter() = default;
@@ -61,4 +62,5 @@ private:
   void operator=(const vtkGraphWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
