@@ -29,6 +29,7 @@
 #include "vtkDataWriter.h"
 #include "vtkIOLegacyModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkStructuredGrid;
 
 class VTKIOLEGACY_EXPORT vtkStructuredGridWriter : public vtkDataWriter
@@ -38,15 +39,15 @@ public:
   vtkTypeMacro(vtkStructuredGridWriter, vtkDataWriter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get the input to this writer.
    */
   vtkStructuredGrid* GetInput();
   vtkStructuredGrid* GetInput(int port);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When WriteExtent is on, vtkStructuredPointsWriter writes
    * data extent in the output file. Otherwise, it writes dimensions.
@@ -57,7 +58,7 @@ public:
   vtkSetMacro(WriteExtent, bool);
   vtkGetMacro(WriteExtent, bool);
   vtkBooleanMacro(WriteExtent, bool);
-  //@}
+  ///@}
 
 protected:
   vtkStructuredGridWriter()
@@ -77,4 +78,5 @@ private:
   void operator=(const vtkStructuredGridWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
