@@ -81,6 +81,7 @@ POSSIBILITY OF SUCH DAMAGES.
 #define VTK_MINC_MAX_DIMS 8
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMINCImageReader);
 
 //------------------------------------------------------------------------------
@@ -318,6 +319,7 @@ int vtkMINCImageReader::CloseNetCDFFile(int ncid)
 //------------------------------------------------------------------------------
 // this is a macro so the vtkErrorMacro will report a useful line number
 #define vtkMINCImageReaderFailAndClose(ncid, status)                                               \
+  do                                                                                               \
   {                                                                                                \
     if ((status) != NC_NOERR)                                                                      \
     {                                                                                              \
@@ -326,7 +328,7 @@ int vtkMINCImageReader::CloseNetCDFFile(int ncid)
         << nc_strerror(status));                                                                   \
     }                                                                                              \
     nc_close(ncid);                                                                                \
-  }
+  } while (false)
 
 //------------------------------------------------------------------------------
 // Function for getting VTK dimension index from the dimension name.
@@ -672,7 +674,8 @@ int vtkMINCImageReader::ReadMINCFileAttributes()
   }
 
   // Get the data type
-  int dataType = this->ConvertMINCTypeToVTKType(this->MINCImageType, this->MINCImageTypeSigned);
+  int dataType =
+    vtkMINCImageReader::ConvertMINCTypeToVTKType(this->MINCImageType, this->MINCImageTypeSigned);
   this->ImageAttributes->SetDataType(dataType);
 
   // Get the name from the file name by removing the path and
@@ -861,24 +864,24 @@ void vtkMINCImageReader::ExecuteInformation()
   unsigned int numberOfDimensions = dimensionNames->GetNumberOfValues();
   for (unsigned int i = 0; i < numberOfDimensions; i++)
   {
-    const char* dimName = dimensionNames->GetValue(i);
+    std::string dimName = dimensionNames->GetValue(i);
     vtkIdType dimLength = dimensionLengths->GetValue(i);
 
     // Set the VTK dimension index.
-    int dimIndex = this->IndexFromDimensionName(dimName);
+    int dimIndex = this->IndexFromDimensionName(dimName.c_str());
 
     // Do special things with the spatial dimensions.
     if (dimIndex >= 0 && dimIndex < 3)
     {
       // Set the spacing from the 'step' attribute.
-      double step = this->ImageAttributes->GetAttributeValueAsDouble(dimName, MIstep);
+      double step = this->ImageAttributes->GetAttributeValueAsDouble(dimName.c_str(), MIstep);
       if (step)
       {
         dataSpacing[dimIndex] = step;
       }
 
       // Set the origin from the 'start' attribute.
-      double start = this->ImageAttributes->GetAttributeValueAsDouble(dimName, MIstart);
+      double start = this->ImageAttributes->GetAttributeValueAsDouble(dimName.c_str(), MIstart);
       if (start)
       {
         dataOrigin[dimIndex] = start;
@@ -889,7 +892,7 @@ void vtkMINCImageReader::ExecuteInformation()
     }
 
     // Check for vector_dimension.
-    else if (strcmp(dimName, MIvector_dimension) == 0)
+    else if (dimName == MIvector_dimension)
     {
       numberOfComponents = dimLength;
     }
@@ -1191,12 +1194,12 @@ void vtkMINCImageReader::ExecuteDataWithInformation(vtkDataObject* output, vtkIn
   {
     idim--;
 
-    const char* dimName = dimensionNames->GetValue(idim);
+    std::string dimName = dimensionNames->GetValue(idim);
     vtkIdType dimLength = dimensionLengths->GetValue(idim);
     length[idim] = dimLength;
 
     // Find the VTK dimension index.
-    int dimIndex = this->IndexFromDimensionName(dimName);
+    int dimIndex = this->IndexFromDimensionName(dimName.c_str());
 
     if (dimIndex >= 0 && dimIndex < 3)
     {
@@ -1205,7 +1208,7 @@ void vtkMINCImageReader::ExecuteDataWithInformation(vtkDataObject* output, vtkIn
       count[idim] = outExt[2 * dimIndex + 1] - outExt[2 * dimIndex] + 1;
       permutedInc[idim] = outInc[dimIndex];
     }
-    else if (strcmp(dimName, MIvector_dimension) == 0)
+    else if (dimName == MIvector_dimension)
     {
       // Vector dimension size is also stored in numComponents.
       start[idim] = 0;
@@ -1358,3 +1361,4 @@ void vtkMINCImageReader::ExecuteDataWithInformation(vtkDataObject* output, vtkIn
 
   this->CloseNetCDFFile(ncid);
 }
+VTK_ABI_NAMESPACE_END
