@@ -68,6 +68,7 @@ POSSIBILITY OF SUCH DAMAGES.
 #include "vtkIOMINCModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkProperty;
 class vtkPolyData;
 class vtkFloatArray;
@@ -83,13 +84,13 @@ public:
   static vtkMNIObjectReader* New();
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set the file name.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
   /**
    * Get the extension for this file format.
@@ -104,7 +105,7 @@ public:
   /**
    * Test whether the specified file can be read.
    */
-  virtual int CanReadFile(const char* name);
+  virtual int CanReadFile(VTK_FILEPATH const char* name);
 
   /**
    * Get the property associated with the object.
@@ -151,4 +152,5 @@ private:
   void operator=(const vtkMNIObjectReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
