@@ -60,7 +60,7 @@ POSSIBILITY OF SUCH DAMAGES.
  * vtkMINCImageReader vtkMNIObjectReader vtkMNITransformReader
  * @par Thanks:
  * Thanks to David Gobbi for contributing this class to VTK.
-*/
+ */
 
 #ifndef vtkMNITagPointWriter_h
 #define vtkMNITagPointWriter_h
@@ -68,6 +68,7 @@ POSSIBILITY OF SUCH DAMAGES.
 #include "vtkIOMINCModule.h" // For export macro
 #include "vtkWriter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 class vtkPointSet;
 class vtkStringArray;
@@ -78,78 +79,74 @@ class vtkPoints;
 class VTKIOMINC_EXPORT vtkMNITagPointWriter : public vtkWriter
 {
 public:
-  vtkTypeMacro(vtkMNITagPointWriter,vtkWriter);
+  vtkTypeMacro(vtkMNITagPointWriter, vtkWriter);
 
-  static vtkMNITagPointWriter *New();
+  static vtkMNITagPointWriter* New();
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Get the extension for this file format.
    */
-  virtual const char* GetFileExtensions() {
-    return ".tag"; }
+  virtual const char* GetFileExtensions() { return ".tag"; }
 
   /**
    * Get the name of this file format.
    */
-  virtual const char* GetDescriptiveName() {
-    return "MNI tags"; }
+  virtual const char* GetDescriptiveName() { return "MNI tags"; }
 
-  //@{
+  ///@{
   /**
    * Set the points (unless you set them as inputs).
    */
-  virtual void SetPoints(int port, vtkPoints *points);
-  virtual void SetPoints(vtkPoints *points) {
-    this->SetPoints(0, points); }
-  virtual vtkPoints *GetPoints(int port);
-  virtual vtkPoints *GetPoints() {
-    return this->GetPoints(0); }
-  //@}
+  virtual void SetPoints(int port, vtkPoints* points);
+  virtual void SetPoints(vtkPoints* points) { this->SetPoints(0, points); }
+  virtual vtkPoints* GetPoints(int port);
+  virtual vtkPoints* GetPoints() { return this->GetPoints(0); }
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the labels (unless the input PointData has an
    * array called LabelText). Labels are optional.
    */
-  virtual void SetLabelText(vtkStringArray *a);
+  virtual void SetLabelText(vtkStringArray* a);
   vtkGetObjectMacro(LabelText, vtkStringArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the weights (unless the input PointData has an
    * array called Weights).  Weights are optional.
    */
-  virtual void SetWeights(vtkDoubleArray *a);
+  virtual void SetWeights(vtkDoubleArray* a);
   vtkGetObjectMacro(Weights, vtkDoubleArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the structure ids (unless the input PointData has
    * an array called StructureIds).  These are optional.
    */
-  virtual void SetStructureIds(vtkIntArray *a);
+  virtual void SetStructureIds(vtkIntArray* a);
   vtkGetObjectMacro(StructureIds, vtkIntArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the structure ids (unless the input PointData has
    * an array called PatientIds).  These are optional.
    */
-  virtual void SetPatientIds(vtkIntArray *a);
+  virtual void SetPatientIds(vtkIntArray* a);
   vtkGetObjectMacro(PatientIds, vtkIntArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set comments to be added to the file.
    */
   vtkSetStringMacro(Comments);
   vtkGetStringMacro(Comments);
-  //@}
+  ///@}
 
   /**
    * Write the file.
@@ -161,44 +158,43 @@ public:
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Specify file name of vtk polygon data file to write.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
 protected:
   vtkMNITagPointWriter();
   ~vtkMNITagPointWriter() override;
 
-  vtkPoints *Points[2];
-  vtkStringArray *LabelText;
-  vtkDoubleArray *Weights;
-  vtkIntArray *StructureIds;
-  vtkIntArray *PatientIds;
-  char *Comments;
+  vtkPoints* Points[2];
+  vtkStringArray* LabelText;
+  vtkDoubleArray* Weights;
+  vtkIntArray* StructureIds;
+  vtkIntArray* PatientIds;
+  char* Comments;
 
   void WriteData() override {}
-  virtual void WriteData(vtkPointSet *inputs[2]);
+  virtual void WriteData(vtkPointSet* inputs[2]);
 
-  int FillInputPortInformation(int port, vtkInformation *info) override;
+  int FillInputPortInformation(int port, vtkInformation* info) override;
 
-  int RequestData(vtkInformation *, vtkInformationVector **,
-                  vtkInformationVector *) override;
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
   char* FileName;
 
   int FileType;
 
-  ostream *OpenFile();
-  void CloseFile(ostream *fp);
+  ostream* OpenFile();
+  void CloseFile(ostream* fp);
 
 private:
   vtkMNITagPointWriter(const vtkMNITagPointWriter&) = delete;
   void operator=(const vtkMNITagPointWriter&) = delete;
-
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
