@@ -43,6 +43,7 @@
 #include "vtkIOMPIImageModule.h" // For export macro
 #include "vtkNrrdReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCharArray;
 class vtkMultiProcessController;
 class vtkMPIOpaqueFileHandle;
@@ -54,14 +55,14 @@ public:
   static vtkPNrrdReader* New();
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/set the multi process controller to use for coordinated reads.  By
    * default, set to the global controller.
    */
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
   virtual void SetController(vtkMultiProcessController*);
-  //@}
+  ///@}
 
 protected:
   vtkPNrrdReader();
@@ -110,14 +111,14 @@ protected:
    */
   virtual void TransformData(vtkImageData* data);
 
-  //@{
+  ///@{
   /**
    * A group of processes that are reading the same file (as determined by
    * PartitionController.
    */
   void SetGroupedController(vtkMultiProcessController*);
   vtkMultiProcessController* GroupedController;
-  //@}
+  ///@}
 
   void ExecuteDataWithInformation(vtkDataObject* data, vtkInformation* outInfo) override;
 
@@ -128,4 +129,5 @@ private:
   void operator=(const vtkPNrrdReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPNrrdReader_h
