@@ -35,6 +35,7 @@
     static MPI_Datatype type() { return mpitype; }                                                 \
   };
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 template <class T>
@@ -177,7 +178,7 @@ vtkMPIMultiBlockPLOT3DReader::vtkMPIMultiBlockPLOT3DReader()
 }
 
 //------------------------------------------------------------------------------
-vtkMPIMultiBlockPLOT3DReader::~vtkMPIMultiBlockPLOT3DReader() {}
+vtkMPIMultiBlockPLOT3DReader::~vtkMPIMultiBlockPLOT3DReader() = default;
 
 //------------------------------------------------------------------------------
 bool vtkMPIMultiBlockPLOT3DReader::CanUseMPIIO()
@@ -234,6 +235,7 @@ void vtkMPIMultiBlockPLOT3DReader::CloseFile(void* vfp)
   {
     vtkErrorMacro("Failed to close file!");
   }
+  delete handle;
 }
 
 //------------------------------------------------------------------------------
@@ -323,3 +325,4 @@ void vtkMPIMultiBlockPLOT3DReader::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "UseMPIIO: " << this->UseMPIIO << endl;
 }
+VTK_ABI_NAMESPACE_END
