@@ -20,14 +20,14 @@
 #include <string>
 
 // Registration of MySQL dynamically with the vtkSQLDatabase factory method.
-vtkSQLDatabase * MySQLCreateFunction(const char* URL)
+VTK_ABI_NAMESPACE_BEGIN
+vtkSQLDatabase* MySQLCreateFunction(const char* URL)
 {
   std::string urlstr(URL ? URL : "");
   std::string protocol, unused;
-  vtkMySQLDatabase *db = 0;
+  vtkMySQLDatabase* db = nullptr;
 
-  if (vtksys::SystemTools::ParseURLProtocol(urlstr, protocol, unused) &&
-      protocol == "mysql")
+  if (vtksys::SystemTools::ParseURLProtocol(urlstr, protocol, unused) && protocol == "mysql")
   {
     db = vtkMySQLDatabase::New();
     db->ParseURL(URL);
@@ -45,3 +45,4 @@ VTKIOMYSQL_EXPORT void vtkIOMySQL_AutoInit_Construct()
     vtkSQLDatabase::RegisterCreateFromURLCallback(MySQLCreateFunction);
   }
 }
+VTK_ABI_NAMESPACE_END
