@@ -2,24 +2,26 @@
 #define vtkMySQLDatabasePrivate_h
 
 #ifdef _WIN32
-# include <winsock.h> // mysql.h relies on the typedefs from here
+#include <winsock.h> // mysql.h relies on the typedefs from here
 #endif
 
 #include "vtkIOMySQLModule.h" // For export macro
-#include <mysql.h> // needed for MYSQL typedefs
+#include <mysql.h>            // needed for MYSQL typedefs
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOMYSQL_EXPORT vtkMySQLDatabasePrivate
 {
 public:
-  vtkMySQLDatabasePrivate() :
-    Connection( nullptr )
+  vtkMySQLDatabasePrivate()
+    : Connection(nullptr)
   {
-  mysql_init( &this->NullConnection );
+    mysql_init(&this->NullConnection);
   }
 
   MYSQL NullConnection;
-  MYSQL *Connection;
+  MYSQL* Connection;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkMySQLDatabasePrivate_h
 // VTK-HeaderTest-Exclude: vtkMySQLDatabasePrivate.h
