@@ -48,17 +48,18 @@
 #include <sqlext.h>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkODBCDatabase);
 
 //------------------------------------------------------------------------------
-static vtkStdString GetErrorMessage(SQLSMALLINT handleType, SQLHANDLE handle, int* code = 0)
+static std::string GetErrorMessage(SQLSMALLINT handleType, SQLHANDLE handle, int* code = nullptr)
 {
   SQLINTEGER sqlNativeCode = 0;
   SQLSMALLINT messageLength = 0;
   SQLRETURN status;
   SQLCHAR state[SQL_SQLSTATE_SIZE + 1];
   SQLCHAR description[SQL_MAX_MESSAGE_LENGTH + 1];
-  vtkStdString finalResult;
+  std::string finalResult;
   int i = 1;
 
   // There may be several error messages queued up so we need to loop
@@ -84,12 +85,12 @@ static vtkStdString GetErrorMessage(SQLSMALLINT handleType, SQLHANDLE handle, in
     }
     else if (status == SQL_ERROR || status == SQL_INVALID_HANDLE)
     {
-      return vtkStdString(messagebuf.str());
+      return messagebuf.str();
     }
     ++i;
   } while (status != SQL_NO_DATA);
 
-  return vtkStdString(messagebuf.str());
+  return messagebuf.str();
 }
 
 //------------------------------------------------------------------------------
@@ -99,9 +100,9 @@ static vtkStdString GetErrorMessage(SQLSMALLINT handleType, SQLHANDLE handle, in
 // Also, this will need to be updated when we start handling Unicode
 // characters.
 
-static vtkStdString odbcGetString(SQLHANDLE statement, int column, int columnSize)
+static std::string odbcGetString(SQLHANDLE statement, int column, int columnSize)
 {
-  vtkStdString returnString;
+  std::string returnString;
   SQLRETURN status = SQL_ERROR;
   SQLLEN lengthIndicator;
 
@@ -185,7 +186,7 @@ vtkODBCDatabase::vtkODBCDatabase()
   this->ServerPort = -1; // use whatever the driver defaults to
 
   // Initialize instance variables
-  this->DatabaseType = 0;
+  this->DatabaseType = nullptr;
   this->SetDatabaseType("ODBC");
 }
 
@@ -198,7 +199,7 @@ vtkODBCDatabase::~vtkODBCDatabase()
   }
   if (this->DatabaseType)
   {
-    this->SetDatabaseType(0);
+    this->SetDatabaseType(nullptr);
   }
   this->SetLastErrorText(nullptr);
   this->SetUserName(nullptr);
@@ -285,7 +286,7 @@ bool vtkODBCDatabase::Open(const char* password)
   }
 
   // Create the connection string itself
-  vtkStdString connectionString;
+  std::string connectionString;
   if (strstr(this->DataSourceName, ".dsn") != nullptr)
   {
     // the data source is a file of some sort
@@ -336,7 +337,7 @@ bool vtkODBCDatabase::Open(const char* password)
 
 #ifdef ODBC_DRIVER_IS_IODBC
   // Set the driver name so we know who to blame
-  vtkStdString driverName("vtkODBCDatabase driver");
+  std::string driverName("vtkODBCDatabase driver");
   status = SQLSetConnectAttr(
     this->Internals->Connection, SQL_APPLICATION_NAME, driverName.c_str(), driverName.size());
   if (status != SQL_SUCCESS && status != SQL_SUCCESS_WITH_INFO)
@@ -456,7 +457,7 @@ vtkStringArray* vtkODBCDatabase::GetTables()
     status = SQLSetStmtAttr(statement, SQL_ATTR_CURSOR_TYPE,
       static_cast<SQLPOINTER>(SQL_CURSOR_FORWARD_ONLY), SQL_IS_UINTEGER);
 
-    vtkStdString tableType("TABLE,");
+    std::string tableType("TABLE,");
 
     status = SQLTables(statement, nullptr, 0, nullptr, 0, nullptr, 0,
       (SQLCHAR*)(const_cast<char*>(tableType.c_str())), static_cast<SQLSMALLINT>(tableType.size()));
@@ -470,7 +471,7 @@ vtkStringArray* vtkODBCDatabase::GetTables()
     status = SQLFetchScroll(statement, SQL_FETCH_NEXT, 0);
     while (status == SQL_SUCCESS)
     {
-      vtkStdString fieldVal = odbcGetString(statement, 2, -1);
+      std::string fieldVal = odbcGetString(statement, 2, -1);
       this->Tables->InsertNextValue(fieldVal);
       status = SQLFetchScroll(statement, SQL_FETCH_NEXT, 0);
     }
@@ -529,11 +530,11 @@ vtkStringArray* vtkODBCDatabase::GetRecord(const char* table)
 
   if (status != SQL_SUCCESS && status != 0)
   {
-    vtkStdString error = GetErrorMessage(SQL_HANDLE_STMT, statement);
+    std::string error = GetErrorMessage(SQL_HANDLE_STMT, statement);
 
     vtkErrorMacro(
       << "vtkODBCDatabase::GetRecord: Unable to retrieve column list (SQLColumns): error "
-      << error.c_str());
+      << error);
     this->SetLastErrorText(error.c_str());
     SQLFreeHandle(SQL_HANDLE_STMT, statement);
     return this->Record;
@@ -542,17 +543,17 @@ vtkStringArray* vtkODBCDatabase::GetRecord(const char* table)
   status = SQLFetchScroll(statement, SQL_FETCH_NEXT, 0);
   if (status != SQL_SUCCESS)
   {
-    vtkStdString error = GetErrorMessage(SQL_HANDLE_STMT, statement);
+    std::string error = GetErrorMessage(SQL_HANDLE_STMT, statement);
     vtkErrorMacro(
       << "vtkODBCDatabase::GetRecord: Unable to retrieve column list (SQLFetchScroll): error "
-      << error.c_str());
+      << error);
     this->SetLastErrorText(error.c_str());
     SQLFreeHandle(SQL_HANDLE_STMT, statement);
     return this->Record;
   }
   while (status == SQL_SUCCESS)
   {
-    vtkStdString fieldName = odbcGetString(statement, 3, -1);
+    std::string fieldName = odbcGetString(statement, 3, -1);
     this->Record->InsertNextValue(fieldName);
     status = SQLFetchScroll(statement, SQL_FETCH_NEXT, 0);
   }
@@ -572,7 +573,7 @@ void vtkODBCDatabase::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "DataSourceName: ";
-  if (this->DataSourceName == 0)
+  if (this->DataSourceName == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -582,7 +583,7 @@ void vtkODBCDatabase::PrintSelf(ostream& os, vtkIndent indent)
   }
 
   os << indent << "DatabaseName: ";
-  if (this->DatabaseName == 0)
+  if (this->DatabaseName == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -592,7 +593,7 @@ void vtkODBCDatabase::PrintSelf(ostream& os, vtkIndent indent)
   }
 
   os << indent << "UserName: ";
-  if (this->UserName == 0)
+  if (this->UserName == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -601,7 +602,7 @@ void vtkODBCDatabase::PrintSelf(ostream& os, vtkIndent indent)
     os << this->UserName << endl;
   }
   os << indent << "HostName: ";
-  if (this->HostName == 0)
+  if (this->HostName == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -610,7 +611,7 @@ void vtkODBCDatabase::PrintSelf(ostream& os, vtkIndent indent)
     os << this->HostName << endl;
   }
   os << indent << "Password: ";
-  if (this->Password == 0)
+  if (this->Password == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -650,7 +651,7 @@ bool vtkODBCDatabase::ParseURL(const char* URL)
   if (!vtksys::SystemTools::ParseURL(
         urlstr, protocol, username, unused, dsname, dataport, database))
   {
-    vtkErrorMacro("Invalid URL: \"" << urlstr.c_str() << "\"");
+    vtkErrorMacro("Invalid URL: \"" << urlstr << "\"");
     return false;
   }
 
@@ -675,7 +676,7 @@ vtkStdString vtkODBCDatabase::GetColumnSpecification(
 
   // Figure out column type
   int colType = schema->GetColumnTypeFromHandle(tblHandle, colHandle);
-  vtkStdString colTypeStr;
+  std::string colTypeStr;
 
   switch (static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>(colType))
   {
@@ -717,14 +718,14 @@ vtkStdString vtkODBCDatabase::GetColumnSpecification(
       break;
   }
 
-  if (colTypeStr.size())
+  if (!colTypeStr.empty())
   {
     queryStr << " " << colTypeStr;
   }
-  else // if ( colTypeStr.size() )
+  else // if ( !colTypeStr.empty() )
   {
     vtkGenericWarningMacro("Unable to get column specification: unsupported data type " << colType);
-    return vtkStdString();
+    return {};
   }
 
   // Decide whether size is allowed, required, or unused
@@ -791,7 +792,7 @@ vtkStdString vtkODBCDatabase::GetColumnSpecification(
   }
 
   vtkStdString attStr = schema->GetColumnAttributesFromHandle(tblHandle, colHandle);
-  if (attStr.size())
+  if (!attStr.empty())
   {
     queryStr << " " << attStr;
   }
@@ -804,7 +805,7 @@ vtkStdString vtkODBCDatabase::GetIndexSpecification(
   vtkSQLDatabaseSchema* schema, int tblHandle, int idxHandle, bool& skipped)
 {
   skipped = false;
-  vtkStdString queryStr = ", ";
+  std::string queryStr = ", ";
   bool mustUseName = true;
 
   int idxType = schema->GetIndexTypeFromHandle(tblHandle, idxHandle);
@@ -821,7 +822,7 @@ vtkStdString vtkODBCDatabase::GetIndexSpecification(
       queryStr += "INDEX ";
       break;
     default:
-      return vtkStdString();
+      return {};
   }
 
   // No index_name for PRIMARY KEYs
@@ -837,7 +838,7 @@ vtkStdString vtkODBCDatabase::GetIndexSpecification(
   {
     vtkGenericWarningMacro(
       "Unable to get index specification: index has incorrect number of columns " << numCnm);
-    return vtkStdString();
+    return {};
   }
 
   bool firstCnm = true;
@@ -865,7 +866,7 @@ bool vtkODBCDatabase::CreateDatabase(const char* dbName, bool dropExisting = fal
   {
     this->DropDatabase(dbName);
   }
-  vtkStdString queryStr;
+  std::string queryStr;
   queryStr = "CREATE DATABASE ";
   queryStr += dbName;
   vtkSQLQuery* query = this->GetQueryInstance();
@@ -881,7 +882,7 @@ bool vtkODBCDatabase::CreateDatabase(const char* dbName, bool dropExisting = fal
 //------------------------------------------------------------------------------
 bool vtkODBCDatabase::DropDatabase(const char* dbName)
 {
-  vtkStdString queryStr;
+  std::string queryStr;
   queryStr = "DROP DATABASE ";
   queryStr += dbName;
   vtkSQLQuery* query = this->GetQueryInstance();
@@ -890,3 +891,4 @@ bool vtkODBCDatabase::DropDatabase(const char* dbName)
   query->Delete();
   return status;
 }
+VTK_ABI_NAMESPACE_END
