@@ -25,6 +25,7 @@
 #include <ctime>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOggTheoraWriterInternal
 {
 public:
@@ -153,7 +154,7 @@ int vtkOggTheoraWriterInternal::Start()
   // the frame rate (as a fraction)
   thInfo.fps_numerator = this->FrameRate;
   thInfo.fps_denominator = 1;
-  // pixel ascpect ratio
+  // pixel aspect ratio
   thInfo.aspect_numerator = 1;
   thInfo.aspect_denominator = 1;
 
@@ -356,7 +357,7 @@ void vtkOggTheoraWriterInternal::RGB2YCbCr(vtkImageData* id, th_ycbcr_buffer ycb
   typedef unsigned char uchar;
 
   //
-  // constant coefficiens
+  // constant coefficients
   //
 
   static const uchar OffY = 16, OffCr = 128, OffCb = 128;
@@ -589,3 +590,4 @@ void vtkOggTheoraWriter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Rate: " << this->Rate << endl;
   os << indent << "Subsampling: " << this->Subsampling << endl;
 }
+VTK_ABI_NAMESPACE_END
