@@ -24,24 +24,25 @@
  * This implementation is based on vtkFFMPEGWriter and uses some code derived
  * from the encoder example distributed with libtheora.
  *
-*/
+ */
 
 #ifndef vtkOggTheoraWriter_h
 #define vtkOggTheoraWriter_h
 
-#include "vtkIOOggTheoraModule.h" // For export macro
 #include "vtkGenericMovieWriter.h"
+#include "vtkIOOggTheoraModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOggTheoraWriterInternal;
 
 class VTKIOOGGTHEORA_EXPORT vtkOggTheoraWriter : public vtkGenericMovieWriter
 {
 public:
-  static vtkOggTheoraWriter *New();
-  vtkTypeMacro(vtkOggTheoraWriter,vtkGenericMovieWriter);
+  static vtkOggTheoraWriter* New();
+  vtkTypeMacro(vtkOggTheoraWriter, vtkGenericMovieWriter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * These methods start writing an Movie file, write a frame to the file
    * and then end the writing process.
@@ -49,9 +50,9 @@ public:
   void Start() override;
   void Write() override;
   void End() override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the compression quality.
    * 0 means worst quality and smallest file size
@@ -59,30 +60,30 @@ public:
    */
   vtkSetClampMacro(Quality, int, 0, 2);
   vtkGetMacro(Quality, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the frame rate, in frame/s.
    */
-  vtkSetClampMacro(Rate, int , 1, 5000);
+  vtkSetClampMacro(Rate, int, 1, 5000);
   vtkGetMacro(Rate, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Is the video to be encoded using 4:2:0 subsampling?
    */
   vtkSetMacro(Subsampling, vtkTypeBool);
   vtkGetMacro(Subsampling, vtkTypeBool);
   vtkBooleanMacro(Subsampling, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkOggTheoraWriter();
   ~vtkOggTheoraWriter() override;
 
-  vtkOggTheoraWriterInternal *Internals;
+  vtkOggTheoraWriterInternal* Internals;
 
   int Initialized;
   int Quality;
@@ -94,4 +95,5 @@ private:
   void operator=(const vtkOggTheoraWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
