@@ -52,6 +52,7 @@
 #include <pdal/PointView.hpp>
 #include <pdal/StageFactory.hpp>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPDALReader);
 
 //------------------------------------------------------------------------------
@@ -66,10 +67,7 @@ vtkPDALReader::vtkPDALReader()
 //------------------------------------------------------------------------------
 vtkPDALReader::~vtkPDALReader()
 {
-  if (this->FileName)
-  {
-    delete[] this->FileName;
-  }
+  delete[] this->FileName;
 }
 
 //------------------------------------------------------------------------------
@@ -85,7 +83,7 @@ int vtkPDALReader::RequestData(vtkInformation* vtkNotUsed(request),
     vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
     pdal::StageFactory factory;
-    std::string driverName = factory.inferReaderDriver(this->FileName);
+    std::string driverName = pdal::StageFactory::inferReaderDriver(this->FileName);
     if (driverName.empty())
     {
       vtkErrorMacro("Cannot infer the reader driver for " << this->FileName);
@@ -403,3 +401,4 @@ void vtkPDALReader::PrintSelf(ostream& os, vtkIndent indent)
   os << "vtkPDALReader" << std::endl;
   os << "Filename: " << this->FileName << std::endl;
 }
+VTK_ABI_NAMESPACE_END
