@@ -78,6 +78,7 @@
 #endif
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkEnSightWriter);
 
 //------------------------------------------------------------------------------
@@ -516,7 +517,7 @@ void vtkEnSightWriter::WriteData()
             this->WriteIntToFile(CellId, fd);
           }
 
-          // element conenctivity information
+          // element connectivity information
           for (k = 0; k < CellsByElement[elementType].size(); k++)
           {
             int CellId = CellsByElement[elementType][k];
@@ -1135,3 +1136,4 @@ void vtkEnSightWriter::ComputeNames()
 
   delete[] buf;
 }
+VTK_ABI_NAMESPACE_END
