@@ -34,9 +34,9 @@
 #include "vtkPointData.h"
 #include "vtkProcessGroup.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
-#include "vtkToolkits.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPChacoReader);
 
 //------------------------------------------------------------------------------
@@ -60,29 +60,13 @@ void vtkPChacoReader::SetController(vtkMultiProcessController* c)
     this->MyId = 0;
   }
 
-  if (this->Controller == c)
+  vtkSetObjectBodyMacro(Controller, vtkMultiProcessController, c);
+
+  if (c)
   {
-    return;
+    this->NumProcesses = c->GetNumberOfProcesses();
+    this->MyId = c->GetLocalProcessId();
   }
-
-  this->Modified();
-
-  if (this->Controller != nullptr)
-  {
-    this->Controller->UnRegister(this);
-    this->Controller = nullptr;
-  }
-
-  if (c == nullptr)
-  {
-    return;
-  }
-
-  this->Controller = c;
-
-  c->Register(this);
-  this->NumProcesses = c->GetNumberOfProcesses();
-  this->MyId = c->GetLocalProcessId();
 }
 
 //------------------------------------------------------------------------------
@@ -316,7 +300,7 @@ void vtkPChacoReader::SetUpEmptyGrid(vtkUnstructuredGrid* output)
     vtkIntArray* ia = vtkIntArray::New();
     ia->SetNumberOfTuples(0);
     ia->SetNumberOfComponents(1);
-    ia->SetName(this->GetGlobalElementIdArrayName());
+    ia->SetName(vtkPChacoReader::GetGlobalElementIdArrayName());
     output->GetCellData()->AddArray(ia);
   }
 
@@ -325,7 +309,7 @@ void vtkPChacoReader::SetUpEmptyGrid(vtkUnstructuredGrid* output)
     vtkIntArray* ia = vtkIntArray::New();
     ia->SetNumberOfTuples(0);
     ia->SetNumberOfComponents(1);
-    ia->SetName(this->GetGlobalNodeIdArrayName());
+    ia->SetName(vtkPChacoReader::GetGlobalNodeIdArrayName());
     output->GetPointData()->AddArray(ia);
   }
 }
@@ -560,3 +544,4 @@ void vtkPChacoReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "NumProcesses: " << this->NumProcesses << endl;
   os << indent << "Controller: " << this->Controller << endl;
 }
+VTK_ABI_NAMESPACE_END
