@@ -26,6 +26,7 @@
 #include "vtkDataSetAlgorithm.h"
 #include "vtkIOParallelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataSet;
 
 class VTKIOPARALLEL_EXPORT vtkPDataSetReader : public vtkDataSetAlgorithm
@@ -35,26 +36,26 @@ public:
   vtkTypeMacro(vtkPDataSetReader, vtkDataSetAlgorithm);
   static vtkPDataSetReader* New();
 
-  //@{
+  ///@{
   /**
    * This file to open and read.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This is set when UpdateInformation is called.
    * It shows the type of the output.
    */
   vtkGetMacro(DataType, int);
-  //@}
+  ///@}
 
   /**
    * Called to determine if the file can be read by the reader.
    */
-  int CanReadFile(const char* filename);
+  int CanReadFile(VTK_FILEPATH const char* filename);
 
 protected:
   vtkPDataSetReader();
@@ -96,4 +97,5 @@ private:
   void operator=(const vtkPDataSetReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
