@@ -15,22 +15,24 @@
 
 #include "vtkPDataSetWriter.h"
 #include "vtkDataSet.h"
-#include "vtkObjectFactory.h"
+#include "vtkErrorCode.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkMultiProcessController.h"
-#include "vtkStructuredGrid.h"
+#include "vtkObjectFactory.h"
 #include "vtkRectilinearGrid.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
-#include "vtkErrorCode.h"
+#include "vtkStructuredGrid.h"
+#include "vtksys/FStream.hxx"
 
+#include <vector>
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPDataSetWriter);
 
-vtkCxxSetObjectMacro(vtkPDataSetWriter,
-                     Controller,
-                     vtkMultiProcessController);
+vtkCxxSetObjectMacro(vtkPDataSetWriter, Controller, vtkMultiProcessController);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPDataSetWriter::vtkPDataSetWriter()
 {
   this->StartPiece = 0;
@@ -46,15 +48,14 @@ vtkPDataSetWriter::vtkPDataSetWriter()
   this->SetController(vtkMultiProcessController::GetGlobalController());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPDataSetWriter::~vtkPDataSetWriter()
 {
   this->SetFilePattern(nullptr);
   this->SetController(nullptr);
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPDataSetWriter::SetNumberOfPieces(int num)
 {
   if (num == this->NumberOfPieces)
@@ -67,21 +68,19 @@ void vtkPDataSetWriter::SetNumberOfPieces(int num)
 
   // Default behavior is for the single process to stream the pieces.
   this->StartPiece = 0;
-  this->EndPiece = num-1;
+  this->EndPiece = num - 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPDataSetWriter::Write()
 {
   int i;
   int length;
-  char *fileRoot;
-  char *fileName;
 
-  ostream *fptr;
-  vtkDataSet *input = this->GetInput();
+  ostream* fptr;
+  vtkDataSet* input = this->GetInput();
   int inputAlgPort;
-  vtkAlgorithm *inputAlg = this->GetInputAlgorithm(0, 0, inputAlgPort);
+  vtkAlgorithm* inputAlg = this->GetInputAlgorithm(0, 0, inputAlgPort);
 
   if (this->FileName == nullptr)
   {
@@ -107,19 +106,19 @@ int vtkPDataSetWriter::Write()
 
   // Lets compute the file root from the file name supplied by the user.
   length = static_cast<int>(strlen(this->FileName));
-  fileRoot = new char [length+1];
-  size_t fileNameSize = length+strlen(this->FilePattern)+20;
-  fileName = new char [fileNameSize];
-  strncpy(fileRoot, this->FileName, length);
+  std::vector<char> fileRoot(length + 1);
+  size_t fileNameSize = length + strlen(this->FilePattern) + 20;
+  std::vector<char> fileName(fileNameSize);
+  strncpy(fileRoot.data(), this->FileName, length);
   fileRoot[length] = '\0';
   // Trim off the pvtk extension.
-  if (strncmp(fileRoot+length-5, ".pvtk", 5) == 0)
+  if (strncmp(fileRoot.data() + length - 5, ".pvtk", 5) == 0)
   {
-    fileRoot[length-5] = '\0';
+    fileRoot[length - 5] = '\0';
   }
-  if (strncmp(fileRoot+length-4, ".vtk", 4) == 0)
+  if (strncmp(fileRoot.data() + length - 4, ".vtk", 4) == 0)
   {
-    fileRoot[length-4] = '\0';
+    fileRoot[length - 4] = '\0';
   }
   // If we are using relative file names, trim off the directory path.
   if (this->UseRelativeFileNames)
@@ -127,7 +126,7 @@ int vtkPDataSetWriter::Write()
     char *tmp, *slash;
     // Find the last / or \ in the file name.
     slash = nullptr;
-    tmp = fileRoot;
+    tmp = fileRoot.data();
     while (*tmp != '\0')
     {
       if (*tmp == '/' || *tmp == '\\')
@@ -140,7 +139,7 @@ int vtkPDataSetWriter::Write()
     if (slash)
     {
       ++slash;
-      tmp = fileRoot;
+      tmp = fileRoot.data();
       while (*slash != '\0')
       {
         *tmp++ = *slash++;
@@ -149,30 +148,29 @@ int vtkPDataSetWriter::Write()
     }
   }
 
-
   // Restore the fileRoot to the full path.
-  strncpy(fileRoot, this->FileName, length);
+  strncpy(fileRoot.data(), this->FileName, length);
   fileRoot[length] = '\0';
   // Trim off the pvtk extension.
-  if (strncmp(fileRoot+length-5, ".pvtk", 5) == 0)
+  if (strncmp(fileRoot.data() + length - 5, ".pvtk", 5) == 0)
   {
-    fileRoot[length-5] = '\0';
+    fileRoot[length - 5] = '\0';
   }
-  if (strncmp(fileRoot+length-4, ".vtk", 4) == 0)
+  if (strncmp(fileRoot.data() + length - 4, ".vtk", 4) == 0)
   {
-    fileRoot[length-4] = '\0';
+    fileRoot[length - 4] = '\0';
   }
 
   this->UpdateInformation();
 
   // Now write the pieces assigned to this writer.
-  vtkDataSetWriter *writer = vtkDataSetWriter::New();
+  vtkDataSetWriter* writer = vtkDataSetWriter::New();
   writer->SetFileTypeToBinary();
-  vtkDataObject *copy;
+  vtkDataObject* copy;
   for (i = this->StartPiece; i <= this->EndPiece; ++i)
   {
-    snprintf(fileName, fileNameSize, this->FilePattern, fileRoot, i);
-    writer->SetFileName(fileName);
+    snprintf(fileName.data(), fileNameSize, this->FilePattern, fileRoot.data(), i);
+    writer->SetFileName(fileName.data());
     inputAlg->UpdatePiece(i, this->NumberOfPieces, this->GhostLevel);
 
     // Store the extent of this piece in Extents. This is later used
@@ -185,7 +183,7 @@ int vtkPDataSetWriter::Write()
     }
     if (ext)
     {
-      this->Extents[i] = std::vector<int>(ext, ext+6);
+      this->Extents[i] = std::vector<int>(ext, ext + 6);
     }
 
     copy = input->NewInstance();
@@ -209,15 +207,12 @@ int vtkPDataSetWriter::Write()
   writer->Delete();
   writer = nullptr;
 
-    // Lets write the toplevel file.
-  if (this->StartPiece == 0 &&
-      (!this->Controller || this->Controller->GetLocalProcessId() == 0))
+  // Lets write the toplevel file.
+  if (this->StartPiece == 0 && (!this->Controller || this->Controller->GetLocalProcessId() == 0))
   {
     fptr = this->OpenFile();
     if (fptr == nullptr)
     {
-      delete [] fileRoot;
-      delete [] fileName;
       return 0;
     }
     // Write a tag so that we know this file type.
@@ -225,11 +220,9 @@ int vtkPDataSetWriter::Write()
     fptr->flush();
     if (fptr->fail())
     {
-      vtkErrorMacro(<< "Unable to write to file: "<< this->FileName);
+      vtkErrorMacro(<< "Unable to write to file: " << this->FileName);
       this->CloseVTKFile(fptr);
       remove(this->FileName);
-      delete [] fileRoot;
-      delete [] fileName;
       delete fptr;
       this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
       return 0;
@@ -239,13 +232,11 @@ int vtkPDataSetWriter::Write()
     {
       case VTK_POLY_DATA:
       case VTK_UNSTRUCTURED_GRID:
-        if (!this->WriteUnstructuredMetaData(input, fileRoot,
-                                             fileName, fileNameSize, fptr))
+        if (!this->WriteUnstructuredMetaData(
+              input, fileRoot.data(), fileName.data(), fileNameSize, fptr))
         {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
-          delete [] fileRoot;
-          delete [] fileName;
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
@@ -253,41 +244,33 @@ int vtkPDataSetWriter::Write()
         break;
       case VTK_IMAGE_DATA:
       case VTK_STRUCTURED_POINTS:
-        if (!this->WriteImageMetaData((vtkImageData*)input, fileRoot,
-                                      fileName, fileNameSize, fptr))
+        if (!this->WriteImageMetaData(
+              (vtkImageData*)input, fileRoot.data(), fileName.data(), fileNameSize, fptr))
         {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
-          delete [] fileRoot;
-          delete [] fileName;
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
         }
         break;
       case VTK_RECTILINEAR_GRID:
-        if (!this->WriteRectilinearGridMetaData((vtkRectilinearGrid*)input,
-                                                fileRoot, fileName,
-                                                fileNameSize, fptr))
+        if (!this->WriteRectilinearGridMetaData(
+              (vtkRectilinearGrid*)input, fileRoot.data(), fileName.data(), fileNameSize, fptr))
         {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
-          delete [] fileRoot;
-          delete [] fileName;
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
         }
         break;
       case VTK_STRUCTURED_GRID:
-        if (!this->WriteStructuredGridMetaData((vtkStructuredGrid*)input,
-                                               fileRoot, fileName,
-                                               fileNameSize, fptr))
+        if (!this->WriteStructuredGridMetaData(
+              (vtkStructuredGrid*)input, fileRoot.data(), fileName.data(), fileNameSize, fptr))
         {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
-          delete [] fileRoot;
-          delete [] fileName;
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
@@ -295,20 +278,16 @@ int vtkPDataSetWriter::Write()
         break;
     }
 
-    //fptr->close();
+    // fptr->close();
     delete fptr;
   }
 
-  delete [] fileName;
-  delete [] fileRoot;
-
   return 1;
 }
 
-//----------------------------------------------------------------------------
-int vtkPDataSetWriter::WriteUnstructuredMetaData(vtkDataSet *input,
-                                         char *root, char *str,
-                                         size_t strSize, ostream *fptr)
+//------------------------------------------------------------------------------
+int vtkPDataSetWriter::WriteUnstructuredMetaData(
+  vtkDataSet* input, char* root, char* str, size_t strSize, ostream* fptr)
 {
   int i;
 
@@ -331,14 +310,12 @@ int vtkPDataSetWriter::WriteUnstructuredMetaData(vtkDataSet *input,
   return 1;
 }
 
-
-//----------------------------------------------------------------------------
-int vtkPDataSetWriter::WriteImageMetaData(vtkImageData * input,
-                                          char *root, char *str,
-                                          size_t strSize, ostream *fptr)
+//------------------------------------------------------------------------------
+int vtkPDataSetWriter::WriteImageMetaData(
+  vtkImageData* input, char* root, char* str, size_t strSize, ostream* fptr)
 {
-  int *pi;
-  double *pf;
+  int* pi;
+  double* pf;
   vtkInformation* inInfo = this->GetInputInformation();
 
   // We should indicate the type of data that is being saved.
@@ -346,15 +323,12 @@ int vtkPDataSetWriter::WriteImageMetaData(vtkImageData * input,
   // Image data has a buch of meta data.
   *fptr << "      scalarType=\"" << input->GetScalarType() << "\"" << endl;
   pf = inInfo->Get(vtkDataObject::ORIGIN());
-  *fptr << "      origin=\""
-        << pf[0] << " " << pf[1] << " " << pf[2] << "\"" << endl;
+  *fptr << "      origin=\"" << pf[0] << " " << pf[1] << " " << pf[2] << "\"" << endl;
   pf = inInfo->Get(vtkDataObject::SPACING());
-  *fptr << "      spacing=\""
-        << pf[0] << " " << pf[1] << " " << pf[2] << "\"" << endl;
+  *fptr << "      spacing=\"" << pf[0] << " " << pf[1] << " " << pf[2] << "\"" << endl;
   pi = vtkStreamingDemandDrivenPipeline::GetWholeExtent(inInfo);
-  *fptr << "      wholeExtent=\""
-        << pi[0] << " " << pi[1] << " " << pi[2] << " "
-        << pi[3] << " " << pi[4] << " " << pi[5] << "\"" << endl;
+  *fptr << "      wholeExtent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " " << pi[3] << " "
+        << pi[4] << " " << pi[5] << "\"" << endl;
 
   // This is making the assumption that all the files will be written out by
   // some processes.
@@ -375,74 +349,67 @@ int vtkPDataSetWriter::WriteImageMetaData(vtkImageData * input,
     int nPiecesTotal = 0;
     vtkIdType nPieces = static_cast<vtkIdType>(this->Extents.size());
 
-    vtkIdType* offsets = nullptr;
-    vtkIdType* nPiecesAll = nullptr;
-    vtkIdType* recvLengths = nullptr;
+    std::vector<vtkIdType> offsets;
+    std::vector<vtkIdType> nPiecesAll;
+    std::vector<vtkIdType> recvLengths;
     if (rank == 0)
     {
-      nPiecesAll = new vtkIdType[nRanks];
-      recvLengths = new vtkIdType[nRanks];
-      offsets = new vtkIdType[nRanks];
+      offsets.resize(nRanks);
+      nPiecesAll.resize(nRanks);
+      recvLengths.resize(nRanks);
     }
-    this->Controller->Gather(&nPieces, nPiecesAll, 1, 0);
+    this->Controller->Gather(&nPieces, nPiecesAll.data(), 1, 0);
     if (rank == 0)
     {
-      for (int i=0; i<nRanks; i++)
+      for (int i = 0; i < nRanks; i++)
       {
-        offsets[i] = nPiecesTotal*7;
+        offsets[i] = nPiecesTotal * 7;
         nPiecesTotal += nPiecesAll[i];
-        recvLengths[i] = nPiecesAll[i]*7;
+        recvLengths[i] = nPiecesAll[i] * 7;
       }
     }
-    int* sendBuffer = nullptr;
-    int sendSize = nPieces*7;
+    std::vector<int> sendBuffer;
+    int sendSize = nPieces * 7;
     if (nPieces > 0)
     {
-      sendBuffer = new int[sendSize];
+      sendBuffer.resize(sendSize);
       ExtentsType::iterator iter = this->Extents.begin();
       for (int count = 0; iter != this->Extents.end(); ++iter, ++count)
       {
-        sendBuffer[count*7] = iter->first;
-        memcpy(&sendBuffer[count*7+1], &iter->second[0], 6*sizeof(int));
+        sendBuffer[count * 7] = iter->first;
+        memcpy(sendBuffer.data() + count * 7 + 1, iter->second.data(), 6 * sizeof(int));
       }
     }
-    int* recvBuffer = nullptr;
+    std::vector<int> recvBuffer;
     if (rank == 0)
     {
-      recvBuffer = new int[nPiecesTotal*7];
+      recvBuffer.resize(nPiecesTotal * 7);
     }
-    this->Controller->GatherV(sendBuffer, recvBuffer, sendSize,
-      recvLengths, offsets, 0);
+    this->Controller->GatherV(
+      sendBuffer.data(), recvBuffer.data(), sendSize, recvLengths.data(), offsets.data(), 0);
 
     if (rank == 0)
     {
       // Add all received values to Extents.
       // These are later written in WritePPieceAttributes()
-      for (int i=1; i<nRanks; i++)
+      for (int i = 1; i < nRanks; i++)
       {
-        for (int j=0; j<nPiecesAll[i]; j++)
+        for (int j = 0; j < nPiecesAll[i]; j++)
         {
-          int* buffer = recvBuffer + offsets[i] + j*7;
-          this->Extents[*buffer] =
-            std::vector<int>(buffer+1, buffer+7);
+          int* buffer = recvBuffer.data() + offsets[i] + j * 7;
+          this->Extents[*buffer] = std::vector<int>(buffer + 1, buffer + 7);
         }
       }
     }
-
-    delete[] nPiecesAll;
-    delete[] recvBuffer;
-    delete[] offsets;
-    delete[] recvLengths;
-    delete[] sendBuffer;
   }
 
   for (int i = 0; i < this->NumberOfPieces; ++i)
   {
-    pi = &this->Extents[i][0];
+    pi = this->Extents[i].data();
     snprintf(str, strSize, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\"" << endl
-          << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
-          << pi[3] << " " << pi[4] << " " << pi[5] << "\" />" << endl;
+          << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " " << pi[3] << " "
+          << pi[4] << " " << pi[5] << "\" />" << endl;
   }
   *fptr << "</File>" << endl;
   fptr->flush();
@@ -453,33 +420,30 @@ int vtkPDataSetWriter::WriteImageMetaData(vtkImageData * input,
   return 1;
 }
 
-//----------------------------------------------------------------------------
-int vtkPDataSetWriter::WriteRectilinearGridMetaData(vtkRectilinearGrid *input,
-                                         char *root, char *str,
-                                         size_t strSize, ostream *fptr)
+//------------------------------------------------------------------------------
+int vtkPDataSetWriter::WriteRectilinearGridMetaData(
+  vtkRectilinearGrid* input, char* root, char* str, size_t strSize, ostream* fptr)
 {
   int i;
-  int *pi;
+  int* pi;
 
   // We should indicate the type of data that is being saved.
   *fptr << "      dataType=\"" << input->GetClassName() << "\"" << endl;
 
-  pi = vtkStreamingDemandDrivenPipeline::GetWholeExtent(
-    this->GetInputInformation());
-  *fptr << "      wholeExtent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
-        << pi[3] << " " << pi[4] << " " << pi[5] << "\"" << endl;
-
+  pi = vtkStreamingDemandDrivenPipeline::GetWholeExtent(this->GetInputInformation());
+  *fptr << "      wholeExtent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " " << pi[3] << " "
+        << pi[4] << " " << pi[5] << "\"" << endl;
 
   // This is making the assumption that all the files will be written out by
   // some processes.
   *fptr << "      numberOfPieces=\"" << this->NumberOfPieces << "\" >" << endl;
   for (i = 0; i < this->NumberOfPieces; ++i)
   {
-    pi = &this->Extents[i][0];
+    pi = this->Extents[i].data();
     snprintf(str, strSize, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\"" << endl
-          << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
-          << pi[3] << " " << pi[4] << " " << pi[5] << "\" />" << endl;
+          << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " " << pi[3] << " "
+          << pi[4] << " " << pi[5] << "\" />" << endl;
   }
   *fptr << "</File>" << endl;
 
@@ -491,33 +455,30 @@ int vtkPDataSetWriter::WriteRectilinearGridMetaData(vtkRectilinearGrid *input,
   return 1;
 }
 
-//----------------------------------------------------------------------------
-int vtkPDataSetWriter::WriteStructuredGridMetaData(vtkStructuredGrid *input,
-                                         char *root, char *str,
-                                         size_t strSize, ostream *fptr)
+//------------------------------------------------------------------------------
+int vtkPDataSetWriter::WriteStructuredGridMetaData(
+  vtkStructuredGrid* input, char* root, char* str, size_t strSize, ostream* fptr)
 {
   int i;
-  int *pi;
+  int* pi;
 
   // We should indicate the type of data that is being saved.
   *fptr << "      dataType=\"" << input->GetClassName() << "\"" << endl;
 
-  pi = vtkStreamingDemandDrivenPipeline::GetWholeExtent(
-    this->GetInputInformation());
-  *fptr << "      wholeExtent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
-        << pi[3] << " " << pi[4] << " " << pi[5] << "\"" << endl;
-
+  pi = vtkStreamingDemandDrivenPipeline::GetWholeExtent(this->GetInputInformation());
+  *fptr << "      wholeExtent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " " << pi[3] << " "
+        << pi[4] << " " << pi[5] << "\"" << endl;
 
   // This is making the assumption that all the files will be written out by
   // some processes.
   *fptr << "      numberOfPieces=\"" << this->NumberOfPieces << "\" >" << endl;
   for (i = 0; i < this->NumberOfPieces; ++i)
   {
-    pi = &this->Extents[i][0];
+    pi = this->Extents[i].data();
     snprintf(str, strSize, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\"" << endl
-          << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
-          << pi[3] << " " << pi[4] << " " << pi[5] << "\" />" << endl;
+          << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " " << pi[3] << " "
+          << pi[4] << " " << pi[5] << "\" />" << endl;
   }
   *fptr << "</File>" << endl;
 
@@ -529,18 +490,17 @@ int vtkPDataSetWriter::WriteStructuredGridMetaData(vtkStructuredGrid *input,
   return 1;
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Open a vtk data file. Returns nullptr if error.
-ostream *vtkPDataSetWriter::OpenFile()
+ostream* vtkPDataSetWriter::OpenFile()
 {
-  ostream *fptr;
+  ostream* fptr;
 
-  fptr = new ofstream(this->FileName, ios::out);
+  fptr = new vtksys::ofstream(this->FileName, ios::out);
 
   if (fptr->fail())
   {
-    vtkErrorMacro(<< "Unable to open file: "<< this->FileName);
+    vtkErrorMacro(<< "Unable to open file: " << this->FileName);
     delete fptr;
     return nullptr;
   }
@@ -552,20 +512,20 @@ void vtkPDataSetWriter::DeleteFiles()
 {
   int i;
   int length = static_cast<int>(strlen(this->FileName));
-  char *fileRoot = new char[length+1];
-  size_t fileNameSize = length+strlen(this->FilePattern)+20;
-  char *fileName = new char[fileNameSize];
+  std::vector<char> fileRoot(length + 1);
+  size_t fileNameSize = length + strlen(this->FilePattern) + 20;
+  std::vector<char> fileName(fileNameSize);
 
-  strncpy(fileRoot, this->FileName, length);
+  strncpy(fileRoot.data(), this->FileName, length);
   fileRoot[length] = '\0';
   // Trim off the pvtk extension.
-  if (strncmp(fileRoot+length-5, ".pvtk", 5) == 0)
+  if (strncmp(fileRoot.data() + length - 5, ".pvtk", 5) == 0)
   {
-    fileRoot[length-5] = '\0';
+    fileRoot[length - 5] = '\0';
   }
-  if (strncmp(fileRoot+length-4, ".vtk", 4) == 0)
+  if (strncmp(fileRoot.data() + length - 4, ".vtk", 4) == 0)
   {
-    fileRoot[length-4] = '\0';
+    fileRoot[length - 4] = '\0';
   }
   // If we are using relative file names, trim off the directory path.
   if (this->UseRelativeFileNames)
@@ -573,7 +533,7 @@ void vtkPDataSetWriter::DeleteFiles()
     char *tmp, *slash;
     // Find the last / or \ in the file name.
     slash = nullptr;
-    tmp = fileRoot;
+    tmp = fileRoot.data();
     while (*tmp != '\0')
     {
       if (*tmp == '/' || *tmp == '\\')
@@ -586,7 +546,7 @@ void vtkPDataSetWriter::DeleteFiles()
     if (slash)
     {
       ++slash;
-      tmp = fileRoot;
+      tmp = fileRoot.data();
       while (*slash != '\0')
       {
         *tmp++ = *slash++;
@@ -597,21 +557,17 @@ void vtkPDataSetWriter::DeleteFiles()
 
   for (i = this->StartPiece; i <= this->EndPiece; i++)
   {
-    snprintf(fileName, fileNameSize, this->FilePattern, fileRoot, i);
-    remove(fileName);
+    snprintf(fileName.data(), fileNameSize, this->FilePattern, fileRoot.data(), i);
+    remove(fileName.data());
   }
 
   remove(this->FileName);
-
-  delete [] fileName;
-  delete [] fileRoot;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPDataSetWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
-
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "StartPiece: " << this->StartPiece << endl;
   os << indent << "EndPiece: " << this->EndPiece << endl;
@@ -620,3 +576,4 @@ void vtkPDataSetWriter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "FilePattern: " << this->FilePattern << endl;
   os << indent << "UseRelativeFileNames: " << this->UseRelativeFileNames << endl;
 }
+VTK_ABI_NAMESPACE_END
