@@ -29,6 +29,7 @@
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkIntArray.h"
+#include "vtkLogger.h"
 #include "vtkMultiBlockDataSet.h"
 #include "vtkMultiProcessController.h"
 #include "vtkObjectFactory.h"
@@ -51,6 +52,7 @@
 #undef DBG_PEXOIIRDR
 #define vtkPExodusIIReaderMAXPATHLEN 2048
 
+VTK_ABI_NAMESPACE_BEGIN
 static const int objTypes[] = { vtkExodusIIReader::EDGE_BLOCK, vtkExodusIIReader::FACE_BLOCK,
   vtkExodusIIReader::ELEM_BLOCK, vtkExodusIIReader::NODE_SET, vtkExodusIIReader::EDGE_SET,
   vtkExodusIIReader::FACE_SET, vtkExodusIIReader::SIDE_SET, vtkExodusIIReader::ELEM_SET,
@@ -168,23 +170,10 @@ vtkPExodusIIReader::~vtkPExodusIIReader()
 //------------------------------------------------------------------------------
 void vtkPExodusIIReader::SetController(vtkMultiProcessController* c)
 {
-  if (this->Controller == c)
-  {
-    return;
-  }
-
-  this->Modified();
+  vtkSetObjectBodyMacro(Controller, vtkMultiProcessController, c);
 
   if (this->Controller)
   {
-    this->Controller->UnRegister(this);
-  }
-
-  this->Controller = c;
-
-  if (this->Controller)
-  {
-    this->Controller->Register(this);
     this->ProcRank = this->Controller->GetLocalProcessId();
     this->ProcSize = this->Controller->GetNumberOfProcesses();
   }
@@ -250,47 +239,31 @@ int vtkPExodusIIReader::RequestInformation(
       }
     }
 
-    int numFiles = this->NumberOfFileNames;
-    if (numFiles <= 1)
+    // Read meta-data from 1st file.
+    // Previously, this went over all files. This was unnecessary.
+    // First file will have all necessary information.
+    // Otherwise we end up with bugs like paraview/paraview#20559
+    // and paraview/paraview#20558 when the files have no arrays at all.
+
+    if (this->NumberOfFileNames > 1)
     {
-      numFiles = this->NumberOfFiles;
+      strcpy(this->MultiFileName, this->FileNames[0]);
+      if (this->GetGenerateFileIdArray())
+      {
+        vtkPExodusIIReader::DetermineFileId(this->FileNames[0]);
+      }
     }
-
-    // Go through the filenames and see if any of them actually have data
-    // in them. It's possible that some of them don't and if they don't
-    // we won't have the proper information generated.
-    int reader_idx = 0;
-    for (int fileIndex = 0; fileIndex < numFiles; ++fileIndex, ++reader_idx)
+    else if (this->FilePattern)
     {
-      if (this->NumberOfFileNames > 1)
-      {
-        strcpy(this->MultiFileName, this->FileNames[fileIndex]);
-        if (this->GetGenerateFileIdArray())
-        {
-          vtkPExodusIIReader::DetermineFileId(this->FileNames[fileIndex]);
-        }
-      }
-      else if (this->FilePattern)
-      {
-        snprintf(this->MultiFileName, vtkPExodusIIReaderMAXPATHLEN, this->FilePattern,
-          this->FilePrefix, fileIndex);
-      }
-      char* nm = new char[strlen(this->MultiFileName) + 1];
-      strcpy(nm, this->MultiFileName);
-      delete[] this->FileName;
-      this->FileName = nm;
-      nm = nullptr;
+      snprintf(
+        this->MultiFileName, vtkPExodusIIReaderMAXPATHLEN, this->FilePattern, this->FilePrefix, 0);
+    }
+    delete[] this->FileName;
+    this->FileName = vtksys::SystemTools::DuplicateString(this->MultiFileName);
 
-      // Read in info based on this->FileName
-      requestInformationRetVal =
-        this->Superclass::RequestInformation(request, inputVector, outputVector);
-
-      if (!this->Metadata->ArrayInfo.empty())
-      {
-        // We have a file with actual data in it
-        break;
-      }
-    } // loop over file names
+    // Read in info based on this->FileName
+    requestInformationRetVal =
+      this->Superclass::RequestInformation(request, inputVector, outputVector);
   }
   this->Controller->Broadcast(&requestInformationRetVal, 1, 0);
   if (!requestInformationRetVal)
@@ -325,7 +298,7 @@ int vtkPExodusIIReader::RequestInformation(
     timeRange[0] = commonTimes[0];
 
     outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), timeRange, 2);
-    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &commonTimes[0], numTimes);
+    outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), commonTimes.data(), numTimes);
   }
 
   if (this->CurrentFilePrefix)
@@ -689,7 +662,7 @@ int vtkPExodusIIReader::RequestData(vtkInformation* vtkNotUsed(request),
   if (append->GetNumberOfInputConnections(0) != 0)
   {
     append->Update();
-    output->ShallowCopy(append->GetOutput());
+    output->CompositeShallowCopy(append->GetOutput());
   }
 
   // I've copied append's output to the 'output' so delete append
@@ -726,11 +699,14 @@ void vtkPExodusIIReader::SetFileRange(int min, int max)
 //------------------------------------------------------------------------------
 void vtkPExodusIIReader::SetFileName(const char* name)
 {
+  vtkLogScopeF(TRACE, "%s: SetFileName(%s)", vtkLogIdentifier(this), name);
   this->SetFileNames(1, &name);
 }
 
 void vtkPExodusIIReader::SetFileNames(int nfiles, const char** names)
 {
+  vtkLogScopeF(TRACE, "%s: SetFileNames(%d, %s)", vtkLogIdentifier(this), nfiles,
+    nfiles > 0 ? names[0] : "nullptr");
   // If I have an old list of filename delete them
   if (this->FileNames)
   {
@@ -1004,7 +980,7 @@ static bool BroadcastRecvString(vtkMultiProcessController* ctrl, std::vector<cha
   if (len)
   {
     str.resize(len);
-    ctrl->Broadcast(&str[0], len, 0);
+    ctrl->Broadcast(str.data(), len, 0);
     return true;
   }
   return false;
@@ -1021,7 +997,7 @@ static void BroadcastDoubleVector(
   }
   if (len)
   {
-    controller->Broadcast(&dvec[0], len, 0);
+    controller->Broadcast(dvec.data(), len, 0);
   }
 }
 
@@ -1036,11 +1012,11 @@ static void BroadcastIntVector(
   }
   if (len)
   {
-    controller->Broadcast(&ivec[0], len, 0);
+    controller->Broadcast(ivec.data(), len, 0);
   }
 }
 
-static void BroadcastString(vtkMultiProcessController* controller, vtkStdString& str, int rank)
+static void BroadcastString(vtkMultiProcessController* controller, std::string& str, int rank)
 {
   unsigned long len = static_cast<unsigned long>(str.size()) + 1;
   controller->Broadcast(&len, 1, 0);
@@ -1050,14 +1026,14 @@ static void BroadcastString(vtkMultiProcessController* controller, vtkStdString&
     {
       std::vector<char> tmp;
       tmp.resize(len);
-      controller->Broadcast(&(tmp[0]), len, 0);
-      str = &tmp[0];
+      controller->Broadcast(tmp.data(), len, 0);
+      str = tmp.data();
     }
     else
     {
       const char* start = str.c_str();
       std::vector<char> tmp(start, start + len);
-      controller->Broadcast(&tmp[0], len, 0);
+      controller->Broadcast(tmp.data(), len, 0);
     }
   }
 }
@@ -1069,8 +1045,7 @@ static void BroadcastStringVector(
   controller->Broadcast(&len, 1, 0);
   if (rank)
     svec.resize(len);
-  std::vector<vtkStdString>::iterator it;
-  for (it = svec.begin(); it != svec.end(); ++it)
+  for (auto it = svec.begin(); it != svec.end(); ++it)
   {
     BroadcastString(controller, *it, rank);
   }
@@ -1482,14 +1457,16 @@ void vtkPExodusIIReader::Broadcast(vtkMultiProcessController* ctrl)
       std::vector<char> tmp;
       delete[] this->FilePattern;
       delete[] this->FilePrefix;
-      // this->SetFilePattern( BroadcastRecvString( ctrl, tmp ) ? &tmp[0] : 0 ); // XXX Bad set
-      // this->SetFilePrefix(  BroadcastRecvString( ctrl, tmp ) ? &tmp[0] : 0 ); // XXX Bad set
+      // XXX Bad set for these two calls
+      // this->SetFilePattern( BroadcastRecvString( ctrl, tmp ) ? tmp.data() : nullptr );
+      // this->SetFilePrefix(  BroadcastRecvString( ctrl, tmp ) ? tmp.data() : nullptr );
       this->FilePattern =
-        BroadcastRecvString(ctrl, tmp) ? vtksys::SystemTools::DuplicateString(&tmp[0]) : nullptr;
+        BroadcastRecvString(ctrl, tmp) ? vtksys::SystemTools::DuplicateString(tmp.data()) : nullptr;
       this->FilePrefix =
-        BroadcastRecvString(ctrl, tmp) ? vtksys::SystemTools::DuplicateString(&tmp[0]) : nullptr;
+        BroadcastRecvString(ctrl, tmp) ? vtksys::SystemTools::DuplicateString(tmp.data()) : nullptr;
     }
     ctrl->Broadcast(this->FileRange, 2, 0);
     ctrl->Broadcast(&this->NumberOfFiles, 1, 0);
   }
 }
+VTK_ABI_NAMESPACE_END
