@@ -38,10 +38,12 @@ PURPOSE.  See the above copyright notice for more information.
 #error MPI_Comm is #define'd somewhere!  That's BAD!  (Try checking netcdf.h.)
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPNetCDFPOPReader);
 
 //============================================================================
-#define CALL_NETCDF(call)                                                                          \
+#define CALL_NETCDF_INT(call)                                                                      \
+  do                                                                                               \
   {                                                                                                \
     int errorcode = call;                                                                          \
     if (errorcode != NC_NOERR)                                                                     \
@@ -49,7 +51,7 @@ vtkStandardNewMacro(vtkPNetCDFPOPReader);
       vtkErrorMacro(<< "netCDF Error: " << nc_strerror(errorcode));                                \
       return 0;                                                                                    \
     }                                                                                              \
-  }
+  } while (false)
 //============================================================================
 
 class vtkPNetCDFPOPReaderInternal
@@ -113,12 +115,12 @@ vtkPNetCDFPOPReader::vtkPNetCDFPOPReader()
 vtkPNetCDFPOPReader::~vtkPNetCDFPOPReader()
 {
   this->SetController(nullptr);
-  this->SetFileName(0);
+  this->SetFileName(nullptr);
   if (this->OpenedFileName)
   {
     nc_close(this->NCDFFD);
   }
-  this->SetOpenedFileName(0);
+  this->SetOpenedFileName(nullptr);
   if (this->SelectionObserver)
   {
     this->SelectionObserver->Delete();
@@ -179,7 +181,7 @@ int vtkPNetCDFPOPReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     if (retval != NC_NOERR)                                          // checks if read file error
     {
       vtkErrorMacro(<< "Can't read file " << nc_strerror(retval));
-      this->SetOpenedFileName(0);
+      this->SetOpenedFileName(nullptr);
       return 0;
     }
     this->SetOpenedFileName(this->FileName);
@@ -202,19 +204,19 @@ int vtkPNetCDFPOPReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     {
       this->Internals->VariableMap[i] = -1;
       // get number of dimensions
-      CALL_NETCDF(nc_inq_varndims(this->NCDFFD, i, &dataDimension));
+      CALL_NETCDF_INT(nc_inq_varndims(this->NCDFFD, i, &dataDimension));
       // Variable Dimension ID's containing x,y,z coords for the rectilinear
       // grid spacing
-      CALL_NETCDF(nc_inq_vardimid(this->NCDFFD, i, dimidsp));
+      CALL_NETCDF_INT(nc_inq_vardimid(this->NCDFFD, i, dimidsp));
       if (dataDimension == 3)
       {
         this->Internals->VariableMap[i] = actualVariableCounter++;
         // get variable name
-        CALL_NETCDF(nc_inq_varname(this->NCDFFD, i, variableName));
+        CALL_NETCDF_INT(nc_inq_varname(this->NCDFFD, i, variableName));
         this->Internals->VariableArraySelection->AddArray(variableName);
         for (int m = 0; m < dataDimension; m++)
         {
-          CALL_NETCDF(nc_inq_dimlen(this->NCDFFD, dimidsp[m], dimensions + m));
+          CALL_NETCDF_INT(nc_inq_dimlen(this->NCDFFD, dimidsp[m], dimensions + m));
           // acquire variable dimensions
         }
         extent[0] = extent[2] = extent[4] = 0; // set extent
@@ -243,7 +245,7 @@ int vtkPNetCDFPOPReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     int numVariables = static_cast<int>(this->Internals->VariableMap.size());
     this->Controller->Broadcast(&numVariables, 1, this->Internals->ReaderRanks[0]);
     this->Controller->Broadcast(
-      &this->Internals->VariableMap[0], numVariables, this->Internals->ReaderRanks[0]);
+      this->Internals->VariableMap.data(), numVariables, this->Internals->ReaderRanks[0]);
 
     // send out the extents data
     this->Controller->Broadcast(extent, 6, this->Internals->ReaderRanks[0]);
@@ -265,7 +267,7 @@ int vtkPNetCDFPOPReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     this->Controller->Broadcast(&numVariables, 1, this->Internals->ReaderRanks[0]);
     this->Internals->VariableMap.resize(numVariables, 0);
     this->Controller->Broadcast(
-      &this->Internals->VariableMap[0], numVariables, this->Internals->ReaderRanks[0]);
+      this->Internals->VariableMap.data(), numVariables, this->Internals->ReaderRanks[0]);
     // Receive the extents data
     this->Controller->Broadcast(extent, 6, this->Internals->ReaderRanks[0]);
   }
@@ -326,7 +328,7 @@ int vtkPNetCDFPOPReader::RequestData(vtkInformation* request,
           &varidp);
       }
 
-      if (firstPass == true)
+      if (firstPass)
       {
         firstPass = false;
         // Get the latitude, longitude & depth values: the first reader process
@@ -358,14 +360,15 @@ int vtkPNetCDFPOPReader::RequestData(vtkInformation* request,
         {
           int dimidsp[3];
           nc_inq_vardimid(this->NCDFFD, varidp, dimidsp);
-          nc_get_vars_float(this->NCDFFD, dimidsp[0], wholeStart, wholeCount, rStride, &buffer[0]);
+          nc_get_vars_float(
+            this->NCDFFD, dimidsp[0], wholeStart, wholeCount, rStride, buffer.data());
           nc_get_vars_float(this->NCDFFD, dimidsp[1], wholeStart + 1, wholeCount + 1, rStride + 1,
             &buffer[wholeCount[0]]);
           nc_get_vars_float(this->NCDFFD, dimidsp[2], wholeStart + 2, wholeCount + 2, rStride + 2,
             &buffer[wholeCount[0] + wholeCount[1]]);
         }
 
-        this->Controller->Broadcast(&buffer[0],
+        this->Controller->Broadcast(buffer.data(),
           static_cast<vtkIdType>(wholeCount[0] + wholeCount[1] + wholeCount[2]),
           this->Internals->ReaderRanks[0]);
 
@@ -443,10 +446,10 @@ int vtkPNetCDFPOPReader::RequestData(vtkInformation* request,
       delete[] this->Internals->AllExtents;
 
       // Wait for all the sends to complete
-      if (this->Internals->SendReqs.size() > 0)
+      if (!this->Internals->SendReqs.empty())
       {
         MPI_Waitall(static_cast<int>(this->Internals->SendReqs.size()),
-          &this->Internals->SendReqs[0], MPI_STATUSES_IGNORE);
+          this->Internals->SendReqs.data(), MPI_STATUSES_IGNORE);
 
         // Now that all the sends are complete, it's safe to free the buffers
         for (size_t j = 0; j < this->Internals->SendBufs.size(); j++)
@@ -457,7 +460,7 @@ int vtkPNetCDFPOPReader::RequestData(vtkInformation* request,
         this->Internals->SendReqs.clear();
       }
 
-      MPI_Waitall(static_cast<int>(recvReqs.size()), &recvReqs[0], MPI_STATUSES_IGNORE);
+      MPI_Waitall(static_cast<int>(recvReqs.size()), recvReqs.data(), MPI_STATUSES_IGNORE);
       recvReqs.clear();
 
       scalars->SetArray(data, numberOfTuples, 0, 1);
@@ -613,7 +616,7 @@ int vtkPNetCDFPOPReader::ReadAndSend(vtkInformation* outInfo, int varID)
 
       // Check to see if any of the previous sends have completed
       // (This helps to keep the number of 'in-flight' sends to a minimum.)
-      if (this->Internals->SendReqs.size())
+      if (!this->Internals->SendReqs.empty())
       {
         int foundOne = 1;
         int reqIndex = 0;
@@ -624,7 +627,7 @@ int vtkPNetCDFPOPReader::ReadAndSend(vtkInformation* outInfo, int varID)
         do
         {
           MPI_Testany(static_cast<int>(this->Internals->SendReqs.size()),
-            &this->Internals->SendReqs[0], &reqIndex, &foundOne, &status);
+            this->Internals->SendReqs.data(), &reqIndex, &foundOne, &status);
         } while (foundOne && reqIndex != MPI_UNDEFINED);
       }
     }
@@ -725,7 +728,7 @@ bool vtkPNetCDFPOPReader::IsReaderRank()
 // file metadata is read by a single rank and broadcast to all the others.)
 bool vtkPNetCDFPOPReader::IsFirstReaderRank()
 {
-  if (this->Internals->ReaderRanks.size() == 0)
+  if (this->Internals->ReaderRanks.empty())
   {
     return false; // sanity check
   }
@@ -737,12 +740,11 @@ bool vtkPNetCDFPOPReader::IsFirstReaderRank()
 //
 void vtkPNetCDFPOPReader::SetController(vtkMPIController* controller)
 {
-  if (this->Controller != controller)
+  vtkSetObjectBodyMacro(Controller, vtkMultiProcessController, controller);
+
+  if (this->Controller != nullptr)
   {
-    this->Controller = controller;
-    if (this->Controller != nullptr)
-    {
-      this->SetReaderRanks(nullptr);
-    }
+    this->SetReaderRanks(nullptr);
   }
 }
+VTK_ABI_NAMESPACE_END
