@@ -38,6 +38,7 @@
 #include "vtkIOParallelNetCDFModule.h" // For export macro
 #include "vtkSLACReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController;
 
 class VTKIOPARALLELNETCDF_EXPORT vtkPSLACReader : public vtkSLACReader
@@ -47,7 +48,7 @@ public:
   static vtkPSLACReader* New();
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The controller used to communicate partition data.  The number of pieces
    * requested must agree with the number of processes, the piece requested must
@@ -56,7 +57,7 @@ public:
    */
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
   virtual void SetController(vtkMultiProcessController*);
-  //@}
+  ///@}
 
 protected:
   vtkPSLACReader();
@@ -94,14 +95,14 @@ protected:
   class vtkInternal;
   vtkInternal* PInternal;
 
-  //@{
+  ///@{
   /**
    * The number of pieces and the requested piece to load.  Synonymous with
    * the number of processes and the local process id.
    */
   int NumberOfPieces;
   int RequestedPiece;
-  //@}
+  ///@}
 
   /**
    * The number of points defined in the mesh file.
@@ -113,7 +114,7 @@ protected:
    */
   vtkIdType NumberOfGlobalMidpoints;
 
-  //@{
+  ///@{
   /**
    * The start/end points read by the given process.
    */
@@ -128,19 +129,20 @@ protected:
       result = this->NumberOfGlobalPoints;
     return result;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Piece information from the last call.
    */
   int NumberOfPiecesCache;
   int RequestedPieceCache;
-  //@}
+  ///@}
 
 private:
   vtkPSLACReader(const vtkPSLACReader&) = delete;
   void operator=(const vtkPSLACReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPSLACReader_h
