@@ -31,6 +31,7 @@
 #include "vtkIOParallelXMLModule.h" // For export macro
 #include "vtkXMLWriter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCallbackCommand;
 class vtkMultiProcessController;
 
@@ -40,15 +41,15 @@ public:
   vtkTypeMacro(vtkXMLPDataObjectWriter, vtkXMLWriter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the number of pieces that are being written in parallel.
    */
   vtkSetMacro(NumberOfPieces, int);
   vtkGetMacro(NumberOfPieces, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the range of pieces assigned to this writer.
    */
@@ -56,25 +57,25 @@ public:
   vtkGetMacro(StartPiece, int);
   vtkSetMacro(EndPiece, int);
   vtkGetMacro(EndPiece, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the ghost level used for this writer's piece.
    */
   vtkSetMacro(GhostLevel, int);
   vtkGetMacro(GhostLevel, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set whether to use a subdirectory to store the pieces
    */
   vtkSetMacro(UseSubdirectory, bool);
   vtkGetMacro(UseSubdirectory, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set whether the writer should write the summary file that
    * refers to all of the pieces' individual files.
@@ -84,9 +85,9 @@ public:
   virtual void SetWriteSummaryFile(int flag);
   vtkGetMacro(WriteSummaryFile, int);
   vtkBooleanMacro(WriteSummaryFile, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Controller used to communicate data type of blocks.
    * By default, the global controller is used. If you want another
@@ -94,7 +95,7 @@ public:
    */
   virtual void SetController(vtkMultiProcessController*);
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
-  //@}
+  ///@}
 
   /**
    * Overridden to handle passing the CONTINUE_EXECUTING() flags to the
@@ -152,13 +153,13 @@ protected:
    */
   virtual void WritePPieceAttributes(int index);
 
-  //@{
+  ///@{
   /**
    * Methods for creating a filename for each piece in the dataset
    */
   char* CreatePieceFileName(int index, const char* path = nullptr);
   void SplitFileName();
-  //@}
+  ///@}
 
   /**
    * Callback registered with the InternalProgressObserver.
@@ -231,4 +232,5 @@ private:
   bool ContinuingExecution;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
