@@ -22,13 +22,14 @@
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPXdmf3Writer);
 
 //------------------------------------------------------------------------------
-vtkPXdmf3Writer::vtkPXdmf3Writer() {}
+vtkPXdmf3Writer::vtkPXdmf3Writer() = default;
 
 //------------------------------------------------------------------------------
-vtkPXdmf3Writer::~vtkPXdmf3Writer() {}
+vtkPXdmf3Writer::~vtkPXdmf3Writer() = default;
 
 //------------------------------------------------------------------------------
 void vtkPXdmf3Writer::PrintSelf(ostream& os, vtkIndent indent)
@@ -75,3 +76,4 @@ int vtkPXdmf3Writer::GlobalContinueExecuting(int localContinue)
   }
   return globalContinue;
 }
+VTK_ABI_NAMESPACE_END
