@@ -20,14 +20,14 @@
 #include <string>
 
 // Registration of PostgreSQL dynamically with the vtkSQLDatabase factory method.
-vtkSQLDatabase * PostgreSQLCreateFunction(const char* URL)
+VTK_ABI_NAMESPACE_BEGIN
+vtkSQLDatabase* PostgreSQLCreateFunction(const char* URL)
 {
   std::string urlstr(URL ? URL : "");
   std::string protocol, unused;
-  vtkPostgreSQLDatabase *db = 0;
+  vtkPostgreSQLDatabase* db = nullptr;
 
-  if (vtksys::SystemTools::ParseURLProtocol(urlstr, protocol, unused) &&
-      protocol == "psql")
+  if (vtksys::SystemTools::ParseURLProtocol(urlstr, protocol, unused) && protocol == "psql")
   {
     db = vtkPostgreSQLDatabase::New();
     db->ParseURL(URL);
@@ -51,3 +51,4 @@ VTKIOPOSTGRESQL_EXPORT void vtkIOPostgreSQL_AutoInit_Construct()
     vtkSQLDatabase::RegisterCreateFromURLCallback(PostgreSQLCreateFunction);
   }
 }
+VTK_ABI_NAMESPACE_END
