@@ -31,6 +31,7 @@
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRowQueryToTable);
 
 vtkRowQueryToTable::vtkRowQueryToTable()
@@ -71,9 +72,7 @@ vtkMTimeType vtkRowQueryToTable::GetMTime()
   return mTime;
 }
 
-int vtkRowQueryToTable::RequestData(
-  vtkInformation*,
-  vtkInformationVector** vtkNotUsed(inputVector),
+int vtkRowQueryToTable::RequestData(vtkInformation*, vtkInformationVector** vtkNotUsed(inputVector),
   vtkInformationVector* outputVector)
 {
   if (this->Query == nullptr)
@@ -120,15 +119,15 @@ int vtkRowQueryToTable::RequestData(
     {
       int i = 1;
       std::ostringstream oss;
-      vtkStdString newName;
+      std::string newName;
       do
       {
         oss.str("");
         oss << name << "_" << i;
         newName = oss.str();
         ++i;
-      } while (output->GetColumnByName(newName));
-      arr->SetName(newName);
+      } while (output->GetColumnByName(newName.c_str()));
+      arr->SetName(newName.c_str());
     }
     else
     {
@@ -150,10 +149,10 @@ int vtkRowQueryToTable::RequestData(
 
     // Update progress every 100 rows
     numRows++;
-    if ((numRows%100)==0)
+    if ((numRows % 100) == 0)
     {
       // 1% for every 100 rows, and then 'spin around'
-      progressGuess = ((numRows/100)%100)*.01;
+      progressGuess = ((numRows / 100) % 100) * .01;
       this->UpdateProgress(progressGuess);
     }
   }
@@ -161,5 +160,4 @@ int vtkRowQueryToTable::RequestData(
 
   return 1;
 }
-
-
+VTK_ABI_NAMESPACE_END
