@@ -21,7 +21,6 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkSQLDatabase.h"
 #include "vtkInformationObjectBaseKey.h"
 #include "vtkSQLQuery.h"
-#include "vtkToolkits.h"
 
 #include "vtkSQLDatabaseSchema.h"
 
@@ -34,6 +33,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include <sstream>
 #include <vtksys/SystemTools.hxx>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSQLDatabase::vtkCallbackVector : public std::vector<vtkSQLDatabase::CreateFunction>
 {
 public:
@@ -123,7 +123,7 @@ vtkStdString vtkSQLDatabase::GetColumnSpecification(
 
   // Figure out column type
   int colType = schema->GetColumnTypeFromHandle(tblHandle, colHandle);
-  vtkStdString colTypeStr;
+  std::string colTypeStr;
   switch (static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>(colType))
   {
     case vtkSQLDatabaseSchema::SERIAL:
@@ -171,7 +171,7 @@ vtkStdString vtkSQLDatabase::GetColumnSpecification(
   else // if ( colTypeStr.size() )
   {
     vtkGenericWarningMacro("Unable to get column specification: unsupported data type " << colType);
-    return vtkStdString();
+    return {};
   }
 
   // Decide whether size is allowed, required, or unused
@@ -236,7 +236,7 @@ vtkStdString vtkSQLDatabase::GetColumnSpecification(
     }
   }
 
-  vtkStdString attStr = schema->GetColumnAttributesFromHandle(tblHandle, colHandle);
+  std::string attStr = schema->GetColumnAttributesFromHandle(tblHandle, colHandle);
   if (!attStr.empty())
   {
     queryStr << " " << attStr;
@@ -269,7 +269,7 @@ vtkStdString vtkSQLDatabase::GetIndexSpecification(
       skipped = true;
       break;
     default:
-      return vtkStdString();
+      return {};
   }
 
   // No index_name for PRIMARY KEYs nor UNIQUEs
@@ -293,7 +293,7 @@ vtkStdString vtkSQLDatabase::GetIndexSpecification(
   {
     vtkGenericWarningMacro(
       "Unable to get index specification: index has incorrect number of columns " << numCnm);
-    return vtkStdString();
+    return {};
   }
 
   bool firstCnm = true;
@@ -374,7 +374,7 @@ vtkSQLDatabase* vtkSQLDatabase::CreateFromURL(const char* URL)
   // SQLite is a bit special so lets get that out of the way :)
   if (!vtksys::SystemTools::ParseURLProtocol(urlstr, protocol, dataglom))
   {
-    vtkGenericWarningMacro("Invalid URL (no protocol found): \"" << urlstr.c_str() << "\"");
+    vtkGenericWarningMacro("Invalid URL (no protocol found): \"" << urlstr << "\"");
     dbURLCritSec.unlock();
     return nullptr;
   }
@@ -390,7 +390,7 @@ vtkSQLDatabase* vtkSQLDatabase::CreateFromURL(const char* URL)
   if (!vtksys::SystemTools::ParseURL(
         urlstr, protocol, username, unused, hostname, dataport, database))
   {
-    vtkGenericWarningMacro("Invalid URL (other components missing): \"" << urlstr.c_str() << "\"");
+    vtkGenericWarningMacro("Invalid URL (other components missing): \"" << urlstr << "\"");
     dbURLCritSec.unlock();
     return nullptr;
   }
@@ -404,7 +404,7 @@ vtkSQLDatabase* vtkSQLDatabase::CreateFromURL(const char* URL)
 
   if (!db)
   {
-    vtkGenericWarningMacro("Unsupported protocol: " << protocol.c_str());
+    vtkGenericWarningMacro("Unsupported protocol: " << protocol);
   }
   dbURLCritSec.unlock();
   return db;
@@ -440,7 +440,7 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
     }
 
     vtkStdString preStr = schema->GetPreambleActionFromHandle(preHandle);
-    query->SetQuery(preStr);
+    query->SetQuery(preStr.c_str());
     if (!query->Execute())
     {
       vtkGenericWarningMacro("Unable to effect the schema: unable to execute query.\nDetails: "
@@ -456,7 +456,7 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
   for (int tblHandle = 0; tblHandle < numTbl; ++tblHandle)
   {
     // Construct the CREATE TABLE query for this table
-    vtkStdString queryStr("CREATE TABLE ");
+    std::string queryStr("CREATE TABLE ");
     queryStr += this->GetTablePreamble(dropIfExists);
     queryStr += schema->GetTableNameFromHandle(tblHandle);
     queryStr += " (";
@@ -483,7 +483,7 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
       }
 
       // Get column creation syntax (backend-dependent)
-      vtkStdString colStr = this->GetColumnSpecification(schema, tblHandle, colHandle);
+      std::string colStr = this->GetColumnSpecification(schema, tblHandle, colHandle);
       if (!colStr.empty())
       {
         queryStr += colStr;
@@ -506,14 +506,14 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
     }
 
     // In case separate INDEX statements are needed (backend-specific)
-    std::vector<vtkStdString> idxStatements;
+    std::vector<std::string> idxStatements;
     bool skipped = false;
 
     // Loop over all indices of the current table
     for (int idxHandle = 0; idxHandle < numIdx; ++idxHandle)
     {
       // Get index creation syntax (backend-dependent)
-      vtkStdString idxStr = this->GetIndexSpecification(schema, tblHandle, idxHandle, skipped);
+      std::string idxStr = this->GetIndexSpecification(schema, tblHandle, idxHandle, skipped);
       if (!idxStr.empty())
       {
         if (skipped)
@@ -547,8 +547,7 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
     for (int optHandle = 0; optHandle < numOpt; ++optHandle)
     {
       vtkStdString optBackend = schema->GetOptionBackendFromHandle(tblHandle, optHandle);
-      if (strcmp(optBackend, VTK_SQL_ALLBACKENDS) != 0 &&
-        strcmp(optBackend, this->GetClassName()) != 0)
+      if (optBackend != VTK_SQL_ALLBACKENDS && optBackend != this->GetClassName())
       {
         continue;
       }
@@ -557,7 +556,7 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
     }
 
     // Execute the CREATE TABLE query
-    query->SetQuery(queryStr);
+    query->SetQuery(queryStr.c_str());
     if (!query->Execute())
     {
       vtkGenericWarningMacro("Unable to effect the schema: unable to execute query.\nDetails: "
@@ -568,10 +567,10 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
     }
 
     // Execute separate CREATE INDEX statements if needed
-    for (std::vector<vtkStdString>::iterator it = idxStatements.begin(); it != idxStatements.end();
+    for (std::vector<std::string>::iterator it = idxStatements.begin(); it != idxStatements.end();
          ++it)
     {
-      query->SetQuery(*it);
+      query->SetQuery(it->c_str());
       if (!query->Execute())
       {
         vtkGenericWarningMacro("Unable to effect the schema: unable to execute query.\nDetails: "
@@ -606,12 +605,12 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
         }
 
         // Get trigger creation syntax (backend-dependent)
-        vtkStdString trgStr = this->GetTriggerSpecification(schema, tblHandle, trgHandle);
+        std::string trgStr = this->GetTriggerSpecification(schema, tblHandle, trgHandle);
 
         // If not empty, execute query
         if (!trgStr.empty())
         {
-          query->SetQuery(vtkStdString(trgStr));
+          query->SetQuery(trgStr.c_str());
           if (!query->Execute())
           {
             vtkGenericWarningMacro(
@@ -650,3 +649,4 @@ bool vtkSQLDatabase::EffectSchema(vtkSQLDatabaseSchema* schema, bool dropIfExist
   query->Delete();
   return true;
 }
+VTK_ABI_NAMESPACE_END
