@@ -32,8 +32,9 @@
 
 #include "vtkGraphAlgorithm.h"
 #include "vtkIOSQLModule.h" // For export macro
-#include "vtkStdString.h"
+#include "vtkStdString.h"   // for vtkStdString
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkEventForwarderCommand;
 
 class VTKIOSQL_EXPORT vtkSQLDatabaseGraphSource : public vtkGraphAlgorithm
@@ -59,7 +60,7 @@ public:
   void AddLinkEdge(const char* column1, const char* column2);
   void ClearLinkEdges();
 
-  //@{
+  ///@{
   /**
    * If on (default), generate edge pedigree ids.
    * If off, assign an array to be edge pedigree ids.
@@ -67,17 +68,17 @@ public:
   vtkGetMacro(GenerateEdgePedigreeIds, bool);
   vtkSetMacro(GenerateEdgePedigreeIds, bool);
   vtkBooleanMacro(GenerateEdgePedigreeIds, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Use this array name for setting or generating edge pedigree ids.
    */
   vtkSetStringMacro(EdgePedigreeIdArrayName);
   vtkGetStringMacro(EdgePedigreeIdArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If on (default), generate a directed output graph.
    * If off, generate an undirected output graph.
@@ -85,7 +86,7 @@ public:
   vtkSetMacro(Directed, bool);
   vtkGetMacro(Directed, bool);
   vtkBooleanMacro(Directed, bool);
-  //@}
+  ///@}
 
 protected:
   vtkSQLDatabaseGraphSource();
@@ -114,6 +115,5 @@ private:
   bool Directed;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkSQLDatabaseGraphSource.h
