@@ -32,8 +32,8 @@
  * in VTK/Utilities/vtksqlite.
  *
  * If you want to open a database that stays in memory and never gets
- * written to disk, pass in the URL 'sqlite://:memory:'; otherwise,
- * specify the file path by passing the URL 'sqlite://<file_path>'.
+ * written to disk, pass in the URL <tt>sqlite://:memory:</tt>; otherwise,
+ * specify the file path by passing the URL <tt>sqlite://\<file_path\></tt>.
  *
  * @par Thanks:
  * Thanks to Andrew Wilson and Philippe Pebay from Sandia National
@@ -41,7 +41,7 @@
  *
  * @sa
  * vtkSQLiteQuery
-*/
+ */
 
 #ifndef vtkSQLiteDatabase_h
 #define vtkSQLiteDatabase_h
@@ -49,6 +49,7 @@
 #include "vtkIOSQLModule.h" // For export macro
 #include "vtkSQLDatabase.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSQLQuery;
 class vtkSQLiteQuery;
 class vtkStringArray;
@@ -62,16 +63,17 @@ class VTKIOSQL_EXPORT vtkSQLiteDatabase : public vtkSQLDatabase
 public:
   vtkTypeMacro(vtkSQLiteDatabase, vtkSQLDatabase);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  static vtkSQLiteDatabase *New();
+  static vtkSQLiteDatabase* New();
 
-  enum {
+  enum
+  {
     USE_EXISTING,
     USE_EXISTING_OR_CREATE,
     CREATE_OR_CLEAR,
     CREATE
   };
 
-  //@{
+  ///@{
   /**
    * Open a new connection to the database.  You need to set the
    * filename before calling this function.  Returns true if the
@@ -83,7 +85,7 @@ public:
    */
   bool Open(const char* password) override;
   bool Open(const char* password, int mode);
-  //@}
+  ///@}
 
   /**
    * Close the connection to the database.
@@ -108,7 +110,7 @@ public:
   /**
    * Get the list of fields for a particular table
    */
-  vtkStringArray* GetRecord(const char *table) override;
+  vtkStringArray* GetRecord(const char* table) override;
 
   /**
    * Return whether a feature is supported by the database.
@@ -125,23 +127,20 @@ public:
    */
   const char* GetLastErrorText() override;
 
-  //@{
+  ///@{
   /**
    * String representing database type (e.g. "sqlite").
    */
-  const char* GetDatabaseType() override
-  {
-    return this->DatabaseType;
-  }
-  //@}
+  const char* GetDatabaseType() override { return this->DatabaseType; }
+  ///@}
 
-  //@{
+  ///@{
   /**
    * String representing the database filename.
    */
-  vtkGetStringMacro(DatabaseFileName);
-  vtkSetStringMacro(DatabaseFileName);
-  //@}
+  vtkGetFilePathMacro(DatabaseFileName);
+  vtkSetFilePathMacro(DatabaseFileName);
+  ///@}
 
   /**
    * Get the URL of the database.
@@ -152,11 +151,12 @@ public:
    * Return the SQL string with the syntax to create a column inside a
    * "CREATE TABLE" SQL statement.
    * NB: this method implements the SQLite-specific syntax:
+   * \code
    * <column name> <column type> <column attributes>
+   * \endcode
    */
-  vtkStdString GetColumnSpecification( vtkSQLDatabaseSchema* schema,
-                                               int tblHandle,
-                                               int colHandle ) override;
+  vtkStdString GetColumnSpecification(
+    vtkSQLDatabaseSchema* schema, int tblHandle, int colHandle) override;
 
 protected:
   vtkSQLiteDatabase();
@@ -170,22 +170,22 @@ protected:
   bool ParseURL(const char* url) override;
 
 private:
-  vtkSQLiteDatabaseInternals *Internal;
+  vtkSQLiteDatabaseInternals* Internal;
 
   // We want this to be private, a user of this class
   // should not be setting this for any reason
   vtkSetStringMacro(DatabaseType);
 
-  vtkStringArray *Tables;
+  vtkStringArray* Tables;
 
   char* DatabaseType;
   char* DatabaseFileName;
 
   vtkStdString TempURL;
 
-  vtkSQLiteDatabase(const vtkSQLiteDatabase &) = delete;
-  void operator=(const vtkSQLiteDatabase &) = delete;
+  vtkSQLiteDatabase(const vtkSQLiteDatabase&) = delete;
+  void operator=(const vtkSQLiteDatabase&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkSQLiteDatabase_h
-
