@@ -37,6 +37,7 @@
 #define COMMIT_TRANSACTION "COMMIT"
 #define ROLLBACK_TRANSACTION "ROLLBACK"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSQLiteQuery::Priv
 {
 public:
@@ -316,14 +317,7 @@ bool vtkSQLiteQuery::NextRow()
   {
     vtkDebugMacro(<< "NextRow(): Initial fetch being handled.");
     this->InitialFetch = false;
-    if (this->InitialFetchResult == SQLITE_DONE)
-    {
-      return false;
-    }
-    else
-    {
-      return true;
-    }
+    return this->InitialFetchResult != SQLITE_DONE;
   }
   else
   {
@@ -353,7 +347,7 @@ bool vtkSQLiteQuery::NextRow()
 //------------------------------------------------------------------------------
 vtkVariant vtkSQLiteQuery::DataValue(vtkIdType column)
 {
-  if (this->IsActive() == false)
+  if (!this->IsActive())
   {
     vtkWarningMacro(<< "DataValue() called on inactive query");
     return vtkVariant();
@@ -656,7 +650,7 @@ bool vtkSQLiteQuery::BindIntegerParameter(int index, int value)
     std::ostringstream errormessage;
     errormessage << "sqlite_bind_int returned error: " << status;
     this->SetLastErrorText(errormessage.str().c_str());
-    vtkErrorMacro(<< errormessage.str().c_str());
+    vtkErrorMacro(<< errormessage.str());
     return false;
   }
   return true;
@@ -815,3 +809,4 @@ bool vtkSQLiteQuery::BindParameter(int index, vtkVariant value)
 {
   return this->Superclass::BindParameter(index, value);
 }
+VTK_ABI_NAMESPACE_END
