@@ -28,6 +28,7 @@
 #include <iostream>
 #include <iterator>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSegYReader);
 
 //------------------------------------------------------------------------------
@@ -179,7 +180,7 @@ int vtkSegYReader::RequestDataObject(vtkInformation*,
 
   if (this->Reader->In.is_open())
   {
-    this->Reader->In.seekg(0, this->Reader->In.beg);
+    this->Reader->In.seekg(0, vtksys::ifstream::beg);
   }
   else
   {
@@ -211,3 +212,4 @@ int vtkSegYReader::RequestDataObject(vtkInformation*,
   }
   return 1;
 }
+VTK_ABI_NAMESPACE_END
