@@ -33,6 +33,7 @@
 #include <map>
 #include <set>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 const int FIRST_TRACE_START_POS = 3600; // this->Traces start after 3200 + 400 file header
@@ -302,7 +303,7 @@ void vtkSegYReaderInternal::ExportData(
   imageData->SetOrigin(origin);
   imageData->SetSpacing(
     vtkMath::Norm(spacing[0]), vtkMath::Norm(spacing[1]), vtkMath::Norm(spacing[2]));
-  int* dims = imageData->GetDimensions();
+  const int* dims = imageData->GetDimensions();
 
   vtkNew<vtkFloatArray> scalars;
   scalars->SetNumberOfComponents(1);
@@ -336,7 +337,8 @@ void vtkSegYReaderInternal::ExportData(
     return;
   }
   grid->SetExtent(extent);
-  int* dims = grid->GetDimensions();
+  int dims[3];
+  grid->GetDimensions(dims);
   vtkNew<vtkPoints> points;
 
   vtkNew<vtkFloatArray> scalars;
@@ -377,3 +379,4 @@ void vtkSegYReaderInternal::ExportData(
   grid->SetPoints(points);
   grid->GetPointData()->SetScalars(scalars);
 }
+VTK_ABI_NAMESPACE_END
