@@ -34,6 +34,7 @@
 #include <sstream>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 class vtkTRUCHASReader::Internal
 {
 public:
@@ -106,7 +107,7 @@ public:
   //----------------------------------------------------------------------------
   hid_t OpenFile(char* _FileName)
   {
-    if (this->FileName.compare(_FileName) != 0)
+    if (this->FileName != _FileName)
     {
       this->CloseFile();
       if (_FileName != nullptr)
@@ -739,7 +740,6 @@ vtkStandardNewMacro(vtkTRUCHASReader);
 
 //------------------------------------------------------------------------------
 vtkTRUCHASReader::vtkTRUCHASReader()
-  : vtkMultiBlockDataSetAlgorithm()
 {
   this->Internals = new vtkTRUCHASReader::Internal;
   this->FileName = nullptr;
@@ -960,6 +960,22 @@ int vtkTRUCHASReader::RequestData(
       continue;
     }
 
+    // get the visualization field name
+    char field_name[MAX_NAME + 1];
+    if (H5Aexists_by_name(now_gid, array_name, "FIELDNAME", H5P_DEFAULT))
+    {
+      memset(field_name, 0, strlen(field_name));
+      hid_t attr = H5Aopen(did, "FIELDNAME", H5P_DEFAULT);
+      hid_t atype = H5Aget_type(attr);
+      hid_t atype_mem = H5Tget_native_type(atype, H5T_DIR_ASCEND);
+      H5Aread(attr, atype_mem, field_name);
+      H5Aclose(attr);
+    }
+    else
+    {
+      strncpy(field_name, array_name, MAX_NAME);
+    }
+
     bool isFloat = this->Internals->array_isFloat[array_name];
     double** vals_out = nullptr;
     int** ivals_out = nullptr;
@@ -1033,8 +1049,26 @@ int vtkTRUCHASReader::RequestData(
           {
             vArray = vtkIntArray::New();
           }
-          vArray->SetName(array_name);
+          vArray->SetName(field_name);
           vArray->SetNumberOfComponents(dims[1]);
+          if (strncmp(array_name, "VOF", 3) == 0)
+          {
+            // For the VOF field, name the components by the given FIELDNAMEX attribute.
+            for (size_t i = 0; i < dims[1]; i++)
+            {
+              std::string attr_name = "FIELDNAME" + std::to_string(i + 1);
+              if (!H5Aexists_by_name(now_gid, array_name, attr_name.c_str(), H5P_DEFAULT))
+                continue;
+              hid_t attr = H5Aopen(did, attr_name.c_str(), H5P_DEFAULT);
+              hid_t atype = H5Aget_type(attr);
+              hid_t atype_mem = H5Tget_native_type(atype, H5T_DIR_ASCEND);
+              char component_name[MAX_NAME + 1];
+              memset(component_name, 0, MAX_NAME);
+              H5Aread(attr, atype_mem, component_name);
+              H5Aclose(attr);
+              vArray->SetComponentName(i, component_name);
+            }
+          }
           vArray->SetNumberOfTuples(grid[b]->GetNumberOfCells());
           arrayGroup->AddArray(vArray);
           vArray->Delete();
@@ -1063,7 +1097,7 @@ int vtkTRUCHASReader::RequestData(
               {
                 mArray = vtkIntArray::New();
               }
-              mArray->SetName(array_name);
+              mArray->SetName(field_name);
               mArray->SetNumberOfComponents(dims[1]);
               mArray->SetNumberOfTuples(totalNumPoints);
               this->Internals->PointData->AddArray(mArray);
@@ -1164,7 +1198,7 @@ int vtkTRUCHASReader::RequestData(
 int vtkTRUCHASReader::CanReadFile(const char* filename)
 {
   size_t len = strlen(filename);
-  if (len < 3 || strcmp(filename + len - 3, ".h5"))
+  if (len < 3 || strcmp(filename + len - 3, ".h5") != 0)
   {
     return 0;
   }
@@ -1327,3 +1361,4 @@ const char* vtkTRUCHASReader::GetCellArrayName(int index)
 {
   return this->CellArrayChoices->GetArrayName(index);
 }
+VTK_ABI_NAMESPACE_END
