@@ -32,6 +32,8 @@
 #include "vtkTextCodecFactory.h"
 #include "vtksys/FStream.hxx"
 
+#include <vtk_utf8.h>
+
 #include <algorithm>
 #include <iostream>
 #include <iterator>
@@ -49,6 +51,7 @@
 /// fields, inserting them into a vtkTable. Based on the iterator from
 /// vtkIOInfoVis::DelimitedTextReader but tailored to Tecplot table files
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
@@ -56,18 +59,17 @@ class DelimitedTextIterator : public vtkTextCodec::OutputIterator
 {
 public:
   typedef std::forward_iterator_tag iterator_category;
-  typedef vtkUnicodeStringValueType value_type;
+  typedef vtkTypeUInt32 value_type;
   typedef std::string::difference_type difference_type;
   typedef value_type* pointer;
   typedef value_type& reference;
 
-  DelimitedTextIterator(vtkTable* const outputTable, const vtkIdType maxRecords,
-    const vtkIdType headerLines, const vtkIdType columnHeadersOnLine,
-    const vtkIdType skipColumnNames)
+  DelimitedTextIterator(vtkTable* outputTable, vtkIdType maxRecords, vtkIdType headerLines,
+    vtkIdType columnHeadersOnLine, vtkIdType skipColumnNames)
     : MaxRecords(maxRecords)
+    // first two lines are title + column names
     , MaxRecordIndex(maxRecords + headerLines)
-    , // first two lines are title + column names
-    WhiteSpaceOnlyString(true)
+    , WhiteSpaceOnlyString(true)
     , OutputTable(outputTable)
     , CurrentRecordIndex(0)
     , CurrentFieldIndex(0)
@@ -111,27 +113,28 @@ public:
     }
   }
 
-  DelimitedTextIterator& operator++(int) override { return *this; }
-
-  DelimitedTextIterator& operator*() override { return *this; }
-
   // Handle windows files that do not have a carriage return line feed on the last line of the file
   // ...
   void ReachedEndOfInput()
   {
-    if (this->CurrentField.empty())
+    if (!this->CurrentField.empty())
     {
-      return;
-    }
-    vtkUnicodeString::value_type value =
-      this->CurrentField[this->CurrentField.character_count() - 1];
-    if (!this->RecordDelimiters.count(value) && !this->Whitespace.count(value))
-    {
-      this->InsertField();
+      std::string::iterator start = this->CurrentField.begin();
+      std::string::iterator end = this->CurrentField.end();
+      std::string::size_type size = utf8::distance(start, end);
+
+      std::string::iterator iterator = start;
+      utf8::advance(iterator, size - 1, end);
+      vtkTypeUInt32 value = utf8::next(iterator, end);
+      // if the last character is not a CR/LF add a column
+      if (!this->RecordDelimiters.count(value) && !this->Whitespace.count(value))
+      {
+        this->InsertField();
+      }
     }
   }
 
-  DelimitedTextIterator& operator=(const vtkUnicodeString::value_type value) override
+  DelimitedTextIterator& operator=(const vtkTypeUInt32& value) override
   {
     // If we've already read our maximum number of records, we're done ...
     if (this->MaxRecords && this->CurrentRecordIndex == this->MaxRecordIndex)
@@ -178,7 +181,7 @@ public:
     // Look for field delimiters unless we're in a string ...
     if (!this->WithinString && this->FieldDelimiters.count(value))
     {
-      // Handle special case of merging consective delimiters ...
+      // Handle special case of merging consecutive delimiters ...
       if (!(this->CurrentField.empty() && this->MergeConsDelims))
       {
         if (!(this->CurrentFieldIndex < SkipColumnNames &&
@@ -203,47 +206,43 @@ public:
     // Process escape sequence ...
     if (this->ProcessEscapeSequence)
     {
-      vtkUnicodeString curr_char;
-      curr_char += value;
-      if (curr_char == vtkUnicodeString::from_utf8("0"))
+      std::string curr_char;
+      utf8::append(value, std::back_inserter(curr_char));
+      if (curr_char == "a")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\0");
+        this->CurrentField += "\a";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("a"))
+      else if (curr_char == "b")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\a");
+        this->CurrentField += "\b";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("b"))
+      else if (curr_char == "t")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\b");
+        this->CurrentField += "\t";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("t"))
+      else if (curr_char == "n")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\t");
+        this->CurrentField += "\n";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("n"))
+      else if (curr_char == "v")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\n");
+        this->CurrentField += "\v";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("v"))
+      else if (curr_char == "f")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\v");
+        this->CurrentField += "\f";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("f"))
+      else if (curr_char == "r")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\f");
+        this->CurrentField += "\r";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("r"))
+      else if (curr_char == "\\")
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\r");
+        this->CurrentField += "\\";
       }
-      else if (curr_char == vtkUnicodeString::from_utf8("\\"))
+      else if (!(curr_char == "0"))
       {
-        this->CurrentField += vtkUnicodeString::from_utf8("\\");
-      }
-      else
-      {
-        this->CurrentField += value;
+        this->CurrentField += curr_char;
       }
       this->ProcessEscapeSequence = false;
       return *this;
@@ -269,7 +268,7 @@ public:
       this->WhiteSpaceOnlyString = false;
     }
     // Keep growing the current field ...
-    this->CurrentField += value;
+    utf8::append(value, std::back_inserter(this->CurrentField));
     return *this;
   }
 
@@ -287,7 +286,7 @@ private:
     {
       vtkDoubleArray* array = vtkDoubleArray::New();
 
-      array->SetName(this->CurrentField.utf8_str());
+      array->SetName(this->CurrentField.c_str());
       this->OutputTable->AddColumn(array);
       array->Delete();
     }
@@ -299,8 +298,7 @@ private:
       vtkDoubleArray* array =
         vtkArrayDownCast<vtkDoubleArray>(this->OutputTable->GetColumn(fieldIndex));
 
-      vtkStdString str;
-      str = this->CurrentField.utf8_str();
+      vtkStdString str = this->CurrentField;
       bool ok;
       double doubleValue = vtkVariant(str).ToDouble(&ok);
       if (ok)
@@ -316,17 +314,17 @@ private:
 
   vtkIdType MaxRecords;
   vtkIdType MaxRecordIndex;
-  std::set<vtkUnicodeString::value_type> RecordDelimiters;
-  std::set<vtkUnicodeString::value_type> FieldDelimiters;
-  std::set<vtkUnicodeString::value_type> StringDelimiters;
-  std::set<vtkUnicodeString::value_type> Whitespace;
-  std::set<vtkUnicodeString::value_type> EscapeDelimiter;
+  std::set<vtkTypeUInt32> RecordDelimiters;
+  std::set<vtkTypeUInt32> FieldDelimiters;
+  std::set<vtkTypeUInt32> StringDelimiters;
+  std::set<vtkTypeUInt32> Whitespace;
+  std::set<vtkTypeUInt32> EscapeDelimiter;
 
   bool WhiteSpaceOnlyString;
   vtkTable* OutputTable;
   vtkIdType CurrentRecordIndex;
   vtkIdType CurrentFieldIndex;
-  vtkUnicodeString CurrentField;
+  std::string CurrentField;
 
   vtkIdType HeaderLines;
   vtkIdType ColumnNamesOnLine;
@@ -336,7 +334,7 @@ private:
   bool MergeConsDelims;
   bool ProcessEscapeSequence;
   bool UseStringDelimiter;
-  vtkUnicodeString::value_type WithinString;
+  vtkTypeUInt32 WithinString;
 };
 
 } // End anonymous namespace
@@ -405,7 +403,6 @@ int vtkTecplotTableReader::RequestData(
       return 0;
     }
 
-    istream* input_stream_pt = nullptr;
     vtksys::ifstream file_stream;
 
     // If the filename hasn't been specified, we're done ...
@@ -424,8 +421,7 @@ int vtkTecplotTableReader::RequestData(
     file_stream.seekg(0, ios::end);
     file_stream.seekg(0, ios::beg);
 
-    input_stream_pt = dynamic_cast<istream*>(&file_stream);
-    vtkTextCodec* transCodec = vtkTextCodecFactory::CodecToHandle(*input_stream_pt);
+    vtkTextCodec* transCodec = vtkTextCodecFactory::CodecToHandle(file_stream);
 
     if (nullptr == transCodec)
     {
@@ -436,9 +432,7 @@ int vtkTecplotTableReader::RequestData(
     DelimitedTextIterator iterator(output_table, this->MaxRecords, this->HeaderLines,
       this->ColumnNamesOnLine, this->SkipColumnNames);
 
-    vtkTextCodec::OutputIterator& outIter = iterator;
-
-    transCodec->ToUnicode(*input_stream_pt, outIter);
+    transCodec->ToUnicode(file_stream, iterator);
     iterator.ReachedEndOfInput();
     transCodec->Delete();
 
@@ -490,3 +484,4 @@ int vtkTecplotTableReader::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
