@@ -32,14 +32,17 @@
 #include "vtkIOXMLModule.h" // For export macro
 #include "vtkXMLReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataSet;
 class vtkInformationIntegerKey;
 class vtkInformationIntegerVectorKey;
 struct vtkXMLCompositeDataReaderInternals;
 
+VTK_ABI_NAMESPACE_END
 #include <set>    // for std::set
 #include <string> // for std::string
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOXML_EXPORT vtkXMLCompositeDataReader : public vtkXMLReader
 {
 public:
@@ -68,15 +71,15 @@ public:
   vtkGetMacro(PieceDistribution, int);
   /**@}*/
 
-  //@{
+  ///@{
   /**
    * Get the output data object for a port on this algorithm.
    */
   vtkCompositeDataSet* GetOutput();
   vtkCompositeDataSet* GetOutput(int);
-  //@}
+  ///@}
 
-  void SetFileName(const char*) override;
+  void SetFileName(VTK_FILEPATH const char*) override;
 
 protected:
   vtkXMLCompositeDataReader();
@@ -154,7 +157,7 @@ private:
   vtkXMLCompositeDataReader(const vtkXMLCompositeDataReader&) = delete;
   void operator=(const vtkXMLCompositeDataReader&) = delete;
 
-  //@{
+  ///@{
   /**
    * Given the number of datasets (@a numDatasets) and number of pieces (@a numPieces),
    * return the piece number of a dataset at the chosen index (@a datasetIndex)
@@ -164,11 +167,12 @@ private:
     unsigned int datasetIndex, unsigned int numDatasets, int numPieces);
   static int GetPieceAssignmentForInterleaveStrategy(
     unsigned int datasetIndex, unsigned int numDatasets, int numPieces);
-  //@}
+  ///@}
 
   int PieceDistribution;
 
   vtkXMLCompositeDataReaderInternals* Internal;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
