@@ -28,10 +28,10 @@
 #include "vtkXMLDataElement.h"
 #include "vtkXMLDataParser.h"
 
-
 #include <cassert>
 #include <map> // needed for std::map
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkXMLDataReader::MapStringToInt : public std::map<std::string, int>
 {
 };
@@ -39,7 +39,7 @@ class vtkXMLDataReader::MapStringToInt64 : public std::map<std::string, vtkTypeI
 {
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLDataReader::vtkXMLDataReader()
   : PointDataTimeStep(new vtkXMLDataReader::MapStringToInt())
   , PointDataOffset(new vtkXMLDataReader::MapStringToInt64())
@@ -49,6 +49,7 @@ vtkXMLDataReader::vtkXMLDataReader()
   this->NumberOfPieces = 0;
   this->PointDataElements = nullptr;
   this->CellDataElements = nullptr;
+  this->TimeDataElements = nullptr;
   this->Piece = 0;
   this->NumberOfPointArrays = 0;
   this->NumberOfCellArrays = 0;
@@ -60,7 +61,7 @@ vtkXMLDataReader::vtkXMLDataReader()
   this->DataProgressObserver->SetClientData(this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLDataReader::~vtkXMLDataReader()
 {
   if (this->XMLParser)
@@ -74,26 +75,24 @@ vtkXMLDataReader::~vtkXMLDataReader()
   this->DataProgressObserver->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::CreateXMLParser()
 {
   this->Superclass::CreateXMLParser();
-  this->XMLParser->AddObserver(vtkCommand::ProgressEvent,
-                               this->DataProgressObserver);
+  this->XMLParser->AddObserver(vtkCommand::ProgressEvent, this->DataProgressObserver);
   if (this->GetParserErrorObserver())
   {
-    this->XMLParser->AddObserver(vtkCommand::ErrorEvent,
-                                 this->GetParserErrorObserver());
+    this->XMLParser->AddObserver(vtkCommand::ErrorEvent, this->GetParserErrorObserver());
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::DestroyXMLParser()
 {
   if (this->XMLParser)
@@ -103,10 +102,10 @@ void vtkXMLDataReader::DestroyXMLParser()
   this->Superclass::DestroyXMLParser();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Note that any changes (add or removing information) made to this method
 // should be replicated in CopyOutputInformation
-void vtkXMLDataReader::SetupOutputInformation(vtkInformation *outInfo)
+void vtkXMLDataReader::SetupOutputInformation(vtkInformation* outInfo)
 {
   if (this->InformationError)
   {
@@ -115,17 +114,14 @@ void vtkXMLDataReader::SetupOutputInformation(vtkInformation *outInfo)
   }
 
   // Initialize DataArraySelections to enable all that are present
-  this->SetDataArraySelections(this->PointDataElements[0],
-                               this->PointDataArraySelection);
-  this->SetDataArraySelections(this->CellDataElements[0],
-                               this->CellDataArraySelection);
+  this->SetDataArraySelections(this->PointDataElements[0], this->PointDataArraySelection);
+  this->SetDataArraySelections(this->CellDataElements[0], this->CellDataArraySelection);
 
   // Setup the Field Information for PointData.  We only need the
   // information from one piece because all pieces have the same set of arrays.
-  vtkInformationVector *infoVector = nullptr;
-  if (!this->SetFieldDataInfo(this->PointDataElements[0],
-                              vtkDataObject::FIELD_ASSOCIATION_POINTS,
-                              this->GetNumberOfPoints(), infoVector))
+  vtkInformationVector* infoVector = nullptr;
+  if (!this->SetFieldDataInfo(this->PointDataElements[0], vtkDataObject::FIELD_ASSOCIATION_POINTS,
+        this->GetNumberOfPoints(), infoVector))
   {
     return;
   }
@@ -137,9 +133,8 @@ void vtkXMLDataReader::SetupOutputInformation(vtkInformation *outInfo)
 
   // now the Cell data
   infoVector = nullptr;
-  if (!this->SetFieldDataInfo(this->CellDataElements[0],
-                              vtkDataObject::FIELD_ASSOCIATION_CELLS,
-                              this->GetNumberOfCells(), infoVector))
+  if (!this->SetFieldDataInfo(this->CellDataElements[0], vtkDataObject::FIELD_ASSOCIATION_CELLS,
+        this->GetNumberOfCells(), infoVector))
   {
     return;
   }
@@ -150,12 +145,10 @@ void vtkXMLDataReader::SetupOutputInformation(vtkInformation *outInfo)
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLDataReader::CopyOutputInformation(vtkInformation *outInfo,
-                                             int port)
+//------------------------------------------------------------------------------
+void vtkXMLDataReader::CopyOutputInformation(vtkInformation* outInfo, int port)
 {
-  vtkInformation *localInfo =
-    this->GetExecutive()->GetOutputInformation(port);
+  vtkInformation* localInfo = this->GetExecutive()->GetOutputInformation(port);
 
   if (localInfo->Has(vtkDataObject::POINT_DATA_VECTOR()))
   {
@@ -167,8 +160,7 @@ void vtkXMLDataReader::CopyOutputInformation(vtkInformation *outInfo,
   }
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataReader::ReadPrimaryElement(vtkXMLDataElement* ePrimary)
 {
   if (!this->Superclass::ReadPrimaryElement(ePrimary))
@@ -195,7 +187,7 @@ int vtkXMLDataReader::ReadPrimaryElement(vtkXMLDataElement* ePrimary)
   {
     this->SetupPieces(numPieces);
     int piece = 0;
-    for (int i = 0;i < numNested; ++i)
+    for (int i = 0; i < numNested; ++i)
     {
       vtkXMLDataElement* eNested = ePrimary->GetNestedElement(i);
       if (strcmp(eNested->GetName(), "Piece") == 0)
@@ -218,7 +210,7 @@ int vtkXMLDataReader::ReadPrimaryElement(vtkXMLDataElement* ePrimary)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::SetupPieces(int numPieces)
 {
   if (this->NumberOfPieces)
@@ -230,26 +222,29 @@ void vtkXMLDataReader::SetupPieces(int numPieces)
   {
     this->PointDataElements = new vtkXMLDataElement*[numPieces];
     this->CellDataElements = new vtkXMLDataElement*[numPieces];
+    this->TimeDataElements = new vtkXMLDataElement*[numPieces];
   }
-  for (int i = 0;i < this->NumberOfPieces; ++i)
+  for (int i = 0; i < this->NumberOfPieces; ++i)
   {
     this->PointDataElements[i] = nullptr;
     this->CellDataElements[i] = nullptr;
+    this->TimeDataElements[i] = nullptr;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::DestroyPieces()
 {
-  delete [] this->PointDataElements;
-  delete [] this->CellDataElements;
+  delete[] this->PointDataElements;
+  delete[] this->CellDataElements;
+  delete[] this->TimeDataElements;
   this->PointDataElements = nullptr;
   this->CellDataElements = nullptr;
+  this->TimeDataElements = nullptr;
   this->NumberOfPieces = 0;
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::SetupOutputData()
 {
   this->Superclass::SetupOutputData();
@@ -272,6 +267,7 @@ void vtkXMLDataReader::SetupOutputData()
   this->PointDataOffset->clear();
   if (ePointData)
   {
+    this->MarkIdTypeArrays(ePointData);
     for (int i = 0; i < ePointData->GetNumberOfNestedElements(); i++)
     {
       vtkXMLDataElement* eNested = ePointData->GetNestedElement(i);
@@ -300,6 +296,7 @@ void vtkXMLDataReader::SetupOutputData()
   this->CellDataOffset->clear();
   if (eCellData)
   {
+    this->MarkIdTypeArrays(eCellData);
     for (int i = 0; i < eCellData->GetNumberOfNestedElements(); i++)
     {
       vtkXMLDataElement* eNested = eCellData->GetNestedElement(i);
@@ -329,14 +326,14 @@ void vtkXMLDataReader::SetupOutputData()
   this->ReadAttributeIndices(eCellData, cellData);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataReader::ReadPiece(vtkXMLDataElement* ePiece, int piece)
 {
   this->Piece = piece;
   return this->ReadPiece(ePiece);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataReader::ReadPiece(vtkXMLDataElement* ePiece)
 {
   // Find the PointData and CellData in the piece.
@@ -355,14 +352,14 @@ int vtkXMLDataReader::ReadPiece(vtkXMLDataElement* ePiece)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataReader::ReadPieceData(int piece)
 {
   this->Piece = piece;
   return this->ReadPieceData();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataReader::ReadPieceData()
 {
   vtkDataSet* output = vtkDataSet::SafeDownCast(this->GetCurrentOutput());
@@ -384,14 +381,13 @@ int vtkXMLDataReader::ReadPieceData()
   if (ePointData)
   {
     int a = 0;
-    for (int i = 0; (i < ePointData->GetNumberOfNestedElements() &&
-             !this->AbortExecute); ++i)
+    for (int i = 0; (i < ePointData->GetNumberOfNestedElements() && !this->AbortExecute); ++i)
     {
       vtkXMLDataElement* eNested = ePointData->GetNestedElement(i);
       if (this->PointDataArrayIsEnabled(eNested))
       {
-        if (strcmp(eNested->GetName(), "DataArray") != 0  &&
-          strcmp(eNested->GetName(),"Array") != 0)
+        if (strcmp(eNested->GetName(), "DataArray") != 0 &&
+          strcmp(eNested->GetName(), "Array") != 0)
         {
           vtkErrorMacro("Invalid Array.");
           this->DataError = 1;
@@ -410,8 +406,8 @@ int vtkXMLDataReader::ReadPieceData()
             if (!this->AbortExecute)
             {
               vtkErrorMacro("Cannot read point data array \""
-                << pointData->GetArray(a-1)->GetName() << "\" from "
-                << ePointData->GetName() << " in piece " << this->Piece
+                << pointData->GetArray(a - 1)->GetName() << "\" from " << ePointData->GetName()
+                << " in piece " << this->Piece
                 << ".  The data array in the element may be too short.");
             }
             return 0;
@@ -423,14 +419,13 @@ int vtkXMLDataReader::ReadPieceData()
   if (eCellData)
   {
     int a = 0;
-    for (int i = 0; (i < eCellData->GetNumberOfNestedElements() &&
-             !this->AbortExecute); ++i)
+    for (int i = 0; (i < eCellData->GetNumberOfNestedElements() && !this->AbortExecute); ++i)
     {
       vtkXMLDataElement* eNested = eCellData->GetNestedElement(i);
       if (this->CellDataArrayIsEnabled(eNested))
       {
         if (strcmp(eNested->GetName(), "DataArray") != 0 &&
-          strcmp(eNested->GetName(),"Array") != 0)
+          strcmp(eNested->GetName(), "Array") != 0)
         {
           this->DataError = 1;
           vtkErrorMacro("Invalid Array");
@@ -448,7 +443,7 @@ int vtkXMLDataReader::ReadPieceData()
             if (!this->AbortExecute)
             {
               vtkErrorMacro("Cannot read cell data array \""
-                << cellData->GetAbstractArray(a-1)->GetName() << "\" from "
+                << cellData->GetAbstractArray(a - 1)->GetName() << "\" from "
                 << ePointData->GetName() << " in piece " << this->Piece
                 << ".  The data array in the element may be too short.");
             }
@@ -467,7 +462,7 @@ int vtkXMLDataReader::ReadPieceData()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::ReadXMLData()
 {
   // Let superclasses read data.  This also allocates output data.
@@ -476,36 +471,31 @@ void vtkXMLDataReader::ReadXMLData()
   this->ReadFieldData();
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLDataReader::ReadArrayForPoints(vtkXMLDataElement* da,
-                                         vtkAbstractArray* outArray)
+//------------------------------------------------------------------------------
+int vtkXMLDataReader::ReadArrayForPoints(vtkXMLDataElement* da, vtkAbstractArray* outArray)
 {
   vtkIdType components = outArray->GetNumberOfComponents();
   vtkIdType numberOfTuples = this->GetNumberOfPoints();
-  return this->ReadArrayValues(
-    da, 0, outArray,0, numberOfTuples*components, POINT_DATA);
+  return this->ReadArrayValues(da, 0, outArray, 0, numberOfTuples * components, POINT_DATA);
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLDataReader::ReadArrayForCells(vtkXMLDataElement* da,
-                                        vtkAbstractArray* outArray)
+//------------------------------------------------------------------------------
+int vtkXMLDataReader::ReadArrayForCells(vtkXMLDataElement* da, vtkAbstractArray* outArray)
 {
   vtkIdType components = outArray->GetNumberOfComponents();
   vtkIdType numberOfTuples = this->GetNumberOfCells();
-  return this->ReadArrayValues(
-    da, 0, outArray,0, numberOfTuples*components, CELL_DATA);
+  return this->ReadArrayValues(da, 0, outArray, 0, numberOfTuples * components, CELL_DATA);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::ConvertGhostLevelsToGhostType(
-  FieldType fieldType, vtkAbstractArray* data, vtkIdType startIndex,
-  vtkIdType numValues)
+  FieldType fieldType, vtkAbstractArray* data, vtkIdType startIndex, vtkIdType numValues)
 {
   vtkUnsignedCharArray* ucData = vtkArrayDownCast<vtkUnsignedCharArray>(data);
   int numComp = data->GetNumberOfComponents();
   const char* name = data->GetName();
-  if (this->GetFileMajorVersion() < 2 && ucData &&
-      numComp == 1 && name && !strcmp(name, "vtkGhostLevels"))
+  if (this->GetFileMajorVersion() < 2 && ucData && numComp == 1 && name &&
+    !strcmp(name, "vtkGhostLevels"))
   {
     // convert ghost levels to ghost type
     unsigned char* ghosts = ucData->GetPointer(0);
@@ -526,21 +516,21 @@ void vtkXMLDataReader::ConvertGhostLevelsToGhostType(
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLDataReader::DataProgressCallbackFunction(vtkObject*, unsigned long,
-                                                    void* clientdata, void*)
+//------------------------------------------------------------------------------
+void vtkXMLDataReader::DataProgressCallbackFunction(
+  vtkObject*, unsigned long, void* clientdata, void*)
 {
   reinterpret_cast<vtkXMLDataReader*>(clientdata)->DataProgressCallback();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataReader::DataProgressCallback()
 {
   if (this->InReadData)
   {
     float width = this->ProgressRange[1] - this->ProgressRange[0];
     float dataProgress = this->XMLParser->GetProgress();
-    float progress = this->ProgressRange[0] + dataProgress*width;
+    float progress = this->ProgressRange[0] + dataProgress * width;
     this->UpdateProgressDiscrete(progress);
     if (this->AbortExecute)
     {
@@ -549,15 +539,15 @@ void vtkXMLDataReader::DataProgressCallback()
   }
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLDataReader::PointDataNeedToReadTimeStep(vtkXMLDataElement *eNested)
+//------------------------------------------------------------------------------
+int vtkXMLDataReader::PointDataNeedToReadTimeStep(vtkXMLDataElement* eNested)
 {
   // First thing need to find the id of this dataarray from its name:
   const char* name = eNested->GetAttribute("Name");
 
   // Easy case no timestep:
-  int numTimeSteps = eNested->GetVectorAttribute("TimeStep",
-    this->NumberOfTimeSteps, this->TimeSteps);
+  int numTimeSteps =
+    eNested->GetVectorAttribute("TimeStep", this->NumberOfTimeSteps, this->TimeSteps);
   if (!(numTimeSteps <= this->NumberOfTimeSteps))
   {
     vtkErrorMacro("Invalid TimeStep specification");
@@ -618,15 +608,15 @@ int vtkXMLDataReader::PointDataNeedToReadTimeStep(vtkXMLDataElement *eNested)
   return 0;
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLDataReader::CellDataNeedToReadTimeStep(vtkXMLDataElement *eNested)
+//------------------------------------------------------------------------------
+int vtkXMLDataReader::CellDataNeedToReadTimeStep(vtkXMLDataElement* eNested)
 {
   // First thing need to find the id of this dataarray from its name:
   const char* name = eNested->GetAttribute("Name");
 
   // Easy case no timestep:
-  int numTimeSteps = eNested->GetVectorAttribute("TimeStep",
-    this->NumberOfTimeSteps, this->TimeSteps);
+  int numTimeSteps =
+    eNested->GetVectorAttribute("TimeStep", this->NumberOfTimeSteps, this->TimeSteps);
   if (!(numTimeSteps <= this->NumberOfTimeSteps))
   {
     vtkErrorMacro("Invalid TimeSteps specification");
@@ -686,3 +676,4 @@ int vtkXMLDataReader::CellDataNeedToReadTimeStep(vtkXMLDataElement *eNested)
   // all other cases we don't need to read:
   return 0;
 }
+VTK_ABI_NAMESPACE_END
