@@ -30,6 +30,7 @@
 #include "vtkSmartPointer.h" // for API
 #include "vtkXMLDataReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkHierarchicalBoxDataSet;
 class vtkMultiBlockDataSet;
 class vtkImageData;
@@ -45,15 +46,15 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent) override;
   static vtkXMLGenericDataObjectReader* New();
 
-  //@{
+  ///@{
   /**
    * Get the reader's output.
    */
   vtkDataObject* GetOutput();
   vtkDataObject* GetOutput(int idx);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the output as various concrete types. This method is typically used
    * when you know exactly what type of data is being read.  Otherwise, use
@@ -68,7 +69,7 @@ public:
   vtkRectilinearGrid* GetRectilinearGridOutput();
   vtkStructuredGrid* GetStructuredGridOutput();
   vtkUnstructuredGrid* GetUnstructuredGridOutput();
-  //@}
+  ///@}
 
   /**
    * Overridden method.
@@ -121,4 +122,5 @@ private:
   void operator=(const vtkXMLGenericDataObjectReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
