@@ -13,51 +13,52 @@
 
 =========================================================================*/
 #include "vtkXMLImageDataWriter.h"
-#include "vtkObjectFactory.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkMatrix3x3.h"
+#include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkXMLImageDataWriter);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLImageDataWriter::vtkXMLImageDataWriter() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLImageDataWriter::~vtkXMLImageDataWriter() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLImageDataWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageData* vtkXMLImageDataWriter::GetInput()
 {
   return static_cast<vtkImageData*>(this->Superclass::GetInput());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLImageDataWriter::GetInputExtent(int* extent)
 {
   this->GetInput()->GetExtent(extent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLImageDataWriter::GetDataSetName()
 {
   return "ImageData";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLImageDataWriter::GetDefaultFileExtension()
 {
   return "vti";
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLImageDataWriter::WritePrimaryElementAttributes(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkXMLImageDataWriter::WritePrimaryElementAttributes(ostream& os, vtkIndent indent)
 {
   this->Superclass::WritePrimaryElementAttributes(os, indent);
   vtkImageData* input = this->GetInput();
@@ -66,10 +67,10 @@ void vtkXMLImageDataWriter::WritePrimaryElementAttributes(ostream &os, vtkIndent
   this->WriteVectorAttribute("Direction", 9, input->GetDirectionMatrix()->GetData());
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLImageDataWriter::FillInputPortInformation(
-  int vtkNotUsed(port), vtkInformation* info)
+//------------------------------------------------------------------------------
+int vtkXMLImageDataWriter::FillInputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkImageData");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
