@@ -21,6 +21,7 @@
 #include <sstream>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkXMLPDataObjectReader::vtkXMLPDataObjectReader()
 {
   this->NumberOfPieces = 0;
@@ -160,6 +161,11 @@ void vtkXMLPDataObjectReader::SetupPieces(int numPieces)
     this->DestroyPieces();
   }
 
+  if (!numPieces)
+  {
+    return;
+  }
+
   this->NumberOfPieces = numPieces;
   this->PieceElements = new vtkXMLDataElement*[this->NumberOfPieces];
   this->CanReadPieceFlag = new int[this->NumberOfPieces];
@@ -186,3 +192,4 @@ int vtkXMLPDataObjectReader::ReadPiece(vtkXMLDataElement* ePiece, int index)
   this->Piece = index;
   return this->ReadPiece(ePiece);
 }
+VTK_ABI_NAMESPACE_END
