@@ -32,6 +32,7 @@
 #include "vtkIOXMLModule.h" // For export macro
 #include "vtkXMLPUnstructuredDataReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkPolyData;
 
@@ -42,13 +43,13 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent) override;
   static vtkXMLPPolyDataReader* New();
 
-  //@{
+  ///@{
   /**
    * Get the reader's output.
    */
   vtkPolyData* GetOutput();
   vtkPolyData* GetOutput(int idx);
-  //@}
+  ///@}
 
 protected:
   vtkXMLPPolyDataReader();
@@ -86,4 +87,5 @@ private:
   void operator=(const vtkXMLPPolyDataReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
