@@ -30,9 +30,10 @@
 #include <cassert>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkXMLPTableReader);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLPTableReader::vtkXMLPTableReader()
 {
   this->PieceReaders = nullptr;
@@ -43,7 +44,7 @@ vtkXMLPTableReader::vtkXMLPTableReader()
   this->ColumnSelection->AddObserver(vtkCommand::ModifiedEvent, this->SelectionObserver);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLPTableReader::~vtkXMLPTableReader()
 {
   if (this->NumberOfPieces)
@@ -55,7 +56,7 @@ vtkXMLPTableReader::~vtkXMLPTableReader()
   this->ColumnSelection->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::CopyOutputInformation(vtkInformation* outInfo, int port)
 {
   vtkInformation* localInfo = this->GetExecutive()->GetOutputInformation(port);
@@ -66,7 +67,7 @@ void vtkXMLPTableReader::CopyOutputInformation(vtkInformation* outInfo, int port
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -75,25 +76,25 @@ void vtkXMLPTableReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Total Number Of Rows: " << this->TotalNumberOfRows << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTable* vtkXMLPTableReader::GetOutput()
 {
   return this->GetOutput(0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTable* vtkXMLPTableReader::GetOutput(int idx)
 {
   return vtkTable::SafeDownCast(this->GetOutputDataObject(idx));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLPTableReader::GetDataSetName()
 {
   return "PTable";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::GetOutputUpdateExtent(int& piece, int& numberOfPieces)
 {
   vtkInformation* outInfo = this->GetCurrentOutputInformation();
@@ -101,7 +102,7 @@ void vtkXMLPTableReader::GetOutputUpdateExtent(int& piece, int& numberOfPieces)
   numberOfPieces = outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupOutputTotals()
 {
   this->TotalNumberOfRows = 0;
@@ -115,7 +116,7 @@ void vtkXMLPTableReader::SetupOutputTotals()
   this->StartRow = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupOutputData()
 {
   this->Superclass::SetupOutputData();
@@ -154,7 +155,7 @@ void vtkXMLPTableReader::SetupOutputData()
   this->ReadAttributeIndices(this->PRowElement, rowData);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::ReadPieceData(int index)
 {
   this->Piece = index;
@@ -172,7 +173,7 @@ int vtkXMLPTableReader::ReadPieceData(int index)
   return this->ReadPieceData();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::CanReadPiece(int index)
 {
   // If necessary, test whether the piece can be read.
@@ -197,7 +198,7 @@ int vtkXMLPTableReader::CanReadPiece(int index)
   return (this->PieceReaders[index] ? 1 : 0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::PieceProgressCallback()
 {
   float width = this->ProgressRange[1] - this->ProgressRange[0];
@@ -210,7 +211,7 @@ void vtkXMLPTableReader::PieceProgressCallback()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupNextPiece()
 {
   if (this->PieceReaders[this->Piece])
@@ -219,7 +220,7 @@ void vtkXMLPTableReader::SetupNextPiece()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::ReadPieceData()
 {
   // Use the internal reader to read the piece.
@@ -272,20 +273,20 @@ int vtkXMLPTableReader::ReadPieceData()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLTableReader* vtkXMLPTableReader::CreatePieceReader()
 {
   return vtkXMLTableReader::New();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::FillOutputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkTable");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::RequestInformation(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -294,13 +295,13 @@ int vtkXMLPTableReader::RequestInformation(
   return this->Superclass::RequestInformation(request, inputVector, outputVector);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTable* vtkXMLPTableReader::GetOutputAsTable()
 {
   return vtkTable::SafeDownCast(this->GetOutputDataObject(0));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTable* vtkXMLPTableReader::GetPieceInputAsTable(int piece)
 {
   vtkXMLTableReader* reader = this->PieceReaders[piece];
@@ -311,26 +312,26 @@ vtkTable* vtkXMLPTableReader::GetPieceInputAsTable(int piece)
   return static_cast<vtkTable*>(reader->GetExecutive()->GetOutputData(0));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkXMLPTableReader::GetNumberOfRows()
 {
   return this->TotalNumberOfRows;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupEmptyOutput()
 {
   this->GetCurrentOutput()->Initialize();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupOutputInformation(vtkInformation* outInfo)
 {
   if (this->InformationError)
   {
     vtkErrorMacro("Should not still be processing output information if have set InformationError");
     return;
-  };
+  }
 
   // Initialize DataArraySelections to enable all that are present
   this->SetDataArraySelections(this->PRowElement, this->ColumnSelection);
@@ -351,7 +352,7 @@ void vtkXMLPTableReader::SetupOutputInformation(vtkInformation* outInfo)
   outInfo->Set(CAN_HANDLE_PIECE_REQUEST(), 1);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::ReadXMLData()
 {
   // Get the update request.
@@ -416,7 +417,7 @@ void vtkXMLPTableReader::ReadXMLData()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::ReadPrimaryElement(vtkXMLDataElement* ePrimary)
 {
 
@@ -458,7 +459,7 @@ int vtkXMLPTableReader::ReadPrimaryElement(vtkXMLDataElement* ePrimary)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupUpdateExtent(int piece, int numberOfPieces)
 {
   this->UpdatePieceId = piece;
@@ -475,7 +476,8 @@ void vtkXMLPTableReader::SetupUpdateExtent(int piece, int numberOfPieces)
   if (this->UpdatePieceId < this->UpdateNumberOfPieces)
   {
     this->StartPiece = (this->UpdatePieceId * this->NumberOfPieces) / this->UpdateNumberOfPieces;
-    this->EndPiece = ((this->UpdatePieceId + 1) * this->NumberOfPieces) / this->UpdateNumberOfPieces;
+    this->EndPiece =
+      ((this->UpdatePieceId + 1) * this->NumberOfPieces) / this->UpdateNumberOfPieces;
   }
   else
   {
@@ -498,13 +500,13 @@ void vtkXMLPTableReader::SetupUpdateExtent(int piece, int numberOfPieces)
   this->SetupOutputTotals();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkXMLPTableReader::GetNumberOfRowsInPiece(int piece)
 {
   return this->PieceReaders[piece] ? this->PieceReaders[piece]->GetNumberOfRows() : 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetupPieces(int numPieces)
 {
   this->Superclass::SetupPieces(numPieces);
@@ -517,7 +519,7 @@ void vtkXMLPTableReader::SetupPieces(int numPieces)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::DestroyPieces()
 {
   for (int i = 0; i < this->NumberOfPieces; ++i)
@@ -535,7 +537,7 @@ void vtkXMLPTableReader::DestroyPieces()
   this->Superclass::DestroyPieces();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::ReadPiece(vtkXMLDataElement* ePiece)
 {
   this->PieceElements[this->Piece] = ePiece;
@@ -562,32 +564,32 @@ int vtkXMLPTableReader::ReadPiece(vtkXMLDataElement* ePiece)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::ColumnIsEnabled(vtkXMLDataElement* elementRowData)
 {
   const char* name = elementRowData->GetAttribute("Name");
   return (name && this->ColumnSelection->ArrayIsEnabled(name));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::GetNumberOfColumnArrays()
 {
   return this->ColumnSelection->GetNumberOfArrays();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLPTableReader::GetColumnArrayName(int index)
 {
   return this->ColumnSelection->GetArrayName(index);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLPTableReader::GetColumnArrayStatus(const char* name)
 {
   return this->ColumnSelection->ArrayIsEnabled(name);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPTableReader::SetColumnArrayStatus(const char* name, int status)
 {
   if (status)
@@ -599,3 +601,4 @@ void vtkXMLPTableReader::SetColumnArrayStatus(const char* name, int status)
     this->ColumnSelection->DisableArray(name);
   }
 }
+VTK_ABI_NAMESPACE_END
