@@ -24,7 +24,7 @@
  *
  * @sa
  * vtkXMLPPolyDataReader
-*/
+ */
 
 #ifndef vtkXMLPolyDataReader_h
 #define vtkXMLPolyDataReader_h
@@ -32,24 +32,25 @@
 #include "vtkIOXMLModule.h" // For export macro
 #include "vtkXMLUnstructuredDataReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPolyData;
 
 class VTKIOXML_EXPORT vtkXMLPolyDataReader : public vtkXMLUnstructuredDataReader
 {
 public:
-  vtkTypeMacro(vtkXMLPolyDataReader,vtkXMLUnstructuredDataReader);
+  vtkTypeMacro(vtkXMLPolyDataReader, vtkXMLUnstructuredDataReader);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  static vtkXMLPolyDataReader *New();
+  static vtkXMLPolyDataReader* New();
 
-  //@{
+  ///@{
   /**
    * Get the reader's output.
    */
-  vtkPolyData *GetOutput();
-  vtkPolyData *GetOutput(int idx);
-  //@}
+  vtkPolyData* GetOutput();
+  vtkPolyData* GetOutput(int idx);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the number of verts/lines/strips/polys in the output.
    */
@@ -57,7 +58,7 @@ public:
   virtual vtkIdType GetNumberOfLines();
   virtual vtkIdType GetNumberOfStrips();
   virtual vtkIdType GetNumberOfPolys();
-  //@}
+  ///@}
 
 protected:
   vtkXMLPolyDataReader();
@@ -75,8 +76,7 @@ protected:
   int ReadPieceData() override;
 
   // Read a data array whose tuples coorrespond to cells.
-  int ReadArrayForCells(vtkXMLDataElement* da,
-    vtkAbstractArray* outArray) override;
+  int ReadArrayForCells(vtkXMLDataElement* da, vtkAbstractArray* outArray) override;
 
   // Get the number of cells in the given piece.  Valid after
   // UpdateInformation.
@@ -119,4 +119,5 @@ private:
   void operator=(const vtkXMLPolyDataReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
