@@ -15,6 +15,7 @@
 #include "vtkXMLReader.h"
 
 #include "vtkArrayIteratorIncludes.h"
+#include "vtkBitArray.h"
 #include "vtkCallbackCommand.h"
 #include "vtkDataArray.h"
 #include "vtkDataArraySelection.h"
@@ -58,6 +59,7 @@
 #include <sstream>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkXMLReader, ReaderErrorObserver, vtkCommand);
 vtkCxxSetObjectMacro(vtkXMLReader, ParserErrorObserver, vtkCommand);
 
@@ -106,7 +108,6 @@ static void ReadStringVersion(const char* version, int& major, int& minor)
 
   for (s = begin; (s != end) && (*s != '.'); ++s)
   {
-    ;
   }
 
   if (s > begin)
@@ -334,7 +335,7 @@ int vtkXMLReader::OpenVTKString()
     return 1;
   }
 
-  if (!this->Stream && this->InputString.compare("") == 0)
+  if (!this->Stream && this->InputString.empty())
   {
     vtkErrorMacro("Input string not specified");
     return 0;
@@ -596,7 +597,7 @@ int vtkXMLReader::RequestInformation(vtkInformation* request,
       std::vector<double> timeSteps(numTimesteps);
       std::iota(timeSteps.begin(), timeSteps.end(), 0.0);
       double timeRange[2] = { timeSteps[0], timeSteps[numTimesteps - 1] };
-      outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &timeSteps[0], numTimesteps);
+      outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), timeSteps.data(), numTimesteps);
       outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), timeRange, 2);
     }
     else
@@ -760,6 +761,52 @@ int vtkXMLDataReaderReadArrayValues(vtkXMLDataElement* da, vtkXMLDataParser* xml
   return result;
 }
 
+//------------------------------------------------------------------------------
+template <>
+int vtkXMLDataReaderReadArrayValues(vtkXMLDataElement* da, vtkXMLDataParser* xmlparser,
+  vtkIdType arrayIndex, vtkBitArrayIterator* iter, vtkIdType startIndex, vtkIdType numValues)
+{
+  // We need to handle bit array separately because the "word" concept is a bit
+  // different: a word size is in bits rather than bytes...
+  if (!iter)
+  {
+    return 0;
+  }
+  vtkBitArray* array = vtkArrayDownCast<vtkBitArray>(iter->GetArray());
+  // Number of expected words:
+  int bitShift = startIndex % 8;
+  size_t numBytes = (numValues + bitShift + 7) / 8;
+  size_t startByteIndex = startIndex / 8;
+  int result;
+
+  vtkNew<vtkBitArray> tmp;
+  tmp->SetNumberOfValues(numValues + bitShift);
+  tmp->SetNumberOfComponents(array->GetNumberOfComponents());
+
+  void* data = tmp->GetVoidPointer(0);
+  if (da->GetAttribute("offset"))
+  {
+    vtkTypeInt64 offset = 0;
+    da->GetScalarAttribute("offset", offset);
+    result =
+      (xmlparser->ReadAppendedData(offset, data, startByteIndex, numBytes, VTK_BIT) == numBytes);
+  }
+  else
+  {
+    int isAscii = 1;
+    const char* format = da->GetAttribute("format");
+    if (format && (strcmp(format, "binary") == 0))
+    {
+      isAscii = 0;
+    }
+    result =
+      (xmlparser->ReadInlineData(da, isAscii, data, startByteIndex, numBytes, VTK_BIT) == numBytes);
+  }
+
+  array->InsertTuples(arrayIndex, numValues / tmp->GetNumberOfComponents(), bitShift, tmp);
+  return result;
+}
+
 //------------------------------------------------------------------------------
 template <>
 int vtkXMLDataReaderReadArrayValues(vtkXMLDataElement* da, vtkXMLDataParser* xmlparser,
@@ -798,7 +845,7 @@ int vtkXMLDataReaderReadArrayValues(vtkXMLDataElement* da, vtkXMLDataParser* xml
   int result = 1;
   vtkIdType inIndex = 0;
   vtkIdType outIndex = arrayIndex;
-  vtkStdString prev_string;
+  std::string prev_string;
   while (result && inIndex < actualNumValues)
   {
     size_t chars_read = 0;
@@ -824,7 +871,7 @@ int vtkXMLDataReaderReadArrayValues(vtkXMLDataElement* da, vtkXMLDataParser* xml
 
     while (ptr < end_ptr)
     {
-      vtkStdString temp_string = ptr; // will read in string until 0x0;
+      std::string temp_string = ptr; // will read in string until 0x0;
       ptr += temp_string.size() + 1;
       if (!prev_string.empty())
       {
@@ -1125,7 +1172,7 @@ bool readVectorInfo(KeyType* key, vtkInformation* info, vtkXMLDataElement* eleme
     }
     values.push_back(value);
   }
-  info->Set(key, &values[0], length);
+  info->Set(key, values.data(), length);
 
   return true;
 }
@@ -1877,7 +1924,7 @@ const char* vtkXMLReader::GetTimeDataArray(int idx) const
   {
     vtkErrorMacro("Invalid index for 'GetTimeDataArray': " << idx);
   }
-  return this->TimeDataStringArray->GetValue(idx);
+  return this->TimeDataStringArray->GetValue(idx).c_str();
 }
 
 //------------------------------------------------------------------------------
@@ -2005,3 +2052,4 @@ vtkInformation* vtkXMLReader::GetCurrentOutputInformation()
 {
   return this->CurrentOutputInformation;
 }
+VTK_ABI_NAMESPACE_END
