@@ -15,13 +15,15 @@
 /**
  * @class   vtkXMLReaderVersion
  * @brief   version number for legacy readers/writers
-*/
+ */
 
 #ifndef vtkXMLReaderVersion_h
 #define vtkXMLReaderVersion_h
 
+VTK_ABI_NAMESPACE_BEGIN
 const int vtkXMLReaderMajorVersion = 2;
-const int vtkXMLReaderMinorVersion = 1;
+const int vtkXMLReaderMinorVersion = 2;
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkXMLReaderVersion_h
 // VTK-HeaderTest-Exclude: vtkXMLReaderVersion.h
