@@ -29,27 +29,31 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #define vtkXMLOffsetsManager_DoNotInclude
 #include "vtkXMLOffsetsManager.h"
-#undef  vtkXMLOffsetsManager_DoNotInclude
+#undef vtkXMLOffsetsManager_DoNotInclude
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkXMLStructuredDataWriter::vtkXMLStructuredDataWriter()
 {
   this->WritePiece = -1;
   this->NumberOfPieces = 1;
   this->GhostLevel = 0;
 
-  this->WriteExtent[0] = 0; this->WriteExtent[1] = -1;
-  this->WriteExtent[2] = 0; this->WriteExtent[3] = -1;
-  this->WriteExtent[4] = 0; this->WriteExtent[5] = -1;
+  this->WriteExtent[0] = 0;
+  this->WriteExtent[1] = -1;
+  this->WriteExtent[2] = 0;
+  this->WriteExtent[3] = -1;
+  this->WriteExtent[4] = 0;
+  this->WriteExtent[5] = -1;
 
   this->CurrentPiece = 0;
   this->ProgressFractions = nullptr;
   this->FieldDataOM->Allocate(0);
   this->PointDataOM = new OffsetsManagerArray;
-  this->CellDataOM  = new OffsetsManagerArray;
+  this->CellDataOM = new OffsetsManagerArray;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLStructuredDataWriter::~vtkXMLStructuredDataWriter()
 {
   delete[] this->ProgressFractions;
@@ -57,41 +61,33 @@ vtkXMLStructuredDataWriter::~vtkXMLStructuredDataWriter()
   delete this->CellDataOM;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
-  os << indent << "WriteExtent: "
-     << this->WriteExtent[0] << " " << this->WriteExtent[1] << "  "
-     << this->WriteExtent[2] << " " << this->WriteExtent[3] << "  "
-     << this->WriteExtent[4] << " " << this->WriteExtent[5] << "\n";
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "WriteExtent: " << this->WriteExtent[0] << " " << this->WriteExtent[1] << "  "
+     << this->WriteExtent[2] << " " << this->WriteExtent[3] << "  " << this->WriteExtent[4] << " "
+     << this->WriteExtent[5] << "\n";
   os << indent << "NumberOfPieces" << this->NumberOfPieces << "\n";
   os << indent << "WritePiece: " << this->WritePiece << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::SetInputUpdateExtent(int piece)
 {
-  vtkInformation* inInfo =
-    this->GetExecutive()->GetInputInformation(0, 0);
-  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),
-    piece);
-  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
-    this->NumberOfPieces);
-  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-    this->GhostLevel);
-  if ((this->WriteExtent[0] == 0) && (this->WriteExtent[1] == -1) &&
-     (this->WriteExtent[2] == 0) && (this->WriteExtent[3] == -1) &&
-     (this->WriteExtent[4] == 0) && (this->WriteExtent[5] == -1))
+  vtkInformation* inInfo = this->GetExecutive()->GetInputInformation(0, 0);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), piece);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), this->NumberOfPieces);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), this->GhostLevel);
+  if ((this->WriteExtent[0] == 0) && (this->WriteExtent[1] == -1) && (this->WriteExtent[2] == 0) &&
+    (this->WriteExtent[3] == -1) && (this->WriteExtent[4] == 0) && (this->WriteExtent[5] == -1))
   {
     inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),
-      inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()),
-      6);
+      inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()), 6);
   }
   else
   {
-    inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),
-      this->WriteExtent, 6);
+    inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), this->WriteExtent, 6);
   }
   inInfo->Set(vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(), 1);
 }
@@ -99,28 +95,26 @@ void vtkXMLStructuredDataWriter::SetInputUpdateExtent(int piece)
 vtkIdType vtkXMLStructuredDataWriter::GetNumberOfValues(vtkDataSet* input)
 {
   vtkIdType dataSetValues = 0;
-  vtkPointData *pointData = input->GetPointData();
+  vtkPointData* pointData = input->GetPointData();
   int pdArrays = pointData->GetNumberOfArrays();
   for (int i = 0; i < pdArrays; ++i)
   {
-    vtkAbstractArray *array = pointData->GetAbstractArray(i);
+    vtkAbstractArray* array = pointData->GetAbstractArray(i);
     dataSetValues += array->GetNumberOfValues();
   }
-  vtkCellData *cellData = input->GetCellData();
+  vtkCellData* cellData = input->GetCellData();
   int cdArrays = cellData->GetNumberOfArrays();
   for (int i = 0; i < cdArrays; ++i)
   {
-    vtkAbstractArray * array = cellData->GetAbstractArray(i);
+    vtkAbstractArray* array = cellData->GetAbstractArray(i);
     dataSetValues += array->GetNumberOfValues();
   }
   return dataSetValues;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
-  vtkInformation* request,
-  vtkInformationVector** inputVector,
-  vtkInformationVector* outputVector)
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
 
   if (request->Has(vtkStreamingDemandDrivenPipeline::REQUEST_INFORMATION()))
@@ -148,7 +142,7 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
     {
       this->SetErrorCode(vtkErrorCode::NoFileNameError);
       vtkErrorMacro("The FileName or Stream must be set first or "
-        "the output must be written to a string.");
+                    "the output must be written to a string.");
       return 0;
     }
 
@@ -158,12 +152,12 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
     this->UpdateProgress(0);
     this->SetProgressText("vtkXMLStructuredDataWriter");
     // Initialize progress range to entire 0..1 range.
-    float wholeProgressRange[] = {0.0f, 1.0f};
+    float wholeProgressRange[] = { 0.0f, 1.0f };
     vtkIdType fieldDataValues = 0;
-    vtkFieldData *fieldData = this->GetInput()->GetFieldData();
+    vtkFieldData* fieldData = this->GetInput()->GetFieldData();
     for (int i = 0; i < fieldData->GetNumberOfArrays(); ++i)
     {
-      vtkAbstractArray *array = fieldData->GetAbstractArray(i);
+      vtkAbstractArray* array = fieldData->GetAbstractArray(i);
       fieldDataValues += array->GetNumberOfValues();
     }
     vtkIdType dataSetValues = fieldDataValues + GetNumberOfValues(this->GetInputAsDataSet());
@@ -171,18 +165,18 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
     {
       dataSetValues = 1;
     }
-    float fraction[] = {0.0f, static_cast<float>(fieldDataValues)/dataSetValues, 1.0f};
+    float fraction[] = { 0.0f, static_cast<float>(fieldDataValues) / dataSetValues, 1.0f };
     this->SetProgressRange(wholeProgressRange, 0, fraction);
     int result = 1;
-    if ((this->CurrentPiece == 0 || this->WritePiece >= 0) && this->CurrentTimeIndex == 0 )
+    if ((this->CurrentPiece == 0 || this->WritePiece >= 0) && this->CurrentTimeIndex == 0)
     {
       if (!this->OpenStream())
       {
         return 0;
       }
       if (this->GetInputAsDataSet() != nullptr &&
-          (this->GetInputAsDataSet()->GetPointGhostArray() != nullptr ||
-           this->GetInputAsDataSet()->GetCellGhostArray() != nullptr))
+        (this->GetInputAsDataSet()->GetPointGhostArray() != nullptr ||
+          this->GetInputAsDataSet()->GetCellGhostArray() != nullptr))
       {
         // use the current version for the file
         this->UsePreviousVersion = false;
@@ -205,8 +199,7 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
         this->UpdateFieldData(fieldDataCopy);
 
         // Write the field data arrays.
-        this->WriteFieldDataAppendedData(fieldDataCopy,
-          this->CurrentTimeIndex, this->FieldDataOM);
+        this->WriteFieldDataAppendedData(fieldDataCopy, this->CurrentTimeIndex, this->FieldDataOM);
         if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
         {
           this->DeletePositionArrays();
@@ -215,7 +208,7 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
       }
     }
 
-    if (!(this->UserContinueExecuting == 0)) //if user ask to stop do not try to write a piece
+    if (!(this->UserContinueExecuting == 0)) // if user ask to stop do not try to write a piece
     {
       this->SetProgressRange(wholeProgressRange, 1, fraction);
       result = this->WriteAPiece();
@@ -235,7 +228,7 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
     {
       request->Remove(vtkStreamingDemandDrivenPipeline::CONTINUE_EXECUTING());
       this->CurrentPiece = 0;
-       // We are done writing all the pieces, lets loop over time now:
+      // We are done writing all the pieces, lets loop over time now:
       this->CurrentTimeIndex++;
 
       if (this->UserContinueExecuting != 1)
@@ -262,8 +255,7 @@ vtkTypeBool vtkXMLStructuredDataWriter::ProcessRequest(
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::AllocatePositionArrays()
 {
   this->ExtentPositions = new vtkTypeInt64[this->NumberOfPieces];
@@ -274,14 +266,14 @@ void vtkXMLStructuredDataWriter::AllocatePositionArrays()
   this->CellDataOM->Allocate(this->NumberOfPieces);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::DeletePositionArrays()
 {
   delete[] this->ExtentPositions;
   this->ExtentPositions = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLStructuredDataWriter::WriteHeader()
 {
   vtkIndent indent = vtkIndent().GetNextIndent();
@@ -309,7 +301,7 @@ int vtkXMLStructuredDataWriter::WriteHeader()
     this->AllocatePositionArrays();
 
     // Loop over each piece and write its structure.
-    for (int i=begin; i < end; ++i)
+    for (int i = begin; i < end; ++i)
     {
       // Update the piece's extent.
 
@@ -359,13 +351,13 @@ int vtkXMLStructuredDataWriter::WriteHeader()
   // each piece.
   float progressRange[2] = { 0.f, 0.f };
   this->GetProgressRange(progressRange);
-  this->ProgressFractions = new float[this->NumberOfPieces+1];
+  this->ProgressFractions = new float[this->NumberOfPieces + 1];
   this->CalculatePieceFractions(this->ProgressFractions);
 
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLStructuredDataWriter::WriteAPiece()
 {
   vtkIndent indent = vtkIndent().GetNextIndent();
@@ -388,9 +380,7 @@ int vtkXMLStructuredDataWriter::WriteAPiece()
     }
     else
     {
-      vtkErrorMacro("Input is invalid for piece "
-                    << this->CurrentPiece
-                    << ".  Aborting.");
+      vtkErrorMacro("Input is invalid for piece " << this->CurrentPiece << ".  Aborting.");
       result = 0;
     }
   }
@@ -402,7 +392,7 @@ int vtkXMLStructuredDataWriter::WriteAPiece()
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLStructuredDataWriter::WriteFooter()
 {
   vtkIndent indent = vtkIndent().GetNextIndent();
@@ -432,7 +422,7 @@ int vtkXMLStructuredDataWriter::WriteFooter()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLStructuredDataWriter::WriteInlineMode(vtkIndent indent)
 {
   vtkDataSet* input = this->GetInputAsDataSet();
@@ -479,25 +469,20 @@ int vtkXMLStructuredDataWriter::WriteInlineMode(vtkIndent indent)
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class iterT>
 inline void vtkXMLStructuredDataWriterCopyTuples(
-  iterT* destIter, vtkIdType destTuple,
-  iterT* srcIter, vtkIdType sourceTuple,
-  vtkIdType numTuples)
+  iterT* destIter, vtkIdType destTuple, iterT* srcIter, vtkIdType sourceTuple, vtkIdType numTuples)
 {
   // for all contiguous-fixed component size arrays (except Bit).
-  int tupleSize = (srcIter->GetDataTypeSize() *
-                   srcIter->GetNumberOfComponents());
+  int tupleSize = (srcIter->GetDataTypeSize() * srcIter->GetNumberOfComponents());
 
-  memcpy(destIter->GetTuple(destTuple), srcIter->GetTuple(sourceTuple),
-    numTuples*tupleSize);
+  memcpy(destIter->GetTuple(destTuple), srcIter->GetTuple(sourceTuple), numTuples * tupleSize);
 }
 
-//----------------------------------------------------------------------------
-inline void vtkXMLStructuredDataWriterCopyTuples(
-  vtkArrayIteratorTemplate<vtkStdString>* destIter, vtkIdType destTuple,
-  vtkArrayIteratorTemplate<vtkStdString>* srcIter, vtkIdType sourceTuple,
+//------------------------------------------------------------------------------
+inline void vtkXMLStructuredDataWriterCopyTuples(vtkArrayIteratorTemplate<vtkStdString>* destIter,
+  vtkIdType destTuple, vtkArrayIteratorTemplate<vtkStdString>* srcIter, vtkIdType sourceTuple,
   vtkIdType numTuples)
 {
   vtkIdType numValues = numTuples * srcIter->GetNumberOfComponents();
@@ -510,19 +495,16 @@ inline void vtkXMLStructuredDataWriterCopyTuples(
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLStructuredDataWriter::WritePrimaryElementAttributes(ostream &os,
-                                                               vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkXMLStructuredDataWriter::WritePrimaryElementAttributes(ostream& os, vtkIndent indent)
 {
   this->Superclass::WritePrimaryElementAttributes(os, indent);
 
   int* ext = this->WriteExtent;
-  if ((this->WriteExtent[0] == 0) && (this->WriteExtent[1] == -1) &&
-     (this->WriteExtent[2] == 0) && (this->WriteExtent[3] == -1) &&
-     (this->WriteExtent[4] == 0) && (this->WriteExtent[5] == -1))
+  if ((this->WriteExtent[0] == 0) && (this->WriteExtent[1] == -1) && (this->WriteExtent[2] == 0) &&
+    (this->WriteExtent[3] == -1) && (this->WriteExtent[4] == 0) && (this->WriteExtent[5] == -1))
   {
-    ext = this->GetInputInformation(0, 0)->Get(
-      vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+    ext = this->GetInputInformation(0, 0)->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
   }
 
   if (this->WritePiece >= 0)
@@ -534,27 +516,24 @@ void vtkXMLStructuredDataWriter::WritePrimaryElementAttributes(ostream &os,
   this->WriteVectorAttribute("WholeExtent", 6, ext);
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLStructuredDataWriter::WriteAppendedPiece(int index,
-                                                    vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkXMLStructuredDataWriter::WriteAppendedPiece(int index, vtkIndent indent)
 {
   // Write the point data and cell data arrays.
   vtkDataSet* input = this->GetInputAsDataSet();
-  this->WritePointDataAppended(input->GetPointData(), indent,
-    &this->PointDataOM->GetPiece(index));
+  this->WritePointDataAppended(input->GetPointData(), indent, &this->PointDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
   {
     return;
   }
-  this->WriteCellDataAppended(input->GetCellData(), indent,
-    &this->CellDataOM->GetPiece(index));
+  this->WriteCellDataAppended(input->GetCellData(), indent, &this->CellDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
   {
     return;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::WriteAppendedPieceData(int index)
 {
   // Write the point data and cell data arrays.
@@ -578,18 +557,13 @@ void vtkXMLStructuredDataWriter::WriteAppendedPieceData(int index)
   this->GetProgressRange(progressRange);
   int pdArrays = input->GetPointData()->GetNumberOfArrays();
   int cdArrays = input->GetCellData()->GetNumberOfArrays();
-  int total = (pdArrays+cdArrays)? (pdArrays+cdArrays):1;
-  float fractions[3] =
-    {
-    0,
-    static_cast<float>(pdArrays) / total,
-    1
-    };
+  int total = (pdArrays + cdArrays) ? (pdArrays + cdArrays) : 1;
+  float fractions[3] = { 0, static_cast<float>(pdArrays) / total, 1 };
 
   // Set the range of progress for the point data arrays.
   this->SetProgressRange(progressRange, 0, fractions);
-  this->WritePointDataAppendedData(input->GetPointData(), this->CurrentTimeIndex,
-                                   &this->PointDataOM->GetPiece(index));
+  this->WritePointDataAppendedData(
+    input->GetPointData(), this->CurrentTimeIndex, &this->PointDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
   {
     return;
@@ -597,11 +571,11 @@ void vtkXMLStructuredDataWriter::WriteAppendedPieceData(int index)
 
   // Set the range of progress for the cell data arrays.
   this->SetProgressRange(progressRange, 1, fractions);
-  this->WriteCellDataAppendedData(input->GetCellData(), this->CurrentTimeIndex,
-                                  &this->CellDataOM->GetPiece(index));
+  this->WriteCellDataAppendedData(
+    input->GetCellData(), this->CurrentTimeIndex, &this->CellDataOM->GetPiece(index));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::WriteInlinePiece(vtkIndent indent)
 {
   // Write the point data and cell data arrays.
@@ -612,13 +586,8 @@ void vtkXMLStructuredDataWriter::WriteInlinePiece(vtkIndent indent)
   this->GetProgressRange(progressRange);
   int pdArrays = input->GetPointData()->GetNumberOfArrays();
   int cdArrays = input->GetCellData()->GetNumberOfArrays();
-  int total = (pdArrays+cdArrays)? (pdArrays+cdArrays):1;
-  float fractions[3] =
-    {
-      0,
-      float(pdArrays)/total,
-      1
-    };
+  int total = (pdArrays + cdArrays) ? (pdArrays + cdArrays) : 1;
+  float fractions[3] = { 0, float(pdArrays) / total, 1 };
 
   // Set the range of progress for the point data arrays.
   this->SetProgressRange(progressRange, 0, fractions);
@@ -633,30 +602,27 @@ void vtkXMLStructuredDataWriter::WriteInlinePiece(vtkIndent indent)
   this->WriteCellDataInline(input->GetCellData(), indent);
 }
 
-//----------------------------------------------------------------------------
-vtkIdType vtkXMLStructuredDataWriter::GetStartTuple(int* extent,
-                                                    vtkIdType* increments,
-                                                    int i, int j, int k)
+//------------------------------------------------------------------------------
+vtkIdType vtkXMLStructuredDataWriter::GetStartTuple(
+  int* extent, vtkIdType* increments, int i, int j, int k)
 {
-  return (((i - extent[0]) * increments[0]) +
-          ((j - extent[2]) * increments[1]) +
-          ((k - extent[4]) * increments[2]));
+  return (((i - extent[0]) * increments[0]) + ((j - extent[2]) * increments[1]) +
+    ((k - extent[4]) * increments[2]));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredDataWriter::CalculatePieceFractions(float* fractions)
 {
   // Calculate the fraction of total data contributed by each piece.
   fractions[0] = 0;
-  for (int i = 0; i < this->NumberOfPieces;++i)
+  for (int i = 0; i < this->NumberOfPieces; ++i)
   {
     int extent[6];
     this->GetInputExtent(extent);
 
     // Add this piece's size to the cumulative fractions array.
-    fractions[i+1] = fractions[i] + ((extent[1]-extent[0]+1)*
-                                     (extent[3]-extent[2]+1)*
-                                     (extent[5]-extent[4]+1));
+    fractions[i + 1] = fractions[i] +
+      ((extent[1] - extent[0] + 1) * (extent[3] - extent[2] + 1) * (extent[5] - extent[4] + 1));
   }
   if (fractions[this->NumberOfPieces] == 0)
   {
@@ -664,6 +630,7 @@ void vtkXMLStructuredDataWriter::CalculatePieceFractions(float* fractions)
   }
   for (int i = 0; i < this->NumberOfPieces; ++i)
   {
-    fractions[i+1] = fractions[i+1] / fractions[this->NumberOfPieces];
+    fractions[i + 1] = fractions[i + 1] / fractions[this->NumberOfPieces];
   }
 }
+VTK_ABI_NAMESPACE_END
