@@ -14,101 +14,104 @@
 =========================================================================*/
 #include "vtkXMLStructuredGridReader.h"
 
+#include "vtkInformation.h"
 #include "vtkObjectFactory.h"
+#include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStructuredGrid.h"
 #include "vtkXMLDataElement.h"
 #include "vtkXMLDataParser.h"
-#include "vtkInformation.h"
-#include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkXMLStructuredGridReader);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLStructuredGridReader::vtkXMLStructuredGridReader()
 {
   this->PointElements = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLStructuredGridReader::~vtkXMLStructuredGridReader()
 {
-  if(this->NumberOfPieces) { this->DestroyPieces(); }
+  if (this->NumberOfPieces)
+  {
+    this->DestroyPieces();
+  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredGridReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStructuredGrid* vtkXMLStructuredGridReader::GetOutput()
 {
   return this->GetOutput(0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStructuredGrid* vtkXMLStructuredGridReader::GetOutput(int idx)
 {
-  return vtkStructuredGrid::SafeDownCast( this->GetOutputDataObject(idx) );
+  return vtkStructuredGrid::SafeDownCast(this->GetOutputDataObject(idx));
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLStructuredGridReader::GetDataSetName()
 {
   return "StructuredGrid";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredGridReader::SetOutputExtent(int* extent)
 {
   vtkStructuredGrid::SafeDownCast(this->GetCurrentOutput())->SetExtent(extent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredGridReader::SetupPieces(int numPieces)
 {
   this->Superclass::SetupPieces(numPieces);
   this->PointElements = new vtkXMLDataElement*[numPieces];
   int i;
-  for(i=0;i < numPieces; ++i)
+  for (i = 0; i < numPieces; ++i)
   {
     this->PointElements[i] = nullptr;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredGridReader::DestroyPieces()
 {
-  delete [] this->PointElements;
+  delete[] this->PointElements;
   this->Superclass::DestroyPieces();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLStructuredGridReader::ReadPiece(vtkXMLDataElement* ePiece)
 {
-  if(!this->Superclass::ReadPiece(ePiece)) { return 0; }
+  if (!this->Superclass::ReadPiece(ePiece))
+  {
+    return 0;
+  }
 
   // Find the Points element in the piece.
   int i;
   this->PointElements[this->Piece] = nullptr;
-  for(i=0; i < ePiece->GetNumberOfNestedElements(); ++i)
+  for (i = 0; i < ePiece->GetNumberOfNestedElements(); ++i)
   {
     vtkXMLDataElement* eNested = ePiece->GetNestedElement(i);
-    if((strcmp(eNested->GetName(), "Points") == 0)
-       && (eNested->GetNumberOfNestedElements() == 1))
+    if ((strcmp(eNested->GetName(), "Points") == 0) && (eNested->GetNumberOfNestedElements() == 1))
     {
       this->PointElements[this->Piece] = eNested;
     }
   }
 
   // If there is any volume, we require a Points element.
-  int* piecePointDimensions = this->PiecePointDimensions + this->Piece*3;
-  if(!this->PointElements[this->Piece] &&
-     (piecePointDimensions[0] > 0) &&
-     (piecePointDimensions[1] > 0) &&
-     (piecePointDimensions[2] > 0))
+  int* piecePointDimensions = this->PiecePointDimensions + this->Piece * 3;
+  if (!this->PointElements[this->Piece] && (piecePointDimensions[0] > 0) &&
+    (piecePointDimensions[1] > 0) && (piecePointDimensions[2] > 0))
   {
     vtkErrorMacro("A piece is missing its Points element "
                   "or element does not have exactly 1 array.");
@@ -118,8 +121,7 @@ int vtkXMLStructuredGridReader::ReadPiece(vtkXMLDataElement* ePiece)
   return 1;
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLStructuredGridReader::SetupOutputData()
 {
   this->Superclass::SetupOutputData();
@@ -137,7 +139,7 @@ void vtkXMLStructuredGridReader::SetupOutputData()
     if (a)
     {
       // Allocate the points array.
-      a->SetNumberOfTuples( this->GetNumberOfPoints() );
+      a->SetNumberOfTuples(this->GetNumberOfPoints());
       points->SetData(a);
       a->Delete();
     }
@@ -155,44 +157,40 @@ void vtkXMLStructuredGridReader::SetupOutputData()
   points->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLStructuredGridReader::ReadPieceData()
 {
   // The amount of data read by the superclass's ReadPieceData comes
   // from point/cell data (we read point specifications here).
-  int dims[3] = {0,0,0};
+  int dims[3] = { 0, 0, 0 };
   this->ComputePointDimensions(this->SubExtent, dims);
-  vtkIdType superclassPieceSize =
-    (this->NumberOfPointArrays*dims[0]*dims[1]*dims[2]+
-     this->NumberOfCellArrays*(dims[0]-1)*(dims[1]-1)*(dims[2]-1));
+  vtkIdType superclassPieceSize = (this->NumberOfPointArrays * dims[0] * dims[1] * dims[2] +
+    this->NumberOfCellArrays * (dims[0] - 1) * (dims[1] - 1) * (dims[2] - 1));
 
   // Total amount of data in this piece comes from point/cell data
   // arrays and the point specifications themselves.
-  vtkIdType totalPieceSize =
-    superclassPieceSize + dims[0]*dims[1]*dims[2];
-  if(totalPieceSize == 0)
+  vtkIdType totalPieceSize = superclassPieceSize + dims[0] * dims[1] * dims[2];
+  if (totalPieceSize == 0)
   {
     totalPieceSize = 1;
   }
 
   // Split the progress range based on the approximate fraction of
   // data that will be read by each step in this method.
-  float progressRange[2] = {0,0};
+  float progressRange[2] = { 0, 0 };
   this->GetProgressRange(progressRange);
-  float fractions[3] =
-    {
-      0,
-      float(superclassPieceSize) / totalPieceSize,
-      1
-    };
+  float fractions[3] = { 0, float(superclassPieceSize) / totalPieceSize, 1 };
 
   // Set the range of progress for the superclass.
   this->SetProgressRange(progressRange, 0, fractions);
 
   // Let the superclass read its data.
-  if(!this->Superclass::ReadPieceData()) { return 0; }
+  if (!this->Superclass::ReadPieceData())
+  {
+    return 0;
+  }
 
-  if(!this->PointElements[this->Piece])
+  if (!this->PointElements[this->Piece])
   {
     // Empty volume.
     return 1;
@@ -202,17 +200,15 @@ int vtkXMLStructuredGridReader::ReadPieceData()
   this->SetProgressRange(progressRange, 1, fractions);
 
   // Read the points array.
-  vtkStructuredGrid* output = vtkStructuredGrid::SafeDownCast(
-      this->GetCurrentOutput());
+  vtkStructuredGrid* output = vtkStructuredGrid::SafeDownCast(this->GetCurrentOutput());
   vtkXMLDataElement* ePoints = this->PointElements[this->Piece];
-  return this->ReadArrayForPoints(ePoints->GetNestedElement(0),
-                                  output->GetPoints()->GetData());
+  return this->ReadArrayForPoints(ePoints->GetNestedElement(0), output->GetPoints()->GetData());
 }
 
-
-int vtkXMLStructuredGridReader::FillOutputPortInformation(int, vtkInformation *info)
+int vtkXMLStructuredGridReader::FillOutputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkStructuredGrid");
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
