@@ -29,6 +29,7 @@
 
 #include <map> // needed for std::map
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkIdTypeArray;
 class vtkUnsignedCharArray;
@@ -41,13 +42,13 @@ public:
   void PrintSelf(ostream& os, vtkIndent indent) override;
   static vtkXMLTableReader* New();
 
-  //@{
+  ///@{
   /**
    * Get the reader's output.
    */
   vtkTable* GetOutput();
   vtkTable* GetOutput(int idx);
-  //@}
+  ///@}
 
   /**
    * Get the number of rows in the output.
@@ -204,4 +205,5 @@ private:
   void operator=(const vtkXMLTableReader&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
