@@ -16,11 +16,13 @@
 
 #include "vtkArrayDispatch.h"
 #include "vtkCellArray.h"
+#include "vtkCellData.h"
 #include "vtkDataArrayRange.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
+#include "vtkPointData.h"
 #include "vtkPointSet.h"
 #include "vtkPoints.h"
 #include "vtkSmartPointer.h"
@@ -29,8 +31,42 @@
 #include "vtkXMLDataElement.h"
 
 #include <cassert>
+#include <tuple>
 #include <utility>
 
+VTK_ABI_NAMESPACE_BEGIN
+namespace
+{
+// Ensures that array1 and array2 are of the same type. Returns a pair with
+// array type selected as follows:
+// * if both arrays have different element bytesize, the one with the larger size
+//   is chosen
+// * if both arrays have different element types, then the type for the second
+//   argument is chosen
+std::pair<vtkSmartPointer<vtkDataArray>, vtkSmartPointer<vtkDataArray>> MatchArrayTypes(
+  vtkSmartPointer<vtkDataArray> array1, vtkSmartPointer<vtkDataArray> array2)
+{
+  if (array1->GetElementComponentSize() > array2->GetElementComponentSize())
+  {
+    auto new2 = vtk::TakeSmartPointer(array1->NewInstance());
+    new2->DeepCopy(array2);
+    return std::make_pair(array1, new2);
+  }
+  else if (array2->GetElementComponentSize() > array1->GetElementComponentSize() ||
+    array1->GetDataType() != array2->GetDataType())
+  {
+    auto new1 = vtk::TakeSmartPointer(array2->NewInstance());
+    new1->DeepCopy(array1);
+    return std::make_pair(new1, array2);
+  }
+  else
+  {
+    return std::make_pair(array1, array2);
+  }
+}
+
+}
+
 //------------------------------------------------------------------------------
 vtkXMLUnstructuredDataReader::vtkXMLUnstructuredDataReader()
 {
@@ -40,6 +76,10 @@ vtkXMLUnstructuredDataReader::vtkXMLUnstructuredDataReader()
   this->TotalNumberOfCells = 0;
 
   this->PointsTimeStep = -1; // invalid state
+  this->CellArrayTimeStepRead = -1;
+  this->CanReadCellArray = true;
+  this->CellArrayCachedFileName = nullptr;
+  this->CellArrayCachedInputString = nullptr;
   this->PointsOffset = static_cast<unsigned long>(-1);
 }
 
@@ -253,6 +293,23 @@ void vtkXMLUnstructuredDataReader::ReadXMLData()
     }
     this->SetupNextPiece();
   }
+  // Prior to major version 2, The vtkGhostType array was named vtkGhostLevels. Since the array has
+  // been already added, we need to re-add it to the output, so that the ghost array for point/cell
+  // data is correctly cached.
+  if (this->GetFileMajorVersion() < 2)
+  {
+    vtkDataSet* output = vtkDataSet::SafeDownCast(this->GetCurrentOutput());
+    vtkPointData* pointData = output->GetPointData();
+    vtkCellData* cellData = output->GetCellData();
+    if (pointData->HasArray("vtkGhostType"))
+    {
+      pointData->AddArray(pointData->GetArray("vtkGhostType"));
+    }
+    if (cellData->HasArray("vtkGhostType"))
+    {
+      cellData->AddArray(cellData->GetArray("vtkGhostType"));
+    }
+  }
 
   delete[] fractions;
 }
@@ -564,7 +621,42 @@ struct ConstructCellArray
 int vtkXMLUnstructuredDataReader::ReadCellArray(vtkIdType numberOfCells,
   vtkIdType vtkNotUsed(totalNumberOfCells), vtkXMLDataElement* eCells, vtkCellArray* outCells)
 {
-  if (numberOfCells <= 0)
+  // This part is here to determine if we need to read the cell array.
+  // If the cell array was already generated in a previous time step, there's no need recreating it.
+  // However, within a same time step, multiple pieces can be present. We need to read them all.
+  // The logic works as follows:
+  // * If there's no output geometry yet, it means we need to create it. We save the current time
+  //   step to know in which time step the cell array is being read.
+  // * If there's already geometry, we either are in a new time step and nothing needs to be done,
+  //   or we're still in the time step used to create the geometry in a new piece and we need to
+  //   read it.
+  // We quit the "create geometry mode" if the cell array time step becomes different than the
+  // current time step.
+  if ((this->ReadFromInputString &&
+        this->CellArrayCachedInputString != this->InputString.c_str()) ||
+    (!this->ReadFromInputString && this->CellArrayCachedFileName != this->FileName))
+  {
+    // We wipe the geometry if a new file or new input string is to be read.
+    outCells->Initialize();
+    if (this->ReadFromInputString)
+    {
+      this->CellArrayCachedInputString = this->InputString.c_str();
+    }
+    else
+    {
+      this->CellArrayCachedFileName = this->FileName;
+    }
+  }
+  if (outCells->GetNumberOfCells() == 0)
+  {
+    this->CellArrayTimeStepRead = this->CurrentTimeStep;
+    this->CanReadCellArray = true;
+  }
+  if (this->CellArrayTimeStepRead != this->CurrentTimeStep)
+  {
+    this->CanReadCellArray = false;
+  }
+  if (!this->CanReadCellArray || numberOfCells <= 0)
   {
     return 1;
   }
@@ -752,18 +844,11 @@ int vtkXMLUnstructuredDataReader::ReadCellArray(vtkIdType numberOfCells,
     {
       return 0;
     }
-
-    // If the offset array was converted, we need to make sure the connectivity
-    // array is of the same type.
-    if (offsetsNeedConversion)
-    {
-      vtkSmartPointer<vtkCellArray::ArrayType64> newArray =
-        vtkSmartPointer<vtkCellArray::ArrayType64>::New();
-      newArray->DeepCopy(conn);
-      conn = newArray;
-    }
   }
 
+  // Ensure that `conn` and `cellOffsets` arrays have same types.
+  std::tie(conn, cellOffsets) = MatchArrayTypes(conn, cellOffsets);
+
   //------------------- Construct vtkCellArray ---------------------------------
 
   if (outCells->GetNumberOfCells() == 0)
@@ -1156,3 +1241,4 @@ int vtkXMLUnstructuredDataReader::CellsNeedToReadTimeStep(
   // all other cases we don't need to read:
   return 0;
 }
+VTK_ABI_NAMESPACE_END
