@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_0_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkXMLUnstructuredDataWriter.h"
 
 #include "vtkCellArray.h"
@@ -45,6 +42,7 @@
 #include <utility>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkXMLUnstructuredDataWriter::vtkXMLUnstructuredDataWriter()
 {
   this->NumberOfPieces = 1;
@@ -162,9 +160,18 @@ vtkTypeBool vtkXMLUnstructuredDataWriter::ProcessRequest(
         }
         else
         {
-          vtkNew<vtkCellTypes> cellTypes;
-          dataSet->GetCellTypes(cellTypes);
-          if (vtkNeedsNewFileVersionV8toV9(cellTypes))
+          vtkNew<vtkUnsignedCharArray> cellTypesArray;
+          if (auto ug = vtkUnstructuredGrid::SafeDownCast(dataSet))
+          {
+            cellTypesArray->ShallowCopy(ug->GetDistinctCellTypesArray());
+          }
+          else
+          {
+            vtkNew<vtkCellTypes> cellTypes;
+            dataSet->GetCellTypes(cellTypes);
+            cellTypesArray->ShallowCopy(cellTypes->GetCellTypesArray());
+          }
+          if (vtkNeedsNewFileVersionV8toV9(cellTypesArray))
           {
             this->UsePreviousVersion = false;
           }
@@ -961,8 +968,8 @@ void vtkXMLUnstructuredDataWriter::ConvertCells(
   conn->Squeeze();
   offsets->Squeeze();
 
-  this->CellPoints = std::move(conn);
-  this->CellOffsets = std::move(offsets);
+  this->CellPoints = conn;
+  this->CellOffsets = offsets;
 }
 
 namespace
@@ -1008,9 +1015,12 @@ struct ConvertCellsVisitor
 void vtkXMLUnstructuredDataWriter::ConvertCells(vtkCellArray* cells)
 {
   ConvertCellsVisitor visitor;
-  cells->Visit(visitor);
-  this->CellPoints = std::move(visitor.Connectivity);
-  this->CellOffsets = std::move(visitor.Offsets);
+  if (cells)
+  {
+    cells->Visit(visitor);
+  }
+  this->CellPoints = visitor.Connectivity;
+  this->CellOffsets = visitor.Offsets;
 }
 
 //------------------------------------------------------------------------------
@@ -1131,3 +1141,4 @@ void vtkXMLUnstructuredDataWriter::SetInputUpdateExtent(int piece, int numPieces
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), piece);
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), ghostLevel);
 }
+VTK_ABI_NAMESPACE_END
