@@ -28,6 +28,7 @@
 
 #include <vtkSmartPointer.h> // for vtkSmartPointer
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPointSet;
 class vtkCellArray;
 class vtkCellIterator;
@@ -41,31 +42,31 @@ public:
   vtkTypeMacro(vtkXMLUnstructuredDataWriter, vtkXMLWriter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the number of pieces used to stream the image through the
    * pipeline while writing to the file.
    */
   vtkSetMacro(NumberOfPieces, int);
   vtkGetMacro(NumberOfPieces, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the piece to write to the file.  If this is
    * negative or equal to the NumberOfPieces, all pieces will be written.
    */
   vtkSetMacro(WritePiece, int);
   vtkGetMacro(WritePiece, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the ghost level used to pad each piece.
    */
   vtkSetMacro(GhostLevel, int);
   vtkGetMacro(GhostLevel, int);
-  //@}
+  ///@}
 
   // See the vtkAlgorithm for a description of what these do
   vtkTypeBool ProcessRequest(
@@ -100,7 +101,7 @@ protected:
   void WriteCellsInline(
     const char* name, vtkCellArray* cells, vtkDataArray* types, vtkIndent indent);
 
-  // New API with face infomration for polyhedron cell support.
+  // New API with face information for polyhedron cell support.
   void WriteCellsInline(const char* name, vtkCellArray* cells, vtkDataArray* types,
     vtkIdTypeArray* faces, vtkIdTypeArray* faceOffsets, vtkIndent indent);
 
@@ -121,7 +122,7 @@ protected:
   void WriteCellsAppendedData(vtkCellIterator* cellIter, vtkIdType numCells,
     vtkIdType cellSizeEstimate, int timestep, OffsetsManagerGroup* cellsManager);
 
-  // New API with face infomration for polyhedron cell support.
+  // New API with face information for polyhedron cell support.
   void WriteCellsAppendedData(vtkCellArray* cells, vtkDataArray* types, vtkIdTypeArray* faces,
     vtkIdTypeArray* faceOffsets, int timestep, OffsetsManagerGroup* cellsManager);
 
@@ -174,4 +175,5 @@ private:
   void operator=(const vtkXMLUnstructuredDataWriter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
