@@ -35,6 +35,7 @@
 
 #include "vtkXMLUtilities.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkXMLDataParser);
 vtkCxxSetObjectMacro(vtkXMLDataParser, Compressor, vtkDataCompressor);
 
@@ -191,11 +192,9 @@ void vtkXMLDataParser::SeekInlineDataPosition(vtkXMLDataElement* element)
     this->SeekG(element->GetXMLByteIndex());
     while (stream->get(c) && (c != '>'))
     {
-      ;
     }
-    while (stream->get(c) && element->IsSpace(c))
+    while (stream->get(c) && vtkXMLDataElement::IsSpace(c))
     {
-      ;
     }
     vtkTypeInt64 pos = this->TellG();
     element->SetInlineDataPosition(pos - 1);
@@ -287,11 +286,9 @@ void vtkXMLDataParser::FindAppendedDataPosition()
   this->SeekG(this->GetXMLByteIndex());
   while (this->Stream->get(c) && (c != '>'))
   {
-    ;
   }
-  while (this->Stream->get(c) && this->IsSpace(c))
+  while (this->Stream->get(c) && vtkXMLDataParser::IsSpace(c))
   {
-    ;
   }
 
   // Store the start of the appended data.  We skip the first
@@ -1343,3 +1340,4 @@ void vtkXMLDataParser::UpdateProgress(float progress)
   double dProgress = progress;
   this->InvokeEvent(vtkCommand::ProgressEvent, &dProgress);
 }
+VTK_ABI_NAMESPACE_END
