@@ -21,21 +21,22 @@
 #include "vtkStringArray.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSILBuilder);
 vtkCxxSetObjectMacro(vtkSILBuilder, SIL, vtkMutableDirectedGraph);
 //------------------------------------------------------------------------------
 vtkSILBuilder::vtkSILBuilder()
 {
-  this->NamesArray = 0;
-  this->CrossEdgesArray = 0;
-  this->SIL = 0;
+  this->NamesArray = nullptr;
+  this->CrossEdgesArray = nullptr;
+  this->SIL = nullptr;
   this->RootVertex = -1;
 }
 
 //------------------------------------------------------------------------------
 vtkSILBuilder::~vtkSILBuilder()
 {
-  this->SetSIL(0);
+  this->SetSIL(nullptr);
 }
 
 //------------------------------------------------------------------------------
@@ -83,3 +84,4 @@ void vtkSILBuilder::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
