@@ -16,10 +16,13 @@
 
 #include "vtkXdmf3ArrayKeeper.h"
 
+// clang-format off
 #include "vtk_xdmf3.h"
 #include VTKXDMF3_HEADER(core/XdmfArray.hpp)
+// clang-format on
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkXdmf3ArrayKeeper::vtkXdmf3ArrayKeeper()
 {
   generation = 0;
@@ -38,7 +41,7 @@ void vtkXdmf3ArrayKeeper::BumpGeneration()
 }
 
 //------------------------------------------------------------------------------
-void vtkXdmf3ArrayKeeper::Insert(XdmfArray *val)
+void vtkXdmf3ArrayKeeper::Insert(XdmfArray* val)
 {
   this->operator[](val) = this->generation;
 }
@@ -47,19 +50,20 @@ void vtkXdmf3ArrayKeeper::Insert(XdmfArray *val)
 void vtkXdmf3ArrayKeeper::Release(bool force)
 {
   vtkXdmf3ArrayKeeper::iterator it = this->begin();
-  //int cnt = 0;
-  //int total = 0;
+  // int cnt = 0;
+  // int total = 0;
   while (it != this->end())
   {
-    //total++;
+    // total++;
     vtkXdmf3ArrayKeeper::iterator current = it++;
     if (force || (current->second != this->generation))
     {
       XdmfArray* atCurrent = current->first;
       atCurrent->release();
       this->erase(current);
-      //cnt++;
+      // cnt++;
     }
   }
-  //cerr << "released " << cnt << "/" << total << " arrays" << endl;
+  // cerr << "released " << cnt << "/" << total << " arrays" << endl;
 }
+VTK_ABI_NAMESPACE_END
