@@ -38,12 +38,14 @@
 
 #include <set>
 
-class vtkXdmf3SILBuilder;
-class vtkXdmf3ArraySelection;
 class XdmfItem;
 class XdmfGraph;
 class XdmfGrid;
 
+VTK_ABI_NAMESPACE_BEGIN
+class vtkXdmf3SILBuilder;
+class vtkXdmf3ArraySelection;
+
 class VTKIOXDMF3_EXPORT vtkXdmf3LightDataHandler
 {
 public:
@@ -104,7 +106,7 @@ private:
    */
   void AddNamedSet(std::string uniqueName);
 
-  //@{
+  ///@{
   /**
    * records times that xdmf grids supply data at
    * if timespecs are only implied we add them to make things simpler later on
@@ -112,7 +114,7 @@ private:
   void InspectTime(shared_ptr<XdmfItem> item);
   void GetSetTime(shared_ptr<XdmfGrid> child, unsigned int& cnt);
   void GetSetTime(shared_ptr<XdmfGraph> child, unsigned int& cnt);
-  //@}
+  ///@}
 
   /**
    * for parallel partitioning
@@ -131,5 +133,6 @@ private:
   std::set<double> times; // relying on implicit sort from set<double>
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkXdmf3LightDataHandler_h
 // VTK-HeaderTest-Exclude: vtkXdmf3LightDataHandler.h
