@@ -33,6 +33,7 @@
 #include "vtkDataObjectAlgorithm.h"
 #include "vtkIOXdmf3Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkXdmf3ArraySelection;
 class vtkGraph;
 
@@ -46,19 +47,19 @@ public:
   /**
    * Set tells the reader the name of a single top level xml file to read.
    */
-  void SetFileName(const char* filename);
+  void SetFileName(VTK_FILEPATH const char* filename);
 
-  //@{
+  ///@{
   /**
    * Add and remove give the reader a list of top level xml files to read.
    * Whether the set is treated as a spatial or temporal collection depends
    * on FileSeriestAsTime.
    */
-  virtual void AddFileName(const char* filename);
+  virtual void AddFileName(VTK_FILEPATH const char* filename);
   virtual void RemoveAllFileNames();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When true (the default) the reader treats a series of files as a temporal
    * collection. When false it treats it as a spatial partition and uses
@@ -66,12 +67,12 @@ public:
    */
   vtkSetMacro(FileSeriesAsTime, bool);
   vtkGetMacro(FileSeriesAsTime, bool);
-  //@}
+  ///@}
 
   /**
    * Determine if the file can be read with this reader.
    */
-  virtual int CanReadFile(const char* filename);
+  virtual int CanReadFile(VTK_FILEPATH const char* filename);
 
   /**
    * Get information about point-based arrays. As is typical with readers this
@@ -86,15 +87,15 @@ public:
    */
   const char* GetPointArrayName(int index);
 
-  //@{
+  ///@{
   /**
    * Get/Set the point array status.
    */
   int GetPointArrayStatus(const char* name);
   void SetPointArrayStatus(const char* name, int status);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get information about cell-based arrays.  As is typical with readers this
    * in only valid after the filename is set and UpdateInformation() has been
@@ -104,9 +105,9 @@ public:
   const char* GetCellArrayName(int index);
   void SetCellArrayStatus(const char* name, int status);
   int GetCellArrayStatus(const char* name);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get information about unaligned arrays.  As is typical with readers this
    * in only valid after the filename is set and UpdateInformation() has been
@@ -116,9 +117,9 @@ public:
   const char* GetFieldArrayName(int index);
   void SetFieldArrayStatus(const char* name, int status);
   int GetFieldArrayStatus(const char* name);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set information about grids. As is typical with readers this is valid
    * only after the filename as been set and UpdateInformation() has been
@@ -128,9 +129,9 @@ public:
   const char* GetGridName(int index);
   void SetGridStatus(const char* gridname, int status);
   int GetGridStatus(const char* gridname);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set information about sets. As is typical with readers this is valid
    * only after the filename as been set and UpdateInformation() has been
@@ -141,7 +142,7 @@ public:
   const char* GetSetName(int index);
   void SetSetStatus(const char* gridname, int status);
   int GetSetStatus(const char* gridname);
-  //@}
+  ///@}
 
   /**
    * These methods are provided to make it easier to use the Sets in ParaView.
@@ -166,7 +167,7 @@ protected:
   ~vtkXdmf3Reader() override;
 
   const char* FileNameInternal;
-  vtkSetStringMacro(FileNameInternal);
+  vtkSetFilePathMacro(FileNameInternal);
 
   // Overridden to announce that we make general DataObjects.
   int FillOutputPortInformation(int port, vtkInformation* info) override;
@@ -206,4 +207,5 @@ private:
   Internals* Internal;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
