@@ -41,6 +41,7 @@
 #include <stack>
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkXdmf3Writer);
 
 //=============================================================================
@@ -75,7 +76,8 @@ public:
     this->Destination = this->DestinationGroups.top();
     this->Domain->insert(dest);
   }
-  void WriteDataObject(vtkDataObject* dataSet, bool hasTime, double time, const char* name = 0)
+  void WriteDataObject(
+    vtkDataObject* dataSet, bool hasTime, double time, const char* name = nullptr)
   {
     if (!dataSet)
     {
@@ -164,7 +166,7 @@ vtkXdmf3Writer::vtkXdmf3Writer()
   this->LightDataLimit = 100;
   this->WriteAllTimeSteps = false;
   this->TimeValues = nullptr;
-  this->TimeValues = 0;
+  this->TimeValues = nullptr;
   this->InitWriters = true;
 
   this->Internal = new Internals();
@@ -336,7 +338,7 @@ void vtkXdmf3Writer::WriteDataInternal(vtkInformation* request)
   size_t tempLength = testString.length();
   testString = testString.substr(0, (tempLength - 4));
   std::string choppedFileName = testString;
-  if (this->InitWriters == true)
+  if (this->InitWriters)
   {
     if (this->NumberOfProcesses == 1)
     {
@@ -387,7 +389,7 @@ void vtkXdmf3Writer::WriteDataInternal(vtkInformation* request)
       std::string rankGridName = "/Xdmf/Domain/Grid[1]";
 
       shared_ptr<XdmfGridController> partController =
-        XdmfGridController::New(rankFileName.c_str(), rankGridName.c_str());
+        XdmfGridController::New(rankFileName, rankGridName);
 
       // tricky part is we have to state what type we are referencing to.
       // otherwise readback fails.
@@ -506,3 +508,4 @@ int vtkXdmf3Writer::CheckParameters()
 {
   return this->CheckParametersInternal(1, 0);
 }
+VTK_ABI_NAMESPACE_END
