@@ -30,6 +30,7 @@
 
 #include "vtkDataObjectAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDoubleArray;
 
 class VTKIOXDMF3_EXPORT vtkXdmf3Writer : public vtkDataObjectAlgorithm
@@ -44,22 +45,22 @@ public:
    */
   virtual void SetInputData(vtkDataObject* dobj);
 
-  //@{
+  ///@{
   /**
    * Set or get the file name of the xdmf file.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * We never write out ghost cells.  This variable is here to satisfy
    * the behavior of ParaView on invoking a parallel writer.
    */
   void SetGhostLevel(int) {}
   int GetGhostLevel() { return 0; }
-  //@}
+  ///@}
 
   /**
    * Write data to output. Method executes subclasses WriteData() method, as
@@ -68,16 +69,16 @@ public:
    */
   virtual int Write();
 
-  //@{
+  ///@{
   /**
    * Topology Geometry and Attribute arrays smaller than this are written in line into the XML.
    * Default is 100.
    */
   vtkSetMacro(LightDataLimit, unsigned int);
   vtkGetMacro(LightDataLimit, unsigned int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Controls whether writer automatically writes all input time steps, or
    * just the timestep that is currently on the input.
@@ -86,7 +87,7 @@ public:
   vtkSetMacro(WriteAllTimeSteps, bool);
   vtkGetMacro(WriteAllTimeSteps, bool);
   vtkBooleanMacro(WriteAllTimeSteps, bool);
-  //@}
+  ///@}
 
 protected:
   vtkXdmf3Writer();
@@ -125,4 +126,5 @@ private:
   Internals* Internal;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* vtkXdmf3Writer_h */
