@@ -22,6 +22,9 @@
 #include "vtkPointData.h"
 #include "vtkScalarsToColors.h"
 
+#include <cmath>
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageMapToWindowLevelColors);
 
 // Constructor sets default values
@@ -69,6 +72,7 @@ int vtkImageMapToWindowLevelColors::RequestData(
       this->DataWasPassed = 0;
     }
 
+    // NOLINTNEXTLINE(bugprone-parent-virtual-call)
     return this->vtkThreadedImageAlgorithm::RequestData(request, inputVector, outputVector);
   }
 
@@ -414,3 +418,4 @@ void vtkImageMapToWindowLevelColors::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Window: " << this->Window << endl;
   os << indent << "Level: " << this->Level << endl;
 }
+VTK_ABI_NAMESPACE_END
