@@ -24,6 +24,7 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStructuredData.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkExtractVOI);
 
 // Construct object to extract all of the input data.
@@ -51,16 +52,23 @@ vtkExtractVOI::~vtkExtractVOI()
 int vtkExtractVOI::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
+  // get the info objects
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+
+  // Re-init helper to full whole extent. This is needed since `RequestData`
+  // modifies the helper to limit to the input extents rather than whole
+  // extents.
+  int wholeExtent[6];
+  inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), wholeExtent);
+  this->Internal->Initialize(
+    this->VOI, wholeExtent, this->SampleRate, (this->IncludeBoundary == 1));
+
   if (!this->Internal->IsValid())
   {
     return 0;
   }
 
   int i;
-
-  // get the info objects
-  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
-
   bool emptyExtent = false;
   int uExt[6];
   for (i = 0; i < 3; i++)
@@ -143,7 +151,7 @@ int vtkExtractVOI::RequestInformation(vtkInformation* vtkNotUsed(request),
 
   if (!this->Internal->IsValid())
   {
-    vtkWarningMacro("Error while initializing filter.");
+    vtkDebugMacro("Error while initializing filter.");
     return 0;
   }
 
@@ -304,3 +312,4 @@ void vtkExtractVOI::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Include Boundary: " << (this->IncludeBoundary ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
