@@ -43,6 +43,7 @@
 #include "vtkImagingCoreModule.h" // For export macro
 
 // Forward Declarations
+VTK_ABI_NAMESPACE_BEGIN
 class vtkExtractStructuredGridHelper;
 
 class VTKIMAGINGCORE_EXPORT vtkExtractVOI : public vtkImageAlgorithm
@@ -56,7 +57,7 @@ public:
    */
   static vtkExtractVOI* New();
 
-  //@{
+  ///@{
   /**
    * Specify i-j-k (min,max) pairs to extract. The resulting structured points
    * dataset can be of any topological dimension (i.e., point, line, image,
@@ -64,9 +65,9 @@ public:
    */
   vtkSetVector6Macro(VOI, int);
   vtkGetVectorMacro(VOI, int, 6);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the sampling rate in the i, j, and k directions. If the rate is >
    * 1, then the resulting VOI will be subsampled representation of the
@@ -75,9 +76,9 @@ public:
    */
   vtkSetVector3Macro(SampleRate, int);
   vtkGetVectorMacro(SampleRate, int, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control whether to enforce that the "boundary" of the grid is output in
    * the subsampling process. (This ivar only has effect when the SampleRate
@@ -89,7 +90,7 @@ public:
   vtkSetMacro(IncludeBoundary, vtkTypeBool);
   vtkGetMacro(IncludeBoundary, vtkTypeBool);
   vtkBooleanMacro(IncludeBoundary, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkExtractVOI();
@@ -119,4 +120,5 @@ private:
   void operator=(const vtkExtractVOI&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
