@@ -27,6 +27,7 @@
 #include "vtkImageAlgorithm.h"
 #include "vtkImagingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 
 class VTKIMAGINGCORE_EXPORT vtkImageChangeInformation : public vtkImageAlgorithm
@@ -36,16 +37,16 @@ public:
   vtkTypeMacro(vtkImageChangeInformation, vtkImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Copy the information from another data set.  By default,
    * the information is copied from the input.
    */
   virtual void SetInformationInputData(vtkImageData*);
   virtual vtkImageData* GetInformationInput();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify new starting values for the extent explicitly.
    * These values are used as WholeExtent[0], WholeExtent[2] and
@@ -55,9 +56,9 @@ public:
    */
   vtkSetVector3Macro(OutputExtentStart, int);
   vtkGetVector3Macro(OutputExtentStart, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a new data spacing explicitly.  The default is to
    * use the spacing of the Input, or of the InformationInput
@@ -65,9 +66,9 @@ public:
    */
   vtkSetVector3Macro(OutputSpacing, double);
   vtkGetVector3Macro(OutputSpacing, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a new data origin explicitly.  The default is to
    * use the origin of the Input, or of the InformationInput
@@ -75,9 +76,9 @@ public:
    */
   vtkSetVector3Macro(OutputOrigin, double);
   vtkGetVector3Macro(OutputOrigin, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the Origin of the output so that image coordinate (0,0,0)
    * lies at the Center of the data set.  This will override
@@ -87,40 +88,40 @@ public:
   vtkSetMacro(CenterImage, vtkTypeBool);
   vtkBooleanMacro(CenterImage, vtkTypeBool);
   vtkGetMacro(CenterImage, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Apply a translation to the extent.
    */
   vtkSetVector3Macro(ExtentTranslation, int);
   vtkGetVector3Macro(ExtentTranslation, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Apply a scale factor to the spacing.
    */
   vtkSetVector3Macro(SpacingScale, double);
   vtkGetVector3Macro(SpacingScale, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Apply a translation to the origin.
    */
   vtkSetVector3Macro(OriginTranslation, double);
   vtkGetVector3Macro(OriginTranslation, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Apply a scale to the origin.  The scale is applied
    * before the translation.
    */
   vtkSetVector3Macro(OriginScale, double);
   vtkGetVector3Macro(OriginScale, double);
-  //@}
+  ///@}
 
 protected:
   vtkImageChangeInformation();
@@ -151,4 +152,5 @@ private:
   void operator=(const vtkImageChangeInformation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
