@@ -26,6 +26,7 @@
 #include "vtkImageReslice.h"
 #include "vtkImagingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGCORE_EXPORT vtkImageFlip : public vtkImageReslice
 {
 public:
@@ -34,16 +35,16 @@ public:
   vtkTypeMacro(vtkImageFlip, vtkImageReslice);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify which axis will be flipped.  This must be an integer
    * between 0 (for x) and 2 (for z). Initial value is 0.
    */
   vtkSetMacro(FilteredAxis, int);
   vtkGetMacro(FilteredAxis, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * By default the image will be flipped about its center, and the
    * Origin, Spacing and Extent of the output will be identical to
@@ -63,7 +64,7 @@ public:
   vtkSetMacro(FlipAboutOrigin, vtkTypeBool);
   vtkGetMacro(FlipAboutOrigin, vtkTypeBool);
   vtkBooleanMacro(FlipAboutOrigin, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Keep the mis-named Axes variations around for compatibility with old
@@ -72,7 +73,7 @@ public:
   void SetFilteredAxes(int axis) { this->SetFilteredAxis(axis); }
   int GetFilteredAxes() { return this->GetFilteredAxis(); }
 
-  //@{
+  ///@{
   /**
    * PreserveImageExtentOff wasn't covered by test scripts and its
    * implementation was broken.  It is deprecated now and it has
@@ -81,7 +82,7 @@ public:
   vtkSetMacro(PreserveImageExtent, vtkTypeBool);
   vtkGetMacro(PreserveImageExtent, vtkTypeBool);
   vtkBooleanMacro(PreserveImageExtent, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkImageFlip();
@@ -98,4 +99,5 @@ private:
   void operator=(const vtkImageFlip&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
