@@ -26,11 +26,13 @@
 #include "vtkImagePadFilter.h"
 #include "vtkImagingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGCORE_EXPORT vtkImageMirrorPad : public vtkImagePadFilter
 {
 public:
   static vtkImageMirrorPad* New();
   vtkTypeMacro(vtkImageMirrorPad, vtkImagePadFilter);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
 protected:
   vtkImageMirrorPad() = default;
@@ -46,6 +48,5 @@ private:
   void operator=(const vtkImageMirrorPad&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkImageMirrorPad.h
