@@ -29,6 +29,7 @@
 #include "vtkImageReslice.h"
 #include "vtkImagingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGCORE_EXPORT vtkImagePermute : public vtkImageReslice
 {
 public:
@@ -37,14 +38,14 @@ public:
 
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The filtered axes are the input axes that get relabeled to X,Y,Z.
    */
   void SetFilteredAxes(int x, int y, int z);
   void SetFilteredAxes(const int xyz[3]) { this->SetFilteredAxes(xyz[0], xyz[1], xyz[2]); }
   vtkGetVector3Macro(FilteredAxes, int);
-  //@}
+  ///@}
 
 protected:
   vtkImagePermute();
@@ -57,4 +58,5 @@ private:
   void operator=(const vtkImagePermute&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
