@@ -23,7 +23,7 @@
  *
  * This filter can be used to resample an image onto a set of arbitrarily
  * placed sample points.  For example, if you have a surface data set
- * (i.e. a vtkPolyData that has been tesselated so that its points are
+ * (i.e. a vtkPolyData that has been tessellated so that its points are
  * very closely spaced), you can color the polydata from the image points.
  *
  * In general, this filter is similar to vtkProbeFilter except that the
@@ -39,6 +39,7 @@
 #include "vtkDataSetAlgorithm.h"
 #include "vtkImagingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractImageInterpolator;
 class vtkUnsignedCharArray;
 class vtkImageData;
@@ -51,7 +52,7 @@ public:
   vtkTypeMacro(vtkImageProbeFilter, vtkDataSetAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the data set that will be probed at the input points.
    * The Input gives the geometry (the points and cells) for the output,
@@ -60,7 +61,7 @@ public:
    */
   void SetSourceData(vtkDataObject* source);
   vtkDataObject* GetSource();
-  //@}
+  ///@}
 
   /**
    * Specify the data set that will be probed at the input points.
@@ -70,7 +71,7 @@ public:
    */
   void SetSourceConnection(vtkAlgorithmOutput* algOutput);
 
-  //@{
+  ///@{
   /**
    * Set the interpolator to use.  If this is not set, then nearest-neighbor
    * interpolation will be used, with the tolerance of the interpolator set
@@ -78,7 +79,7 @@ public:
    */
   virtual void SetInterpolator(vtkAbstractImageInterpolator* interpolator);
   virtual vtkAbstractImageInterpolator* GetInterpolator() { return this->Interpolator; }
-  //@}
+  ///@}
 
 protected:
   vtkImageProbeFilter();
@@ -123,4 +124,5 @@ private:
     vtkIdType endId, ProbePointsThreadLocal* threadLocal);
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
