@@ -17,7 +17,7 @@
  * @brief   Shifts constant frequency to center for
  * display.
  *
- * Is used for dispaying images in frequency space.  FFT converts spatial
+ * Is used for displaying images in frequency space.  FFT converts spatial
  * images into frequency space, but puts the zero frequency at the origin.
  * This filter shifts the zero frequency to the center of the image.
  * Input and output are assumed to be doubles.
@@ -29,11 +29,13 @@
 #include "vtkImageDecomposeFilter.h"
 #include "vtkImagingFourierModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGFOURIER_EXPORT vtkImageFourierCenter : public vtkImageDecomposeFilter
 {
 public:
   static vtkImageFourierCenter* New();
   vtkTypeMacro(vtkImageFourierCenter, vtkImageDecomposeFilter);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
 protected:
   vtkImageFourierCenter();
@@ -50,6 +52,5 @@ private:
   void operator=(const vtkImageFourierCenter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkImageFourierCenter.h
