@@ -34,6 +34,7 @@
 #include "vtkImagingFourierModule.h" // For export macro
 #include "vtkThreadedImageAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGFOURIER_EXPORT vtkImageIdealHighPass : public vtkThreadedImageAlgorithm
 {
 public:
@@ -41,7 +42,7 @@ public:
   vtkTypeMacro(vtkImageIdealHighPass, vtkThreadedImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the cutoff frequency for each axis.
    * The values are specified in the order X, Y, Z, Time.
@@ -56,7 +57,7 @@ public:
   double GetXCutOff() { return this->CutOff[0]; }
   double GetYCutOff() { return this->CutOff[1]; }
   double GetZCutOff() { return this->CutOff[2]; }
-  //@}
+  ///@}
 
 protected:
   vtkImageIdealHighPass();
@@ -73,4 +74,5 @@ private:
   void operator=(const vtkImageIdealHighPass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
