@@ -44,6 +44,7 @@
 #include "vtkImageSpatialAlgorithm.h"
 #include "vtkImagingGeneralModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGGENERAL_EXPORT vtkImageAnisotropicDiffusion3D : public vtkImageSpatialAlgorithm
 {
 public:
@@ -59,14 +60,14 @@ public:
    */
   void SetNumberOfIterations(int num);
 
-  //@{
+  ///@{
   /**
    * Get the number of iterations.
    */
   vtkGetMacro(NumberOfIterations, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the difference threshold that stops diffusion.
    * when the difference between two pixel is greater than this threshold,
@@ -76,17 +77,17 @@ public:
    */
   vtkSetMacro(DiffusionThreshold, double);
   vtkGetMacro(DiffusionThreshold, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the difference factor
    */
   vtkSetMacro(DiffusionFactor, double);
   vtkGetMacro(DiffusionFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Choose neighbors to diffuse (6 faces, 12 edges, 8 corners).
    */
@@ -99,16 +100,16 @@ public:
   vtkSetMacro(Corners, vtkTypeBool);
   vtkGetMacro(Corners, vtkTypeBool);
   vtkBooleanMacro(Corners, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Switch between gradient magnitude threshold and pixel gradient threshold.
    */
   vtkSetMacro(GradientMagnitudeThreshold, vtkTypeBool);
   vtkGetMacro(GradientMagnitudeThreshold, vtkTypeBool);
   vtkBooleanMacro(GradientMagnitudeThreshold, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkImageAnisotropicDiffusion3D();
@@ -135,4 +136,5 @@ private:
   void operator=(const vtkImageAnisotropicDiffusion3D&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
