@@ -20,8 +20,15 @@
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageCityBlockDistance);
 
+//------------------------------------------------------------------------------
+void vtkImageCityBlockDistance::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 vtkImageCityBlockDistance::vtkImageCityBlockDistance() = default;
 
@@ -211,3 +218,4 @@ int vtkImageCityBlockDistance::IterativeRequestData(vtkInformation* vtkNotUsed(r
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
