@@ -26,6 +26,7 @@
 #include "vtkImagingGeneralModule.h" // For export macro
 #include "vtkThreadedImageAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGGENERAL_EXPORT vtkImageEuclideanToPolar : public vtkThreadedImageAlgorithm
 {
 public:
@@ -33,7 +34,7 @@ public:
   vtkTypeMacro(vtkImageEuclideanToPolar, vtkThreadedImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Theta is an angle. Maximum specifies when it maps back to 0.
    * ThetaMaximum defaults to 255 instead of 2PI, because unsigned char
@@ -41,7 +42,7 @@ public:
    */
   vtkSetMacro(ThetaMaximum, double);
   vtkGetMacro(ThetaMaximum, double);
-  //@}
+  ///@}
 
 protected:
   vtkImageEuclideanToPolar();
@@ -56,4 +57,5 @@ private:
   void operator=(const vtkImageEuclideanToPolar&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
