@@ -31,6 +31,7 @@
 #include "vtkImagingGeneralModule.h" // For export macro
 #include "vtkThreadedImageAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGGENERAL_EXPORT vtkImageSlab : public vtkThreadedImageAlgorithm
 {
 public:
@@ -38,7 +39,7 @@ public:
   vtkTypeMacro(vtkImageSlab, vtkThreadedImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set the slice direction: zero for x, 1 for y, 2 for z.
    * The default is the Z direction.
@@ -48,18 +49,18 @@ public:
   void SetOrientationToY() { this->SetOrientation(1); }
   void SetOrientationToZ() { this->SetOrientation(2); }
   vtkGetMacro(Orientation, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the range of slices to combine. The default is to project
    * through all slices.
    */
   vtkSetVector2Macro(SliceRange, int);
   vtkGetVector2Macro(SliceRange, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the operation to use when combining slices.  The choices are
    * "Mean", "Sum", "Min", "Max".  The default is "Mean".
@@ -71,9 +72,9 @@ public:
   void SetOperationToSum() { this->SetOperation(VTK_IMAGE_SLAB_SUM); }
   vtkGetMacro(Operation, int);
   const char* GetOperationAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Use trapezoid integration for slab computation.  This weighs the
    * first and last slices by half when doing sum and mean, as compared
@@ -83,9 +84,9 @@ public:
   vtkSetMacro(TrapezoidIntegration, vtkTypeBool);
   vtkBooleanMacro(TrapezoidIntegration, vtkTypeBool);
   vtkGetMacro(TrapezoidIntegration, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on multi-slice output.  Each slice of the output will be
    * a projection through the specified range of input slices, e.g.
@@ -96,9 +97,9 @@ public:
   vtkSetMacro(MultiSliceOutput, vtkTypeBool);
   vtkBooleanMacro(MultiSliceOutput, vtkTypeBool);
   vtkGetMacro(MultiSliceOutput, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the output scalar type to float or double, to avoid
    * potential overflow when doing a summation operation.
@@ -109,7 +110,7 @@ public:
   void SetOutputScalarTypeToDouble() { this->SetOutputScalarType(VTK_DOUBLE); }
   void SetOutputScalarTypeToInputScalarType() { this->SetOutputScalarType(0); }
   vtkGetMacro(OutputScalarType, int);
-  //@}
+  ///@}
 
 protected:
   vtkImageSlab();
@@ -135,4 +136,5 @@ private:
   void operator=(const vtkImageSlab&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
