@@ -47,6 +47,7 @@
 #include "vtkImageAlgorithm.h"
 #include "vtkImagingHybridModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGHYBRID_EXPORT vtkBooleanTexture : public vtkImageAlgorithm
 {
 public:
@@ -55,101 +56,101 @@ public:
   vtkTypeMacro(vtkBooleanTexture, vtkImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set the X texture map dimension.
    */
   vtkSetMacro(XSize, int);
   vtkGetMacro(XSize, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the Y texture map dimension.
    */
   vtkSetMacro(YSize, int);
   vtkGetMacro(YSize, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the thickness of the "on" region.
    */
   vtkSetMacro(Thickness, int);
   vtkGetMacro(Thickness, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "in/in" region.
    */
   vtkSetVector2Macro(InIn, unsigned char);
   vtkGetVectorMacro(InIn, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "in/out" region.
    */
   vtkSetVector2Macro(InOut, unsigned char);
   vtkGetVectorMacro(InOut, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "out/in" region.
    */
   vtkSetVector2Macro(OutIn, unsigned char);
   vtkGetVectorMacro(OutIn, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "out/out" region.
    */
   vtkSetVector2Macro(OutOut, unsigned char);
   vtkGetVectorMacro(OutOut, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "on/on" region.
    */
   vtkSetVector2Macro(OnOn, unsigned char);
   vtkGetVectorMacro(OnOn, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "on/in" region.
    */
   vtkSetVector2Macro(OnIn, unsigned char);
   vtkGetVectorMacro(OnIn, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "on/out" region.
    */
   vtkSetVector2Macro(OnOut, unsigned char);
   vtkGetVectorMacro(OnOut, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "in/on" region.
    */
   vtkSetVector2Macro(InOn, unsigned char);
   vtkGetVectorMacro(InOn, unsigned char, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify intensity/transparency for "out/on" region.
    */
   vtkSetVector2Macro(OutOn, unsigned char);
   vtkGetVectorMacro(OutOn, unsigned char, 2);
-  //@}
+  ///@}
 
 protected:
   vtkBooleanTexture();
@@ -177,4 +178,5 @@ private:
   void operator=(const vtkBooleanTexture&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
