@@ -19,12 +19,13 @@
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageCursor3D);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageCursor3D::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   int idx;
 
@@ -38,7 +39,7 @@ void vtkImageCursor3D::PrintSelf(ostream& os, vtkIndent indent)
   os << ")\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageCursor3D::vtkImageCursor3D()
 {
   this->CursorPosition[0] = 0;
@@ -49,11 +50,8 @@ vtkImageCursor3D::vtkImageCursor3D()
   this->CursorValue = 255;
 }
 
-
-
 template <class T>
-void vtkImageCursor3DExecute(vtkImageCursor3D *self,
-                             vtkImageData *outData, T *ptr)
+void vtkImageCursor3DExecute(vtkImageCursor3D* self, vtkImageData* outData, T* ptr)
 {
   int min0, max0, min1, max1, min2, max2;
   int c0, c1, c2;
@@ -74,60 +72,54 @@ void vtkImageCursor3DExecute(vtkImageCursor3D *self,
     {
       if (idx >= min0 && idx <= max0)
       {
-        ptr = static_cast<T *>(outData->GetScalarPointer(idx, c1, c2));
+        ptr = static_cast<T*>(outData->GetScalarPointer(idx, c1, c2));
         *ptr = static_cast<T>(value);
       }
     }
   }
 
-
   if (c0 >= min0 && c0 <= max0 && c2 >= min2 && c2 <= max2)
   {
     for (idx = c1 - rad; idx <= c1 + rad; ++idx)
     {
       if (idx >= min1 && idx <= max1)
       {
-        ptr = static_cast<T *>(outData->GetScalarPointer(c0, idx, c2));
+        ptr = static_cast<T*>(outData->GetScalarPointer(c0, idx, c2));
         *ptr = static_cast<T>(value);
       }
     }
   }
 
-
   if (c0 >= min0 && c0 <= max0 && c1 >= min1 && c1 <= max1)
   {
     for (idx = c2 - rad; idx <= c2 + rad; ++idx)
     {
       if (idx >= min2 && idx <= max2)
       {
-        ptr = static_cast<T *>(outData->GetScalarPointer(c0, c1, idx));
+        ptr = static_cast<T*>(outData->GetScalarPointer(c0, c1, idx));
         *ptr = static_cast<T>(value);
       }
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Split up into finished and border datas.  Fill the border datas.
 int vtkImageCursor3D::RequestData(
-  vtkInformation* request,
-  vtkInformationVector** inputVector,
-  vtkInformationVector* outputVector)
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
-  void *ptr = nullptr;
+  void* ptr = nullptr;
 
   // let superclass allocate data
   this->Superclass::RequestData(request, inputVector, outputVector);
 
   // get the data object
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
-  vtkImageData *outData =
-    vtkImageData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
+  vtkImageData* outData = vtkImageData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   switch (outData->GetScalarType())
   {
-    vtkTemplateMacro(
-      vtkImageCursor3DExecute(this,outData, static_cast<VTK_TT *>(ptr)));
+    vtkTemplateMacro(vtkImageCursor3DExecute(this, outData, static_cast<VTK_TT*>(ptr)));
     default:
       vtkErrorMacro(<< "Execute: Unknown ScalarType");
       return 1;
@@ -135,7 +127,4 @@ int vtkImageCursor3D::RequestData(
 
   return 1;
 }
-
-
-
-
+VTK_ABI_NAMESPACE_END
