@@ -52,6 +52,7 @@
 #include "vtkImagingHybridModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkVolumeReader;
 
 class VTKIMAGINGHYBRID_EXPORT vtkSliceCubes : public vtkObject
@@ -65,38 +66,38 @@ public:
   void Write() { this->Update(); }
   void Update();
 
-  //@{
+  ///@{
   /**
    * Set/get object to read slices.
    */
   virtual void SetReader(vtkVolumeReader*);
   vtkGetObjectMacro(Reader, vtkVolumeReader);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify file name of marching cubes output file.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get isosurface contour value.
    */
   vtkSetMacro(Value, double);
   vtkGetMacro(Value, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify file name of marching cubes limits file. The limits file
    * speeds up subsequent reading of output triangle file.
    */
-  vtkSetStringMacro(LimitsFileName);
-  vtkGetStringMacro(LimitsFileName);
-  //@}
+  vtkSetFilePathMacro(LimitsFileName);
+  vtkGetFilePathMacro(LimitsFileName);
+  ///@}
 
 protected:
   vtkSliceCubes();
@@ -114,4 +115,5 @@ private:
   void operator=(const vtkSliceCubes&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
