@@ -34,6 +34,7 @@
 #include "vtkImagingMorphologicalModule.h" // For export macro
 #include "vtkThreadedImageAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIMAGINGMORPHOLOGICAL_EXPORT vtkImageNonMaximumSuppression
   : public vtkThreadedImageAlgorithm
 {
@@ -42,15 +43,15 @@ public:
   vtkTypeMacro(vtkImageNonMaximumSuppression, vtkThreadedImageAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set the magnitude and vector inputs.
    */
   void SetMagnitudeInputData(vtkImageData* input) { this->SetInputData(0, input); }
   void SetVectorInputData(vtkImageData* input) { this->SetInputData(1, input); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If "HandleBoundariesOn" then boundary pixels are duplicated
    * So central differences can get values.
@@ -58,15 +59,15 @@ public:
   vtkSetMacro(HandleBoundaries, vtkTypeBool);
   vtkGetMacro(HandleBoundaries, vtkTypeBool);
   vtkBooleanMacro(HandleBoundaries, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Determines how the input is interpreted (set of 2d slices or a 3D volume)
    */
   vtkSetClampMacro(Dimensionality, int, 2, 3);
   vtkGetMacro(Dimensionality, int);
-  //@}
+  ///@}
 
 protected:
   vtkImageNonMaximumSuppression();
@@ -88,4 +89,5 @@ private:
   void operator=(const vtkImageNonMaximumSuppression&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
