@@ -63,6 +63,8 @@ POSSIBILITY OF SUCH DAMAGES.
 #include "vtkSignedCharArray.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+#include "vtkSMPTools.h"
+
 #include <algorithm>
 #include <map>
 #include <utility>
@@ -70,6 +72,7 @@ POSSIBILITY OF SUCH DAMAGES.
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolyDataToImageStencil);
 
 //------------------------------------------------------------------------------
@@ -153,10 +156,7 @@ private:
   MapType EdgeMap;
 
 public:
-  EdgeLocator()
-    : EdgeMap()
-  {
-  }
+  EdgeLocator() = default;
   ~EdgeLocator() { this->Initialize(); }
 
   // Description:
@@ -774,9 +774,9 @@ int vtkPolyDataToImageStencil::RequestData(
 
   int extent[6];
   data->GetExtent(extent);
-  // ThreadedExecute is only called from a single thread for
-  // now, but it could as easily be called from ThreadedRequestData
-  this->ThreadedExecute(data, extent, 0);
+  ParallelWorker worker(extent, this, data);
+
+  vtkSMPTools::For(extent[4], extent[5] + 1, 1, worker);
 
   return 1;
 }
@@ -787,3 +787,4 @@ int vtkPolyDataToImageStencil::FillInputPortInformation(int, vtkInformation* inf
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPolyData");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
