@@ -38,17 +38,18 @@
 
 using namespace boost;
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBoostBiconnectedComponents);
 
 vtkBoostBiconnectedComponents::vtkBoostBiconnectedComponents()
 {
-  this->OutputArrayName = 0;
+  this->OutputArrayName = nullptr;
 }
 
 vtkBoostBiconnectedComponents::~vtkBoostBiconnectedComponents()
 {
   // release mem
-  this->SetOutputArrayName(0);
+  this->SetOutputArrayName(nullptr);
 }
 
 int vtkBoostBiconnectedComponents::RequestData(vtkInformation* vtkNotUsed(request),
@@ -164,3 +165,4 @@ void vtkBoostBiconnectedComponents::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "OutputArrayName: " << (this->OutputArrayName ? this->OutputArrayName : "(none)")
      << endl;
 }
+VTK_ABI_NAMESPACE_END
