@@ -41,6 +41,7 @@
 
 using namespace boost;
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBoostBrandesCentrality);
 
 //------------------------------------------------------------------------------
@@ -97,7 +98,7 @@ int vtkBoostBrandesCentrality::RequestData(vtkInformation* vtkNotUsed(request),
   edgeCMap->SetName("centrality");
   vtkGraphEdgePropertyMapHelper<vtkFloatArray*> helper(edgeCMap);
 
-  vtkSmartPointer<vtkDataArray> edgeWeight(0);
+  vtkSmartPointer<vtkDataArray> edgeWeight(nullptr);
   if (this->UseEdgeWeightArray && this->EdgeWeightArrayName)
   {
     if (!this->InvertEdgeWeightArray)
@@ -185,3 +186,4 @@ int vtkBoostBrandesCentrality::RequestData(vtkInformation* vtkNotUsed(request),
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
