@@ -20,6 +20,7 @@
 =========================================================================*/
 
 #include "vtkBoostRandomSparseArraySource.h"
+#include "vtkArrayData.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
@@ -30,6 +31,7 @@
 
 //------------------------------------------------------------------------------
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBoostRandomSparseArraySource);
 
 //------------------------------------------------------------------------------
@@ -116,3 +118,4 @@ int vtkBoostRandomSparseArraySource::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
