@@ -36,7 +36,6 @@
 #include "vtkSparseArray.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
-#include "vtkUnicodeStringArray.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
@@ -47,6 +46,7 @@
 #include <stdexcept>
 
 /// Convert a 1D array to a table with one column ...
+VTK_ABI_NAMESPACE_BEGIN
 template <typename ValueT, typename ColumnT>
 static bool ConvertVector(vtkArray* Array, vtkTable* Output)
 {
@@ -61,7 +61,7 @@ static bool ConvertVector(vtkArray* Array, vtkTable* Output)
 
   ColumnT* const column = ColumnT::New();
   column->SetNumberOfTuples(extents.GetSize());
-  column->SetName(array->GetName());
+  column->SetName(array->GetName().c_str());
   for (vtkIdType i = extents.GetBegin(); i != extents.GetEnd(); ++i)
   {
     column->SetValue(i - extents.GetBegin(), array->GetValue(i));
@@ -206,8 +206,6 @@ int vtkArrayToTable::RequestData(
       return 1;
     if (ConvertVector<vtkStdString, vtkStringArray>(input_array, output_table))
       return 1;
-    if (ConvertVector<vtkUnicodeString, vtkUnicodeStringArray>(input_array, output_table))
-      return 1;
 
     if (ConvertMatrix<double, vtkDoubleArray>(input_array, output_table))
       return 1;
@@ -239,8 +237,6 @@ int vtkArrayToTable::RequestData(
       return 1;
     if (ConvertMatrix<vtkStdString, vtkStringArray>(input_array, output_table))
       return 1;
-    if (ConvertMatrix<vtkUnicodeString, vtkUnicodeStringArray>(input_array, output_table))
-      return 1;
 
     throw std::runtime_error("Unhandled input array type.");
   }
@@ -255,3 +251,4 @@ int vtkArrayToTable::RequestData(
 
   return 0;
 }
+VTK_ABI_NAMESPACE_END
