@@ -36,6 +36,7 @@
 #include <string> // Using STL.
 #include <vector> // Using STL.
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCollapseVerticesByArray);
 
 //------------------------------------------------------------------------------
@@ -47,8 +48,7 @@ public:
 
 //------------------------------------------------------------------------------
 vtkCollapseVerticesByArray::vtkCollapseVerticesByArray()
-  : vtkGraphAlgorithm()
-  , AllowSelfLoops(false)
+  : AllowSelfLoops(false)
   , VertexArray(nullptr)
   , CountEdgesCollapsed(false)
   , EdgesCollapsedArray(nullptr)
@@ -273,7 +273,7 @@ vtkGraph* vtkCollapseVerticesByArray::Create(vtkGraph* inGraph)
     bool alreadyAdded(false);
     for (size_t j = 0; j < this->Internal->AggregateEdgeArrays.size(); ++j)
     {
-      if (strcmp(absArray->GetName(), this->Internal->AggregateEdgeArrays[j].c_str()) == 0)
+      if (absArray->GetName() == this->Internal->AggregateEdgeArrays[j])
       {
         vtkDataArray* inDataArray = vtkArrayDownCast<vtkDataArray>(absArray);
         if (inDataArray)
@@ -388,7 +388,7 @@ vtkGraph* vtkCollapseVerticesByArray::Create(vtkGraph* inGraph)
   }
 
   // Now itereate over all the edges in the graph.
-  // Result vary dependeing on whether the input graph is
+  // Result vary depending on whether the input graph is
   // directed or not.
   vtkEdgeListIteratorRefPtr elItr(vtkEdgeListIteratorRefPtr::New());
   inGraph->GetEdges(elItr);
@@ -517,3 +517,4 @@ void vtkCollapseVerticesByArray::FindEdge(
     }
   }
 }
+VTK_ABI_NAMESPACE_END
