@@ -48,6 +48,7 @@
 #include "vtkDataObjectAlgorithm.h"
 #include "vtkInfovisCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKINFOVISCORE_EXPORT vtkGenerateIndexArray : public vtkDataObjectAlgorithm
 {
 public:
@@ -56,38 +57,38 @@ public:
   vtkTypeMacro(vtkGenerateIndexArray, vtkDataObjectAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Control the output index array name.  Default: "index".
    */
   vtkSetStringMacro(ArrayName);
   vtkGetStringMacro(ArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control the location where the index array will be stored.
    */
   vtkSetMacro(FieldType, int);
   vtkGetMacro(FieldType, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specifies an optional reference array for index-generation.
    */
   vtkSetStringMacro(ReferenceArrayName);
   vtkGetStringMacro(ReferenceArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specifies whether the index array should be marked as
    * pedigree ids.  Default: false.
    */
   vtkSetMacro(PedigreeID, int);
   vtkGetMacro(PedigreeID, int);
-  //@}
+  ///@}
 
   enum
   {
@@ -120,4 +121,5 @@ private:
   void operator=(const vtkGenerateIndexArray&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
