@@ -45,6 +45,7 @@
 #include "vtkInfovisCoreModule.h" // For export macro
 #include "vtkTableAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKINFOVISCORE_EXPORT vtkMergeColumns : public vtkTableAlgorithm
 {
 public:
@@ -52,13 +53,13 @@ public:
   vtkTypeMacro(vtkMergeColumns, vtkTableAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * The name to give the merged column created by this filter.
    */
   vtkSetStringMacro(MergedColumnName);
   vtkGetStringMacro(MergedColumnName);
-  //@}
+  ///@}
 
 protected:
   vtkMergeColumns();
@@ -73,4 +74,5 @@ private:
   void operator=(const vtkMergeColumns&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
