@@ -37,6 +37,7 @@
 
 #include <set>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStringToCategory);
 
 vtkStringToCategory::vtkStringToCategory()
@@ -117,7 +118,7 @@ int vtkStringToCategory::RequestData(
   fd->AddArray(catArr);
   catArr->Delete();
   vtkIdList* list = vtkIdList::New();
-  std::set<vtkStdString> s;
+  std::set<std::string> s;
   int category = 0;
   for (vtkIdType i = 0; i < numTuples * numComp; i++)
   {
@@ -203,3 +204,4 @@ void vtkStringToCategory::PrintSelf(ostream& os, vtkIndent indent)
      << "CategoryArrayName: " << (this->CategoryArrayName ? this->CategoryArrayName : "(null)")
      << endl;
 }
+VTK_ABI_NAMESPACE_END
