@@ -9,86 +9,79 @@
 #include "vtkSelectionNode.h"
 #include "vtkSmartPointer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkThresholdGraph);
 
-//-----------------------------------------------------------------------------
-vtkThresholdGraph::vtkThresholdGraph() : vtkGraphAlgorithm(),
-  LowerThreshold(0.0),
-  UpperThreshold(0.0)
+//------------------------------------------------------------------------------
+vtkThresholdGraph::vtkThresholdGraph()
+  : LowerThreshold(0.0)
+  , UpperThreshold(0.0)
 {
 }
 
+//------------------------------------------------------------------------------
+vtkThresholdGraph::~vtkThresholdGraph() = default;
 
-//-----------------------------------------------------------------------------
-vtkThresholdGraph::~vtkThresholdGraph()
-{
-  // Do nothing.
-}
-
-//-----------------------------------------------------------------------------
-void  vtkThresholdGraph::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkThresholdGraph::PrintSelf(ostream& os, vtkIndent indent)
 {
   // Base class print.
   vtkGraphAlgorithm::PrintSelf(os, indent);
 
-  os << indent << "LowerThreshold: "  << this->LowerThreshold << endl;
-  os << indent << "UpperThreshold: "  << this->UpperThreshold << endl;
+  os << indent << "LowerThreshold: " << this->LowerThreshold << endl;
+  os << indent << "UpperThreshold: " << this->UpperThreshold << endl;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkThresholdGraph::RequestData(vtkInformation* vtkNotUsed(request),
-                                   vtkInformationVector** inputVector,
-                                   vtkInformationVector* outputVector)
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
-  if(!inputVector[0])
+  if (!inputVector[0])
   {
     vtkErrorMacro("Error: nullptr or invalid input vtkInformationVector.");
     return 1;
   }
 
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
-  if(!inInfo)
+  if (!inInfo)
   {
     vtkErrorMacro("Error: nullptr or invalid input vtkInformation.");
     return 1;
   }
 
   vtkDataObject* inDataObj = inInfo->Get(vtkDataObject::DATA_OBJECT());
-  if(!inDataObj)
+  if (!inDataObj)
   {
     vtkErrorMacro("Error: nullptr or invalid input data object.");
     return 1;
   }
 
-  if(!outputVector)
+  if (!outputVector)
   {
     vtkErrorMacro("Error: nullptr or invalid output vtkInformationVector.");
     return 1;
   }
 
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
-  if(!outInfo)
+  if (!outInfo)
   {
-    vtkErrorMacro("Error: nullptr of invalid output vtkInformation.")
+    vtkErrorMacro("Error: nullptr of invalid output vtkInformation.");
   }
 
   vtkDataObject* outDataObj = outInfo->Get(vtkDataObject::DATA_OBJECT());
-  if(!outDataObj)
+  if (!outDataObj)
   {
     vtkErrorMacro("Error: nullptr or invalid output data object.");
     return 1;
   }
 
-  vtkSmartPointer<vtkExtractSelectedGraph> extractThreshold (
+  vtkSmartPointer<vtkExtractSelectedGraph> extractThreshold(
     vtkSmartPointer<vtkExtractSelectedGraph>::New());
-  vtkSmartPointer<vtkSelection> threshold (vtkSmartPointer<vtkSelection>::New());
-  vtkSmartPointer<vtkSelectionNode> thresholdNode (
-    vtkSmartPointer<vtkSelectionNode>::New());
-  vtkSmartPointer<vtkDoubleArray> thresholdArr (
-    vtkSmartPointer<vtkDoubleArray>::New());
+  vtkSmartPointer<vtkSelection> threshold(vtkSmartPointer<vtkSelection>::New());
+  vtkSmartPointer<vtkSelectionNode> thresholdNode(vtkSmartPointer<vtkSelectionNode>::New());
+  vtkSmartPointer<vtkDoubleArray> thresholdArr(vtkSmartPointer<vtkDoubleArray>::New());
 
-  vtkInformationVector* inArrayVec =
-    this->GetInformation()->Get(INPUT_ARRAYS_TO_PROCESS());
+  vtkInformationVector* inArrayVec = this->GetInformation()->Get(INPUT_ARRAYS_TO_PROCESS());
 
   if (!inArrayVec)
   {
@@ -101,22 +94,21 @@ int vtkThresholdGraph::RequestData(vtkInformation* vtkNotUsed(request),
     vtkErrorMacro("Problem getting name of array to process.");
     return 1;
   }
-  if ( ! inArrayInfo->Has(vtkDataObject::FIELD_NAME()))
+  if (!inArrayInfo->Has(vtkDataObject::FIELD_NAME()))
   {
     vtkErrorMacro("Missing field name.");
     return 1;
   }
-  const char* arrayNameToProcess =
-    inArrayInfo->Get(vtkDataObject::FIELD_NAME());
+  const char* arrayNameToProcess = inArrayInfo->Get(vtkDataObject::FIELD_NAME());
 
-  if(!arrayNameToProcess)
+  if (!arrayNameToProcess)
   {
     vtkErrorMacro("Unable to find valid array.");
     return 1;
   }
 
   int fieldAssociation(-1);
-  if(!inArrayInfo->Has(vtkDataObject::FIELD_ASSOCIATION()))
+  if (!inArrayInfo->Has(vtkDataObject::FIELD_ASSOCIATION()))
   {
     vtkErrorMacro("Unable to query field association for the scalar.");
     return 1;
@@ -130,18 +122,18 @@ int vtkThresholdGraph::RequestData(vtkInformation* vtkNotUsed(request),
   thresholdNode->SetSelectionList(thresholdArr);
   thresholdNode->SetContentType(vtkSelectionNode::THRESHOLDS);
 
-  if(fieldAssociation == vtkDataObject::FIELD_ASSOCIATION_EDGES)
+  if (fieldAssociation == vtkDataObject::FIELD_ASSOCIATION_EDGES)
   {
     thresholdNode->SetFieldType(vtkSelectionNode::EDGE);
   }
-  else if(fieldAssociation == vtkDataObject::FIELD_ASSOCIATION_VERTICES)
+  else if (fieldAssociation == vtkDataObject::FIELD_ASSOCIATION_VERTICES)
   {
     thresholdNode->SetFieldType(vtkSelectionNode::VERTEX);
   }
   else
   {
-    vtkErrorMacro("Array selected should be associated with vertex or " <<
-                  "edge data.");
+    vtkErrorMacro("Array selected should be associated with vertex or "
+      << "edge data.");
     return 1;
   }
 
@@ -158,7 +150,7 @@ int vtkThresholdGraph::RequestData(vtkInformation* vtkNotUsed(request),
 
   vtkDataObject* output = extractThreshold->GetOutputDataObject(0);
 
-  if(!output)
+  if (!output)
   {
     vtkErrorMacro("nullptr or invalid output.");
     return 1;
@@ -168,3 +160,4 @@ int vtkThresholdGraph::RequestData(vtkInformation* vtkNotUsed(request),
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
