@@ -25,6 +25,7 @@
 #include "vtkStringArray.h"
 #include "vtkTree.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTreeDifferenceFilter);
 
 //------------------------------------------------------------------------------
@@ -165,8 +166,8 @@ bool vtkTreeDifferenceFilter::GenerateMapping(vtkTree* tree1, vtkTree* tree2)
   for (vtkIdType vertexItr = 0; vertexItr < nodeNames1->GetNumberOfTuples(); ++vertexItr)
   {
     vtkIdType vertexId1 = vertexItr;
-    std::string nodeName = nodeNames1->GetValue(vertexId1);
-    if (nodeName.compare("") == 0)
+    vtkStdString nodeName = nodeNames1->GetValue(vertexId1);
+    if (nodeName.empty())
     {
       continue;
     }
@@ -313,3 +314,4 @@ void vtkTreeDifferenceFilter::PrintSelf(ostream& os, vtkIndent indent)
   }
   os << indent << "ComparisonArrayIsVertexData: " << this->ComparisonArrayIsVertexData << std::endl;
 }
+VTK_ABI_NAMESPACE_END
