@@ -22,7 +22,7 @@
 
 #include "vtkTree.h"
 
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkAreaLayoutStrategy::vtkAreaLayoutStrategy()
 {
   this->ShrinkPercentage = 0.0;
@@ -30,10 +30,8 @@ vtkAreaLayoutStrategy::vtkAreaLayoutStrategy()
 
 vtkAreaLayoutStrategy::~vtkAreaLayoutStrategy() = default;
 
-void vtkAreaLayoutStrategy::LayoutEdgePoints(
-  vtkTree* inputTree,
-  vtkDataArray* vtkNotUsed(coordsArray),
-  vtkDataArray* vtkNotUsed(sizeArray),
+void vtkAreaLayoutStrategy::LayoutEdgePoints(vtkTree* inputTree,
+  vtkDataArray* vtkNotUsed(coordsArray), vtkDataArray* vtkNotUsed(sizeArray),
   vtkTree* edgeRoutingTree)
 {
   edgeRoutingTree->ShallowCopy(inputTree);
@@ -41,8 +39,7 @@ void vtkAreaLayoutStrategy::LayoutEdgePoints(
 
 void vtkAreaLayoutStrategy::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
   os << indent << "ShrinkPercentage: " << this->ShrinkPercentage << endl;
 }
-
-
+VTK_ABI_NAMESPACE_END
