@@ -25,9 +25,9 @@
 #include "vtkCellData.h"
 #include "vtkDataArray.h"
 #include "vtkFloatArray.h"
-#include "vtkMath.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
+#include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPoints.h"
@@ -35,6 +35,7 @@
 #include "vtkTree.h"
 #include "vtkTreeDFSIterator.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBoxLayoutStrategy);
 
 vtkBoxLayoutStrategy::vtkBoxLayoutStrategy() = default;
@@ -42,9 +43,7 @@ vtkBoxLayoutStrategy::vtkBoxLayoutStrategy() = default;
 vtkBoxLayoutStrategy::~vtkBoxLayoutStrategy() = default;
 
 void vtkBoxLayoutStrategy::Layout(
-    vtkTree* inputTree,
-    vtkDataArray* coordsArray,
-    vtkDataArray* vtkNotUsed(sizeArray))
+  vtkTree* inputTree, vtkDataArray* coordsArray, vtkDataArray* vtkNotUsed(sizeArray))
 {
   if (!inputTree)
   {
@@ -55,8 +54,7 @@ void vtkBoxLayoutStrategy::Layout(
     vtkErrorMacro("Area array not defined.");
     return;
   }
-  vtkSmartPointer<vtkTreeDFSIterator> dfs =
-    vtkSmartPointer<vtkTreeDFSIterator>::New();
+  vtkSmartPointer<vtkTreeDFSIterator> dfs = vtkSmartPointer<vtkTreeDFSIterator>::New();
   dfs->SetTree(inputTree);
   float coords[4];
   vtkSmartPointer<vtkAdjacentVertexIterator> children =
@@ -66,12 +64,13 @@ void vtkBoxLayoutStrategy::Layout(
     vtkIdType vertex = dfs->Next();
     if (vertex == inputTree->GetRoot())
     {
-      coords[0] = 0; coords[1] = 1; coords[2] = 0; coords[3] = 1;
+      coords[0] = 0;
+      coords[1] = 1;
+      coords[2] = 0;
+      coords[3] = 1;
       coordsArray->SetTuple(vertex, coords);
-      inputTree->GetPoints()->SetPoint(vertex,
-        (coords[0] + coords[1])/2.0,
-        (coords[2] + coords[3])/2.0,
-        0.0);
+      inputTree->GetPoints()->SetPoint(
+        vertex, (coords[0] + coords[1]) / 2.0, (coords[2] + coords[3]) / 2.0, 0.0);
     }
     double doubleCoords[4];
     coordsArray->GetTuple(vertex, doubleCoords);
@@ -91,14 +90,13 @@ void vtkBoxLayoutStrategy::Layout(
     if (!inputTree->IsLeaf(vertex))
     {
       // Divide the available space with simple algo
-      int xDivisions =
-        static_cast<int>(sqrt(static_cast<double>(nchildren))+1); // Ceiling
+      int xDivisions = static_cast<int>(sqrt(static_cast<double>(nchildren)) + 1); // Ceiling
       int yDivisions = xDivisions;
 
       // Okay try shrinking the bounds
-      if ((xDivisions-1)*yDivisions >= nchildren)
+      if ((xDivisions - 1) * yDivisions >= nchildren)
         --xDivisions;
-      if (xDivisions*(yDivisions-1) >= nchildren)
+      if (xDivisions * (yDivisions - 1) >= nchildren)
         --yDivisions;
 
       // Get the children
@@ -119,20 +117,14 @@ void vtkBoxLayoutStrategy::Layout(
           vtkIdType child = children->Next();
 
           // Give children their positions
-          coords[0] =
-            parentMinX + xDelta * j;// minX
-          coords[1] =
-            parentMinX + xDelta * (j + 1.0);// maxX
-          coords[2] =
-            parentMinY + ySpace - yDelta * (i + 1.0);// minY
-          coords[3] =
-            parentMinY + ySpace - yDelta*i;// maxY
+          coords[0] = parentMinX + xDelta * j;                  // minX
+          coords[1] = parentMinX + xDelta * (j + 1.0);          // maxX
+          coords[2] = parentMinY + ySpace - yDelta * (i + 1.0); // minY
+          coords[3] = parentMinY + ySpace - yDelta * i;         // maxY
 
           coordsArray->SetTuple(child, coords);
-          inputTree->GetPoints()->SetPoint(child,
-            (coords[0] + coords[1])/2.0,
-            (coords[2] + coords[3])/2.0,
-            0.0);
+          inputTree->GetPoints()->SetPoint(
+            child, (coords[0] + coords[1]) / 2.0, (coords[2] + coords[3]) / 2.0, 0.0);
         }
       }
     }
@@ -141,5 +133,6 @@ void vtkBoxLayoutStrategy::Layout(
 
 void vtkBoxLayoutStrategy::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
