@@ -22,12 +22,13 @@
 
 #include "vtkTree.h"
 
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkCirclePackLayoutStrategy::vtkCirclePackLayoutStrategy() = default;
 
 vtkCirclePackLayoutStrategy::~vtkCirclePackLayoutStrategy() = default;
 
 void vtkCirclePackLayoutStrategy::PrintSelf(ostream& os, vtkIndent indent)
 {
-    this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
