@@ -30,10 +30,11 @@
 #include "vtkFastSplatter.h"
 #include "vtkFloatArray.h"
 #include "vtkGraph.h"
+#include "vtkIdTypeArray.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
-#include "vtkIdTypeArray.h"
+#include "vtkLogger.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
@@ -41,15 +42,16 @@
 #include "vtkSmartPointer.h"
 #include "vtkTree.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCommunity2DLayoutStrategy);
 
 // Cool-down function.
 static inline float CoolDown(float t, float r)
 {
-  return t-(t/r);
+  return t - (t / r);
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkCommunity2DLayoutStrategy::vtkCommunity2DLayoutStrategy()
 {
@@ -75,23 +77,22 @@ vtkCommunity2DLayoutStrategy::vtkCommunity2DLayoutStrategy()
   this->CommunityStrength = 1.0;
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkCommunity2DLayoutStrategy::~vtkCommunity2DLayoutStrategy()
 {
   this->SetEdgeWeightField(nullptr);
   this->SetCommunityArrayName(nullptr);
-  delete [] this->EdgeArray;
+  delete[] this->EdgeArray;
 }
 
-
 // Helper functions
-void vtkCommunity2DLayoutStrategy::GenerateCircularSplat(vtkImageData *splat, int x, int y)
+void vtkCommunity2DLayoutStrategy::GenerateCircularSplat(vtkImageData* splat, int x, int y)
 {
   splat->SetDimensions(x, y, 1);
   splat->AllocateScalars(VTK_FLOAT, 1);
 
-  const int *dimensions = splat->GetDimensions();
+  const int* dimensions = splat->GetDimensions();
 
   // Circular splat: 1 in the middle and 0 at the corners and sides
   for (int row = 0; row < dimensions[1]; ++row)
@@ -101,13 +102,13 @@ void vtkCommunity2DLayoutStrategy::GenerateCircularSplat(vtkImageData *splat, in
       float splatValue;
 
       // coordinates will range from -1 to 1
-      float xCoord = (col - dimensions[0]/2.0) / (dimensions[0]/2.0);
-      float yCoord = (row - dimensions[1]/2.0) / (dimensions[1]/2.0);
+      float xCoord = (col - dimensions[0] / 2.0) / (dimensions[0] / 2.0);
+      float yCoord = (row - dimensions[1] / 2.0) / (dimensions[1] / 2.0);
 
-      float radius = sqrt(xCoord*xCoord + yCoord*yCoord);
+      float radius = sqrt(xCoord * xCoord + yCoord * yCoord);
       if ((1 - radius) > 0)
       {
-        splatValue = 1-radius;
+        splatValue = 1 - radius;
       }
       else
       {
@@ -115,21 +116,21 @@ void vtkCommunity2DLayoutStrategy::GenerateCircularSplat(vtkImageData *splat, in
       }
 
       // Set value
-      splat->SetScalarComponentFromFloat(col,row,0,0,splatValue);
+      splat->SetScalarComponentFromFloat(col, row, 0, 0, splatValue);
     }
   }
 }
 
-void vtkCommunity2DLayoutStrategy::GenerateGaussianSplat(vtkImageData *splat, int x, int y)
+void vtkCommunity2DLayoutStrategy::GenerateGaussianSplat(vtkImageData* splat, int x, int y)
 {
   splat->SetDimensions(x, y, 1);
   splat->AllocateScalars(VTK_FLOAT, 1);
 
-  const int *dimensions = splat->GetDimensions();
+  const int* dimensions = splat->GetDimensions();
 
   // Gaussian splat
   float falloff = 10; // fast falloff
-  float e= 2.71828182845904;
+  float e = 2.71828182845904;
 
   for (int row = 0; row < dimensions[1]; ++row)
   {
@@ -138,18 +139,18 @@ void vtkCommunity2DLayoutStrategy::GenerateGaussianSplat(vtkImageData *splat, in
       float splatValue;
 
       // coordinates will range from -1 to 1
-      float xCoord = (col - dimensions[0]/2.0) / (dimensions[0]/2.0);
-      float yCoord = (row - dimensions[1]/2.0) / (dimensions[1]/2.0);
+      float xCoord = (col - dimensions[0] / 2.0) / (dimensions[0] / 2.0);
+      float yCoord = (row - dimensions[1] / 2.0) / (dimensions[1] / 2.0);
 
-      splatValue = pow(e,-((xCoord*xCoord + yCoord*yCoord) * falloff));
+      splatValue = pow(e, -((xCoord * xCoord + yCoord * yCoord) * falloff));
 
       // Set value
-      splat->SetScalarComponentFromFloat(col,row,0,0,splatValue);
+      splat->SetScalarComponentFromFloat(col, row, 0, 0, splatValue);
     }
   }
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the graph that will be laid out
 void vtkCommunity2DLayoutStrategy::Initialize()
 {
@@ -169,8 +170,8 @@ void vtkCommunity2DLayoutStrategy::Initialize()
   }
 
   // Get a quick pointer to the point data
-  vtkFloatArray *array = vtkArrayDownCast<vtkFloatArray>(pts->GetData());
-  float *rawPointData = array->GetPointer(0);
+  vtkFloatArray* array = vtkArrayDownCast<vtkFloatArray>(pts->GetData());
+  float* rawPointData = array->GetPointer(0);
 
   // Avoid divide by zero
   float div = 1;
@@ -188,7 +189,7 @@ void vtkCommunity2DLayoutStrategy::Initialize()
   // Set up array to store repulsion values
   this->RepulsionArray->SetNumberOfComponents(3);
   this->RepulsionArray->SetNumberOfTuples(numVertices);
-  for (vtkIdType i=0; i<numVertices*3; ++i)
+  for (vtkIdType i = 0; i < numVertices * 3; ++i)
   {
     this->RepulsionArray->SetValue(i, 0);
   }
@@ -196,20 +197,20 @@ void vtkCommunity2DLayoutStrategy::Initialize()
   // Set up array to store attraction values
   this->AttractionArray->SetNumberOfComponents(3);
   this->AttractionArray->SetNumberOfTuples(numVertices);
-  for (vtkIdType i=0; i<numVertices*3; ++i)
+  for (vtkIdType i = 0; i < numVertices * 3; ++i)
   {
     this->AttractionArray->SetValue(i, 0);
   }
 
   // Put the edge data into compact, fast access edge data structure
-  delete [] this->EdgeArray;
+  delete[] this->EdgeArray;
   this->EdgeArray = new vtkLayoutEdge[numEdges];
 
   // Jitter x and y, skip z
-  for (vtkIdType i=0; i<numVertices*3; i+=3)
+  for (vtkIdType i = 0; i < numVertices * 3; i += 3)
   {
-    rawPointData[i] += this->RestDistance*(vtkMath::Random() - .5);
-    rawPointData[i+1] += this->RestDistance*(vtkMath::Random() - .5);
+    rawPointData[i] += this->RestDistance * (vtkMath::Random() - .5);
+    rawPointData[i + 1] += this->RestDistance * (vtkMath::Random() - .5);
   }
 
   // Get the weight array
@@ -217,7 +218,8 @@ void vtkCommunity2DLayoutStrategy::Initialize()
   double weight, maxWeight = 1;
   if (this->WeightEdges && this->EdgeWeightField != nullptr)
   {
-    weightArray = vtkArrayDownCast<vtkDataArray>(this->Graph->GetEdgeData()->GetAbstractArray(this->EdgeWeightField));
+    weightArray = vtkArrayDownCast<vtkDataArray>(
+      this->Graph->GetEdgeData()->GetAbstractArray(this->EdgeWeightField));
     if (weightArray != nullptr)
     {
       for (vtkIdType w = 0; w < weightArray->GetNumberOfTuples(); w++)
@@ -232,8 +234,7 @@ void vtkCommunity2DLayoutStrategy::Initialize()
   }
 
   // Load up the edge data structures
-  vtkSmartPointer<vtkEdgeListIterator> edges =
-    vtkSmartPointer<vtkEdgeListIterator>::New();
+  vtkSmartPointer<vtkEdgeListIterator> edges = vtkSmartPointer<vtkEdgeListIterator>::New();
   this->Graph->GetEdges(edges);
   while (edges->HasNext())
   {
@@ -261,10 +262,9 @@ void vtkCommunity2DLayoutStrategy::Initialize()
   this->GenerateGaussianSplat(this->SplatImage, 41, 41);
   this->DensityGrid->SetInputData(1, this->SplatImage);
   this->DensityGrid->SetOutputDimensions(100, 100, 1);
-
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 // Simple graph layout method
 void vtkCommunity2DLayoutStrategy::Layout()
@@ -286,37 +286,36 @@ void vtkCommunity2DLayoutStrategy::Layout()
   vtkIdType numEdges = this->Graph->GetNumberOfEdges();
 
   // Get a quick pointer to the community array
-  vtkDataArray *community =
-    this->Graph->GetVertexData()->GetArray(this->CommunityArrayName);
+  vtkDataArray* community = this->Graph->GetVertexData()->GetArray(this->CommunityArrayName);
   if (community == nullptr)
   {
-    vtkWarningMacro("vtkCommunity2DLayoutStrategy did not find a \"community\" array." <<
-                    "\n so the layout will not pull communities together like it should");
+    vtkWarningMacro("vtkCommunity2DLayoutStrategy did not find a \"community\" array."
+      << "\n so the layout will not pull communities together like it should");
   }
 
   // Get a quick pointer to the point data
-  vtkFloatArray *array = vtkArrayDownCast<vtkFloatArray>(pts->GetData());
-  float *rawPointData = array->GetPointer(0);
+  vtkFloatArray* array = vtkArrayDownCast<vtkFloatArray>(pts->GetData());
+  float* rawPointData = array->GetPointer(0);
 
   // This is the mega, uber, triple inner loop
   // ye of weak hearts, tread no further!
-  float delta[]={0,0,0};
+  float delta[] = { 0, 0, 0 };
   float disSquared;
   float attractValue;
   float epsilon = 1e-5;
-  vtkIdType rawSourceIndex=0;
-  vtkIdType rawTargetIndex=0;
-  for(int i = 0; i < this->IterationsPerLayout; ++i)
+  vtkIdType rawSourceIndex = 0;
+  vtkIdType rawTargetIndex = 0;
+  for (int i = 0; i < this->IterationsPerLayout; ++i)
   {
 
     // Initialize the repulsion and attraction arrays
-    for (vtkIdType j=0; j<numVertices*3; ++j)
+    for (vtkIdType j = 0; j < numVertices * 3; ++j)
     {
       this->RepulsionArray->SetValue(j, 0);
     }
 
     // Set up array to store attraction values
-    for (vtkIdType j=0; j<numVertices*3; ++j)
+    for (vtkIdType j = 0; j < numVertices * 3; ++j)
     {
       this->AttractionArray->SetValue(j, 0);
     }
@@ -327,10 +326,10 @@ void vtkCommunity2DLayoutStrategy::Layout()
     this->Graph->GetBounds(bounds);
 
     // Give bounds a 10% padding
-    paddedBounds[0] = bounds[0] - (bounds[1]-bounds[0])*.1;
-    paddedBounds[1] = bounds[1] + (bounds[1]-bounds[0])*.1;
-    paddedBounds[2] = bounds[2] - (bounds[3]-bounds[2])*.1;
-    paddedBounds[3] = bounds[3] + (bounds[3]-bounds[2])*.1;
+    paddedBounds[0] = bounds[0] - (bounds[1] - bounds[0]) * .1;
+    paddedBounds[1] = bounds[1] + (bounds[1] - bounds[0]) * .1;
+    paddedBounds[2] = bounds[2] - (bounds[3] - bounds[2]) * .1;
+    paddedBounds[3] = bounds[3] + (bounds[3] - bounds[2]) * .1;
     paddedBounds[4] = paddedBounds[5] = 0;
 
     // Update the density grid
@@ -345,53 +344,50 @@ void vtkCommunity2DLayoutStrategy::Layout()
     }
 
     // Get the array handle
-    float *densityArray = static_cast<float*>
-      (this->DensityGrid->GetOutput()->GetScalarPointer());
+    float* densityArray = static_cast<float*>(this->DensityGrid->GetOutput()->GetScalarPointer());
 
     // Get the dimensions of the density grid
     int dims[3];
     this->DensityGrid->GetOutputDimensions(dims);
 
-
     // Calculate the repulsive forces
-    float *rawRepulseArray = this->RepulsionArray->GetPointer(0);
-    for(vtkIdType j=0; j<numVertices; ++j)
+    float* rawRepulseArray = this->RepulsionArray->GetPointer(0);
+    for (vtkIdType j = 0; j < numVertices; ++j)
     {
       rawSourceIndex = j * 3;
 
       // Compute indices into the density grid
-      int indexX = static_cast<int>(
-                   (rawPointData[rawSourceIndex]-paddedBounds[0]) /
-                   (paddedBounds[1]-paddedBounds[0]) * dims[0] + .5);
-      int indexY = static_cast<int>(
-                   (rawPointData[rawSourceIndex+1]-paddedBounds[2]) /
-                   (paddedBounds[3]-paddedBounds[2]) * dims[1] + .5);
+      int indexX = static_cast<int>((rawPointData[rawSourceIndex] - paddedBounds[0]) /
+          (paddedBounds[1] - paddedBounds[0]) * dims[0] +
+        .5);
+      int indexY = static_cast<int>((rawPointData[rawSourceIndex + 1] - paddedBounds[2]) /
+          (paddedBounds[3] - paddedBounds[2]) * dims[1] +
+        .5);
 
       // Look up the gradient density within the density grid
-      float x1 = densityArray[indexY * dims[0] + indexX-1];
-      float x2 = densityArray[indexY * dims[0] + indexX+1];
-      float y1 = densityArray[(indexY-1) * dims[0] + indexX];
-      float y2 = densityArray[(indexY+1) * dims[0] + indexX];
+      float x1 = densityArray[indexY * dims[0] + indexX - 1];
+      float x2 = densityArray[indexY * dims[0] + indexX + 1];
+      float y1 = densityArray[(indexY - 1) * dims[0] + indexX];
+      float y2 = densityArray[(indexY + 1) * dims[0] + indexX];
 
-      rawRepulseArray[rawSourceIndex]   = (x1-x2); // Push away from higher
-      rawRepulseArray[rawSourceIndex+1] = (y1-y2);
+      rawRepulseArray[rawSourceIndex] = (x1 - x2); // Push away from higher
+      rawRepulseArray[rawSourceIndex + 1] = (y1 - y2);
     }
 
     // Calculate the attractive forces
-    float *rawAttractArray = this->AttractionArray->GetPointer(0);
-    for (vtkIdType j=0; j<numEdges; ++j)
+    float* rawAttractArray = this->AttractionArray->GetPointer(0);
+    for (vtkIdType j = 0; j < numEdges; ++j)
     {
       rawSourceIndex = this->EdgeArray[j].from * 3;
       rawTargetIndex = this->EdgeArray[j].to * 3;
 
       // No need to attract points to themselves
-      if (rawSourceIndex == rawTargetIndex) continue;
+      if (rawSourceIndex == rawTargetIndex)
+        continue;
 
-      delta[0] = rawPointData[rawSourceIndex] -
-             rawPointData[rawTargetIndex];
-      delta[1] = rawPointData[rawSourceIndex+1] -
-              rawPointData[rawTargetIndex+1];
-      disSquared = delta[0]*delta[0] + delta[1]*delta[1];
+      delta[0] = rawPointData[rawSourceIndex] - rawPointData[rawTargetIndex];
+      delta[1] = rawPointData[rawSourceIndex + 1] - rawPointData[rawTargetIndex + 1];
+      disSquared = delta[0] * delta[0] + delta[1] * delta[1];
 
       // Compute a bunch of parameters used below
       int sourceIndex = this->EdgeArray[j].from;
@@ -402,8 +398,8 @@ void vtkCommunity2DLayoutStrategy::Layout()
       float communityWeight = 1;
       if (community)
       {
-        int sourceComm = static_cast<int> (community->GetTuple1(sourceIndex));
-        int targetComm = static_cast<int> (community->GetTuple1(targetIndex));
+        int sourceComm = static_cast<int>(community->GetTuple1(sourceIndex));
+        int targetComm = static_cast<int>(community->GetTuple1(targetIndex));
 
         // Often -1 is used for no/unspecified community
         // if either node is marked as such then just skip
@@ -428,24 +424,23 @@ void vtkCommunity2DLayoutStrategy::Layout()
       } // if community
 
       // Perform weight adjustment
-      attractValue = this->EdgeArray[j].weight*communityWeight*disSquared -
-                     this->RestDistance;
+      attractValue = this->EdgeArray[j].weight * communityWeight * disSquared - this->RestDistance;
 
-      rawAttractArray[rawSourceIndex]   -= delta[0] * attractValue;
-      rawAttractArray[rawSourceIndex+1] -= delta[1] * attractValue;
-      rawAttractArray[rawTargetIndex]   += delta[0] * attractValue;
-      rawAttractArray[rawTargetIndex+1] += delta[1] * attractValue;
+      rawAttractArray[rawSourceIndex] -= delta[0] * attractValue;
+      rawAttractArray[rawSourceIndex + 1] -= delta[1] * attractValue;
+      rawAttractArray[rawTargetIndex] += delta[0] * attractValue;
+      rawAttractArray[rawTargetIndex + 1] += delta[1] * attractValue;
     } // for each edge
 
     // Okay now set new positions based on replusion
     // and attraction 'forces'
-    for(vtkIdType j=0; j<numVertices; ++j)
+    for (vtkIdType j = 0; j < numVertices; ++j)
     {
       rawSourceIndex = j * 3;
 
       // Get forces for this node
       float forceX = rawAttractArray[rawSourceIndex] + rawRepulseArray[rawSourceIndex];
-      float forceY = rawAttractArray[rawSourceIndex+1] + rawRepulseArray[rawSourceIndex+1];
+      float forceY = rawAttractArray[rawSourceIndex + 1] + rawRepulseArray[rawSourceIndex + 1];
 
       // Forces can get extreme so limit them
       // Note: This is pseudo-normalization of the
@@ -453,13 +448,13 @@ void vtkCommunity2DLayoutStrategy::Layout()
 
       // Avoid divide by zero
       float forceDiv = fabs(forceX) + fabs(forceY) + epsilon;
-      float pNormalize = vtkMath::Min(1.0f, 1.0f/forceDiv);
+      float pNormalize = vtkMath::Min(1.0f, 1.0f / forceDiv);
       pNormalize *= this->Temp;
       forceX *= pNormalize;
       forceY *= pNormalize;
 
       rawPointData[rawSourceIndex] += forceX;
-      rawPointData[rawSourceIndex+1] += forceY;
+      rawPointData[rawSourceIndex + 1] += forceY;
     }
 
     // The point coordinates have been modified
@@ -469,13 +464,12 @@ void vtkCommunity2DLayoutStrategy::Layout()
     this->Temp = CoolDown(this->Temp, this->CoolDownRate);
 
     // Announce progress
-    double progress = (i+this->TotalIterations) /
-                      static_cast<double>(this->MaxNumberOfIterations);
-    this->InvokeEvent(vtkCommand::ProgressEvent, static_cast<void *>(&progress));
+    double progress =
+      (i + this->TotalIterations) / static_cast<double>(this->MaxNumberOfIterations);
+    this->InvokeEvent(vtkCommand::ProgressEvent, static_cast<void*>(&progress));
 
   } // End loop this->IterationsPerLayout
 
-
   // Check for completion of layout
   this->TotalIterations += this->IterationsPerLayout;
   if (this->TotalIterations >= this->MaxNumberOfIterations)
@@ -509,21 +503,19 @@ void vtkCommunity2DLayoutStrategy::ResolveCoincidentVertices()
 
   // Get a quick pointer to the point data
   vtkPoints* pts = this->Graph->GetPoints();
-  vtkFloatArray *array = vtkArrayDownCast<vtkFloatArray>(pts->GetData());
-  float *rawPointData = array->GetPointer(0);
+  vtkFloatArray* array = vtkArrayDownCast<vtkFloatArray>(pts->GetData());
+  float* rawPointData = array->GetPointer(0);
 
   // Place the vertices into a giant grid (100xNumVertices)
   // and see if you have any collisions
-  vtkBitArray *giantGrid = vtkBitArray::New();
-  vtkIdType xDim =
-    static_cast<int>(sqrt(static_cast<double>(numVertices)) * 10);
-  vtkIdType yDim =
-    static_cast<int>(sqrt(static_cast<double>(numVertices)) * 10);
+  vtkBitArray* giantGrid = vtkBitArray::New();
+  vtkIdType xDim = static_cast<int>(sqrt(static_cast<double>(numVertices)) * 10);
+  vtkIdType yDim = static_cast<int>(sqrt(static_cast<double>(numVertices)) * 10);
   vtkIdType gridSize = xDim * yDim;
   giantGrid->SetNumberOfValues(gridSize);
 
   // Initialize array to zeros
-  for(vtkIdType i=0; i<gridSize; ++i)
+  for (vtkIdType i = 0; i < gridSize; ++i)
   {
     giantGrid->SetValue(i, 0);
   }
@@ -532,35 +524,35 @@ void vtkCommunity2DLayoutStrategy::ResolveCoincidentVertices()
   this->Graph->GetBounds(bounds);
 
   // Give bounds a 10% padding
-  paddedBounds[0] = bounds[0] - (bounds[1]-bounds[0])*.1;
-  paddedBounds[1] = bounds[1] + (bounds[1]-bounds[0])*.1;
-  paddedBounds[2] = bounds[2] - (bounds[3]-bounds[2])*.1;
-  paddedBounds[3] = bounds[3] + (bounds[3]-bounds[2])*.1;
+  paddedBounds[0] = bounds[0] - (bounds[1] - bounds[0]) * .1;
+  paddedBounds[1] = bounds[1] + (bounds[1] - bounds[0]) * .1;
+  paddedBounds[2] = bounds[2] - (bounds[3] - bounds[2]) * .1;
+  paddedBounds[3] = bounds[3] + (bounds[3] - bounds[2]) * .1;
   paddedBounds[4] = paddedBounds[5] = 0;
 
   int totalCollisionOps = 0;
 
-  for(vtkIdType i=0; i<numVertices; ++i)
+  for (vtkIdType i = 0; i < numVertices; ++i)
   {
     int rawIndex = i * 3;
 
     // Compute indices into the buckets
-    int indexX = static_cast<int>(
-                 (rawPointData[rawIndex]-paddedBounds[0]) /
-                 (paddedBounds[1]-paddedBounds[0]) * (xDim-1) + .5);
-    int indexY = static_cast<int>(
-                 (rawPointData[rawIndex+1]-paddedBounds[2]) /
-                 (paddedBounds[3]-paddedBounds[2]) * (yDim-1) + .5);
+    int indexX = static_cast<int>((rawPointData[rawIndex] - paddedBounds[0]) /
+        (paddedBounds[1] - paddedBounds[0]) * (xDim - 1) +
+      .5);
+    int indexY = static_cast<int>((rawPointData[rawIndex + 1] - paddedBounds[2]) /
+        (paddedBounds[3] - paddedBounds[2]) * (yDim - 1) +
+      .5);
 
     // See if you collide with another vertex
-    if (giantGrid->GetValue(indexX + indexY*xDim))
+    if (giantGrid->GetValue(indexX + indexY * xDim))
     {
 
       // Oh my... try to get yourself out of this
       // by randomly jumping to a place that doesn't
       // have another vertex
       bool collision = true;
-      float jumpDistance = 5.0*(paddedBounds[1]-paddedBounds[0])/xDim; // 2.5 grid spaces max
+      float jumpDistance = 5.0 * (paddedBounds[1] - paddedBounds[0]) / xDim; // 2.5 grid spaces max
       int collisionOps = 0;
 
       // You get 10 tries and then we have to punt
@@ -569,26 +561,26 @@ void vtkCommunity2DLayoutStrategy::ResolveCoincidentVertices()
         collisionOps++;
 
         // Move
-        rawPointData[rawIndex] += jumpDistance*(vtkMath::Random() - .5);
-        rawPointData[rawIndex+1] += jumpDistance*(vtkMath::Random() - .5);
+        rawPointData[rawIndex] += jumpDistance * (vtkMath::Random() - .5);
+        rawPointData[rawIndex + 1] += jumpDistance * (vtkMath::Random() - .5);
 
         // Test
-        indexX = static_cast<int>(
-                 (rawPointData[rawIndex]-paddedBounds[0]) /
-                 (paddedBounds[1]-paddedBounds[0]) * (xDim-1) + .5);
-        indexY = static_cast<int>(
-                     (rawPointData[rawIndex+1]-paddedBounds[2]) /
-                     (paddedBounds[3]-paddedBounds[2]) * (yDim-1) + .5);
-        if (!giantGrid->GetValue(indexX + indexY*xDim))
+        indexX = static_cast<int>((rawPointData[rawIndex] - paddedBounds[0]) /
+            (paddedBounds[1] - paddedBounds[0]) * (xDim - 1) +
+          .5);
+        indexY = static_cast<int>((rawPointData[rawIndex + 1] - paddedBounds[2]) /
+            (paddedBounds[3] - paddedBounds[2]) * (yDim - 1) +
+          .5);
+        if (!giantGrid->GetValue(indexX + indexY * xDim))
         {
           collision = false; // yea
         }
       } // while
-        totalCollisionOps += collisionOps;
+      totalCollisionOps += collisionOps;
     } // if collide
 
     // Put into a bucket
-    giantGrid->SetValue(indexX + indexY*xDim, 1);
+    giantGrid->SetValue(indexX + indexY * xDim, 1);
   }
 
   // Delete giantGrid
@@ -596,20 +588,23 @@ void vtkCommunity2DLayoutStrategy::ResolveCoincidentVertices()
   giantGrid->Delete();
 
   // Report number of collision operations just for sanity check
-  // vtkWarningMacro("Collision Ops: " << totalCollisionOps);
+  vtkLog(TRACE, "Collision Ops: " << totalCollisionOps);
 }
 
 void vtkCommunity2DLayoutStrategy::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
   os << indent << "RandomSeed: " << this->RandomSeed << endl;
   os << indent << "MaxNumberOfIterations: " << this->MaxNumberOfIterations << endl;
   os << indent << "IterationsPerLayout: " << this->IterationsPerLayout << endl;
   os << indent << "InitialTemperature: " << this->InitialTemperature << endl;
   os << indent << "CoolDownRate: " << this->CoolDownRate << endl;
   os << indent << "RestDistance: " << this->RestDistance << endl;
-  os << indent << "EdgeWeightField: " << (this->EdgeWeightField ? this->EdgeWeightField : "(none)") << endl;
-  os << indent << "CommunityArrayName: " << (this->CommunityArrayName ? this->CommunityArrayName : "(none)") << endl;
+  os << indent << "EdgeWeightField: " << (this->EdgeWeightField ? this->EdgeWeightField : "(none)")
+     << endl;
+  os << indent
+     << "CommunityArrayName: " << (this->CommunityArrayName ? this->CommunityArrayName : "(none)")
+     << endl;
   os << indent << "CommunityStrength: " << this->CommunityStrength << endl;
-
 }
+VTK_ABI_NAMESPACE_END
