@@ -38,6 +38,7 @@
 
 #include "vtkSmartPointer.h" // Required for smart pointer internal ivars.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFastSplatter;
 class vtkFloatArray;
 class vtkGraphToPolyData;
@@ -51,7 +52,7 @@ public:
   vtkTypeMacro(vtkFast2DLayoutStrategy, vtkGraphLayoutStrategy);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Seed the random number generator used to jitter point positions.
    * This has a significant effect on their final positions when
@@ -59,9 +60,9 @@ public:
    */
   vtkSetClampMacro(RandomSeed, int, 0, VTK_INT_MAX);
   vtkGetMacro(RandomSeed, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the maximum number of iterations to be used.
    * The higher this number, the more iterations through the algorithm
@@ -72,9 +73,9 @@ public:
    */
   vtkSetClampMacro(MaxNumberOfIterations, int, 0, VTK_INT_MAX);
   vtkGetMacro(MaxNumberOfIterations, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the number of iterations per layout.
    * The only use for this ivar is for the application
@@ -84,9 +85,9 @@ public:
    */
   vtkSetClampMacro(IterationsPerLayout, int, 0, VTK_INT_MAX);
   vtkGetMacro(IterationsPerLayout, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the initial temperature.  The temperature default is '5'
    * for no particular reason
@@ -95,9 +96,9 @@ public:
    */
   vtkSetClampMacro(InitialTemperature, float, 0.0, VTK_FLOAT_MAX);
   vtkGetMacro(InitialTemperature, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the Cool-down rate.
    * The higher this number is, the longer it will take to "cool-down",
@@ -108,16 +109,16 @@ public:
    */
   vtkSetClampMacro(CoolDownRate, double, 0.01, VTK_DOUBLE_MAX);
   vtkGetMacro(CoolDownRate, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Manually set the resting distance. Otherwise the
    * distance is computed automatically.
    */
   vtkSetMacro(RestDistance, float);
   vtkGetMacro(RestDistance, float);
-  //@}
+  ///@}
 
   /**
    * This strategy sets up some data structures
@@ -184,4 +185,5 @@ private:
   void operator=(const vtkFast2DLayoutStrategy&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
