@@ -27,25 +27,28 @@
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSplineGraphEdges);
 vtkCxxSetObjectMacro(vtkSplineGraphEdges, Spline, vtkSpline);
 
-namespace {
+namespace
+{
 // N-function defined at:
 // http://mathworld.wolfram.com/B-Spline.html
 // optimized for j = 3.
 double CubicSpline(vtkIdType i, double* k, double t)
 {
-  if (t >= k[i] && t < k[i+1])
+  if (t >= k[i] && t < k[i + 1])
   {
-    double denom = (k[i+3]-k[i])*(k[i+2]-k[i])*(k[i+1]-k[i]);
-    if (denom == 0.0) return 0.0;
+    double denom = (k[i + 3] - k[i]) * (k[i + 2] - k[i]) * (k[i + 1] - k[i]);
+    if (denom == 0.0)
+      return 0.0;
     double temp = t - k[i];
-    return temp*temp*temp/denom;
+    return temp * temp * temp / denom;
   }
-  if (t >= k[i+1] && t < k[i+2])
+  if (t >= k[i + 1] && t < k[i + 2])
   {
-    double denom1 = (k[i+3]-k[i])*(k[i+2]-k[i])*(k[i+2]-k[i+1]);
+    double denom1 = (k[i + 3] - k[i]) * (k[i + 2] - k[i]) * (k[i + 2] - k[i + 1]);
     double term1;
     if (denom1 == 0.0)
     {
@@ -53,10 +56,10 @@ double CubicSpline(vtkIdType i, double* k, double t)
     }
     else
     {
-      term1 = (t-k[i])*(t-k[i])*(k[i+2]-t)/denom1;
+      term1 = (t - k[i]) * (t - k[i]) * (k[i + 2] - t) / denom1;
     }
 
-    double denom2 = (k[i+3]-k[i])*(k[i+3]-k[i+1])*(k[i+2]-k[i+1]);
+    double denom2 = (k[i + 3] - k[i]) * (k[i + 3] - k[i + 1]) * (k[i + 2] - k[i + 1]);
     double term2;
     if (denom2 == 0.0)
     {
@@ -64,10 +67,10 @@ double CubicSpline(vtkIdType i, double* k, double t)
     }
     else
     {
-      term2 = (t-k[i])*(k[i+3]-t)*(t-k[i+1])/denom2;
+      term2 = (t - k[i]) * (k[i + 3] - t) * (t - k[i + 1]) / denom2;
     }
 
-    double denom3 = (k[i+4]-k[i+1])*(k[i+3]-k[i+1])*(k[i+2]-k[i+1]);
+    double denom3 = (k[i + 4] - k[i + 1]) * (k[i + 3] - k[i + 1]) * (k[i + 2] - k[i + 1]);
     double term3;
     if (denom3 == 0.0)
     {
@@ -75,14 +78,14 @@ double CubicSpline(vtkIdType i, double* k, double t)
     }
     else
     {
-      term3 = (k[i+4]-t)*(t-k[i+1])*(t-k[i+1])/denom3;
+      term3 = (k[i + 4] - t) * (t - k[i + 1]) * (t - k[i + 1]) / denom3;
     }
 
     return term1 + term2 + term3;
   }
-  if (t >= k[i+2] && t < k[i+3])
+  if (t >= k[i + 2] && t < k[i + 3])
   {
-    double denom1 = (k[i+3]-k[i])*(k[i+3]-k[i+1])*(k[i+3]-k[i+2]);
+    double denom1 = (k[i + 3] - k[i]) * (k[i + 3] - k[i + 1]) * (k[i + 3] - k[i + 2]);
     double term1;
     if (denom1 == 0.0)
     {
@@ -90,10 +93,10 @@ double CubicSpline(vtkIdType i, double* k, double t)
     }
     else
     {
-      term1 = (t-k[i])*(k[i+3]-t)*(k[i+3]-t)/denom1;
+      term1 = (t - k[i]) * (k[i + 3] - t) * (k[i + 3] - t) / denom1;
     }
 
-    double denom2 = (k[i+4]-k[i+1])*(k[i+3]-k[i+1])*(k[i+3]-k[i+2]);
+    double denom2 = (k[i + 4] - k[i + 1]) * (k[i + 3] - k[i + 1]) * (k[i + 3] - k[i + 2]);
     double term2;
     if (denom2 == 0.0)
     {
@@ -101,10 +104,10 @@ double CubicSpline(vtkIdType i, double* k, double t)
     }
     else
     {
-      term2 = (k[i+4]-t)*(t-k[i+1])*(k[i+3]-t)/denom2;
+      term2 = (k[i + 4] - t) * (t - k[i + 1]) * (k[i + 3] - t) / denom2;
     }
 
-    double denom3 = (k[i+4]-k[i+1])*(k[i+4]-k[i+2])*(k[i+3]-k[i+2]);
+    double denom3 = (k[i + 4] - k[i + 1]) * (k[i + 4] - k[i + 2]) * (k[i + 3] - k[i + 2]);
     double term3;
     if (denom3 == 0.0)
     {
@@ -112,17 +115,18 @@ double CubicSpline(vtkIdType i, double* k, double t)
     }
     else
     {
-      term3 = (k[i+4]-t)*(k[i+4]-t)*(t-k[i+2])/denom3;
+      term3 = (k[i + 4] - t) * (k[i + 4] - t) * (t - k[i + 2]) / denom3;
     }
 
     return term1 + term2 + term3;
   }
-  if (t >= k[i+3] && t < k[i+4])
+  if (t >= k[i + 3] && t < k[i + 4])
   {
-    double denom = (k[i+4]-k[i+1])*(k[i+4]-k[i+2])*(k[i+4]-k[i+3]);
-    if (denom == 0.0) return 0.0;
-    double temp = k[i+4] - t;
-    return temp*temp*temp/denom;
+    double denom = (k[i + 4] - k[i + 1]) * (k[i + 4] - k[i + 2]) * (k[i + 4] - k[i + 3]);
+    if (denom == 0.0)
+      return 0.0;
+    double temp = k[i + 4] - t;
+    return temp * temp * temp / denom;
   }
   return 0.0;
 }
@@ -214,10 +218,8 @@ vtkMTimeType vtkSplineGraphEdges::GetMTime()
   return mtime;
 }
 
-int vtkSplineGraphEdges::RequestData(
-  vtkInformation *vtkNotUsed(request),
-  vtkInformationVector **inputVector,
-  vtkInformationVector *outputVector)
+int vtkSplineGraphEdges::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   if (!this->Spline)
   {
@@ -226,14 +228,12 @@ int vtkSplineGraphEdges::RequestData(
   }
 
   // get the info objects
-  vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
+  vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
+  vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
   // get the input and output
-  vtkGraph *input = vtkGraph::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
-  vtkGraph *output = vtkGraph::SafeDownCast(
-    outInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkGraph* input = vtkGraph::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkGraph* output = vtkGraph::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   output->ShallowCopy(input);
   output->DeepCopyEdgePoints(input);
@@ -260,8 +260,7 @@ int vtkSplineGraphEdges::RequestData(
     }
     if (i % 1000 == 0)
     {
-      double progress = static_cast<double>(i)/
-        static_cast<double>(output->GetNumberOfEdges());
+      double progress = static_cast<double>(i) / static_cast<double>(output->GetNumberOfEdges());
       this->InvokeEvent(vtkCommand::ProgressEvent, &progress);
     }
   }
@@ -281,19 +280,18 @@ void vtkSplineGraphEdges::GeneratePoints(vtkGraph* g, vtkIdType e)
   g->GetEdgePoints(e, numInternalPoints, internalPoints);
 
   vtkIdType numPoints = numInternalPoints + 2;
-  double* points = new double[3*static_cast<size_t>(numPoints)];
-  memcpy(points + 3, internalPoints, sizeof(double)*3
-         *static_cast<size_t>(numInternalPoints));
+  double* points = new double[3 * static_cast<size_t>(numPoints)];
+  memcpy(points + 3, internalPoints, sizeof(double) * 3 * static_cast<size_t>(numInternalPoints));
   g->GetPoint(g->GetSourceVertex(e), points);
-  g->GetPoint(g->GetTargetVertex(e), points + 3*(numInternalPoints+1));
+  g->GetPoint(g->GetTargetVertex(e), points + 3 * (numInternalPoints + 1));
 
   double* xPrev;
   double* x;
   double length = 0.0;
-  double* xEnd = points + 3*numPoints;
-  for (xPrev = points, x = points+3; x != xEnd; xPrev += 3, x += 3)
+  double* xEnd = points + 3 * numPoints;
+  for (xPrev = points, x = points + 3; x != xEnd; xPrev += 3, x += 3)
   {
-    double len = sqrt(vtkMath::Distance2BetweenPoints(x,xPrev));
+    double len = sqrt(vtkMath::Distance2BetweenPoints(x, xPrev));
     length += len;
   }
 
@@ -309,7 +307,7 @@ void vtkSplineGraphEdges::GeneratePoints(vtkGraph* g, vtkIdType e)
   this->YSpline->AddPoint(0.0, points[1]);
   this->ZSpline->AddPoint(0.0, points[2]);
   double len = 0.0;
-  for (xPrev = points, x = points+3; x != xEnd; xPrev += 3, x += 3)
+  for (xPrev = points, x = points + 3; x != xEnd; xPrev += 3, x += 3)
   {
     double dist = sqrt(vtkMath::Distance2BetweenPoints(x, xPrev));
     if (dist == 0)
@@ -317,7 +315,7 @@ void vtkSplineGraphEdges::GeneratePoints(vtkGraph* g, vtkIdType e)
       continue;
     }
     len += dist;
-    double t = len/length;
+    double t = len / length;
 
     this->XSpline->AddPoint(t, x[0]);
     this->YSpline->AddPoint(t, x[1]);
@@ -326,20 +324,19 @@ void vtkSplineGraphEdges::GeneratePoints(vtkGraph* g, vtkIdType e)
 
   // Now compute the new points
   vtkIdType numNewPoints = this->NumberOfSubdivisions - 1;
-  double* newPoints = new double[3*numNewPoints];
+  double* newPoints = new double[3 * numNewPoints];
   vtkIdType i;
   for (i = 0, x = newPoints; i < numNewPoints; i++, x += 3)
   {
-    double t = static_cast<double>(i+1) /
-      static_cast<double>(this->NumberOfSubdivisions);
+    double t = static_cast<double>(i + 1) / static_cast<double>(this->NumberOfSubdivisions);
     x[0] = this->XSpline->Evaluate(t);
     x[1] = this->YSpline->Evaluate(t);
     x[2] = this->ZSpline->Evaluate(t);
   }
   g->SetEdgePoints(e, numNewPoints, newPoints);
 
-  delete [] points;
-  delete [] newPoints;
+  delete[] points;
+  delete[] newPoints;
 }
 
 void vtkSplineGraphEdges::GenerateBSpline(vtkGraph* g, vtkIdType e)
@@ -357,19 +354,18 @@ void vtkSplineGraphEdges::GenerateBSpline(vtkGraph* g, vtkIdType e)
     numInternalPoints = 2;
   }
   vtkIdType numPoints = numInternalPoints + 2;
-  double* points = new double[3*numPoints];
+  double* points = new double[3 * numPoints];
   if (repeat)
   {
-    memcpy(points + 3, internalPoints, sizeof(double)*3);
-    memcpy(points + 6, internalPoints, sizeof(double)*3);
+    memcpy(points + 3, internalPoints, sizeof(double) * 3);
+    memcpy(points + 6, internalPoints, sizeof(double) * 3);
   }
   else
   {
-    memcpy(points + 3, internalPoints, sizeof(double)*3
-           *static_cast<size_t>(numInternalPoints));
+    memcpy(points + 3, internalPoints, sizeof(double) * 3 * static_cast<size_t>(numInternalPoints));
   }
   g->GetPoint(g->GetSourceVertex(e), points);
-  g->GetPoint(g->GetTargetVertex(e), points + 3*(numInternalPoints+1));
+  g->GetPoint(g->GetTargetVertex(e), points + 3 * (numInternalPoints + 1));
 
   if (numPoints <= 3)
   {
@@ -383,15 +379,15 @@ void vtkSplineGraphEdges::GenerateBSpline(vtkGraph* g, vtkIdType e)
   knots[1] = 0.0;
   knots[2] = 0.0;
   knots[3] = 0.0;
-  knots[numKnots-4] = 1.0;
-  knots[numKnots-3] = 1.0;
-  knots[numKnots-2] = 1.0;
-  knots[numKnots-1] = 1.0;
+  knots[numKnots - 4] = 1.0;
+  knots[numKnots - 3] = 1.0;
+  knots[numKnots - 2] = 1.0;
+  knots[numKnots - 1] = 1.0;
 
   vtkIdType i;
-  for (i = 4; i < numKnots-4; ++i)
+  for (i = 4; i < numKnots - 4; ++i)
   {
-    knots[i] = static_cast<double>(i-3)/static_cast<double>(numKnots-7);
+    knots[i] = static_cast<double>(i - 3) / static_cast<double>(numKnots - 7);
   }
 
   // Special case of 3 points, make symmetric
@@ -402,39 +398,38 @@ void vtkSplineGraphEdges::GenerateBSpline(vtkGraph* g, vtkIdType e)
 
   // Now compute the new points
   vtkIdType numNewPoints = this->NumberOfSubdivisions - 1;
-  double* newPoints = new double[3*numNewPoints];
+  double* newPoints = new double[3 * numNewPoints];
   double* xNew;
   for (i = 0, xNew = newPoints; i < numNewPoints; i++, xNew += 3)
   {
     xNew[0] = 0.0;
     xNew[1] = 0.0;
     xNew[2] = 0.0;
-    double t = static_cast<double>(i+1) /
-      static_cast<double>(this->NumberOfSubdivisions);
+    double t = static_cast<double>(i + 1) / static_cast<double>(this->NumberOfSubdivisions);
     double* x = points;
-    //double bsum = 0.0;
+    // double bsum = 0.0;
     for (vtkIdType j = 0; j < numPoints; ++j, x += 3)
     {
-      //double b = BCubic(j+2, knots, t);
-      //double b = N(j, 3, knots, t);
+      // double b = BCubic(j+2, knots, t);
+      // double b = N(j, 3, knots, t);
       double b = CubicSpline(j, knots, t);
-      //bsum += b;
-      xNew[0] += x[0]*b;
-      xNew[1] += x[1]*b;
-      xNew[2] += x[2]*b;
+      // bsum += b;
+      xNew[0] += x[0] * b;
+      xNew[1] += x[1] * b;
+      xNew[2] += x[2] * b;
     }
-    //cerr << "bsum: " << bsum << endl;
+    // cerr << "bsum: " << bsum << endl;
   }
   g->SetEdgePoints(e, numNewPoints, newPoints);
 
-  delete [] points;
-  delete [] knots;
-  delete [] newPoints;
+  delete[] points;
+  delete[] knots;
+  delete[] newPoints;
 }
 
 void vtkSplineGraphEdges::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
   os << indent << "SplineType: " << this->SplineType << endl;
   os << indent << "NumberOfSubdivisions: " << this->NumberOfSubdivisions << endl;
   os << indent << "Spline: " << (this->Spline ? "" : "(none)") << endl;
@@ -443,3 +438,4 @@ void vtkSplineGraphEdges::PrintSelf(ostream& os, vtkIndent indent)
     this->Spline->PrintSelf(os, indent.GetNextIndent());
   }
 }
+VTK_ABI_NAMESPACE_END
