@@ -24,6 +24,9 @@
 #include "vtkRenderer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+#include <cmath>
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageViewer);
 
 //------------------------------------------------------------------------------
@@ -279,3 +282,4 @@ void vtkImageViewer::SetRenderWindow(vtkRenderWindow* renWin)
   vtkSetObjectBodyMacro(RenderWindow, vtkRenderWindow, renWin);
   renWin->AddRenderer(this->GetRenderer());
 }
+VTK_ABI_NAMESPACE_END
