@@ -18,8 +18,8 @@
 #include "vtkCommand.h"
 #include "vtkImageActor.h"
 #include "vtkImageData.h"
-#include "vtkImageMapper3D.h"
 #include "vtkImageMapToWindowLevelColors.h"
+#include "vtkImageMapper3D.h"
 #include "vtkInformation.h"
 #include "vtkInteractorStyleImage.h"
 #include "vtkObjectFactory.h"
@@ -28,16 +28,17 @@
 #include "vtkRenderer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageViewer2);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageViewer2::vtkImageViewer2()
 {
-  this->RenderWindow    = nullptr;
-  this->Renderer        = nullptr;
-  this->ImageActor      = vtkImageActor::New();
-  this->WindowLevel     = vtkImageMapToWindowLevelColors::New();
-  this->Interactor      = nullptr;
+  this->RenderWindow = nullptr;
+  this->Renderer = nullptr;
+  this->ImageActor = vtkImageActor::New();
+  this->WindowLevel = vtkImageMapToWindowLevelColors::New();
+  this->Interactor = nullptr;
   this->InteractorStyle = nullptr;
 
   this->Slice = 0;
@@ -46,18 +47,18 @@ vtkImageViewer2::vtkImageViewer2()
 
   // Setup the pipeline
 
-  vtkRenderWindow *renwin = vtkRenderWindow::New();
+  vtkRenderWindow* renwin = vtkRenderWindow::New();
   this->SetRenderWindow(renwin);
   renwin->Delete();
 
-  vtkRenderer *ren = vtkRenderer::New();
+  vtkRenderer* ren = vtkRenderer::New();
   this->SetRenderer(ren);
   ren->Delete();
 
   this->InstallPipeline();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageViewer2::~vtkImageViewer2()
 {
   if (this->WindowLevel)
@@ -97,8 +98,8 @@ vtkImageViewer2::~vtkImageViewer2()
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetupInteractor(vtkRenderWindowInteractor *arg)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetupInteractor(vtkRenderWindowInteractor* arg)
 {
   if (this->Interactor == arg)
   {
@@ -127,8 +128,8 @@ void vtkImageViewer2::SetupInteractor(vtkRenderWindowInteractor *arg)
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetRenderWindow(vtkRenderWindow *arg)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetRenderWindow(vtkRenderWindow* arg)
 {
   if (this->RenderWindow == arg)
   {
@@ -152,8 +153,8 @@ void vtkImageViewer2::SetRenderWindow(vtkRenderWindow *arg)
   this->InstallPipeline();
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetRenderer(vtkRenderer *arg)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetRenderer(vtkRenderer* arg)
 {
   if (this->Renderer == arg)
   {
@@ -178,50 +179,49 @@ void vtkImageViewer2::SetRenderer(vtkRenderer *arg)
   this->UpdateOrientation();
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetSize(int a,int b)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetSize(int width, int height)
 {
-  this->RenderWindow->SetSize(a, b);
+  this->RenderWindow->SetSize(width, height);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkImageViewer2::GetSize()
 {
   return this->RenderWindow->GetSize();
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::GetSliceRange(int &min, int &max)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::GetSliceRange(int& min, int& max)
 {
-  vtkAlgorithm *input = this->GetInputAlgorithm();
+  vtkAlgorithm* input = this->GetInputAlgorithm();
   if (input)
   {
     input->UpdateInformation();
-    int *w_ext = input->GetOutputInformation(0)->Get(
-      vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+    int* w_ext =
+      input->GetOutputInformation(0)->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
     min = w_ext[this->SliceOrientation * 2];
     max = w_ext[this->SliceOrientation * 2 + 1];
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkImageViewer2::GetSliceRange()
 {
-  vtkAlgorithm *input = this->GetInputAlgorithm();
+  vtkAlgorithm* input = this->GetInputAlgorithm();
   if (input)
   {
     input->UpdateInformation();
-    return input->GetOutputInformation(0)->Get(
-      vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()) +
+    return input->GetOutputInformation(0)->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()) +
       this->SliceOrientation * 2;
   }
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkImageViewer2::GetSliceMin()
 {
-  int *range = this->GetSliceRange();
+  int* range = this->GetSliceRange();
   if (range)
   {
     return range[0];
@@ -229,10 +229,10 @@ int vtkImageViewer2::GetSliceMin()
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkImageViewer2::GetSliceMax()
 {
-  int *range = this->GetSliceRange();
+  int* range = this->GetSliceRange();
   if (range)
   {
     return range[1];
@@ -240,10 +240,10 @@ int vtkImageViewer2::GetSliceMax()
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::SetSlice(int slice)
 {
-  int *range = this->GetSliceRange();
+  int* range = this->GetSliceRange();
   if (range)
   {
     if (slice < range[0])
@@ -268,11 +268,11 @@ void vtkImageViewer2::SetSlice(int slice)
   this->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::SetSliceOrientation(int orientation)
 {
   if (orientation < vtkImageViewer2::SLICE_ORIENTATION_YZ ||
-      orientation > vtkImageViewer2::SLICE_ORIENTATION_XY)
+    orientation > vtkImageViewer2::SLICE_ORIENTATION_XY)
   {
     vtkErrorMacro("Error - invalid slice orientation " << orientation);
     return;
@@ -287,7 +287,7 @@ void vtkImageViewer2::SetSliceOrientation(int orientation)
 
   // Update the viewer
 
-  int *range = this->GetSliceRange();
+  int* range = this->GetSliceRange();
   if (range)
   {
     this->Slice = static_cast<int>((range[0] + range[1]) * 0.5);
@@ -306,41 +306,41 @@ void vtkImageViewer2::SetSliceOrientation(int orientation)
   this->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::UpdateOrientation()
 {
   // Set the camera position
 
-  vtkCamera *cam = this->Renderer ? this->Renderer->GetActiveCamera() : nullptr;
+  vtkCamera* cam = this->Renderer ? this->Renderer->GetActiveCamera() : nullptr;
   if (cam)
   {
     switch (this->SliceOrientation)
     {
       case vtkImageViewer2::SLICE_ORIENTATION_XY:
-        cam->SetFocalPoint(0,0,0);
-        cam->SetPosition(0,0,1); // -1 if medical ?
-        cam->SetViewUp(0,1,0);
+        cam->SetFocalPoint(0, 0, 0);
+        cam->SetPosition(0, 0, 1); // -1 if medical ?
+        cam->SetViewUp(0, 1, 0);
         break;
 
       case vtkImageViewer2::SLICE_ORIENTATION_XZ:
-        cam->SetFocalPoint(0,0,0);
-        cam->SetPosition(0,-1,0); // 1 if medical ?
-        cam->SetViewUp(0,0,1);
+        cam->SetFocalPoint(0, 0, 0);
+        cam->SetPosition(0, -1, 0); // 1 if medical ?
+        cam->SetViewUp(0, 0, 1);
         break;
 
       case vtkImageViewer2::SLICE_ORIENTATION_YZ:
-        cam->SetFocalPoint(0,0,0);
-        cam->SetPosition(1,0,0); // -1 if medical ?
-        cam->SetViewUp(0,0,1);
+        cam->SetFocalPoint(0, 0, 0);
+        cam->SetPosition(1, 0, 0); // -1 if medical ?
+        cam->SetViewUp(0, 0, 1);
         break;
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::UpdateDisplayExtent()
 {
-  vtkAlgorithm *input = this->GetInputAlgorithm();
+  vtkAlgorithm* input = this->GetInputAlgorithm();
   if (!input || !this->ImageActor)
   {
     return;
@@ -348,8 +348,7 @@ void vtkImageViewer2::UpdateDisplayExtent()
 
   input->UpdateInformation();
   vtkInformation* outInfo = input->GetOutputInformation(0);
-  int *w_ext = outInfo->Get(
-    vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+  int* w_ext = outInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
 
   // Is the slice in range ? If not, fix it
 
@@ -384,14 +383,13 @@ void vtkImageViewer2::UpdateDisplayExtent()
 
   if (this->Renderer)
   {
-    if (this->InteractorStyle &&
-        this->InteractorStyle->GetAutoAdjustCameraClippingRange())
+    if (this->InteractorStyle && this->InteractorStyle->GetAutoAdjustCameraClippingRange())
     {
       this->Renderer->ResetCameraClippingRange();
     }
     else
     {
-      vtkCamera *cam = this->Renderer->GetActiveCamera();
+      vtkCamera* cam = this->Renderer->GetActiveCamera();
       if (cam)
       {
         double bounds[6];
@@ -399,182 +397,175 @@ void vtkImageViewer2::UpdateDisplayExtent()
         double spos = bounds[this->SliceOrientation * 2];
         double cpos = cam->GetPosition()[this->SliceOrientation];
         double range = fabs(spos - cpos);
-        double *spacing = outInfo->Get(vtkDataObject::SPACING());
-        double avg_spacing =
-          (spacing[0] + spacing[1] + spacing[2]) / 3.0;
-        cam->SetClippingRange(
-          range - avg_spacing * 3.0, range + avg_spacing * 3.0);
+        double* spacing = outInfo->Get(vtkDataObject::SPACING());
+        double avg_spacing = (spacing[0] + spacing[1] + spacing[2]) / 3.0;
+        cam->SetClippingRange(range - avg_spacing * 3.0, range + avg_spacing * 3.0);
       }
     }
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetPosition(int a,int b)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetPosition(int x, int y)
 {
-  this->RenderWindow->SetPosition(a, b);
+  this->RenderWindow->SetPosition(x, y);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkImageViewer2::GetPosition()
 {
   return this->RenderWindow->GetPosition();
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetDisplayId(void *a)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetDisplayId(void* a)
 {
   this->RenderWindow->SetDisplayId(a);
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetWindowId(void *a)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetWindowId(void* a)
 {
   this->RenderWindow->SetWindowId(a);
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetParentId(void *a)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetParentId(void* a)
 {
   this->RenderWindow->SetParentId(a);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkImageViewer2::GetColorWindow()
 {
   return this->WindowLevel->GetWindow();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkImageViewer2::GetColorLevel()
 {
   return this->WindowLevel->GetLevel();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::SetColorWindow(double s)
 {
   this->WindowLevel->SetWindow(s);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::SetColorLevel(double s)
 {
   this->WindowLevel->SetLevel(s);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 class vtkImageViewer2Callback : public vtkCommand
 {
 public:
-  static vtkImageViewer2Callback *New() { return new vtkImageViewer2Callback; }
+  static vtkImageViewer2Callback* New() { return new vtkImageViewer2Callback; }
 
-  void Execute(vtkObject *caller,
-               unsigned long event,
-               void *vtkNotUsed(callData)) override
+  void Execute(vtkObject* caller, unsigned long event, void* vtkNotUsed(callData)) override
   {
-      if (this->IV->GetInput() == nullptr)
-      {
-        return;
-      }
+    if (this->IV->GetInput() == nullptr)
+    {
+      return;
+    }
 
-      // Reset
+    // Reset
 
-      if (event == vtkCommand::ResetWindowLevelEvent)
-      {
-        this->IV->GetInputAlgorithm()->UpdateWholeExtent();
-        double *range = this->IV->GetInput()->GetScalarRange();
-        this->IV->SetColorWindow(range[1] - range[0]);
-        this->IV->SetColorLevel(0.5 * (range[1] + range[0]));
-        this->IV->Render();
-        return;
-      }
-
-      // Start
-
-      if (event == vtkCommand::StartWindowLevelEvent)
-      {
-        this->InitialWindow = this->IV->GetColorWindow();
-        this->InitialLevel = this->IV->GetColorLevel();
-        return;
-      }
-
-      // Adjust the window level here
-
-      vtkInteractorStyleImage *isi =
-        static_cast<vtkInteractorStyleImage *>(caller);
-
-      int *size = this->IV->GetRenderWindow()->GetSize();
-      double window = this->InitialWindow;
-      double level = this->InitialLevel;
-
-      // Compute normalized delta
-
-      double dx = 4.0 *
-        (isi->GetWindowLevelCurrentPosition()[0] -
-         isi->GetWindowLevelStartPosition()[0]) / size[0];
-      double dy = 4.0 *
-        (isi->GetWindowLevelStartPosition()[1] -
-         isi->GetWindowLevelCurrentPosition()[1]) / size[1];
-
-      // Scale by current values
-
-      if (fabs(window) > 0.01)
-      {
-        dx = dx * window;
-      }
-      else
-      {
-        dx = dx * (window < 0 ? -0.01 : 0.01);
-      }
-      if (fabs(level) > 0.01)
-      {
-        dy = dy * level;
-      }
-      else
-      {
-        dy = dy * (level < 0 ? -0.01 : 0.01);
-      }
-
-      // Abs so that direction does not flip
-
-      if (window < 0.0)
-      {
-        dx = -1*dx;
-      }
-      if (level < 0.0)
-      {
-        dy = -1*dy;
-      }
-
-      // Compute new window level
-
-      double newWindow = dx + window;
-      double newLevel;
-      newLevel = level - dy;
-
-      // Stay away from zero and really
-
-      if (fabs(newWindow) < 0.01)
-      {
-        newWindow = 0.01*(newWindow < 0 ? -1 : 1);
-      }
-      if (fabs(newLevel) < 0.01)
-      {
-        newLevel = 0.01*(newLevel < 0 ? -1 : 1);
-      }
-
-      this->IV->SetColorWindow(newWindow);
-      this->IV->SetColorLevel(newLevel);
+    if (event == vtkCommand::ResetWindowLevelEvent)
+    {
+      this->IV->GetInputAlgorithm()->UpdateWholeExtent();
+      double* range = this->IV->GetInput()->GetScalarRange();
+      this->IV->SetColorWindow(range[1] - range[0]);
+      this->IV->SetColorLevel(0.5 * (range[1] + range[0]));
       this->IV->Render();
+      return;
+    }
+
+    // Start
+
+    if (event == vtkCommand::StartWindowLevelEvent)
+    {
+      this->InitialWindow = this->IV->GetColorWindow();
+      this->InitialLevel = this->IV->GetColorLevel();
+      return;
+    }
+
+    // Adjust the window level here
+
+    vtkInteractorStyleImage* isi = static_cast<vtkInteractorStyleImage*>(caller);
+
+    const int* size = this->IV->GetRenderWindow()->GetSize();
+    double window = this->InitialWindow;
+    double level = this->InitialLevel;
+
+    // Compute normalized delta
+
+    double dx = 4.0 *
+      (isi->GetWindowLevelCurrentPosition()[0] - isi->GetWindowLevelStartPosition()[0]) / size[0];
+    double dy = 4.0 *
+      (isi->GetWindowLevelStartPosition()[1] - isi->GetWindowLevelCurrentPosition()[1]) / size[1];
+
+    // Scale by current values
+
+    if (fabs(window) > 0.01)
+    {
+      dx = dx * window;
+    }
+    else
+    {
+      dx = dx * (window < 0 ? -0.01 : 0.01);
+    }
+    if (fabs(level) > 0.01)
+    {
+      dy = dy * level;
+    }
+    else
+    {
+      dy = dy * (level < 0 ? -0.01 : 0.01);
+    }
+
+    // Abs so that direction does not flip
+
+    if (window < 0.0)
+    {
+      dx = -1 * dx;
+    }
+    if (level < 0.0)
+    {
+      dy = -1 * dy;
+    }
+
+    // Compute new window level
+
+    double newWindow = dx + window;
+    double newLevel;
+    newLevel = level - dy;
+
+    // Stay away from zero and really
+
+    if (fabs(newWindow) < 0.01)
+    {
+      newWindow = 0.01 * (newWindow < 0 ? -1 : 1);
+    }
+    if (fabs(newLevel) < 0.01)
+    {
+      newLevel = 0.01 * (newLevel < 0 ? -1 : 1);
+    }
+
+    this->IV->SetColorWindow(newWindow);
+    this->IV->SetColorLevel(newLevel);
+    this->IV->Render();
   }
 
-  vtkImageViewer2 *IV;
+  vtkImageViewer2* IV;
   double InitialWindow;
   double InitialLevel;
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::InstallPipeline()
 {
   if (this->RenderWindow && this->Renderer)
@@ -587,14 +578,11 @@ void vtkImageViewer2::InstallPipeline()
     if (!this->InteractorStyle)
     {
       this->InteractorStyle = vtkInteractorStyleImage::New();
-      vtkImageViewer2Callback *cbk = vtkImageViewer2Callback::New();
+      vtkImageViewer2Callback* cbk = vtkImageViewer2Callback::New();
       cbk->IV = this;
-      this->InteractorStyle->AddObserver(
-        vtkCommand::WindowLevelEvent, cbk);
-      this->InteractorStyle->AddObserver(
-        vtkCommand::StartWindowLevelEvent, cbk);
-      this->InteractorStyle->AddObserver(
-        vtkCommand::ResetWindowLevelEvent, cbk);
+      this->InteractorStyle->AddObserver(vtkCommand::WindowLevelEvent, cbk);
+      this->InteractorStyle->AddObserver(vtkCommand::StartWindowLevelEvent, cbk);
+      this->InteractorStyle->AddObserver(vtkCommand::ResetWindowLevelEvent, cbk);
       cbk->Delete();
     }
 
@@ -609,12 +597,11 @@ void vtkImageViewer2::InstallPipeline()
 
   if (this->ImageActor && this->WindowLevel)
   {
-    this->ImageActor->GetMapper()->SetInputConnection(
-      this->WindowLevel->GetOutputPort());
+    this->ImageActor->GetMapper()->SetInputConnection(this->WindowLevel->GetOutputPort());
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::UnInstallPipeline()
 {
   if (this->ImageActor)
@@ -639,19 +626,19 @@ void vtkImageViewer2::UnInstallPipeline()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::Render()
 {
   if (this->FirstRender)
   {
     // Initialize the size if not set yet
 
-    vtkAlgorithm *input = this->GetInputAlgorithm();
+    vtkAlgorithm* input = this->GetInputAlgorithm();
     if (input)
     {
       input->UpdateInformation();
-      int *w_ext = this->GetInputInformation()->Get(
-        vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
+      int* w_ext =
+        this->GetInputInformation()->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
       int xs = 0, ys = 0;
 
       switch (this->SliceOrientation)
@@ -676,15 +663,13 @@ void vtkImageViewer2::Render()
       // if it would be smaller than 150 by 100 then limit to 150 by 100
       if (this->RenderWindow->GetSize()[0] == 0)
       {
-        this->RenderWindow->SetSize(
-          xs < 150 ? 150 : xs, ys < 100 ? 100 : ys);
+        this->RenderWindow->SetSize(xs < 150 ? 150 : xs, ys < 100 ? 100 : ys);
       }
 
       if (this->Renderer)
       {
         this->Renderer->ResetCamera();
-        this->Renderer->GetActiveCamera()->SetParallelScale(
-          xs < 150 ? 75 : (xs - 1 ) / 2.0);
+        this->Renderer->GetActiveCamera()->SetParallelScale(xs < 150 ? 75 : (xs - 1) / 2.0);
       }
       this->FirstRender = 0;
     }
@@ -695,76 +680,77 @@ void vtkImageViewer2::Render()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkImageViewer2::GetWindowName()
 {
   return this->RenderWindow->GetWindowName();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::SetOffScreenRendering(vtkTypeBool i)
 {
   this->RenderWindow->SetOffScreenRendering(i);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkImageViewer2::GetOffScreenRendering()
 {
   return this->RenderWindow->GetOffScreenRendering();
 }
 
-//----------------------------------------------------------------------------
-void vtkImageViewer2::SetInputData(vtkImageData *in)
+//------------------------------------------------------------------------------
+void vtkImageViewer2::SetInputData(vtkImageData* in)
 {
   this->WindowLevel->SetInputData(in);
   this->UpdateDisplayExtent();
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageData* vtkImageViewer2::GetInput()
 {
   return vtkImageData::SafeDownCast(this->WindowLevel->GetInput());
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformation* vtkImageViewer2::GetInputInformation()
 {
   return this->WindowLevel->GetInputInformation();
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAlgorithm* vtkImageViewer2::GetInputAlgorithm()
 {
   return this->WindowLevel->GetInputAlgorithm();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::SetInputConnection(vtkAlgorithmOutput* input)
 {
   this->WindowLevel->SetInputConnection(input);
   this->UpdateDisplayExtent();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageViewer2::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "RenderWindow:\n";
-  this->RenderWindow->PrintSelf(os,indent.GetNextIndent());
+  this->RenderWindow->PrintSelf(os, indent.GetNextIndent());
   os << indent << "Renderer:\n";
-  this->Renderer->PrintSelf(os,indent.GetNextIndent());
+  this->Renderer->PrintSelf(os, indent.GetNextIndent());
   os << indent << "ImageActor:\n";
-  this->ImageActor->PrintSelf(os,indent.GetNextIndent());
+  this->ImageActor->PrintSelf(os, indent.GetNextIndent());
   os << indent << "WindowLevel:\n" << endl;
-  this->WindowLevel->PrintSelf(os,indent.GetNextIndent());
+  this->WindowLevel->PrintSelf(os, indent.GetNextIndent());
   os << indent << "Slice: " << this->Slice << endl;
   os << indent << "SliceOrientation: " << this->SliceOrientation << endl;
   os << indent << "InteractorStyle: " << endl;
   if (this->InteractorStyle)
   {
     os << "\n";
-    this->InteractorStyle->PrintSelf(os,indent.GetNextIndent());
+    this->InteractorStyle->PrintSelf(os, indent.GetNextIndent());
   }
   else
   {
     os << "None";
   }
 }
+VTK_ABI_NAMESPACE_END
