@@ -14,34 +14,34 @@
 =========================================================================*/
 #include "vtkResliceImageViewer.h"
 
+#include "vtkBoundedPlanePointPlacer.h"
 #include "vtkCamera.h"
 #include "vtkCommand.h"
 #include "vtkImageActor.h"
-#include "vtkResliceCursorWidget.h"
-#include "vtkResliceCursorLineRepresentation.h"
-#include "vtkResliceCursorThickLineRepresentation.h"
-#include "vtkResliceCursorActor.h"
-#include "vtkResliceCursorPolyDataAlgorithm.h"
-#include "vtkPlane.h"
-#include "vtkResliceCursor.h"
 #include "vtkImageData.h"
 #include "vtkImageMapToWindowLevelColors.h"
+#include "vtkImageReslice.h"
 #include "vtkInteractorStyleImage.h"
+#include "vtkMath.h"
 #include "vtkObjectFactory.h"
+#include "vtkPlane.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRenderer.h"
-#include "vtkSmartPointer.h"
-#include "vtkImageReslice.h"
-#include "vtkScalarsToColors.h"
-#include "vtkBoundedPlanePointPlacer.h"
-#include "vtkPlane.h"
-#include "vtkMath.h"
+#include "vtkResliceCursor.h"
+#include "vtkResliceCursorActor.h"
+#include "vtkResliceCursorLineRepresentation.h"
+#include "vtkResliceCursorPolyDataAlgorithm.h"
+#include "vtkResliceCursorThickLineRepresentation.h"
+#include "vtkResliceCursorWidget.h"
 #include "vtkResliceImageViewerMeasurements.h"
+#include "vtkScalarsToColors.h"
+#include "vtkSmartPointer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkResliceImageViewer);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This class is used to scroll slices with the scroll bar. In the case of MPR
 // view, it moves one "normalized spacing" in the direction of the normal to
 // the resliced plane, provided the new center will continue to lie within the
@@ -49,10 +49,12 @@ vtkStandardNewMacro(vtkResliceImageViewer);
 class vtkResliceImageViewerScrollCallback : public vtkCommand
 {
 public:
-  static vtkResliceImageViewerScrollCallback *New()
-    { return new vtkResliceImageViewerScrollCallback; }
+  static vtkResliceImageViewerScrollCallback* New()
+  {
+    return new vtkResliceImageViewerScrollCallback;
+  }
 
-  void Execute(vtkObject *, unsigned long ev, void*) override
+  void Execute(vtkObject*, unsigned long ev, void*) override
   {
     if (!this->Viewer->GetSliceScrollOnMouseWheel())
     {
@@ -61,8 +63,7 @@ public:
 
     // Do not process if any modifiers are ON
     if (this->Viewer->GetInteractor()->GetShiftKey() ||
-        this->Viewer->GetInteractor()->GetControlKey() ||
-        this->Viewer->GetInteractor()->GetAltKey())
+      this->Viewer->GetInteractor()->GetControlKey() || this->Viewer->GetInteractor()->GetAltKey())
     {
       return;
     }
@@ -75,11 +76,14 @@ public:
     this->SetAbortFlag(1);
   }
 
-  vtkResliceImageViewerScrollCallback():Viewer(nullptr) {}
-  vtkResliceImageViewer *Viewer;
+  vtkResliceImageViewerScrollCallback()
+    : Viewer(nullptr)
+  {
+  }
+  vtkResliceImageViewer* Viewer;
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkResliceImageViewer::vtkResliceImageViewer()
 {
   // Default is to not use the reslice cursor widget, ie use fast
@@ -90,18 +94,15 @@ vtkResliceImageViewer::vtkResliceImageViewer()
 
   this->ResliceCursorWidget = vtkResliceCursorWidget::New();
 
-  vtkSmartPointer< vtkResliceCursor > resliceCursor =
-    vtkSmartPointer< vtkResliceCursor >::New();
+  vtkSmartPointer<vtkResliceCursor> resliceCursor = vtkSmartPointer<vtkResliceCursor>::New();
   resliceCursor->SetThickMode(0);
   resliceCursor->SetThickness(10, 10, 10);
 
-  vtkSmartPointer< vtkResliceCursorLineRepresentation >
-    resliceCursorRep = vtkSmartPointer<
-      vtkResliceCursorLineRepresentation >::New();
-  resliceCursorRep->GetResliceCursorActor()->
-      GetCursorAlgorithm()->SetResliceCursor(resliceCursor);
-  resliceCursorRep->GetResliceCursorActor()->
-      GetCursorAlgorithm()->SetReslicePlaneNormal(this->SliceOrientation);
+  vtkSmartPointer<vtkResliceCursorLineRepresentation> resliceCursorRep =
+    vtkSmartPointer<vtkResliceCursorLineRepresentation>::New();
+  resliceCursorRep->GetResliceCursorActor()->GetCursorAlgorithm()->SetResliceCursor(resliceCursor);
+  resliceCursorRep->GetResliceCursorActor()->GetCursorAlgorithm()->SetReslicePlaneNormal(
+    this->SliceOrientation);
   this->ResliceCursorWidget->SetRepresentation(resliceCursorRep);
 
   this->PointPlacer = vtkBoundedPlanePointPlacer::New();
@@ -116,7 +117,7 @@ vtkResliceImageViewer::vtkResliceImageViewer()
   this->InstallPipeline();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkResliceImageViewer::~vtkResliceImageViewer()
 {
   this->Measurements->Delete();
@@ -131,76 +132,72 @@ vtkResliceImageViewer::~vtkResliceImageViewer()
   this->ScrollCallback->Delete();
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetThickMode( int t )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetThickMode(int t)
 {
-  vtkSmartPointer< vtkResliceCursor > rc = this->GetResliceCursor();
+  vtkSmartPointer<vtkResliceCursor> rc = this->GetResliceCursor();
 
   if (t == this->GetThickMode())
   {
     return;
   }
 
-  vtkSmartPointer< vtkResliceCursorLineRepresentation >
-    resliceCursorRepOld = vtkResliceCursorLineRepresentation::SafeDownCast(
-                          this->ResliceCursorWidget->GetRepresentation());
-  vtkSmartPointer< vtkResliceCursorLineRepresentation > resliceCursorRepNew;
+  vtkSmartPointer<vtkResliceCursorLineRepresentation> resliceCursorRepOld =
+    vtkResliceCursorLineRepresentation::SafeDownCast(
+      this->ResliceCursorWidget->GetRepresentation());
+  vtkSmartPointer<vtkResliceCursorLineRepresentation> resliceCursorRepNew;
 
   this->GetResliceCursor()->SetThickMode(t);
 
   if (t)
   {
-    resliceCursorRepNew = vtkSmartPointer<
-        vtkResliceCursorThickLineRepresentation >::New();
+    resliceCursorRepNew = vtkSmartPointer<vtkResliceCursorThickLineRepresentation>::New();
   }
   else
   {
-    resliceCursorRepNew = vtkSmartPointer<
-        vtkResliceCursorLineRepresentation >::New();
+    resliceCursorRepNew = vtkSmartPointer<vtkResliceCursorLineRepresentation>::New();
   }
 
   int e = this->ResliceCursorWidget->GetEnabled();
   this->ResliceCursorWidget->SetEnabled(0);
 
-  resliceCursorRepNew->GetResliceCursorActor()->
-      GetCursorAlgorithm()->SetResliceCursor(rc);
-  resliceCursorRepNew->GetResliceCursorActor()->
-      GetCursorAlgorithm()->SetReslicePlaneNormal(this->SliceOrientation);
+  resliceCursorRepNew->GetResliceCursorActor()->GetCursorAlgorithm()->SetResliceCursor(rc);
+  resliceCursorRepNew->GetResliceCursorActor()->GetCursorAlgorithm()->SetReslicePlaneNormal(
+    this->SliceOrientation);
   this->ResliceCursorWidget->SetRepresentation(resliceCursorRepNew);
   resliceCursorRepNew->SetLookupTable(resliceCursorRepOld->GetLookupTable());
 
   resliceCursorRepNew->SetWindowLevel(
-      resliceCursorRepOld->GetWindow(),
-      resliceCursorRepOld->GetLevel(), 1);
+    resliceCursorRepOld->GetWindow(), resliceCursorRepOld->GetLevel(), 1);
 
   this->ResliceCursorWidget->SetEnabled(e);
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetResliceCursor( vtkResliceCursor * rc )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetResliceCursor(vtkResliceCursor* rc)
 {
-  vtkResliceCursorRepresentation *rep =
-    vtkResliceCursorRepresentation::SafeDownCast(
-          this->GetResliceCursorWidget()->GetRepresentation());
+  vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+    this->GetResliceCursorWidget()->GetRepresentation());
   rep->GetCursorAlgorithm()->SetResliceCursor(rc);
 
   // Rehook the observer to this reslice cursor.
   this->Measurements->SetResliceImageViewer(this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkResliceImageViewer::GetThickMode()
 {
-  return (vtkResliceCursorThickLineRepresentation::
-    SafeDownCast(this->ResliceCursorWidget->GetRepresentation())) ? 1 : 0;
+  return (vtkResliceCursorThickLineRepresentation::SafeDownCast(
+           this->ResliceCursorWidget->GetRepresentation()))
+    ? 1
+    : 0;
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetLookupTable( vtkScalarsToColors * l )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetLookupTable(vtkScalarsToColors* l)
 {
-  if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
-          this->ResliceCursorWidget->GetRepresentation()))
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+        this->ResliceCursorWidget->GetRepresentation()))
   {
     rep->SetLookupTable(l);
   }
@@ -213,12 +210,11 @@ void vtkResliceImageViewer::SetLookupTable( vtkScalarsToColors * l )
   }
 }
 
-//----------------------------------------------------------------------------
-vtkScalarsToColors * vtkResliceImageViewer::GetLookupTable()
+//------------------------------------------------------------------------------
+vtkScalarsToColors* vtkResliceImageViewer::GetLookupTable()
 {
-  if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
-          this->ResliceCursorWidget->GetRepresentation()))
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+        this->ResliceCursorWidget->GetRepresentation()))
   {
     return rep->GetLookupTable();
   }
@@ -226,38 +222,38 @@ vtkScalarsToColors * vtkResliceImageViewer::GetLookupTable()
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::UpdateOrientation()
 {
-    // Set the camera position
+  // Set the camera position
 
-    vtkCamera *cam = this->Renderer ? this->Renderer->GetActiveCamera() : nullptr;
-    if (cam)
+  vtkCamera* cam = this->Renderer ? this->Renderer->GetActiveCamera() : nullptr;
+  if (cam)
+  {
+    switch (this->SliceOrientation)
     {
-      switch (this->SliceOrientation)
-      {
-        case vtkImageViewer2::SLICE_ORIENTATION_XY:
-          cam->SetFocalPoint(0,0,0);
-          cam->SetPosition(0,0,1); // -1 if medical ?
-          cam->SetViewUp(0,1,0);
-          break;
+      case vtkImageViewer2::SLICE_ORIENTATION_XY:
+        cam->SetFocalPoint(0, 0, 0);
+        cam->SetPosition(0, 0, 1); // -1 if medical ?
+        cam->SetViewUp(0, 1, 0);
+        break;
 
-        case vtkImageViewer2::SLICE_ORIENTATION_XZ:
-          cam->SetFocalPoint(0,0,0);
-          cam->SetPosition(0,-1,0); // 1 if medical ?
-          cam->SetViewUp(0,0,1);
-          break;
+      case vtkImageViewer2::SLICE_ORIENTATION_XZ:
+        cam->SetFocalPoint(0, 0, 0);
+        cam->SetPosition(0, -1, 0); // 1 if medical ?
+        cam->SetViewUp(0, 0, 1);
+        break;
 
-        case vtkImageViewer2::SLICE_ORIENTATION_YZ:
-          cam->SetFocalPoint(0,0,0);
-          cam->SetPosition(1,0,0); // -1 if medical ?
-          cam->SetViewUp(0,0,1);
-          break;
-      }
+      case vtkImageViewer2::SLICE_ORIENTATION_YZ:
+        cam->SetFocalPoint(0, 0, 0);
+        cam->SetPosition(1, 0, 0); // -1 if medical ?
+        cam->SetViewUp(0, 0, 1);
+        break;
     }
+  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::UpdateDisplayExtent()
 {
   // Only update the display extent in axis aligned mode
@@ -268,7 +264,7 @@ void vtkResliceImageViewer::UpdateDisplayExtent()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::InstallPipeline()
 {
   this->Superclass::InstallPipeline();
@@ -280,16 +276,14 @@ void vtkResliceImageViewer::InstallPipeline()
     // Observe the scroll for slice manipulation at a higher priority
     // than the interactor style.
     this->Interactor->RemoveObserver(this->ScrollCallback);
-    this->Interactor->AddObserver(vtkCommand::MouseWheelForwardEvent,
-        this->ScrollCallback, 0.55 );
-    this->Interactor->AddObserver(vtkCommand::MouseWheelBackwardEvent,
-        this->ScrollCallback, 0.55 );
+    this->Interactor->AddObserver(vtkCommand::MouseWheelForwardEvent, this->ScrollCallback, 0.55);
+    this->Interactor->AddObserver(vtkCommand::MouseWheelBackwardEvent, this->ScrollCallback, 0.55);
   }
 
   if (this->Renderer)
   {
     this->ResliceCursorWidget->SetDefaultRenderer(this->Renderer);
-    vtkCamera *cam = this->Renderer->GetActiveCamera();
+    vtkCamera* cam = this->Renderer->GetActiveCamera();
     cam->ParallelProjectionOn();
   }
 
@@ -299,20 +293,18 @@ void vtkResliceImageViewer::InstallPipeline()
     this->ImageActor->SetVisibility(0);
     this->UpdateOrientation();
 
-    double bounds[6] = {0, 1, 0, 1, 0, 1};
+    double bounds[6] = { 0, 1, 0, 1, 0, 1 };
 
-    vtkCamera *cam = this->Renderer->GetActiveCamera();
-    double onespacing[3] = {1, 1, 1};
-    double *spacing = onespacing;
+    vtkCamera* cam = this->Renderer->GetActiveCamera();
+    double onespacing[3] = { 1, 1, 1 };
+    double* spacing = onespacing;
     if (this->GetResliceCursor()->GetImage())
     {
       this->GetResliceCursor()->GetImage()->GetBounds(bounds);
       spacing = this->GetResliceCursor()->GetImage()->GetSpacing();
     }
-    double avg_spacing =
-      (spacing[0] + spacing[1] + spacing[2]) / 3.0;
-    cam->SetClippingRange(
-      bounds[this->SliceOrientation * 2] - 100 * avg_spacing,
+    double avg_spacing = (spacing[0] + spacing[1] + spacing[2]) / 3.0;
+    cam->SetClippingRange(bounds[this->SliceOrientation * 2] - 100 * avg_spacing,
       bounds[this->SliceOrientation * 2 + 1] + 100 * avg_spacing);
   }
   else
@@ -328,7 +320,7 @@ void vtkResliceImageViewer::InstallPipeline()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::UnInstallPipeline()
 {
   this->ResliceCursorWidget->SetEnabled(0);
@@ -341,19 +333,17 @@ void vtkResliceImageViewer::UnInstallPipeline()
   this->Superclass::UnInstallPipeline();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::UpdatePointPlacer()
 {
   if (this->ResliceMode == RESLICE_OBLIQUE)
   {
     this->PointPlacer->SetProjectionNormalToOblique();
-    if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
+    if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
     {
-      const int planeOrientation =
-        rep->GetCursorAlgorithm()->GetReslicePlaneNormal();
-      vtkPlane *plane = this->GetResliceCursor()->GetPlane(planeOrientation);
+      const int planeOrientation = rep->GetCursorAlgorithm()->GetReslicePlaneNormal();
+      vtkPlane* plane = this->GetResliceCursor()->GetPlane(planeOrientation);
       this->PointPlacer->SetObliquePlane(plane);
     }
   }
@@ -365,8 +355,8 @@ void vtkResliceImageViewer::UpdatePointPlacer()
       return;
     }
 
-    vtkImageData *input = this->ImageActor->GetInput();
-    if ( !input )
+    vtkImageData* input = this->ImageActor->GetInput();
+    if (!input)
     {
       return;
     }
@@ -385,29 +375,28 @@ void vtkResliceImageViewer::UpdatePointPlacer()
 
     int axis = vtkBoundedPlanePointPlacer::XAxis;
     double position = 0.0;
-    if ( displayExtent[0] == displayExtent[1] )
+    if (displayExtent[0] == displayExtent[1])
     {
       axis = vtkBoundedPlanePointPlacer::XAxis;
-      position = origin[0] + displayExtent[0]*spacing[0];
+      position = origin[0] + displayExtent[0] * spacing[0];
     }
-    else if ( displayExtent[2] == displayExtent[3] )
+    else if (displayExtent[2] == displayExtent[3])
     {
       axis = vtkBoundedPlanePointPlacer::YAxis;
-      position = origin[1] + displayExtent[2]*spacing[1];
+      position = origin[1] + displayExtent[2] * spacing[1];
     }
-    else if ( displayExtent[4] == displayExtent[5] )
+    else if (displayExtent[4] == displayExtent[5])
     {
       axis = vtkBoundedPlanePointPlacer::ZAxis;
-      position = origin[2] + displayExtent[4]*spacing[2];
+      position = origin[2] + displayExtent[4] * spacing[2];
     }
 
     this->PointPlacer->SetProjectionNormal(axis);
     this->PointPlacer->SetProjectionPosition(position);
   }
-
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::Render()
 {
   if (!this->WindowLevel->GetInput())
@@ -420,12 +409,11 @@ void vtkResliceImageViewer::Render()
   this->Superclass::Render();
 }
 
-//----------------------------------------------------------------------------
-vtkResliceCursor * vtkResliceImageViewer::GetResliceCursor()
+//------------------------------------------------------------------------------
+vtkResliceCursor* vtkResliceImageViewer::GetResliceCursor()
 {
-  if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
-          this->ResliceCursorWidget->GetRepresentation()))
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+        this->ResliceCursorWidget->GetRepresentation()))
   {
     return rep->GetResliceCursor();
   }
@@ -433,10 +421,10 @@ vtkResliceCursor * vtkResliceImageViewer::GetResliceCursor()
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetInputData(vtkImageData *in)
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetInputData(vtkImageData* in)
 {
-  if(!in)
+  if (!in)
   {
     return;
   }
@@ -448,31 +436,29 @@ void vtkResliceImageViewer::SetInputData(vtkImageData *in)
 
   double range[2];
   in->GetScalarRange(range);
-  if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
-          this->ResliceCursorWidget->GetRepresentation()))
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+        this->ResliceCursorWidget->GetRepresentation()))
   {
-    if (vtkImageReslice *reslice =
-        vtkImageReslice::SafeDownCast(rep->GetReslice()))
+    if (vtkImageReslice* reslice = vtkImageReslice::SafeDownCast(rep->GetReslice()))
     {
       // default background color is the min value of the image scalar range
-      reslice->SetBackgroundColor(range[0],range[0],range[0],range[0]);
-      this->SetColorWindow(range[1]-range[0]);
-      this->SetColorLevel((range[0]+range[1])/2.0);
+      reslice->SetBackgroundColor(range[0], range[0], range[0], range[0]);
+      this->SetColorWindow(range[1] - range[0]);
+      this->SetColorLevel((range[0] + range[1]) / 2.0);
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::SetInputConnection(vtkAlgorithmOutput* input)
 {
-  vtkErrorMacro( << "Use SetInputData instead. " );
+  vtkErrorMacro(<< "Use SetInputData instead. ");
   this->WindowLevel->SetInputConnection(input);
   this->UpdateDisplayExtent();
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetResliceMode( int r )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetResliceMode(int r)
 {
   if (r == this->ResliceMode)
   {
@@ -485,67 +471,63 @@ void vtkResliceImageViewer::SetResliceMode( int r )
   this->InstallPipeline();
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetColorWindow( double w )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetColorWindow(double w)
 {
-  double rmin = this->GetColorLevel() - 0.5*fabs( w );
-  double rmax = rmin + fabs( w );
-  this->GetLookupTable()->SetRange( rmin, rmax );
+  double rmin = this->GetColorLevel() - 0.5 * fabs(w);
+  double rmax = rmin + fabs(w);
+  this->GetLookupTable()->SetRange(rmin, rmax);
 
   this->WindowLevel->SetWindow(w);
-  if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
-          this->ResliceCursorWidget->GetRepresentation()))
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+        this->ResliceCursorWidget->GetRepresentation()))
   {
     rep->SetWindowLevel(w, rep->GetLevel(), 1);
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::SetColorLevel( double w )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::SetColorLevel(double w)
 {
-  double rmin = w - 0.5*fabs( this->GetColorWindow() );
-  double rmax = rmin + fabs( this->GetColorWindow() );
-  this->GetLookupTable()->SetRange( rmin, rmax );
+  double rmin = w - 0.5 * fabs(this->GetColorWindow());
+  double rmax = rmin + fabs(this->GetColorWindow());
+  this->GetLookupTable()->SetRange(rmin, rmax);
 
   this->WindowLevel->SetLevel(w);
-  if (vtkResliceCursorRepresentation *rep =
-        vtkResliceCursorRepresentation::SafeDownCast(
-          this->ResliceCursorWidget->GetRepresentation()))
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
+        this->ResliceCursorWidget->GetRepresentation()))
   {
     rep->SetWindowLevel(rep->GetWindow(), w, 1);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::Reset()
 {
   this->ResliceCursorWidget->ResetResliceCursor();
 }
 
-//----------------------------------------------------------------------------
-vtkPlane * vtkResliceImageViewer::GetReslicePlane()
+//------------------------------------------------------------------------------
+vtkPlane* vtkResliceImageViewer::GetReslicePlane()
 {
   // Get the reslice plane
-  if (vtkResliceCursorRepresentation *rep =
-      vtkResliceCursorRepresentation::SafeDownCast(
+  if (vtkResliceCursorRepresentation* rep = vtkResliceCursorRepresentation::SafeDownCast(
         this->ResliceCursorWidget->GetRepresentation()))
   {
-    const int planeOrientation =
-      rep->GetCursorAlgorithm()->GetReslicePlaneNormal();
-    vtkPlane *plane = this->GetResliceCursor()->GetPlane(planeOrientation);
+    const int planeOrientation = rep->GetCursorAlgorithm()->GetReslicePlaneNormal();
+    vtkPlane* plane = this->GetResliceCursor()->GetPlane(planeOrientation);
     return plane;
   }
 
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkResliceImageViewer::GetInterSliceSpacingInResliceMode()
 {
   double n[3], imageSpacing[3], resliceSpacing = 0;
 
-  if (vtkPlane *plane = this->GetReslicePlane())
+  if (vtkPlane* plane = this->GetReslicePlane())
   {
     plane->GetNormal(n);
     this->GetResliceCursor()->GetImage()->GetSpacing(imageSpacing);
@@ -555,28 +537,27 @@ double vtkResliceImageViewer::GetInterSliceSpacingInResliceMode()
   return resliceSpacing;
 }
 
-//----------------------------------------------------------------------------
-void vtkResliceImageViewer::IncrementSlice( int inc )
+//------------------------------------------------------------------------------
+void vtkResliceImageViewer::IncrementSlice(int inc)
 {
-  if (this->GetResliceMode() ==
-      vtkResliceImageViewer::RESLICE_AXIS_ALIGNED)
+  if (this->GetResliceMode() == vtkResliceImageViewer::RESLICE_AXIS_ALIGNED)
   {
     int oldSlice = this->GetSlice();
-    this->SetSlice(this->GetSlice() + inc);
+    this->SetSlice(this->GetSlice() + static_cast<int>(std::round(inc * this->SliceScrollFactor)));
     if (this->GetSlice() != oldSlice)
     {
-      this->InvokeEvent( vtkResliceImageViewer::SliceChangedEvent, nullptr );
-      this->InvokeEvent( vtkCommand::InteractionEvent, nullptr );
+      this->InvokeEvent(vtkResliceImageViewer::SliceChangedEvent, nullptr);
+      this->InvokeEvent(vtkCommand::InteractionEvent, nullptr);
     }
   }
   else
   {
-    if (vtkPlane *p = this->GetReslicePlane())
+    if (vtkPlane* p = this->GetReslicePlane())
     {
       double n[3], c[3], bounds[6];
       p->GetNormal(n);
       const double spacing =
-          this->GetInterSliceSpacingInResliceMode() * inc;
+        this->GetInterSliceSpacingInResliceMode() * inc * this->SliceScrollFactor;
       this->GetResliceCursor()->GetCenter(c);
       vtkMath::MultiplyScalar(n, spacing);
       c[0] += n[0];
@@ -584,39 +565,40 @@ void vtkResliceImageViewer::IncrementSlice( int inc )
       c[2] += n[2];
 
       // If the new center is inside, put it there...
-      if (vtkImageData *image = this->GetResliceCursor()->GetImage())
+      if (vtkImageData* image = this->GetResliceCursor()->GetImage())
       {
         image->GetBounds(bounds);
-        if (c[0] >= bounds[0] && c[0] <= bounds[1] &&
-            c[1] >= bounds[2] && c[1] <= bounds[3] &&
-            c[2] >= bounds[4] && c[2] <= bounds[5])
+        if (c[0] >= bounds[0] && c[0] <= bounds[1] && c[1] >= bounds[2] && c[1] <= bounds[3] &&
+          c[2] >= bounds[4] && c[2] <= bounds[5])
         {
           this->GetResliceCursor()->SetCenter(c);
 
-          this->InvokeEvent( vtkResliceImageViewer::SliceChangedEvent, nullptr );
-          this->InvokeEvent( vtkCommand::InteractionEvent, nullptr );
+          this->InvokeEvent(vtkResliceImageViewer::SliceChangedEvent, nullptr);
+          this->InvokeEvent(vtkCommand::InteractionEvent, nullptr);
         }
       }
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkResliceImageViewer::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "ResliceCursorWidget:\n";
-  this->ResliceCursorWidget->PrintSelf(os,indent.GetNextIndent());
+  this->ResliceCursorWidget->PrintSelf(os, indent.GetNextIndent());
   os << indent << "ResliceMode: " << this->ResliceMode << endl;
   os << indent << "SliceScrollOnMouseWheel: " << this->SliceScrollOnMouseWheel << endl;
+  os << indent << "SliceScrollFactor: " << this->SliceScrollFactor << endl;
   os << indent << "Point Placer: ";
-  this->PointPlacer->PrintSelf(os,indent.GetNextIndent());
+  this->PointPlacer->PrintSelf(os, indent.GetNextIndent());
   os << indent << "Measurements: ";
-  this->Measurements->PrintSelf(os,indent.GetNextIndent());
+  this->Measurements->PrintSelf(os, indent.GetNextIndent());
   os << indent << "Interactor: " << this->Interactor << "\n";
   if (this->Interactor)
   {
-    this->Interactor->PrintSelf(os,indent.GetNextIndent());
+    this->Interactor->PrintSelf(os, indent.GetNextIndent());
   }
 }
+VTK_ABI_NAMESPACE_END
