@@ -33,6 +33,7 @@
 #include "vtkImageViewer2.h"
 #include "vtkInteractionImageModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkResliceCursorWidget;
 class vtkResliceCursor;
 class vtkScalarsToColors;
@@ -44,43 +45,43 @@ class vtkPlane;
 class VTKINTERACTIONIMAGE_EXPORT vtkResliceImageViewer : public vtkImageViewer2
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard VTK methods.
    */
   static vtkResliceImageViewer* New();
   vtkTypeMacro(vtkResliceImageViewer, vtkImageViewer2);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Render the resulting image.
    */
   void Render() override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the input image to the viewer.
    */
   void SetInputData(vtkImageData* in) override;
   void SetInputConnection(vtkAlgorithmOutput* input) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set window and level for mapping pixels to colors.
    */
   void SetColorWindow(double s) override;
   void SetColorLevel(double s) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the internal render window, renderer, image actor, and
    * image map instances.
    */
   vtkGetObjectMacro(ResliceCursorWidget, vtkResliceCursorWidget);
-  //@}
+  ///@}
 
   /**
    * Set/get the slice orientation
@@ -103,57 +104,57 @@ public:
     this->SetResliceMode(vtkResliceImageViewer::RESLICE_OBLIQUE);
   }
 
-  //@{
+  ///@{
   /**
    * Set/Get the reslice cursor.
    */
   vtkResliceCursor* GetResliceCursor();
   void SetResliceCursor(vtkResliceCursor* rc);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the lookup table
    */
   virtual void SetLookupTable(vtkScalarsToColors*);
   vtkScalarsToColors* GetLookupTable();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Switch to / from thick mode
    */
   virtual void SetThickMode(int);
   virtual int GetThickMode();
-  //@}
+  ///@}
 
   /**
    * Reset all views back to initial state
    */
   virtual void Reset();
 
-  //@{
+  ///@{
   /**
    * Get the point placer.
    */
   vtkGetObjectMacro(PointPlacer, vtkBoundedPlanePointPlacer);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the measurements manager
    */
   vtkGetObjectMacro(Measurements, vtkResliceImageViewerMeasurements);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the render window interactor
    */
   vtkGetObjectMacro(Interactor, vtkRenderWindowInteractor);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Scroll slices on the mouse wheel ? In the case of MPR
    * view, it moves one "normalized spacing" in the direction of the normal to
@@ -163,7 +164,20 @@ public:
   vtkSetMacro(SliceScrollOnMouseWheel, vtkTypeBool);
   vtkGetMacro(SliceScrollOnMouseWheel, vtkTypeBool);
   vtkBooleanMacro(SliceScrollOnMouseWheel, vtkTypeBool);
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * Define a factor that will be applied in addition to the inter slice spacing when scrolling
+   * image. When the view is in axis aligned ResliceMode, and the factor is not an integer,
+   * then the new value of the slice will be rounded. Otherwise, the factor is applied
+   * normally. Default value is 1.0.
+   * Note that in axis aligned ResliceMode, the factor is applied in local coordinate (i, j, k),
+   * whereas in oblique ResliceMode, the factor is applied in world coordinate (x, y, z)
+   */
+  vtkSetMacro(SliceScrollFactor, double);
+  vtkGetMacro(SliceScrollFactor, double);
+  ///@}
 
   /**
    * Increment/Decrement slice by 'inc' slices
@@ -185,14 +199,14 @@ protected:
   void UpdateDisplayExtent() override;
   virtual void UpdatePointPlacer();
 
-  //@{
+  ///@{
   /**
    * Convenience methods to get the reslice plane and the normalized
    * spacing between slices in reslice mode.
    */
   vtkPlane* GetReslicePlane();
   double GetInterSliceSpacingInResliceMode();
-  //@}
+  ///@}
 
   vtkResliceCursorWidget* ResliceCursorWidget;
   vtkBoundedPlanePointPlacer* PointPlacer;
@@ -200,10 +214,12 @@ protected:
   vtkResliceImageViewerMeasurements* Measurements;
   vtkTypeBool SliceScrollOnMouseWheel;
   vtkResliceImageViewerScrollCallback* ScrollCallback;
+  double SliceScrollFactor = 1.0;
 
 private:
   vtkResliceImageViewer(const vtkResliceImageViewer&) = delete;
   void operator=(const vtkResliceImageViewer&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
