@@ -14,8 +14,8 @@
 =========================================================================*/
 #include "vtkInteractorStyleMultiTouchCamera.h"
 
-#include "vtkCamera.h"
 #include "vtkCallbackCommand.h"
+#include "vtkCamera.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPlane.h"
@@ -24,21 +24,22 @@
 #include "vtkRenderer.h"
 #include "vtkTransform.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInteractorStyleMultiTouchCamera);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleMultiTouchCamera::vtkInteractorStyleMultiTouchCamera() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleMultiTouchCamera::~vtkInteractorStyleMultiTouchCamera() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnStartRotate()
 {
   this->StartGesture();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnRotate()
 {
   if (this->State != VTKIS_GESTURE)
@@ -49,38 +50,38 @@ void vtkInteractorStyleMultiTouchCamera::OnRotate()
   int pointer = this->Interactor->GetPointerIndex();
 
   this->FindPokedRenderer(this->Interactor->GetEventPositions(pointer)[0],
-                          this->Interactor->GetEventPositions(pointer)[1]);
+    this->Interactor->GetEventPositions(pointer)[1]);
 
-  if ( this->CurrentRenderer == nullptr )
+  if (this->CurrentRenderer == nullptr)
   {
     return;
   }
 
-  vtkCamera *camera = this->CurrentRenderer->GetActiveCamera();
+  vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
 
-  int *pinchPositionDisplay = this->Interactor->GetEventPositions(pointer);
+  int* pinchPositionDisplay = this->Interactor->GetEventPositions(pointer);
 
   // Calculate the focal depth since we'll be using it a lot
   double viewFocus[4];
   camera->GetFocalPoint(viewFocus);
-  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2],
-    viewFocus);
+  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2], viewFocus);
   double focalDepth = viewFocus[2];
 
-  double oldPickPoint[4] = { 0,0,0,0 };
-  vtkInteractorObserver::ComputeDisplayToWorld(this->CurrentRenderer, pinchPositionDisplay[0], pinchPositionDisplay[1], focalDepth, oldPickPoint);
+  double oldPickPoint[4] = { 0, 0, 0, 0 };
+  vtkInteractorObserver::ComputeDisplayToWorld(this->CurrentRenderer, pinchPositionDisplay[0],
+    pinchPositionDisplay[1], focalDepth, oldPickPoint);
 
   camera->Roll(this->Interactor->GetRotation() - this->Interactor->GetLastRotation());
 
   camera->GetFocalPoint(viewFocus);
-  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2],
-    viewFocus);
+  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2], viewFocus);
   focalDepth = viewFocus[2];
 
-  double newPickPoint[4] = { 0,0,0,0 };
-  vtkInteractorObserver::ComputeDisplayToWorld(this->CurrentRenderer, pinchPositionDisplay[0], pinchPositionDisplay[1], focalDepth, newPickPoint);
+  double newPickPoint[4] = { 0, 0, 0, 0 };
+  vtkInteractorObserver::ComputeDisplayToWorld(this->CurrentRenderer, pinchPositionDisplay[0],
+    pinchPositionDisplay[1], focalDepth, newPickPoint);
 
-  double motionVector[3] = { 0,0,0 };
+  double motionVector[3] = { 0, 0, 0 };
   vtkMath::Subtract(oldPickPoint, newPickPoint, motionVector);
 
   vtkNew<vtkTransform> cameraTransform;
@@ -93,19 +94,19 @@ void vtkInteractorStyleMultiTouchCamera::OnRotate()
   this->Interactor->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnEndRotate()
 {
   this->EndGesture();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnStartPinch()
 {
   this->StartGesture();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnPinch()
 {
   if (this->State != VTKIS_GESTURE)
@@ -116,31 +117,28 @@ void vtkInteractorStyleMultiTouchCamera::OnPinch()
   int pointer = this->Interactor->GetPointerIndex();
 
   this->FindPokedRenderer(this->Interactor->GetEventPositions(pointer)[0],
-                          this->Interactor->GetEventPositions(pointer)[1]);
+    this->Interactor->GetEventPositions(pointer)[1]);
 
-  if ( this->CurrentRenderer == nullptr )
+  if (this->CurrentRenderer == nullptr)
   {
     return;
   }
 
-  vtkCamera *camera = this->CurrentRenderer->GetActiveCamera();
+  vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
 
-  int *pinchPositionDisplay = this->Interactor->GetEventPositions(pointer);
+  int* pinchPositionDisplay = this->Interactor->GetEventPositions(pointer);
 
   // Calculate the focal depth since we'll be using it a lot
   double viewFocus[4], focalDepth;
   camera->GetFocalPoint(viewFocus);
-  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2],
-    viewFocus);
+  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2], viewFocus);
   focalDepth = viewFocus[2];
 
   // Remember the position of the center of the pinch in world coordinates
   // This position should stay in the same location on the screen after the dolly has been performed
-  double oldPickPoint[4] = { 0,0,0,0 };
-  this->ComputeDisplayToWorld(pinchPositionDisplay[0],
-                              pinchPositionDisplay[1],
-                              focalDepth,
-                              oldPickPoint);
+  double oldPickPoint[4] = { 0, 0, 0, 0 };
+  this->ComputeDisplayToWorld(
+    pinchPositionDisplay[0], pinchPositionDisplay[1], focalDepth, oldPickPoint);
 
   double dyf = this->Interactor->GetScale() / this->Interactor->GetLastScale();
   if (camera->GetParallelProjection())
@@ -157,19 +155,16 @@ void vtkInteractorStyleMultiTouchCamera::OnPinch()
   }
 
   camera->GetFocalPoint(viewFocus);
-  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2],
-    viewFocus);
+  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2], viewFocus);
   focalDepth = viewFocus[2];
 
   // New position at the center of the pinch gesture
-  double newPickPoint[4] = { 0,0,0,0 };
-  this->ComputeDisplayToWorld(pinchPositionDisplay[0],
-                              pinchPositionDisplay[1],
-                              focalDepth,
-                              newPickPoint);
+  double newPickPoint[4] = { 0, 0, 0, 0 };
+  this->ComputeDisplayToWorld(
+    pinchPositionDisplay[0], pinchPositionDisplay[1], focalDepth, newPickPoint);
 
   // Determine how far the pinch center has been shifted from it's original location
-  double motionVector[4] = { 0,0,0 };
+  double motionVector[4] = { 0, 0, 0 };
   vtkMath::Subtract(oldPickPoint, newPickPoint, motionVector);
 
   // Translate the camera to compensate for the shift of the pinch center
@@ -185,19 +180,19 @@ void vtkInteractorStyleMultiTouchCamera::OnPinch()
   this->Interactor->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnEndPinch()
 {
   this->EndGesture();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnStartPan()
 {
   this->StartGesture();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnPan()
 {
   if (this->State != VTKIS_GESTURE)
@@ -208,15 +203,15 @@ void vtkInteractorStyleMultiTouchCamera::OnPan()
   int pointer = this->Interactor->GetPointerIndex();
 
   this->FindPokedRenderer(this->Interactor->GetEventPositions(pointer)[0],
-                          this->Interactor->GetEventPositions(pointer)[1]);
+    this->Interactor->GetEventPositions(pointer)[1]);
 
-  if ( this->CurrentRenderer == nullptr )
+  if (this->CurrentRenderer == nullptr)
   {
     return;
   }
 
-  vtkCamera *camera = this->CurrentRenderer->GetActiveCamera();
-  vtkRenderWindowInteractor *rwi = this->Interactor;
+  vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
+  vtkRenderWindowInteractor* rwi = this->Interactor;
 
   // handle panning - 2 DOF
   double viewFocus[4], focalDepth, viewPoint[3];
@@ -224,22 +219,16 @@ void vtkInteractorStyleMultiTouchCamera::OnPan()
 
   // Calculate the focal depth since we'll be using it a lot
   camera->GetFocalPoint(viewFocus);
-  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2],
-                              viewFocus);
+  this->ComputeWorldToDisplay(viewFocus[0], viewFocus[1], viewFocus[2], viewFocus);
   focalDepth = viewFocus[2];
 
-  double *trans = this->Interactor->GetTranslation();
-  this->ComputeDisplayToWorld(viewFocus[0] + trans[0],
-                              viewFocus[1] + trans[1],
-                              focalDepth,
-                              newPickPoint);
+  double* trans = this->Interactor->GetTranslation();
+  this->ComputeDisplayToWorld(
+    viewFocus[0] + trans[0], viewFocus[1] + trans[1], focalDepth, newPickPoint);
 
   // Has to recalc old mouse point since the viewport has moved,
   // so can't move it outside the loop
-  this->ComputeDisplayToWorld(viewFocus[0],
-                              viewFocus[1],
-                              focalDepth,
-                              oldPickPoint);
+  this->ComputeDisplayToWorld(viewFocus[0], viewFocus[1], focalDepth, oldPickPoint);
 
   // Camera motion is reversed
   motionVector[0] = oldPickPoint[0] - newPickPoint[0];
@@ -248,13 +237,11 @@ void vtkInteractorStyleMultiTouchCamera::OnPan()
 
   camera->GetFocalPoint(viewFocus);
   camera->GetPosition(viewPoint);
-  camera->SetFocalPoint(motionVector[0] + viewFocus[0],
-                        motionVector[1] + viewFocus[1],
-                        motionVector[2] + viewFocus[2]);
+  camera->SetFocalPoint(
+    motionVector[0] + viewFocus[0], motionVector[1] + viewFocus[1], motionVector[2] + viewFocus[2]);
 
-  camera->SetPosition(motionVector[0] + viewPoint[0],
-                      motionVector[1] + viewPoint[1],
-                      motionVector[2] + viewPoint[2]);
+  camera->SetPosition(
+    motionVector[0] + viewPoint[0], motionVector[1] + viewPoint[1], motionVector[2] + viewPoint[2]);
 
   // clean up
   if (this->Interactor->GetLightFollowCamera())
@@ -266,14 +253,15 @@ void vtkInteractorStyleMultiTouchCamera::OnPan()
   rwi->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::OnEndPan()
 {
   this->EndGesture();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleMultiTouchCamera::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
