@@ -23,23 +23,25 @@
  * @sa
  * vtkInteractorStyleTrackballActor vtkInteractorStyleJoystickCamera
  * vtkInteractorStyleJoystickActor
-*/
+ */
 
 #ifndef vtkInteractorStyleMultiTouchCamera_h
 #define vtkInteractorStyleMultiTouchCamera_h
 
 #include "vtkInteractionStyleModule.h" // For export macro
-#include "vtkRenderWindowInteractor.h" // for max pointers
 #include "vtkInteractorStyleTrackballCamera.h"
+#include "vtkRenderWindowInteractor.h" // for max pointers
 
-class VTKINTERACTIONSTYLE_EXPORT vtkInteractorStyleMultiTouchCamera : public vtkInteractorStyleTrackballCamera
+VTK_ABI_NAMESPACE_BEGIN
+class VTKINTERACTIONSTYLE_EXPORT vtkInteractorStyleMultiTouchCamera
+  : public vtkInteractorStyleTrackballCamera
 {
 public:
-  static vtkInteractorStyleMultiTouchCamera *New();
-  vtkTypeMacro(vtkInteractorStyleMultiTouchCamera,vtkInteractorStyleTrackballCamera);
+  static vtkInteractorStyleMultiTouchCamera* New();
+  vtkTypeMacro(vtkInteractorStyleMultiTouchCamera, vtkInteractorStyleTrackballCamera);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Event bindings for gestures
    */
@@ -53,7 +55,7 @@ public:
   void OnPan() override;
   void OnEndPan() override;
 
-  //@}
+  ///@}
 
 protected:
   vtkInteractorStyleMultiTouchCamera();
@@ -64,4 +66,5 @@ private:
   void operator=(const vtkInteractorStyleMultiTouchCamera&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
