@@ -24,14 +24,15 @@
 #include "vtkCamera.h"
 #include "vtkCommand.h"
 #include "vtkObjectFactory.h"
-#include "vtkRenderer.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInteractorStyleRubberBand2D);
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleRubberBand2D::vtkInteractorStyleRubberBand2D()
 {
   this->PixelArray = vtkUnsignedCharArray::New();
@@ -43,16 +44,16 @@ vtkInteractorStyleRubberBand2D::vtkInteractorStyleRubberBand2D()
   this->EndPosition[1] = 0;
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleRubberBand2D::~vtkInteractorStyleRubberBand2D()
 {
   this->PixelArray->Delete();
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnLeftButtonDown()
 {
-  if(this->Interaction == NONE)
+  if (this->Interaction == NONE)
   {
     if (this->Interactor->GetAltKey())
     {
@@ -61,7 +62,7 @@ void vtkInteractorStyleRubberBand2D::OnLeftButtonDown()
     else
     {
       this->Interaction = SELECTING;
-      vtkRenderWindow *renWin = this->Interactor->GetRenderWindow();
+      vtkRenderWindow* renWin = this->Interactor->GetRenderWindow();
 
       this->StartPosition[0] = this->Interactor->GetEventPosition()[0];
       this->StartPosition[1] = this->Interactor->GetEventPosition()[1];
@@ -70,27 +71,28 @@ void vtkInteractorStyleRubberBand2D::OnLeftButtonDown()
 
       this->PixelArray->Initialize();
       this->PixelArray->SetNumberOfComponents(4);
-      int *size = renWin->GetSize();
-      this->PixelArray->SetNumberOfTuples(size[0]*size[1]);
+      const int* size = renWin->GetSize();
+      this->PixelArray->SetNumberOfTuples(size[0] * size[1]);
 
-      renWin->GetRGBACharPixelData(0, 0, size[0]-1, size[1]-1, 1, this->PixelArray);
+      renWin->GetRGBACharPixelData(0, 0, size[0] - 1, size[1] - 1, 1, this->PixelArray);
     }
     this->FindPokedRenderer(this->StartPosition[0], this->StartPosition[1]);
     this->InvokeEvent(vtkCommand::StartInteractionEvent);
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnLeftButtonUp()
 {
-  if(this->Interaction == SELECTING)
+  if (this->Interaction == SELECTING)
   {
     this->Interaction = NONE;
 
     // Clear the rubber band
-    int* size = this->Interactor->GetRenderWindow()->GetSize();
+    const int* size = this->Interactor->GetRenderWindow()->GetSize();
     unsigned char* pixels = this->PixelArray->GetPointer(0);
-    this->Interactor->GetRenderWindow()->SetRGBACharPixelData(0, 0, size[0]-1, size[1]-1, pixels, 0);
+    this->Interactor->GetRenderWindow()->SetRGBACharPixelData(
+      0, 0, size[0] - 1, size[1] - 1, pixels, 0);
     this->Interactor->GetRenderWindow()->Frame();
 
     unsigned int rect[5];
@@ -109,84 +111,83 @@ void vtkInteractorStyleRubberBand2D::OnLeftButtonUp()
     this->InvokeEvent(vtkCommand::SelectionChangedEvent, reinterpret_cast<void*>(rect));
     this->InvokeEvent(vtkCommand::EndInteractionEvent);
   }
-  else if(this->Interaction == PANNING)
+  else if (this->Interaction == PANNING)
   {
     this->Interaction = NONE;
     this->InvokeEvent(vtkCommand::EndInteractionEvent);
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnMiddleButtonDown()
 {
-  if(this->Interaction == NONE)
+  if (this->Interaction == NONE)
   {
     this->Interaction = PANNING;
     this->FindPokedRenderer(
-      this->Interactor->GetEventPosition()[0],
-      this->Interactor->GetEventPosition()[1]);
+      this->Interactor->GetEventPosition()[0], this->Interactor->GetEventPosition()[1]);
     this->InvokeEvent(vtkCommand::StartInteractionEvent);
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnMiddleButtonUp()
 {
-  if(this->Interaction == PANNING)
+  if (this->Interaction == PANNING)
   {
     this->Interaction = NONE;
     this->InvokeEvent(vtkCommand::EndInteractionEvent);
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnRightButtonDown()
 {
-  if(this->Interaction == NONE)
+  if (this->Interaction == NONE)
   {
     this->Interaction = ZOOMING;
     this->FindPokedRenderer(
-      this->Interactor->GetEventPosition()[0],
-      this->Interactor->GetEventPosition()[1]);
+      this->Interactor->GetEventPosition()[0], this->Interactor->GetEventPosition()[1]);
     this->InvokeEvent(vtkCommand::StartInteractionEvent);
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnRightButtonUp()
 {
-  if(this->Interaction == ZOOMING)
+  if (this->Interaction == ZOOMING)
   {
     this->Interaction = NONE;
     this->InvokeEvent(vtkCommand::EndInteractionEvent);
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnMouseMove()
 {
   if (this->Interaction == PANNING || this->Interaction == ZOOMING)
   {
     vtkRenderWindowInteractor* rwi = this->GetInteractor();
-    int lastPt[] = {0, 0};
+    int lastPt[] = { 0, 0 };
     rwi->GetLastEventPosition(lastPt);
-    int curPt[] = {0, 0};
+    int curPt[] = { 0, 0 };
     rwi->GetEventPosition(curPt);
 
     vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
     double lastScale = 2.0 * camera->GetParallelScale() / this->CurrentRenderer->GetSize()[1];
-    double lastFocalPt[] = {0, 0, 0};
+    double lastFocalPt[] = { 0, 0, 0 };
     camera->GetFocalPoint(lastFocalPt);
-    double lastPos[] = {0, 0, 0};
+    double lastPos[] = { 0, 0, 0 };
     camera->GetPosition(lastPos);
 
     if (this->Interaction == PANNING)
     {
-      double delta[] = {0, 0, 0};
-      delta[0] = -lastScale*(curPt[0] - lastPt[0]);
-      delta[1] = -lastScale*(curPt[1] - lastPt[1]);
+      double delta[] = { 0, 0, 0 };
+      delta[0] = -lastScale * (curPt[0] - lastPt[0]);
+      delta[1] = -lastScale * (curPt[1] - lastPt[1]);
       delta[2] = 0;
-      camera->SetFocalPoint(lastFocalPt[0] + delta[0], lastFocalPt[1] + delta[1], lastFocalPt[2] + delta[2]);
+      camera->SetFocalPoint(
+        lastFocalPt[0] + delta[0], lastFocalPt[1] + delta[1], lastFocalPt[2] + delta[2]);
       camera->SetPosition(lastPos[0] + delta[0], lastPos[1] + delta[1], lastPos[2] + delta[2]);
       this->InvokeEvent(vtkCommand::InteractionEvent);
       rwi->Render();
@@ -194,7 +195,7 @@ void vtkInteractorStyleRubberBand2D::OnMouseMove()
     else if (this->Interaction == ZOOMING)
     {
       double motion = 10.0;
-      double dyf = motion*(curPt[1] - lastPt[1])/this->CurrentRenderer->GetCenter()[1];
+      double dyf = motion * (curPt[1] - lastPt[1]) / this->CurrentRenderer->GetCenter()[1];
       double factor = pow(1.1, dyf);
       camera->SetParallelScale(camera->GetParallelScale() / factor);
       this->InvokeEvent(vtkCommand::InteractionEvent);
@@ -205,18 +206,18 @@ void vtkInteractorStyleRubberBand2D::OnMouseMove()
   {
     this->EndPosition[0] = this->Interactor->GetEventPosition()[0];
     this->EndPosition[1] = this->Interactor->GetEventPosition()[1];
-    int *size = this->Interactor->GetRenderWindow()->GetSize();
-    if (this->EndPosition[0] > (size[0]-1))
+    const int* size = this->Interactor->GetRenderWindow()->GetSize();
+    if (this->EndPosition[0] > (size[0] - 1))
     {
-      this->EndPosition[0] = size[0]-1;
+      this->EndPosition[0] = size[0] - 1;
     }
     if (this->EndPosition[0] < 0)
     {
       this->EndPosition[0] = 0;
     }
-    if (this->EndPosition[1] > (size[1]-1))
+    if (this->EndPosition[1] > (size[1] - 1))
     {
-      this->EndPosition[1] = size[1]-1;
+      this->EndPosition[1] = size[1] - 1;
     }
     if (this->EndPosition[1] < 0)
     {
@@ -231,12 +232,11 @@ void vtkInteractorStyleRubberBand2D::OnMouseMove()
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnMouseWheelForward()
 {
   this->FindPokedRenderer(
-    this->Interactor->GetEventPosition()[0],
-    this->Interactor->GetEventPosition()[1]);
+    this->Interactor->GetEventPosition()[0], this->Interactor->GetEventPosition()[1]);
   vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
   if (!camera)
   {
@@ -252,12 +252,11 @@ void vtkInteractorStyleRubberBand2D::OnMouseWheelForward()
   this->Interaction = NONE;
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::OnMouseWheelBackward()
 {
   this->FindPokedRenderer(
-    this->Interactor->GetEventPosition()[0],
-    this->Interactor->GetEventPosition()[1]);
+    this->Interactor->GetEventPosition()[0], this->Interactor->GetEventPosition()[1]);
   vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
   if (!camera)
   {
@@ -273,70 +272,97 @@ void vtkInteractorStyleRubberBand2D::OnMouseWheelBackward()
   this->Interaction = NONE;
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::RedrawRubberBand()
 {
   // Update the rubber band on the screen
-  int *size = this->Interactor->GetRenderWindow()->GetSize();
+  const int* size = this->Interactor->GetRenderWindow()->GetSize();
 
-  vtkUnsignedCharArray *tmpPixelArray = vtkUnsignedCharArray::New();
+  vtkUnsignedCharArray* tmpPixelArray = vtkUnsignedCharArray::New();
   tmpPixelArray->DeepCopy(this->PixelArray);
-  unsigned char *pixels = tmpPixelArray->GetPointer(0);
+  unsigned char* pixels = tmpPixelArray->GetPointer(0);
 
   int min[2], max[2];
 
-  min[0] = this->StartPosition[0] <= this->EndPosition[0] ?
-    this->StartPosition[0] : this->EndPosition[0];
-  if (min[0] < 0) { min[0] = 0; }
-  if (min[0] >= size[0]) { min[0] = size[0] - 1; }
+  min[0] =
+    this->StartPosition[0] <= this->EndPosition[0] ? this->StartPosition[0] : this->EndPosition[0];
+  if (min[0] < 0)
+  {
+    min[0] = 0;
+  }
+  if (min[0] >= size[0])
+  {
+    min[0] = size[0] - 1;
+  }
 
-  min[1] = this->StartPosition[1] <= this->EndPosition[1] ?
-    this->StartPosition[1] : this->EndPosition[1];
-  if (min[1] < 0) { min[1] = 0; }
-  if (min[1] >= size[1]) { min[1] = size[1] - 1; }
+  min[1] =
+    this->StartPosition[1] <= this->EndPosition[1] ? this->StartPosition[1] : this->EndPosition[1];
+  if (min[1] < 0)
+  {
+    min[1] = 0;
+  }
+  if (min[1] >= size[1])
+  {
+    min[1] = size[1] - 1;
+  }
 
-  max[0] = this->EndPosition[0] > this->StartPosition[0] ?
-    this->EndPosition[0] : this->StartPosition[0];
-  if (max[0] < 0) { max[0] = 0; }
-  if (max[0] >= size[0]) { max[0] = size[0] - 1; }
+  max[0] =
+    this->EndPosition[0] > this->StartPosition[0] ? this->EndPosition[0] : this->StartPosition[0];
+  if (max[0] < 0)
+  {
+    max[0] = 0;
+  }
+  if (max[0] >= size[0])
+  {
+    max[0] = size[0] - 1;
+  }
 
-  max[1] = this->EndPosition[1] > this->StartPosition[1] ?
-    this->EndPosition[1] : this->StartPosition[1];
-  if (max[1] < 0) { max[1] = 0; }
-  if (max[1] >= size[1]) { max[1] = size[1] - 1; }
+  max[1] =
+    this->EndPosition[1] > this->StartPosition[1] ? this->EndPosition[1] : this->StartPosition[1];
+  if (max[1] < 0)
+  {
+    max[1] = 0;
+  }
+  if (max[1] >= size[1])
+  {
+    max[1] = size[1] - 1;
+  }
 
   int i;
   for (i = min[0]; i <= max[0]; i++)
   {
-    pixels[4*(min[1]*size[0]+i)] = 255 ^ pixels[4*(min[1]*size[0]+i)];
-    pixels[4*(min[1]*size[0]+i)+1] = 255 ^ pixels[4*(min[1]*size[0]+i)+1];
-    pixels[4*(min[1]*size[0]+i)+2] = 255 ^ pixels[4*(min[1]*size[0]+i)+2];
-    pixels[4*(max[1]*size[0]+i)] = 255 ^ pixels[4*(max[1]*size[0]+i)];
-    pixels[4*(max[1]*size[0]+i)+1] = 255 ^ pixels[4*(max[1]*size[0]+i)+1];
-    pixels[4*(max[1]*size[0]+i)+2] = 255 ^ pixels[4*(max[1]*size[0]+i)+2];
+    pixels[4 * (min[1] * size[0] + i)] = 255 ^ pixels[4 * (min[1] * size[0] + i)];
+    pixels[4 * (min[1] * size[0] + i) + 1] = 255 ^ pixels[4 * (min[1] * size[0] + i) + 1];
+    pixels[4 * (min[1] * size[0] + i) + 2] = 255 ^ pixels[4 * (min[1] * size[0] + i) + 2];
+    pixels[4 * (max[1] * size[0] + i)] = 255 ^ pixels[4 * (max[1] * size[0] + i)];
+    pixels[4 * (max[1] * size[0] + i) + 1] = 255 ^ pixels[4 * (max[1] * size[0] + i) + 1];
+    pixels[4 * (max[1] * size[0] + i) + 2] = 255 ^ pixels[4 * (max[1] * size[0] + i) + 2];
   }
-  for (i = min[1]+1; i < max[1]; i++)
+  for (i = min[1] + 1; i < max[1]; i++)
   {
-    pixels[4*(i*size[0]+min[0])] = 255 ^ pixels[4*(i*size[0]+min[0])];
-    pixels[4*(i*size[0]+min[0])+1] = 255 ^ pixels[4*(i*size[0]+min[0])+1];
-    pixels[4*(i*size[0]+min[0])+2] = 255 ^ pixels[4*(i*size[0]+min[0])+2];
-    pixels[4*(i*size[0]+max[0])] = 255 ^ pixels[4*(i*size[0]+max[0])];
-    pixels[4*(i*size[0]+max[0])+1] = 255 ^ pixels[4*(i*size[0]+max[0])+1];
-    pixels[4*(i*size[0]+max[0])+2] = 255 ^ pixels[4*(i*size[0]+max[0])+2];
+    pixels[4 * (i * size[0] + min[0])] = 255 ^ pixels[4 * (i * size[0] + min[0])];
+    pixels[4 * (i * size[0] + min[0]) + 1] = 255 ^ pixels[4 * (i * size[0] + min[0]) + 1];
+    pixels[4 * (i * size[0] + min[0]) + 2] = 255 ^ pixels[4 * (i * size[0] + min[0]) + 2];
+    pixels[4 * (i * size[0] + max[0])] = 255 ^ pixels[4 * (i * size[0] + max[0])];
+    pixels[4 * (i * size[0] + max[0]) + 1] = 255 ^ pixels[4 * (i * size[0] + max[0]) + 1];
+    pixels[4 * (i * size[0] + max[0]) + 2] = 255 ^ pixels[4 * (i * size[0] + max[0]) + 2];
   }
 
-  this->Interactor->GetRenderWindow()->SetRGBACharPixelData(0, 0, size[0]-1, size[1]-1, pixels, 0);
+  this->Interactor->GetRenderWindow()->SetRGBACharPixelData(
+    0, 0, size[0] - 1, size[1] - 1, pixels, 0);
   this->Interactor->GetRenderWindow()->Frame();
 
   tmpPixelArray->Delete();
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleRubberBand2D::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Interaction: " << this->Interaction << endl;
   os << indent << "RenderOnMouseMove: " << this->RenderOnMouseMove << endl;
-  os << indent << "StartPosition: " << this->StartPosition[0] << "," << this->StartPosition[1] << endl;
+  os << indent << "StartPosition: " << this->StartPosition[0] << "," << this->StartPosition[1]
+     << endl;
   os << indent << "EndPosition: " << this->EndPosition[0] << "," << this->EndPosition[1] << endl;
 }
+VTK_ABI_NAMESPACE_END
