@@ -17,7 +17,7 @@
  * @brief   manipulate objects in the scene independent of each other
  *
  * vtkInteractorStyleTrackballActor allows the user to interact with (rotate,
- * pan, etc.) objects in the scene indendent of each other.  In trackball
+ * pan, etc.) objects in the scene independent of each other.  In trackball
  * interaction, the magnitude of the mouse motion is proportional to the
  * actor motion associated with a particular mouse binding. For example,
  * small left-button motions cause small changes in the rotation of the
@@ -40,6 +40,7 @@
 #include "vtkInteractionStyleModule.h" // For export macro
 #include "vtkInteractorStyle.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellPicker;
 
 class VTKINTERACTIONSTYLE_EXPORT vtkInteractorStyleTrackballActor : public vtkInteractorStyle
@@ -49,7 +50,7 @@ public:
   vtkTypeMacro(vtkInteractorStyleTrackballActor, vtkInteractorStyle);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Event bindings controlling the effects of pressing mouse buttons
    * or moving the mouse.
@@ -61,7 +62,7 @@ public:
   void OnMiddleButtonUp() override;
   void OnRightButtonDown() override;
   void OnRightButtonUp() override;
-  //@}
+  ///@}
 
   // These methods for the different interactions in different modes
   // are overridden in subclasses to perform the correct motion. Since
@@ -92,4 +93,5 @@ private:
   void operator=(const vtkInteractorStyleTrackballActor&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
