@@ -1,6 +1,6 @@
-#include "vtkSeedWidget.h"
-#include "vtkSeedRepresentation.h"
 #include "vtkHandleWidget.h"
+#include "vtkSeedRepresentation.h"
+#include "vtkSeedWidget.h"
 
 #include <cstdlib>
 #include <iostream>
@@ -8,11 +8,11 @@
 #include "WidgetTestingMacros.h"
 #include "vtkPointHandleRepresentation2D.h"
 
-int vtkSeedWidgetTest1(int , char * [] )
+int vtkSeedWidgetTest1(int, char*[])
 {
-  vtkSmartPointer< vtkSeedWidget > node1 = vtkSmartPointer< vtkSeedWidget >::New();
+  vtkSmartPointer<vtkSeedWidget> node1 = vtkSmartPointer<vtkSeedWidget>::New();
 
-  EXERCISE_BASIC_ABSTRACT_METHODS ( node1 );
+  EXERCISE_BASIC_ABSTRACT_METHODS(node1);
 
   node1->SetProcessEvents(0);
   node1->SetProcessEvents(1);
@@ -24,11 +24,11 @@ int vtkSeedWidgetTest1(int , char * [] )
   node1->RestartInteraction();
 
   // have to create a handle rep before create new handle
-  vtkSmartPointer<vtkPointHandleRepresentation2D> handle = vtkSmartPointer<vtkPointHandleRepresentation2D>::New();
-  handle->GetProperty()->SetColor(1,0,0);
+  vtkSmartPointer<vtkPointHandleRepresentation2D> handle =
+    vtkSmartPointer<vtkPointHandleRepresentation2D>::New();
+  handle->GetProperty()->SetColor(1, 0, 0);
   rep1->SetHandleRepresentation(handle);
 
-
   vtkSmartPointer<vtkHandleWidget> handleWidget = node1->CreateNewHandle();
   if (handleWidget == nullptr)
   {
