@@ -74,6 +74,7 @@
 #include "vtkAbstractWidget.h"
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAngleRepresentation;
 class vtkHandleWidget;
 class vtkAngleWidgetCallback;
@@ -86,13 +87,13 @@ public:
    */
   static vtkAngleWidget* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for a VTK class.
    */
   vtkTypeMacro(vtkAngleWidget, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * The method for activating and deactivating this widget. This method
@@ -149,7 +150,7 @@ public:
     Manipulate
   };
 
-  //@{
+  ///@{
   /**
    * Set the state of the widget. If the state is set to "Manipulate" then it
    * is assumed that the widget and its representation will be initialized
@@ -162,7 +163,7 @@ public:
    */
   virtual void SetWidgetStateToStart();
   virtual void SetWidgetStateToManipulate();
-  //@}
+  ///@}
 
   /**
    * Return the current widget state.
@@ -204,4 +205,5 @@ private:
   void operator=(const vtkAngleWidget&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
