@@ -82,8 +82,10 @@
 #define vtkAxesTransformWidget_h
 
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAxesTransformRepresentation;
 class vtkHandleWidget;
 
@@ -95,13 +97,13 @@ public:
    */
   static vtkAxesTransformWidget* New();
 
-  //@{
+  ///@{
   /**
    * Standard vtkObject methods
    */
   vtkTypeMacro(vtkAxesTransformWidget, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Override superclasses' SetEnabled() method because the line
@@ -143,11 +145,16 @@ protected:
   ~vtkAxesTransformWidget() override;
 
   int WidgetState;
-  enum _WidgetState
+  enum WidgetStateType
   {
     Start = 0,
     Active
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
+
   int CurrentHandle;
 
   // These methods handle events
@@ -164,4 +171,5 @@ private:
   void operator=(const vtkAxesTransformWidget&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
