@@ -32,17 +32,17 @@
 #include <cassert>
 #include <map>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBalloonWidget);
 
 //-- Define the PIMPLd array of vtkProp and vtkString --
 struct vtkBalloon
 {
-  vtkStdString Text;
+  std::string Text;
   vtkImageData* Image;
 
   vtkBalloon()
-    : Text()
-    , Image(nullptr)
+    : Image(nullptr)
   {
   }
   vtkBalloon(const vtkBalloon& balloon)
@@ -54,7 +54,7 @@ struct vtkBalloon
       this->Image->Register(nullptr);
     }
   }
-  vtkBalloon(vtkStdString* str, vtkImageData* img)
+  vtkBalloon(std::string* str, vtkImageData* img)
   {
     this->Text = *str;
     this->Image = img;
@@ -65,7 +65,7 @@ struct vtkBalloon
   }
   vtkBalloon(const char* str, vtkImageData* img)
   {
-    this->Text = vtkStdString(str);
+    this->Text = str;
     this->Image = img;
     if (this->Image)
     {
@@ -322,7 +322,7 @@ int vtkBalloonWidget::SubclassHoverAction()
       this->CurrentProp = (*iter).first;
       this->CurrentProp->Register(this);
       reinterpret_cast<vtkBalloonRepresentation*>(this->WidgetRep)
-        ->SetBalloonText((*iter).second.Text);
+        ->SetBalloonText((*iter).second.Text.c_str());
       reinterpret_cast<vtkBalloonRepresentation*>(this->WidgetRep)
         ->SetBalloonImage((*iter).second.Image);
       this->WidgetRep->StartWidgetInteraction(e);
@@ -362,3 +362,4 @@ void vtkBalloonWidget::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Picker: " << this->Picker << "\n";
 }
+VTK_ABI_NAMESPACE_END
