@@ -33,11 +33,11 @@
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBiDimensionalRepresentation2D);
 
 //------------------------------------------------------------------------------
 vtkBiDimensionalRepresentation2D::vtkBiDimensionalRepresentation2D()
-  : vtkBiDimensionalRepresentation()
 {
   // Create the geometry for the two axes
   this->LineCells = vtkCellArray::New();
@@ -857,3 +857,4 @@ void vtkBiDimensionalRepresentation2D::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Selected Line Property: (none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
