@@ -31,6 +31,7 @@
 #include <algorithm>
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBorderRepresentation);
 
 //------------------------------------------------------------------------------
@@ -38,12 +39,6 @@ vtkBorderRepresentation::vtkBorderRepresentation()
 {
   this->InteractionState = vtkBorderRepresentation::Outside;
 
-  this->ShowVerticalBorder = BORDER_ON;
-  this->ShowHorizontalBorder = BORDER_ON;
-  this->ProportionalResize = 0;
-  this->Tolerance = 3;
-  this->SelectionPoint[0] = this->SelectionPoint[1] = 0.0;
-
   // Initial positioning information
   this->Negotiated = 0;
   this->PositionCoordinate->SetCoordinateSystemToNormalizedViewport();
@@ -95,17 +90,10 @@ vtkBorderRepresentation::vtkBorderRepresentation()
   this->PolygonProperty->SetOpacity(this->PolygonOpacity);
   this->PolygonProperty->SetPointSize(0.f);
   this->BWActorPolygon->SetProperty(this->PolygonProperty);
-
-  this->MinimumSize[0] = 1;
-  this->MinimumSize[1] = 1;
-  this->MaximumSize[0] = 100000;
-  this->MaximumSize[1] = 100000;
-
-  this->Moving = 0;
 }
 
 //------------------------------------------------------------------------------
-vtkBorderRepresentation::~vtkBorderRepresentation() {}
+vtkBorderRepresentation::~vtkBorderRepresentation() = default;
 
 //------------------------------------------------------------------------------
 void vtkBorderRepresentation::ComputeRoundCorners()
@@ -118,9 +106,10 @@ void vtkBorderRepresentation::ComputeRoundCorners()
 
   // Create round corners after the transform as we do not want to scale the corners
   vtkPolyData* pd = this->BWTransformFilter->GetOutput();
-  vtkPoints* pdPoints = pd->GetPoints();
+  vtkNew<vtkPoints> pdPoints;
+  pdPoints->DeepCopy(pd->GetPoints());
 
-  if (lines->GetNumberOfCells() != 1 || this->CornerResolution == 0 || this->BorderThickness == 0)
+  if (lines->GetNumberOfCells() != 1 || this->CornerResolution == 0)
   {
     // All borders are not shown, we cannot compute
     // round corners
@@ -224,6 +213,7 @@ void vtkBorderRepresentation::SetShowBorder(int border)
 {
   this->SetShowVerticalBorder(border);
   this->SetShowHorizontalBorder(border);
+  this->SetShowPolygonBackground(border);
   this->UpdateShowBorder();
 }
 
@@ -242,8 +232,23 @@ int vtkBorderRepresentation::GetShowBorderMaxValue()
 //------------------------------------------------------------------------------
 int vtkBorderRepresentation::GetShowBorder()
 {
-  return this->GetShowVerticalBorder() != BORDER_OFF ? this->GetShowVerticalBorder()
-                                                     : this->GetShowHorizontalBorder();
+  return this->GetShowVerticalBorder() != BORDER_OFF
+    ? this->GetShowVerticalBorder()
+    : (this->GetShowHorizontalBorder() != BORDER_OFF ? this->GetShowHorizontalBorder()
+                                                     : this->GetShowPolygonBackground());
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::SetShowPolygon(int polygon)
+{
+  this->SetShowPolygonBackground(polygon);
+  this->UpdateShowBorder();
+}
+
+//------------------------------------------------------------------------------
+int vtkBorderRepresentation::GetShowPolygon()
+{
+  return this->GetShowPolygonBackground();
 }
 
 //------------------------------------------------------------------------------
@@ -373,6 +378,86 @@ void vtkBorderRepresentation::WidgetInteraction(double eventPos[2])
       break;
   }
 
+  // Enforce bounds to keep the widget on screen and bigger than minimum size
+  if (!this->ProportionalResize && this->EnforceNormalizedViewportBounds)
+  {
+    switch (this->InteractionState)
+    {
+      case vtkBorderRepresentation::AdjustingP0:
+        par1[0] = std::min(
+          std::max(par1[0] /*+ delX*/, 0.0), par2[0] - this->MinimumNormalizedViewportSize[0]);
+        par1[1] = std::min(
+          std::max(par1[1] /*+ delY*/, 0.0), par2[1] - this->MinimumNormalizedViewportSize[1]);
+        break;
+      case vtkBorderRepresentation::AdjustingP1:
+        par2[0] = std::min(
+          std::max(par2[0] /*+ delX2*/, par1[0] + this->MinimumNormalizedViewportSize[0]), 1.0);
+        par1[1] = std::min(
+          std::max(par1[1] /*+ delY2*/, 0.0), par2[1] - this->MinimumNormalizedViewportSize[1]);
+        break;
+      case vtkBorderRepresentation::AdjustingP2:
+        par2[0] = std::min(
+          std::max(par2[0] /*+ delX*/, par1[0] + this->MinimumNormalizedViewportSize[0]), 1.0);
+        par2[1] = std::min(
+          std::max(par2[1] /*+ delY*/, par1[1] + this->MinimumNormalizedViewportSize[1]), 1.0);
+        break;
+      case vtkBorderRepresentation::AdjustingP3:
+        par1[0] = std::min(
+          std::max(par1[0] /*+ delX2*/, 0.0), par2[0] - this->MinimumNormalizedViewportSize[0]);
+        par2[1] = std::min(
+          std::max(par2[1] /*+ delY2*/, par1[1] + this->MinimumNormalizedViewportSize[1]), 1.0);
+        break;
+      case vtkBorderRepresentation::AdjustingE0:
+        par1[1] = std::min(
+          std::max(par1[1] /*+ delY*/, 0.0), par2[1] - this->MinimumNormalizedViewportSize[1]);
+        break;
+      case vtkBorderRepresentation::AdjustingE1:
+        par2[0] = std::min(
+          std::max(par2[0] /*+ delX*/, par1[0] + this->MinimumNormalizedViewportSize[0]), 1.0);
+        break;
+      case vtkBorderRepresentation::AdjustingE2:
+        par2[1] = std::min(
+          std::max(par2[1] /*+ delY*/, par1[1] + this->MinimumNormalizedViewportSize[1]), 1.0);
+        break;
+      case vtkBorderRepresentation::AdjustingE3:
+        par1[0] = std::min(
+          std::max(par1[0] /*+ delX*/, 0.0), par2[0] - this->MinimumNormalizedViewportSize[0]);
+        break;
+      case vtkBorderRepresentation::Inside:
+        if (this->Moving)
+        {
+          // Keep border from moving off normalized screen
+          if (par1[0] < 0.0)
+          {
+            double delta = -par1[0];
+            par1[0] += delta;
+            par2[0] += delta;
+          }
+          if (par1[1] < 0.0)
+          {
+            double delta = -par1[1];
+            par1[1] += delta;
+            par2[1] += delta;
+          }
+          if (par2[0] > 1.0)
+          {
+            double delta = par2[0] - 1.0;
+            par1[0] -= delta;
+            par2[0] -= delta;
+          }
+          if (par2[1] > 1.0)
+          {
+            double delta = par2[1] - 1.0;
+            par1[1] -= delta;
+            par2[1] -= delta;
+          }
+        }
+        break;
+      default:
+        break;
+    }
+  }
+
   // Modify the representation
   if (par2[0] > par1[0] && par2[1] > par1[1])
   {
@@ -467,7 +552,7 @@ int vtkBorderRepresentation::ComputeInteractionState(int X, int Y, int vtkNotUse
       if (this->Moving)
       {
         // FIXME: This must be wrong.  Moving is not an entry in the
-        // _InteractionState enum.  It is an ivar flag and it has no business
+        // InteractionStateType enum.  It is an ivar flag and it has no business
         // being set to InteractionState.  This just happens to work because
         // Inside happens to be 1, and this gets set when Moving is 1.
         this->InteractionState = vtkBorderRepresentation::Moving;
@@ -493,6 +578,7 @@ void vtkBorderRepresentation::UpdateShowBorder()
     HorizontalBorder = 0x02,
     AllBorders = VerticalBorder | HorizontalBorder
   };
+
   int currentBorder = NoBorder;
   switch (this->BWPolyData->GetLines()->GetNumberOfCells())
   {
@@ -513,6 +599,8 @@ void vtkBorderRepresentation::UpdateShowBorder()
       currentBorder = NoBorder;
       break;
   }
+  bool currentBackground = this->BWActorPolygon->GetVisibility();
+
   int newBorder = NoBorder;
   if (this->ShowVerticalBorder == this->ShowHorizontalBorder)
   {
@@ -537,12 +625,18 @@ void vtkBorderRepresentation::UpdateShowBorder()
           ? HorizontalBorder
           : NoBorder);
   }
-  bool visible = (newBorder != NoBorder);
-  if (currentBorder != newBorder && visible)
+  bool backgroundVisible = (this->ShowPolygonBackground == BORDER_ON ||
+    (this->ShowPolygonBackground == BORDER_ACTIVE &&
+      this->InteractionState != vtkBorderRepresentation::Outside));
+
+  bool edgesVisible = (newBorder != NoBorder);
+  if ((currentBorder != newBorder || currentBackground != backgroundVisible) &&
+    (edgesVisible || backgroundVisible))
   {
     vtkNew<vtkCellArray> outline;
     switch (newBorder)
     {
+      case NoBorder: // fall-through for backgrounds only
       case AllBorders:
         outline->InsertNextCell(5);
         outline->InsertCellPoint(0);
@@ -575,7 +669,8 @@ void vtkBorderRepresentation::UpdateShowBorder()
     this->Modified();
     this->ComputeRoundCorners();
   }
-  this->BWActorEdges->SetVisibility(visible);
+  this->BWActorEdges->SetVisibility(edgesVisible);
+  this->BWActorPolygon->SetVisibility(backgroundVisible);
 }
 
 //------------------------------------------------------------------------------
@@ -591,6 +686,24 @@ void vtkBorderRepresentation::SetBWActorDisplayOverlay(bool enable)
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::SetBWActorDisplayOverlayEdges(bool enable)
+{
+  if (this->BWActorEdges)
+  {
+    this->BWActorEdges->SetVisibility(enable);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::SetBWActorDisplayOverlayPolygon(bool enable)
+{
+  if (this->BWActorPolygon)
+  {
+    this->BWActorPolygon->SetVisibility(enable);
+  }
+}
+
 //------------------------------------------------------------------------------
 void vtkBorderRepresentation::BuildRepresentation()
 {
@@ -674,35 +787,68 @@ void vtkBorderRepresentation::ReleaseGraphicsResources(vtkWindow* w)
 int vtkBorderRepresentation::RenderOverlay(vtkViewport* w)
 {
   this->BuildRepresentation();
-  if (!this->BWActorEdges->GetVisibility())
+
+  vtkTypeBool edgesVisible = this->BWActorEdges->GetVisibility();
+  vtkTypeBool polygonVisible = this->BWActorPolygon->GetVisibility();
+  if (edgesVisible && polygonVisible)
   {
-    return 0;
+    return this->BWActorEdges->RenderOverlay(w) && this->BWActorPolygon->RenderOverlay(w);
   }
-  return this->BWActorEdges->RenderOverlay(w) && this->BWActorPolygon->RenderOverlay(w);
+  else if (edgesVisible)
+  {
+    return this->BWActorEdges->RenderOverlay(w);
+  }
+  else if (polygonVisible)
+  {
+    return this->BWActorPolygon->RenderOverlay(w);
+  }
+  return 0;
 }
 
 //------------------------------------------------------------------------------
 int vtkBorderRepresentation::RenderOpaqueGeometry(vtkViewport* w)
 {
   this->BuildRepresentation();
-  if (!this->BWActorEdges->GetVisibility())
+
+  vtkTypeBool edgesVisible = this->BWActorEdges->GetVisibility();
+  vtkTypeBool polygonVisible = this->BWActorPolygon->GetVisibility();
+  if (edgesVisible && polygonVisible)
   {
-    return 0;
+    return this->BWActorEdges->RenderOpaqueGeometry(w) &&
+      this->BWActorPolygon->RenderOpaqueGeometry(w);
   }
-  return this->BWActorEdges->RenderOpaqueGeometry(w) &&
-    this->BWActorPolygon->RenderOpaqueGeometry(w);
+  else if (edgesVisible)
+  {
+    return this->BWActorEdges->RenderOpaqueGeometry(w);
+  }
+  else if (polygonVisible)
+  {
+    return this->BWActorPolygon->RenderOpaqueGeometry(w);
+  }
+  return 0;
 }
 
 //------------------------------------------------------------------------------
 int vtkBorderRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport* w)
 {
   this->BuildRepresentation();
-  if (!this->BWActorEdges->GetVisibility())
+
+  vtkTypeBool edgesVisible = this->BWActorEdges->GetVisibility();
+  vtkTypeBool polygonVisible = this->BWActorPolygon->GetVisibility();
+  if (edgesVisible && polygonVisible)
   {
-    return 0;
+    return this->BWActorEdges->RenderTranslucentPolygonalGeometry(w) &&
+      this->BWActorPolygon->RenderTranslucentPolygonalGeometry(w);
   }
-  return this->BWActorEdges->RenderTranslucentPolygonalGeometry(w) &&
-    this->BWActorPolygon->RenderTranslucentPolygonalGeometry(w);
+  else if (edgesVisible)
+  {
+    return this->BWActorEdges->RenderTranslucentPolygonalGeometry(w);
+  }
+  else if (polygonVisible)
+  {
+    return this->BWActorPolygon->RenderTranslucentPolygonalGeometry(w);
+  }
+  return 0;
 }
 
 //------------------------------------------------------------------------------
@@ -711,12 +857,98 @@ int vtkBorderRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport* w)
 vtkTypeBool vtkBorderRepresentation::HasTranslucentPolygonalGeometry()
 {
   this->BuildRepresentation();
-  if (!this->BWActorEdges->GetVisibility())
+
+  vtkTypeBool edgesVisible = this->BWActorEdges->GetVisibility();
+  vtkTypeBool polygonVisible = this->BWActorPolygon->GetVisibility();
+  if (edgesVisible && polygonVisible)
   {
-    return 0;
+    return this->BWActorEdges->HasTranslucentPolygonalGeometry() &&
+      this->BWActorPolygon->HasTranslucentPolygonalGeometry();
   }
-  return this->BWActorEdges->HasTranslucentPolygonalGeometry() &&
-    this->BWActorPolygon->HasTranslucentPolygonalGeometry();
+  else if (edgesVisible)
+  {
+    return this->BWActorEdges->HasTranslucentPolygonalGeometry();
+  }
+  else if (polygonVisible)
+  {
+    return this->BWActorPolygon->HasTranslucentPolygonalGeometry();
+  }
+  return 0;
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::SetPolygonRGBA(double rgba[4])
+{
+  this->SetPolygonRGBA(rgba[0], rgba[1], rgba[2], rgba[3]);
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::SetPolygonRGBA(double r, double g, double b, double a)
+{
+  this->SetPolygonColor(r, g, b);
+  this->SetPolygonOpacity(a);
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::GetPolygonRGBA(double rgba[4])
+{
+  this->GetPolygonRGBA(rgba[0], rgba[1], rgba[2], rgba[3]);
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::GetPolygonRGBA(double& r, double& g, double& b, double& a)
+{
+  this->GetPolygonColor(r, g, b);
+  a = this->GetPolygonOpacity();
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::UpdateWindowLocation()
+{
+  if (this->WindowLocation != vtkBorderRepresentation::AnyLocation)
+  {
+    double* pos2 = this->Position2Coordinate->GetValue();
+    switch (this->WindowLocation)
+    {
+      case vtkBorderRepresentation::LowerLeftCorner:
+        this->SetPosition(0.01, 0.01);
+        break;
+      case vtkBorderRepresentation::LowerRightCorner:
+        this->SetPosition(0.99 - pos2[0], 0.01);
+        break;
+      case vtkBorderRepresentation::LowerCenter:
+        this->SetPosition((1 - pos2[0]) / 2.0, 0.01);
+        break;
+      case vtkBorderRepresentation::UpperLeftCorner:
+        this->SetPosition(0.01, 0.99 - pos2[1]);
+        break;
+      case vtkBorderRepresentation::UpperRightCorner:
+        this->SetPosition(0.99 - pos2[0], 0.99 - pos2[1]);
+        break;
+      case vtkBorderRepresentation::UpperCenter:
+        this->SetPosition((1 - pos2[0]) / 2.0, 0.99 - pos2[1]);
+        break;
+      default:
+        break;
+    }
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkBorderRepresentation::SetWindowLocation(int enumLocation)
+{
+  if (this->WindowLocation == enumLocation)
+  {
+    return;
+  }
+
+  this->WindowLocation = enumLocation;
+
+  if (this->WindowLocation != vtkBorderRepresentation::AnyLocation)
+  {
+    this->UpdateWindowLocation();
+  }
+  this->Modified();
 }
 
 //------------------------------------------------------------------------------
@@ -752,6 +984,20 @@ void vtkBorderRepresentation::PrintSelf(ostream& os, vtkIndent indent)
     os << "Active" << endl;
   }
 
+  os << indent << "Show Polygon: ";
+  if (this->ShowPolygonBackground == BORDER_OFF)
+  {
+    os << "Off" << endl;
+  }
+  else if (this->ShowPolygonBackground == BORDER_ON)
+  {
+    os << "On" << endl;
+  }
+  else // if ( this->ShowPolygonBackground == BORDER_ACTIVE)
+  {
+    os << "Active" << endl;
+  }
+
   if (this->BorderProperty)
   {
     os << indent << "Border Property:" << endl;
@@ -772,7 +1018,11 @@ void vtkBorderRepresentation::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Polygon Property: (none)" << endl;
   }
 
+  os << indent << "Enforce Normalized Viewport Bounds: "
+     << (this->EnforceNormalizedViewportBounds ? "On\n" : "Off\n");
   os << indent << "Proportional Resize: " << (this->ProportionalResize ? "On" : "Off") << endl;
+  os << indent << "Minimum Normalized Viewport Size: " << this->MinimumNormalizedViewportSize[0]
+     << " " << this->MinimumNormalizedViewportSize[1] << endl;
   os << indent << "Minimum Size: " << this->MinimumSize[0] << " " << this->MinimumSize[1] << endl;
   os << indent << "Maximum Size: " << this->MaximumSize[0] << " " << this->MaximumSize[1] << endl;
 
@@ -791,4 +1041,31 @@ void vtkBorderRepresentation::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "PolygonColor: (" << this->PolygonColor[0] << ", " << this->PolygonColor[1]
      << ", " << this->PolygonColor[2] << ")" << endl;
   os << indent << "PolygonOpacity: " << this->PolygonOpacity << endl;
+
+  os << indent << "Window Location: ";
+  switch (this->WindowLocation)
+  {
+    case vtkBorderRepresentation::LowerLeftCorner:
+      os << "LowerLeftCorner\n";
+      break;
+    case vtkBorderRepresentation::LowerRightCorner:
+      os << "LowerRightCorner\n";
+      break;
+    case vtkBorderRepresentation::LowerCenter:
+      os << "LowerCenter\n";
+      break;
+    case vtkBorderRepresentation::UpperLeftCorner:
+      os << "UpperLeftCorner\n";
+      break;
+    case vtkBorderRepresentation::UpperRightCorner:
+      os << "UpperRightCorner\n";
+      break;
+    case vtkBorderRepresentation::UpperCenter:
+      os << "UpperCenter\n";
+      break;
+    case vtkBorderRepresentation::AnyLocation:
+      os << "Any Location\n";
+      break;
+  }
 }
+VTK_ABI_NAMESPACE_END
