@@ -74,8 +74,10 @@
 #define vtkBorderWidget_h
 
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBorderRepresentation;
 
 class VTKINTERACTIONWIDGETS_EXPORT vtkBorderWidget : public vtkAbstractWidget
@@ -86,15 +88,15 @@ public:
    */
   static vtkBorderWidget* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for class.
    */
   vtkTypeMacro(vtkBorderWidget, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Indicate whether the interior region of the widget can be selected or
    * not. If not, then events (such as left mouse down) allow the user to
@@ -104,9 +106,9 @@ public:
   vtkSetMacro(Selectable, vtkTypeBool);
   vtkGetMacro(Selectable, vtkTypeBool);
   vtkBooleanMacro(Selectable, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Indicate whether the boundary of the widget can be resized.
    * If not, the cursor will not change to "resize" type when mouse
@@ -115,7 +117,7 @@ public:
   vtkSetMacro(Resizable, vtkTypeBool);
   vtkGetMacro(Resizable, vtkTypeBool);
   vtkBooleanMacro(Resizable, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Specify an instance of vtkWidgetRepresentation used to represent this
@@ -140,6 +142,12 @@ public:
    */
   void CreateDefaultRepresentation() override;
 
+  /**
+   * Reimplement ProcessEvents to disable it when using relative location with
+   * windowLocation. When using exact location this override has no effect.
+   */
+  vtkTypeBool GetProcessEvents() override;
+
 protected:
   vtkBorderWidget();
   ~vtkBorderWidget() override;
@@ -174,17 +182,22 @@ protected:
 
   // widget state
   int WidgetState;
-  enum _WidgetState
+  enum WidgetStateType
   {
     Start = 0,
     Define,
     Manipulate,
     Selected
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
 
 private:
   vtkBorderWidget(const vtkBorderWidget&) = delete;
   void operator=(const vtkBorderWidget&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
