@@ -26,6 +26,7 @@
 #include "vtkWidgetEvent.h"
 #include "vtkWidgetEventTranslator.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBoxWidget2);
 
 //------------------------------------------------------------------------------
@@ -67,26 +68,27 @@ vtkBoxWidget2::vtkBoxWidget2()
     vtkCommand::MouseMoveEvent, vtkWidgetEvent::Move, this, vtkBoxWidget2::MoveAction);
 
   {
-    vtkNew<vtkEventDataButton3D> ed;
-    ed->SetDevice(vtkEventDataDevice::RightController);
-    ed->SetInput(vtkEventDataDeviceInput::Trigger);
+    vtkNew<vtkEventDataDevice3D> ed;
+    ed->SetDevice(vtkEventDataDevice::Any);
+    ed->SetInput(vtkEventDataDeviceInput::Any);
     ed->SetAction(vtkEventDataAction::Press);
-    this->CallbackMapper->SetCallbackMethod(vtkCommand::Button3DEvent, ed.Get(),
+    this->CallbackMapper->SetCallbackMethod(vtkCommand::Select3DEvent, ed.Get(),
       vtkWidgetEvent::Select3D, this, vtkBoxWidget2::SelectAction3D);
   }
 
   {
-    vtkNew<vtkEventDataButton3D> ed;
-    ed->SetDevice(vtkEventDataDevice::RightController);
-    ed->SetInput(vtkEventDataDeviceInput::Trigger);
+    vtkNew<vtkEventDataDevice3D> ed;
+    ed->SetDevice(vtkEventDataDevice::Any);
+    ed->SetInput(vtkEventDataDeviceInput::Any);
     ed->SetAction(vtkEventDataAction::Release);
-    this->CallbackMapper->SetCallbackMethod(vtkCommand::Button3DEvent, ed.Get(),
+    this->CallbackMapper->SetCallbackMethod(vtkCommand::Select3DEvent, ed.Get(),
       vtkWidgetEvent::EndSelect3D, this, vtkBoxWidget2::EndSelectAction3D);
   }
 
   {
-    vtkNew<vtkEventDataMove3D> ed;
-    ed->SetDevice(vtkEventDataDevice::RightController);
+    vtkNew<vtkEventDataDevice3D> ed;
+    ed->SetDevice(vtkEventDataDevice::Any);
+    ed->SetInput(vtkEventDataDeviceInput::Any);
     this->CallbackMapper->SetCallbackMethod(
       vtkCommand::Move3DEvent, ed.Get(), vtkWidgetEvent::Move3D, this, vtkBoxWidget2::MoveAction3D);
   }
@@ -250,6 +252,15 @@ void vtkBoxWidget2::SelectAction3D(vtkAbstractWidget* w)
     return;
   }
 
+  // watch for motion events from this device
+  vtkEventData* edata = static_cast<vtkEventData*>(self->CallData);
+  vtkEventDataDevice3D* edd = edata->GetAsEventDataDevice3D();
+  if (!edd)
+  {
+    return;
+  }
+  self->LastDevice = static_cast<int>(edd->GetDevice());
+
   // We are definitely selected
   if (!self->Parent)
   {
@@ -397,6 +408,19 @@ void vtkBoxWidget2::MoveAction3D(vtkAbstractWidget* w)
     return;
   }
 
+  // watch for motion events from this device
+  vtkEventData* edata = static_cast<vtkEventData*>(self->CallData);
+  vtkEventDataDevice3D* edd = edata->GetAsEventDataDevice3D();
+  if (!edd)
+  {
+    return;
+  }
+
+  if (!edd->DeviceMatches(static_cast<vtkEventDataDevice>(self->LastDevice)))
+  {
+    return;
+  }
+
   // Okay, adjust the representation
   self->WidgetRep->ComplexInteraction(
     self->Interactor, self, vtkWidgetEvent::Move3D, self->CallData);
@@ -544,3 +568,4 @@ void vtkBoxWidget2::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Rotation Enabled: " << (this->RotationEnabled ? "On\n" : "Off\n");
   os << indent << "Move Faces Enabled: " << (this->MoveFacesEnabled ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
