@@ -14,59 +14,57 @@
 =========================================================================*/
 #include "vtkButtonWidget.h"
 #include "vtkButtonRepresentation.h"
-#include "vtkTexturedButtonRepresentation.h"
-#include "vtkCommand.h"
 #include "vtkCallbackCommand.h"
-#include "vtkRenderWindowInteractor.h"
-#include "vtkObjectFactory.h"
-#include "vtkRenderer.h"
-#include "vtkWidgetEventTranslator.h"
-#include "vtkWidgetCallbackMapper.h"
+#include "vtkCommand.h"
 #include "vtkEvent.h"
-#include "vtkWidgetEvent.h"
+#include "vtkObjectFactory.h"
 #include "vtkRenderWindow.h"
+#include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
+#include "vtkTexturedButtonRepresentation.h"
+#include "vtkWidgetCallbackMapper.h"
+#include "vtkWidgetEvent.h"
+#include "vtkWidgetEventTranslator.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkButtonWidget);
 
-//----------------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkButtonWidget::vtkButtonWidget()
 {
   // Set the initial state
   this->WidgetState = vtkButtonWidget::Start;
 
   // Okay, define the events
-  this->CallbackMapper->SetCallbackMethod(vtkCommand::LeftButtonPressEvent,
-                                          vtkWidgetEvent::Select,
-                                          this, vtkButtonWidget::SelectAction);
-  this->CallbackMapper->SetCallbackMethod(vtkCommand::MouseMoveEvent,
-                                          vtkWidgetEvent::Move,
-                                          this, vtkButtonWidget::MoveAction);
+  this->CallbackMapper->SetCallbackMethod(
+    vtkCommand::LeftButtonPressEvent, vtkWidgetEvent::Select, this, vtkButtonWidget::SelectAction);
+  this->CallbackMapper->SetCallbackMethod(
+    vtkCommand::MouseMoveEvent, vtkWidgetEvent::Move, this, vtkButtonWidget::MoveAction);
   this->CallbackMapper->SetCallbackMethod(vtkCommand::LeftButtonReleaseEvent,
-                                          vtkWidgetEvent::EndSelect,
-                                          this, vtkButtonWidget::EndSelectAction);
+    vtkWidgetEvent::EndSelect, this, vtkButtonWidget::EndSelectAction);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkButtonWidget::CreateDefaultRepresentation()
 {
-  if ( ! this->WidgetRep )
+  if (!this->WidgetRep)
   {
     this->WidgetRep = vtkTexturedButtonRepresentation::New();
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkButtonWidget::SetEnabled(int enabling)
 {
-  if ( enabling ) //----------------
+  if (enabling) //----------------
   {
     if (this->Interactor)
     {
       if (!this->CurrentRenderer)
       {
-        int X=this->Interactor->GetEventPosition()[0];
-        int Y=this->Interactor->GetEventPosition()[1];
-        this->SetCurrentRenderer(this->Interactor->FindPokedRenderer(X,Y));
+        int X = this->Interactor->GetEventPosition()[0];
+        int Y = this->Interactor->GetEventPosition()[1];
+        this->SetCurrentRenderer(this->Interactor->FindPokedRenderer(X, Y));
       }
       this->CreateDefaultRepresentation();
       this->WidgetRep->SetRenderer(this->CurrentRenderer);
@@ -79,16 +77,16 @@ void vtkButtonWidget::SetEnabled(int enabling)
   Superclass::SetEnabled(enabling);
 }
 
-//----------------------------------------------------------------------------------
-void vtkButtonWidget::MoveAction(vtkAbstractWidget *w)
+//------------------------------------------------------------------------------
+void vtkButtonWidget::MoveAction(vtkAbstractWidget* w)
 {
-  vtkButtonWidget *self = reinterpret_cast<vtkButtonWidget*>(w);
+  vtkButtonWidget* self = reinterpret_cast<vtkButtonWidget*>(w);
 
   int X = self->Interactor->GetEventPosition()[0];
   int Y = self->Interactor->GetEventPosition()[1];
 
   // Motion while selecting is ignored
-  if ( self->WidgetState == vtkButtonWidget::Selecting )
+  if (self->WidgetState == vtkButtonWidget::Selecting)
   {
     self->EventCallbackCommand->SetAbortFlag(1);
     return;
@@ -97,12 +95,12 @@ void vtkButtonWidget::MoveAction(vtkAbstractWidget *w)
   // Get the new state and compare it to the old
   int renderRequired = 0;
   int state = self->WidgetRep->ComputeInteractionState(X, Y);
-  if ( self->WidgetState == vtkButtonWidget::Hovering )
+  if (self->WidgetState == vtkButtonWidget::Hovering)
   {
-    if ( state == vtkButtonRepresentation::Outside )
+    if (state == vtkButtonRepresentation::Outside)
     {
       renderRequired = 1;
-      if ( self->ManagesCursor )
+      if (self->ManagesCursor)
       {
         self->RequestCursorShape(VTK_CURSOR_DEFAULT);
       }
@@ -110,12 +108,12 @@ void vtkButtonWidget::MoveAction(vtkAbstractWidget *w)
       self->WidgetState = vtkButtonWidget::Start;
     }
   }
-  else //state is Start
+  else // state is Start
   {
-    if ( state == vtkButtonRepresentation::Inside )
+    if (state == vtkButtonRepresentation::Inside)
     {
       renderRequired = 1;
-      if ( self->ManagesCursor )
+      if (self->ManagesCursor)
       {
         self->RequestCursorShape(VTK_CURSOR_HAND);
       }
@@ -125,29 +123,29 @@ void vtkButtonWidget::MoveAction(vtkAbstractWidget *w)
     }
   }
 
-  if ( renderRequired )
+  if (renderRequired)
   {
     self->Render();
   }
 }
 
-//----------------------------------------------------------------------------------
-void vtkButtonWidget::SelectAction(vtkAbstractWidget *w)
+//------------------------------------------------------------------------------
+void vtkButtonWidget::SelectAction(vtkAbstractWidget* w)
 {
-  vtkButtonWidget *self = reinterpret_cast<vtkButtonWidget*>(w);
+  vtkButtonWidget* self = reinterpret_cast<vtkButtonWidget*>(w);
 
   int X = self->Interactor->GetEventPosition()[0];
   int Y = self->Interactor->GetEventPosition()[1];
 
   // The state must be hovering for anything to happen. MoveAction sets the
   // state.
-  if ( self->WidgetState != vtkButtonWidget::Hovering )
+  if (self->WidgetState != vtkButtonWidget::Hovering)
   {
     return;
   }
 
   // Okay, make sure that the selection is in the current renderer
-  if (!self->CurrentRenderer || !self->CurrentRenderer->IsInViewport(X,Y))
+  if (!self->CurrentRenderer || !self->CurrentRenderer->IsInViewport(X, Y))
   {
     self->WidgetState = vtkButtonWidget::Start;
     return;
@@ -160,13 +158,12 @@ void vtkButtonWidget::SelectAction(vtkAbstractWidget *w)
   self->Render();
 }
 
-
-//----------------------------------------------------------------------------------
-void vtkButtonWidget::EndSelectAction(vtkAbstractWidget *w)
+//------------------------------------------------------------------------------
+void vtkButtonWidget::EndSelectAction(vtkAbstractWidget* w)
 {
-  vtkButtonWidget *self = reinterpret_cast<vtkButtonWidget*>(w);
+  vtkButtonWidget* self = reinterpret_cast<vtkButtonWidget*>(w);
 
-  if ( self->WidgetState != vtkButtonWidget::Selecting )
+  if (self->WidgetState != vtkButtonWidget::Selecting)
   {
     return;
   }
@@ -175,18 +172,18 @@ void vtkButtonWidget::EndSelectAction(vtkAbstractWidget *w)
   int Y = self->Interactor->GetEventPosition()[1];
 
   int state = self->WidgetRep->ComputeInteractionState(X, Y);
-  if ( state == vtkButtonRepresentation::Outside )
+  if (state == vtkButtonRepresentation::Outside)
   {
-    if ( self->ManagesCursor )
+    if (self->ManagesCursor)
     {
       self->RequestCursorShape(VTK_CURSOR_DEFAULT);
     }
     self->WidgetRep->Highlight(vtkButtonRepresentation::HighlightNormal);
     self->WidgetState = vtkButtonWidget::Start;
   }
-  else //state == vtkButtonRepresentation::Inside
+  else // state == vtkButtonRepresentation::Inside
   {
-    if ( self->ManagesCursor )
+    if (self->ManagesCursor)
     {
       self->RequestCursorShape(VTK_CURSOR_HAND);
     }
@@ -197,15 +194,14 @@ void vtkButtonWidget::EndSelectAction(vtkAbstractWidget *w)
   // Complete interaction
   self->EventCallbackCommand->SetAbortFlag(1);
   reinterpret_cast<vtkButtonRepresentation*>(self->WidgetRep)->NextState();
-  self->InvokeEvent(vtkCommand::StateChangedEvent,nullptr);
+  self->InvokeEvent(vtkCommand::StateChangedEvent, nullptr);
   self->Render();
 }
 
-
-//----------------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkButtonWidget::PrintSelf(ostream& os, vtkIndent indent)
 {
-  //Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
-  this->Superclass::PrintSelf(os,indent);
-
+  // Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
