@@ -49,6 +49,7 @@
 #include "vtkAbstractWidget.h"
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCheckerboardRepresentation;
 class vtkSliderWidget;
 
@@ -60,13 +61,13 @@ public:
    */
   static vtkCheckerboardWidget* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for a VTK class.
    */
   vtkTypeMacro(vtkCheckerboardWidget, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * The method for activating and deactivating this widget. This method
@@ -120,4 +121,5 @@ private:
   void operator=(const vtkCheckerboardWidget&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
