@@ -26,6 +26,7 @@
 #include <algorithm>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkClosedSurfacePointPlacer);
 vtkCxxSetObjectMacro(vtkClosedSurfacePointPlacer, BoundingPlanes, vtkPlaneCollection);
 
@@ -219,7 +220,8 @@ int vtkClosedSurfacePointPlacer::ComputeWorldPosition(vtkRenderer* ren, double d
     if (t != VTK_DOUBLE_MAX)
     {
       node.Plane = plane;
-      node.Distance = this->GetDistanceFromObject(node.p, this->InnerBoundingPlanes, d);
+      node.Distance =
+        vtkClosedSurfacePointPlacer::GetDistanceFromObject(node.p, this->InnerBoundingPlanes, d);
       intersections.push_back(node);
       vtkDebugMacro(<< "We aren't parallel to plane with normal: (" << plane->GetNormal()[0] << ","
                     << plane->GetNormal()[1] << "," << plane->GetNormal()[2] << ")");
@@ -357,3 +359,4 @@ void vtkClosedSurfacePointPlacer::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Minimum Distance: " << this->MinimumDistance << "\n";
 }
+VTK_ABI_NAMESPACE_END
