@@ -30,22 +30,24 @@
 #ifndef vtkContinuousValueWidgetRepresentation_h
 #define vtkContinuousValueWidgetRepresentation_h
 
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKINTERACTIONWIDGETS_EXPORT vtkContinuousValueWidgetRepresentation
   : public vtkWidgetRepresentation
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for the class.
    */
   vtkTypeMacro(vtkContinuousValueWidgetRepresentation, vtkWidgetRepresentation);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods to interface with the vtkSliderWidget. The PlaceWidget() method
    * assumes that the parameter bounds[6] specifies the location in display
@@ -56,15 +58,19 @@ public:
   void StartWidgetInteraction(double eventPos[2]) override = 0;
   void WidgetInteraction(double eventPos[2]) override = 0;
   //  virtual void Highlight(int);
-  //@}
+  ///@}
 
   // Enums are used to describe what is selected
-  enum _InteractionState
+  enum InteractionStateType
   {
     Outside = 0,
     Inside,
     Adjusting
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef InteractionStateType _InteractionState;
+#endif
 
   // Set/Get the value
   virtual void SetValue(double value);
@@ -81,4 +87,5 @@ private:
   void operator=(const vtkContinuousValueWidgetRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
