@@ -18,6 +18,7 @@
 #include "vtkIntArray.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkContourLineInterpolator::vtkContourLineInterpolator() = default;
 
 //------------------------------------------------------------------------------
@@ -81,3 +82,4 @@ void vtkContourLineInterpolator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
