@@ -14,8 +14,7 @@
 =========================================================================*/
 /**
  * @class   vtkCurveRepresentation
- * @brief   vtkWidgetRepresentation
- * base class for a widget that represents an curve that connects control
+ * @brief   base class for a widget that represents a curve that connects control
  * points.
  *
  * Base class for widgets used to define curves from points, such as
@@ -23,16 +22,19 @@
  * uses handles, the number of which can be changed, to represent the
  * points that define the curve. The handles can be picked can be
  * picked on the curve itself to translate or rotate it in the scene.
+ *
+ * @sa
+ * vtkPolyLineRepresentation vtkSplineRepresentation
  */
 
 #ifndef vtkCurveRepresentation_h
 #define vtkCurveRepresentation_h
 
-#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"        // needed for vtkPolyDataAlgorithm
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkCellPicker;
 class vtkDoubleArray;
@@ -154,20 +156,6 @@ public:
   vtkGetMacro(NumberOfHandles, int);
   ///@}
 
-  ///@{
-  /**
-   * @deprecated VTK 9.1. Use `GetDirectional`  and `SetDirectional` instead.
-   */
-  VTK_DEPRECATED_IN_9_1_0("renamed to SetDirectional")
-  virtual void SetDirectionalLine(bool val);
-  VTK_DEPRECATED_IN_9_1_0("renamed to GetDirectional")
-  virtual bool GetDirectionalLine();
-  VTK_DEPRECATED_IN_9_1_0("renamed to DirectionalOn")
-  virtual void DirectionalLineOn();
-  VTK_DEPRECATED_IN_9_1_0("renamed to DirectionalOff")
-  virtual void DirectionalLineOff();
-  ///@}
-
   ///@{
   /**
    * Set the representation to be directional or not.
@@ -255,6 +243,16 @@ public:
    */
   void SetLineColor(double r, double g, double b);
 
+  ///@{
+  /**
+   * Set the color when unselected and selected.
+   */
+  void SetInteractionColor(double, double, double);
+  void SetInteractionColor(double c[3]) { this->SetInteractionColor(c[0], c[1], c[2]); }
+  void SetForegroundColor(double, double, double);
+  void SetForegroundColor(double c[3]) { this->SetForegroundColor(c[0], c[1], c[2]); }
+  ///@}
+
   /*
    * Register internal Pickers within PickingManager
    */
@@ -291,7 +289,7 @@ public:
 
   ///@{
   /**
-   * Returns true if ContrainedAxis
+   * Returns true if ConstrainedAxis
    **/
   bool IsTranslationConstrained() { return this->TranslationAxis != Axis::NONE; }
   ///@}
@@ -387,4 +385,5 @@ private:
   vtkCurveRepresentation(const vtkCurveRepresentation&) = delete;
   void operator=(const vtkCurveRepresentation&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 #endif
