@@ -38,6 +38,7 @@
 #include "vtkVectorText.h"
 #include "vtkWindow.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkDistanceRepresentation3D);
 
 //------------------------------------------------------------------------------
@@ -429,11 +430,7 @@ void vtkDistanceRepresentation3D::SetLabelPosition(double labelPosition)
   vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting LabelPosition to "
                 << labelPosition);
 
-  if (this->LabelPosition == labelPosition)
-  {
-    ;
-  }
-  else
+  if (this->LabelPosition != labelPosition)
   {
     this->LabelPosition = labelPosition;
   }
@@ -482,3 +479,4 @@ void vtkDistanceRepresentation3D::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "LabelActor: " << this->LabelActor << endl;
   os << indent << "GlyphActor: " << this->GlyphActor << endl;
 }
+VTK_ABI_NAMESPACE_END
