@@ -45,9 +45,11 @@
 #ifndef vtkHandleRepresentation_h
 #define vtkHandleRepresentation_h
 
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCoordinate;
 class vtkRenderer;
 class vtkPointPlacer;
@@ -55,15 +57,15 @@ class vtkPointPlacer;
 class VTKINTERACTIONWIDGETS_EXPORT vtkHandleRepresentation : public vtkWidgetRepresentation
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instances of this class.
    */
   vtkTypeMacro(vtkHandleRepresentation, vtkWidgetRepresentation);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Handles usually have their coordinates set in display coordinates
    * (generally by an associated widget) and internally maintain the position
@@ -78,9 +80,9 @@ public:
   virtual void SetWorldPosition(double pos[3]);
   virtual void GetWorldPosition(double pos[3]);
   virtual double* GetWorldPosition() VTK_SIZEHINT(3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The tolerance representing the distance to the widget (in pixels)
    * in which the cursor is considered near enough to the widget to
@@ -88,9 +90,9 @@ public:
    */
   vtkSetClampMacro(Tolerance, int, 1, 100);
   vtkGetMacro(Tolerance, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Flag controls whether the widget becomes visible when the mouse pointer
    * moves close to it (i.e., the widget becomes active). By default,
@@ -99,13 +101,13 @@ public:
   vtkSetMacro(ActiveRepresentation, vtkTypeBool);
   vtkGetMacro(ActiveRepresentation, vtkTypeBool);
   vtkBooleanMacro(ActiveRepresentation, vtkTypeBool);
-  //@}
+  ///@}
 
   // Enums define the state of the representation relative to the mouse pointer
   // position. Used by ComputeInteractionState() to communicate with the
   // widget. Note that ComputeInteractionState() and several other methods
   // must be implemented by subclasses.
-  enum _InteractionState
+  enum InteractionStateType
   {
     Outside = 0,
     Nearby,
@@ -113,8 +115,12 @@ public:
     Translating,
     Scaling
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef InteractionStateType _InteractionState;
+#endif
 
-  //@{
+  ///@{
   /**
    * The interaction state may be set from a widget (e.g., HandleWidget) or
    * other object. This controls how the interaction with the widget
@@ -125,9 +131,9 @@ public:
    * further.
    */
   vtkSetClampMacro(InteractionState, int, Outside, Scaling);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether any motions (such as scale, translate, etc.) are
    * constrained in some way (along an axis, etc.) Widgets can use this
@@ -136,7 +142,7 @@ public:
   vtkSetMacro(Constrained, vtkTypeBool);
   vtkGetMacro(Constrained, vtkTypeBool);
   vtkBooleanMacro(Constrained, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Method has to be overridden in the subclasses which has
@@ -147,14 +153,14 @@ public:
    */
   virtual int CheckConstraint(vtkRenderer* renderer, double pos[2]);
 
-  //@{
+  ///@{
   /**
    * Methods to make this class properly act like a vtkWidgetRepresentation.
    */
   void ShallowCopy(vtkProp* prop) override;
   virtual void DeepCopy(vtkProp* prop);
   void SetRenderer(vtkRenderer* ren) override;
-  //@}
+  ///@}
 
   /**
    * Overload the superclasses' GetMTime() because the internal vtkCoordinates
@@ -162,7 +168,7 @@ public:
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the point placer. Point placers can be used to dictate constraints
    * on the placement of handles. As an example, see vtkBoundedPlanePointPlacer
@@ -173,68 +179,80 @@ public:
    */
   virtual void SetPointPlacer(vtkPointPlacer*);
   vtkGetObjectMacro(PointPlacer, vtkPointPlacer);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Gets the translation vector
    */
   virtual void GetTranslationVector(const double* p1, const double* p2, double* v) const;
 
-  //@{
+  ///@{
   /**
    * Translates world position by vector p1p2 projected on the constraint axis if any.
    */
   virtual void Translate(const double* p1, const double* p2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Translates world position by vector v projected on the constraint axis if any.
    */
   virtual void Translate(const double* v);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Gets/Sets the constraint axis for translations. Returns Axis::NONE
    * if none.
    **/
   vtkGetMacro(TranslationAxis, int);
   vtkSetClampMacro(TranslationAxis, int, -1, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Toggles constraint translation axis on/off.
    */
   void SetXTranslationAxisOn() { this->TranslationAxis = Axis::XAxis; }
   void SetYTranslationAxisOn() { this->TranslationAxis = Axis::YAxis; }
   void SetZTranslationAxisOn() { this->TranslationAxis = Axis::ZAxis; }
+  void SetCustomTranslationAxisOn() { this->TranslationAxis = Axis::Custom; }
   void SetTranslationAxisOff() { this->TranslationAxis = Axis::NONE; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Returns true if ContrainedAxis
+   * Get/Set the translation axis used when vtkHandleRepresentation::TranslationAxis
+   * is set to Axis::Custom.
+   *
+   * @see SetCustomTranslationAxisOn
+   */
+  vtkGetVector3Macro(CustomTranslationAxis, double);
+  vtkSetVector3Macro(CustomTranslationAxis, double);
+  ///@}
+
+  ///@{
+  /**
+   * Returns true if ConstrainedAxis
    **/
   bool IsTranslationConstrained() { return this->TranslationAxis != Axis::NONE; }
-  //@}
+  ///@}
 
 protected:
   vtkHandleRepresentation();
   ~vtkHandleRepresentation() override;
 
-  int Tolerance;
-  vtkTypeBool ActiveRepresentation;
-  vtkTypeBool Constrained;
+  int Tolerance = 15;
+  vtkTypeBool ActiveRepresentation = false;
+  vtkTypeBool Constrained = false;
 
   // Two vtkCoordinates are available to subclasses, one in display
   // coordinates and the other in world coordinates. These facilitate
   // the conversion between these two systems. Note that the WorldPosition
   // is the ultimate maintainer of position.
-  vtkCoordinate* DisplayPosition;
-  vtkCoordinate* WorldPosition;
+  vtkNew<vtkCoordinate> DisplayPosition;
+  vtkNew<vtkCoordinate> WorldPosition;
 
   // Keep track of when coordinates were changed
   vtkTimeStamp DisplayPositionTime;
@@ -244,11 +262,13 @@ protected:
   vtkPointPlacer* PointPlacer;
 
   // Constraint axis translation
-  int TranslationAxis;
+  int TranslationAxis = Axis::NONE;
+  double CustomTranslationAxis[3] = { 1.0, 0.0, 0.0 };
 
 private:
   vtkHandleRepresentation(const vtkHandleRepresentation&) = delete;
   void operator=(const vtkHandleRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
