@@ -108,6 +108,7 @@
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkPolyDataSourceWidget.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkAbstractPropPicker;
 class vtkDataSetMapper;
@@ -723,4 +724,5 @@ private:
   void operator=(const vtkImagePlaneWidget&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
