@@ -39,9 +39,11 @@
 #ifndef vtkImplicitCylinderRepresentation_h
 #define vtkImplicitCylinderRepresentation_h
 
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_3_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkPolyDataMapper;
 class vtkCellPicker;
@@ -71,15 +73,15 @@ public:
    */
   static vtkImplicitCylinderRepresentation* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for the class.
    */
   vtkTypeMacro(vtkImplicitCylinderRepresentation, vtkWidgetRepresentation);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the center of the cylinder. The center is located along the
    * cylinder axis.
@@ -88,9 +90,9 @@ public:
   void SetCenter(double x[3]);
   double* GetCenter() VTK_SIZEHINT(3);
   void GetCenter(double xyz[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the axis of rotation for the cylinder. If the axis is not
    * specified as a unit vector, it will be normalized.
@@ -99,18 +101,18 @@ public:
   void SetAxis(double a[3]);
   double* GetAxis() VTK_SIZEHINT(3);
   void GetAxis(double a[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the radius of the cylinder. Note that if the radius is
    * too big the cylinder will be outside of the bounding box.
    */
   void SetRadius(double r);
   double GetRadius();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the minimum and maximum radius of the cylinder. This
    * helps prevent the cylinder from "disappearing" during
@@ -122,9 +124,9 @@ public:
   vtkGetMacro(MinRadius, double);
   vtkSetClampMacro(MaxRadius, double, 0.25, VTK_FLOAT_MAX);
   vtkGetMacro(MaxRadius, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Force the cylinder widget to be aligned with one of the x-y-z axes.
    * If one axis is set on, the other two will be set off.
@@ -141,9 +143,9 @@ public:
   void SetAlongZAxis(vtkTypeBool);
   vtkGetMacro(AlongZAxis, vtkTypeBool);
   vtkBooleanMacro(AlongZAxis, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable the drawing of the cylinder. In some cases the cylinder
    * interferes with the object that it is operating on (e.g., the
@@ -153,9 +155,9 @@ public:
   void SetDrawCylinder(vtkTypeBool drawCyl);
   vtkGetMacro(DrawCylinder, vtkTypeBool);
   vtkBooleanMacro(DrawCylinder, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the resolution of the cylinder. This is the number of
    * polygonal facets used to approximate the curved cylindrical
@@ -164,9 +166,9 @@ public:
    */
   vtkSetClampMacro(Resolution, int, 8, VTK_MAX_CYL_RESOLUTION);
   vtkGetMacro(Resolution, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off tubing of the wire outline of the cylinder
    * intersection (against the bounding box). The tube thickens the
@@ -175,9 +177,9 @@ public:
   vtkSetMacro(Tubing, vtkTypeBool);
   vtkGetMacro(Tubing, vtkTypeBool);
   vtkBooleanMacro(Tubing, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the ability to translate the bounding box by moving it
    * with the mouse.
@@ -185,9 +187,9 @@ public:
   vtkSetMacro(OutlineTranslation, vtkTypeBool);
   vtkGetMacro(OutlineTranslation, vtkTypeBool);
   vtkBooleanMacro(OutlineTranslation, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the ability to move the widget outside of the bounds
    * specified in the PlaceWidget() invocation.
@@ -195,9 +197,9 @@ public:
   vtkSetMacro(OutsideBounds, vtkTypeBool);
   vtkGetMacro(OutsideBounds, vtkTypeBool);
   vtkBooleanMacro(OutsideBounds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the bounds of the widget representation. PlaceWidget can also be
    * used to set the bounds of the widget but it may also have other effects
@@ -206,9 +208,9 @@ public:
    */
   vtkSetVector6Macro(WidgetBounds, double);
   vtkGetVector6Macro(WidgetBounds, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off whether the cylinder should be constrained to the widget bounds.
    * If on, the center will not be allowed to move outside the set widget bounds
@@ -220,16 +222,16 @@ public:
   vtkSetMacro(ConstrainToWidgetBounds, vtkTypeBool);
   vtkGetMacro(ConstrainToWidgetBounds, vtkTypeBool);
   vtkBooleanMacro(ConstrainToWidgetBounds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the ability to scale the widget with the mouse.
    */
   vtkSetMacro(ScaleEnabled, vtkTypeBool);
   vtkGetMacro(ScaleEnabled, vtkTypeBool);
   vtkBooleanMacro(ScaleEnabled, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Get the implicit function for the cylinder. The user must provide the
@@ -249,50 +251,68 @@ public:
    * Satisfies the superclass API.  This will change the state of the widget
    * to match changes that have been made to the underlying PolyDataSource.
    */
-  void UpdatePlacement(void);
+  void UpdatePlacement();
 
-  //@{
+  ///@{
   /**
    * Get the properties on the axis (line and cone).
    */
   vtkGetObjectMacro(AxisProperty, vtkProperty);
   vtkGetObjectMacro(SelectedAxisProperty, vtkProperty);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the cylinder properties. The properties of the cylinder when selected
    * and unselected can be manipulated.
    */
   vtkGetObjectMacro(CylinderProperty, vtkProperty);
   vtkGetObjectMacro(SelectedCylinderProperty, vtkProperty);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the property of the outline.
    */
   vtkGetObjectMacro(OutlineProperty, vtkProperty);
   vtkGetObjectMacro(SelectedOutlineProperty, vtkProperty);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the property of the intersection edges. (This property also
    * applies to the edges when tubed.)
    */
   vtkGetObjectMacro(EdgesProperty, vtkProperty);
-  //@}
-  //@{
+  ///@}
+
+  ///@{
+  /**
+   * Set the color of all the widgets handles (edges, axis, selected cylinder)
+   * and their color during interaction. Foreground color applies to the outlines and unselected
+   * cylinder.
+   */
+  void SetInteractionColor(double, double, double);
+  void SetInteractionColor(double c[3]) { this->SetInteractionColor(c[0], c[1], c[2]); }
+  void SetHandleColor(double, double, double);
+  void SetHandleColor(double c[3]) { this->SetHandleColor(c[0], c[1], c[2]); }
+  void SetForegroundColor(double, double, double);
+  void SetForegroundColor(double c[3]) { this->SetForegroundColor(c[0], c[1], c[2]); }
+  ///@}
+
+  ///@{
   /**
    * Set color to the edge
    */
-  void SetEdgeColor(vtkLookupTable*);
-  void SetEdgeColor(double, double, double);
-  void SetEdgeColor(double c[3]);
-  //@}
+  VTK_DEPRECATED_IN_9_3_0("Please use GetEdgesProperty or SetHandleColor instead.")
+  void SetEdgeColor(vtkLookupTable*) {}
+  VTK_DEPRECATED_IN_9_3_0("Please use GetEdgesProperty or SetHandleColor instead.")
+  void SetEdgeColor(double, double, double) {}
+  VTK_DEPRECATED_IN_9_3_0("Please use GetEdgesProperty or SetHandleColor instead.")
+  void SetEdgeColor(double[3]) {}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods to interface with the vtkImplicitCylinderWidget.
    */
@@ -302,9 +322,9 @@ public:
   void StartWidgetInteraction(double eventPos[2]) override;
   void WidgetInteraction(double newEventPos[2]) override;
   void EndWidgetInteraction(double newEventPos[2]) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods supporting the rendering process.
    */
@@ -314,9 +334,9 @@ public:
   int RenderOpaqueGeometry(vtkViewport*) override;
   int RenderTranslucentPolygonalGeometry(vtkViewport*) override;
   vtkTypeBool HasTranslucentPolygonalGeometry() override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a translation distance used by the BumpCylinder() method. Note that the
    * distance is normalized; it is the fraction of the length of the bounding
@@ -324,7 +344,7 @@ public:
    */
   vtkSetClampMacro(BumpDistance, double, 0.000001, 1);
   vtkGetMacro(BumpDistance, double);
-  //@}
+  ///@}
 
   /**
    * Translate the cylinder in the direction of the view vector by the
@@ -344,7 +364,7 @@ public:
   void PushCylinder(double distance);
 
   // Manage the state of the widget
-  enum _InteractionState
+  enum InteractionStateType
   {
     Outside = 0,
     Moving,
@@ -355,8 +375,12 @@ public:
     Scaling,
     TranslatingCenter
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef InteractionStateType _InteractionState;
+#endif
 
-  //@{
+  ///@{
   /**
    * The interaction state may be set from a widget (e.g.,
    * vtkImplicitCylinderWidget) or other object. This controls how the
@@ -367,32 +391,32 @@ public:
    * based on events, the widget may modify this further.
    */
   vtkSetClampMacro(InteractionState, int, Outside, TranslatingCenter);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets the visual appearance of the representation based on the
    * state it is in. This state is usually the same as InteractionState.
    */
   virtual void SetRepresentationState(int);
   vtkGetMacro(RepresentationState, int);
-  //@}
+  ///@}
 
   /*
    * Register internal Pickers within PickingManager
    */
   void RegisterPickers() override;
 
-  //@{
+  ///@{
   /**
    * Gets/Sets the constraint axis for translations. Returns Axis::NONE
    * if none.
    **/
   vtkGetMacro(TranslationAxis, int);
   vtkSetClampMacro(TranslationAxis, int, -1, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Toggles constraint translation axis on/off.
    */
@@ -400,14 +424,14 @@ public:
   void SetYTranslationAxisOn() { this->TranslationAxis = Axis::YAxis; }
   void SetZTranslationAxisOn() { this->TranslationAxis = Axis::ZAxis; }
   void SetTranslationAxisOff() { this->TranslationAxis = Axis::NONE; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Returns true if ContrainedAxis
+   * Returns true if ConstrainedAxis
    **/
   bool IsTranslationConstrained() { return this->TranslationAxis != Axis::NONE; }
-  //@}
+  ///@}
 
 protected:
   vtkImplicitCylinderRepresentation();
@@ -530,4 +554,5 @@ private:
   void operator=(const vtkImplicitCylinderRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
