@@ -15,13 +15,11 @@
 #include "vtkImplicitPlaneRepresentation.h"
 
 #include "vtkActor.h"
-#include "vtkAssemblyNode.h"
 #include "vtkAssemblyPath.h"
 #include "vtkBox.h"
 #include "vtkCallbackCommand.h"
 #include "vtkCamera.h"
 #include "vtkCellPicker.h"
-#include "vtkCommand.h"
 #include "vtkConeSource.h"
 #include "vtkCutter.h"
 #include "vtkEventData.h"
@@ -50,6 +48,7 @@
 
 #include <cfloat> //for FLT_EPSILON
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImplicitPlaneRepresentation);
 
 //------------------------------------------------------------------------------
@@ -98,7 +97,7 @@ vtkImplicitPlaneRepresentation::vtkImplicitPlaneRepresentation()
   this->Cutter->SetCutFunction(this->Plane);
   this->PlaneSource = vtkPlaneSource::New();
   this->PlaneSource->SetOutputPointsPrecision(vtkAlgorithm::DOUBLE_PRECISION);
-  this->PlaneSource->SetResolution(128, 128);
+  this->PlaneSource->SetResolution(1, 1);
   this->CutMapper = vtkPolyDataMapper::New();
   this->CutMapper->SetInputConnection(this->Cutter->GetOutputPort());
   this->CutActor = vtkActor::New();
@@ -119,7 +118,7 @@ vtkImplicitPlaneRepresentation::vtkImplicitPlaneRepresentation()
   this->EdgesActor->SetMapper(this->EdgesMapper);
   this->Tubing = 1; // control whether tubing is on
 
-  // Create the + plane normal
+  // Create the +- plane normal
   this->LineSource = vtkLineSource::New();
   this->LineSource->SetResolution(1);
   this->LineSource->SetOutputPointsPrecision(vtkAlgorithm::DOUBLE_PRECISION);
@@ -137,15 +136,6 @@ vtkImplicitPlaneRepresentation::vtkImplicitPlaneRepresentation()
   this->ConeActor = vtkActor::New();
   this->ConeActor->SetMapper(this->ConeMapper);
 
-  // Create the - plane normal
-  this->LineSource2 = vtkLineSource::New();
-  this->LineSource2->SetOutputPointsPrecision(vtkAlgorithm::DOUBLE_PRECISION);
-  this->LineSource2->SetResolution(1);
-  this->LineMapper2 = vtkPolyDataMapper::New();
-  this->LineMapper2->SetInputConnection(this->LineSource2->GetOutputPort());
-  this->LineActor2 = vtkActor::New();
-  this->LineActor2->SetMapper(this->LineMapper2);
-
   this->ConeSource2 = vtkConeSource::New();
   this->ConeSource2->SetOutputPointsPrecision(vtkAlgorithm::DOUBLE_PRECISION);
   this->ConeSource2->SetResolution(12);
@@ -185,7 +175,6 @@ vtkImplicitPlaneRepresentation::vtkImplicitPlaneRepresentation()
   this->Picker->AddPickList(this->CutActor);
   this->Picker->AddPickList(this->LineActor);
   this->Picker->AddPickList(this->ConeActor);
-  this->Picker->AddPickList(this->LineActor2);
   this->Picker->AddPickList(this->ConeActor2);
   this->Picker->AddPickList(this->SphereActor);
   this->Picker->AddPickList(this->OutlineActor);
@@ -197,7 +186,6 @@ vtkImplicitPlaneRepresentation::vtkImplicitPlaneRepresentation()
   // Pass the initial properties to the actors.
   this->LineActor->SetProperty(this->NormalProperty);
   this->ConeActor->SetProperty(this->NormalProperty);
-  this->LineActor2->SetProperty(this->NormalProperty);
   this->ConeActor2->SetProperty(this->NormalProperty);
   this->SphereActor->SetProperty(this->NormalProperty);
   this->CutActor->SetProperty(this->PlaneProperty);
@@ -239,10 +227,6 @@ vtkImplicitPlaneRepresentation::~vtkImplicitPlaneRepresentation()
   this->ConeMapper->Delete();
   this->ConeActor->Delete();
 
-  this->LineSource2->Delete();
-  this->LineMapper2->Delete();
-  this->LineActor2->Delete();
-
   this->ConeSource2->Delete();
   this->ConeMapper2->Delete();
   this->ConeActor2->Delete();
@@ -279,7 +263,6 @@ void vtkImplicitPlaneRepresentation::SetLockNormalToCamera(vtkTypeBool lock)
   {
     this->Picker->DeletePickList(this->LineActor);
     this->Picker->DeletePickList(this->ConeActor);
-    this->Picker->DeletePickList(this->LineActor2);
     this->Picker->DeletePickList(this->ConeActor2);
     this->Picker->DeletePickList(this->SphereActor);
 
@@ -289,7 +272,6 @@ void vtkImplicitPlaneRepresentation::SetLockNormalToCamera(vtkTypeBool lock)
   {
     this->Picker->AddPickList(this->LineActor);
     this->Picker->AddPickList(this->ConeActor);
-    this->Picker->AddPickList(this->LineActor2);
     this->Picker->AddPickList(this->ConeActor2);
     this->Picker->AddPickList(this->SphereActor);
   }
@@ -341,8 +323,7 @@ int vtkImplicitPlaneRepresentation::ComputeInteractionState(int X, int Y, int vt
   if (this->InteractionState == vtkImplicitPlaneRepresentation::Moving)
   {
     vtkProp* prop = path->GetFirstNode()->GetViewProp();
-    if (prop == this->ConeActor || prop == this->LineActor || prop == this->ConeActor2 ||
-      prop == this->LineActor2)
+    if (prop == this->ConeActor || prop == this->LineActor || prop == this->ConeActor2)
     {
       this->InteractionState = vtkImplicitPlaneRepresentation::Rotating;
       this->SetRepresentationState(vtkImplicitPlaneRepresentation::Rotating);
@@ -428,8 +409,7 @@ int vtkImplicitPlaneRepresentation::ComputeComplexInteractionState(
     if (this->InteractionState == vtkImplicitPlaneRepresentation::Moving)
     {
       vtkProp* prop = path->GetFirstNode()->GetViewProp();
-      if (prop == this->ConeActor || prop == this->LineActor || prop == this->ConeActor2 ||
-        prop == this->LineActor2)
+      if (prop == this->ConeActor || prop == this->LineActor || prop == this->ConeActor2)
       {
         this->InteractionState = vtkImplicitPlaneRepresentation::Rotating;
         this->SetRepresentationState(vtkImplicitPlaneRepresentation::Rotating);
@@ -692,7 +672,6 @@ double* vtkImplicitPlaneRepresentation::GetBounds()
   this->BoundingBox->AddBounds(this->ConeActor->GetBounds());
   this->BoundingBox->AddBounds(this->LineActor->GetBounds());
   this->BoundingBox->AddBounds(this->ConeActor2->GetBounds());
-  this->BoundingBox->AddBounds(this->LineActor2->GetBounds());
   this->BoundingBox->AddBounds(this->SphereActor->GetBounds());
 
   return this->BoundingBox->GetBounds();
@@ -701,17 +680,18 @@ double* vtkImplicitPlaneRepresentation::GetBounds()
 //------------------------------------------------------------------------------
 void vtkImplicitPlaneRepresentation::GetActors(vtkPropCollection* pc)
 {
-  if (this->Visibility)
+  if (!pc)
   {
-    this->OutlineActor->GetActors(pc);
-    this->CutActor->GetActors(pc);
-    this->EdgesActor->GetActors(pc);
-    this->ConeActor->GetActors(pc);
-    this->LineActor->GetActors(pc);
-    this->ConeActor2->GetActors(pc);
-    this->LineActor2->GetActors(pc);
-    this->SphereActor->GetActors(pc);
+    return;
   }
+  pc->AddItem(this->OutlineActor);
+  pc->AddItem(this->CutActor);
+  pc->AddItem(this->EdgesActor);
+  pc->AddItem(this->ConeActor);
+  pc->AddItem(this->LineActor);
+  pc->AddItem(this->ConeActor2);
+  pc->AddItem(this->SphereActor);
+  this->Superclass::GetActors(pc);
 }
 
 //------------------------------------------------------------------------------
@@ -723,7 +703,6 @@ void vtkImplicitPlaneRepresentation::ReleaseGraphicsResources(vtkWindow* w)
   this->ConeActor->ReleaseGraphicsResources(w);
   this->LineActor->ReleaseGraphicsResources(w);
   this->ConeActor2->ReleaseGraphicsResources(w);
-  this->LineActor2->ReleaseGraphicsResources(w);
   this->SphereActor->ReleaseGraphicsResources(w);
 }
 
@@ -742,7 +721,6 @@ int vtkImplicitPlaneRepresentation::RenderOpaqueGeometry(vtkViewport* v)
     count += this->ConeActor->RenderOpaqueGeometry(v);
     count += this->LineActor->RenderOpaqueGeometry(v);
     count += this->ConeActor2->RenderOpaqueGeometry(v);
-    count += this->LineActor2->RenderOpaqueGeometry(v);
     count += this->SphereActor->RenderOpaqueGeometry(v);
   }
   if (this->DrawPlane)
@@ -768,7 +746,6 @@ int vtkImplicitPlaneRepresentation::RenderTranslucentPolygonalGeometry(vtkViewpo
     count += this->ConeActor->RenderTranslucentPolygonalGeometry(v);
     count += this->LineActor->RenderTranslucentPolygonalGeometry(v);
     count += this->ConeActor2->RenderTranslucentPolygonalGeometry(v);
-    count += this->LineActor2->RenderTranslucentPolygonalGeometry(v);
     count += this->SphereActor->RenderTranslucentPolygonalGeometry(v);
   }
   if (this->DrawPlane)
@@ -793,7 +770,6 @@ vtkTypeBool vtkImplicitPlaneRepresentation::HasTranslucentPolygonalGeometry()
     result |= this->ConeActor->HasTranslucentPolygonalGeometry();
     result |= this->LineActor->HasTranslucentPolygonalGeometry();
     result |= this->ConeActor2->HasTranslucentPolygonalGeometry();
-    result |= this->LineActor2->HasTranslucentPolygonalGeometry();
     result |= this->SphereActor->HasTranslucentPolygonalGeometry();
   }
   if (this->DrawPlane)
@@ -930,7 +906,6 @@ void vtkImplicitPlaneRepresentation::HighlightNormal(int highlight)
   {
     this->LineActor->SetProperty(this->SelectedNormalProperty);
     this->ConeActor->SetProperty(this->SelectedNormalProperty);
-    this->LineActor2->SetProperty(this->SelectedNormalProperty);
     this->ConeActor2->SetProperty(this->SelectedNormalProperty);
     this->SphereActor->SetProperty(this->SelectedNormalProperty);
   }
@@ -938,7 +913,6 @@ void vtkImplicitPlaneRepresentation::HighlightNormal(int highlight)
   {
     this->LineActor->SetProperty(this->NormalProperty);
     this->ConeActor->SetProperty(this->NormalProperty);
-    this->LineActor2->SetProperty(this->NormalProperty);
     this->ConeActor2->SetProperty(this->NormalProperty);
     this->SphereActor->SetProperty(this->NormalProperty);
   }
@@ -1295,33 +1269,56 @@ void vtkImplicitPlaneRepresentation::CreateDefaultProperties()
 
   this->SelectedNormalProperty = vtkProperty::New();
   this->SelectedNormalProperty->SetColor(1, 0, 0);
-  this->NormalProperty->SetLineWidth(2);
+  this->SelectedNormalProperty->SetLineWidth(2);
 
   // Plane properties
   this->PlaneProperty = vtkProperty::New();
   this->PlaneProperty->SetAmbient(1.0);
-  this->PlaneProperty->SetAmbientColor(1.0, 1.0, 1.0);
+  this->PlaneProperty->SetColor(1.0, 1.0, 1.0);
   this->PlaneProperty->SetOpacity(0.5);
   this->CutActor->SetProperty(this->PlaneProperty);
 
   this->SelectedPlaneProperty = vtkProperty::New();
   this->SelectedPlaneProperty->SetAmbient(1.0);
-  this->SelectedPlaneProperty->SetAmbientColor(0.0, 1.0, 0.0);
+  this->SelectedPlaneProperty->SetColor(0.0, 1.0, 0.0);
   this->SelectedPlaneProperty->SetOpacity(0.25);
 
   // Outline properties
   this->OutlineProperty = vtkProperty::New();
   this->OutlineProperty->SetAmbient(1.0);
-  this->OutlineProperty->SetAmbientColor(1.0, 1.0, 1.0);
+  this->OutlineProperty->SetColor(1.0, 1.0, 1.0);
 
   this->SelectedOutlineProperty = vtkProperty::New();
   this->SelectedOutlineProperty->SetAmbient(1.0);
-  this->SelectedOutlineProperty->SetAmbientColor(0.0, 1.0, 0.0);
+  this->SelectedOutlineProperty->SetColor(0.0, 1.0, 0.0);
 
   // Edge property
   this->EdgesProperty = vtkProperty::New();
   this->EdgesProperty->SetAmbient(1.0);
-  this->EdgesProperty->SetAmbientColor(1.0, 1.0, 1.0);
+  this->EdgesProperty->SetColor(1.0, 1.0, 1.0);
+}
+
+//------------------------------------------------------------------------------
+void vtkImplicitPlaneRepresentation::SetInteractionColor(double r, double g, double b)
+{
+  this->SelectedNormalProperty->SetColor(r, g, b);
+  this->SelectedOutlineProperty->SetColor(r, g, b);
+  this->SelectedPlaneProperty->SetColor(r, g, b);
+}
+
+//------------------------------------------------------------------------------
+void vtkImplicitPlaneRepresentation::SetHandleColor(double r, double g, double b)
+{
+  this->NormalProperty->SetColor(r, g, b);
+  this->EdgesProperty->SetColor(r, g, b);
+  this->SetEdgeColor(r, g, b);
+}
+
+//------------------------------------------------------------------------------
+void vtkImplicitPlaneRepresentation::SetForegroundColor(double r, double g, double b)
+{
+  this->PlaneProperty->SetColor(r, g, b);
+  this->OutlineProperty->SetColor(r, g, b);
 }
 
 //------------------------------------------------------------------------------
@@ -1608,7 +1605,7 @@ void vtkImplicitPlaneRepresentation::UpdatePlacement()
 {
   this->Outline->Update();
   this->Cutter->Update();
-  this->Edges->Update();
+  // this->Edges->Update();
   this->BuildRepresentation();
 }
 
@@ -1644,11 +1641,9 @@ void vtkImplicitPlaneRepresentation::BuildRepresentation()
   this->ConeActor->SetPropertyKeys(info);
   this->LineActor->SetPropertyKeys(info);
   this->ConeActor2->SetPropertyKeys(info);
-  this->LineActor2->SetPropertyKeys(info);
   this->SphereActor->SetPropertyKeys(info);
 
-  if (this->GetMTime() > this->BuildTime || this->Plane->GetMTime() > this->BuildTime ||
-    this->Renderer->GetRenderWindow()->GetMTime() > this->BuildTime)
+  if (this->GetMTime() > this->BuildTime || this->Plane->GetMTime() > this->BuildTime)
   {
     double* origin = this->Plane->GetOrigin();
     double* normal = this->Plane->GetNormal();
@@ -1734,8 +1729,7 @@ void vtkImplicitPlaneRepresentation::BuildRepresentation()
     p2[1] = origin[1] + 0.30 * d * normal[1];
     p2[2] = origin[2] + 0.30 * d * normal[2];
 
-    this->LineSource->SetPoint1(origin);
-    this->LineSource->SetPoint2(p2);
+    this->LineSource->SetPoint1(p2);
     this->ConeSource->SetCenter(p2);
     this->ConeSource->SetDirection(normal);
 
@@ -1743,8 +1737,7 @@ void vtkImplicitPlaneRepresentation::BuildRepresentation()
     p2[1] = origin[1] - 0.30 * d * normal[1];
     p2[2] = origin[2] - 0.30 * d * normal[2];
 
-    this->LineSource2->SetPoint1(origin[0], origin[1], origin[2]);
-    this->LineSource2->SetPoint2(p2);
+    this->LineSource->SetPoint2(p2);
     this->ConeSource2->SetCenter(p2);
     this->ConeSource2->SetDirection(normal[0], normal[1], normal[2]);
 
@@ -1760,7 +1753,12 @@ void vtkImplicitPlaneRepresentation::BuildRepresentation()
     {
       this->EdgesMapper->SetInputConnection(this->Edges->GetOutputPort());
     }
+  }
 
+  // we resize handles when rebuilt and when renderwindow changes
+  if (this->GetMTime() > this->BuildTime || this->Plane->GetMTime() > this->BuildTime ||
+    this->Renderer->GetRenderWindow()->GetMTime() > this->BuildTime)
+  {
     this->SizeHandles();
     this->BuildTime.Modified();
   }
@@ -1805,3 +1803,4 @@ void vtkImplicitPlaneRepresentation::RegisterPickers()
   }
   pm->AddPicker(this->Picker, this);
 }
+VTK_ABI_NAMESPACE_END
