@@ -38,28 +38,30 @@
 #ifndef vtkImplicitPlaneRepresentation_h
 #define vtkImplicitPlaneRepresentation_h
 
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
-class vtkPolyDataMapper;
+class vtkBox;
 class vtkCellPicker;
 class vtkConeSource;
+class vtkCutter;
+class vtkFeatureEdges;
+class vtkImageData;
 class vtkLineSource;
-class vtkSphereSource;
-class vtkTubeFilter;
+class vtkLookupTable;
+class vtkOutlineFilter;
 class vtkPlane;
 class vtkPlaneSource;
-class vtkCutter;
-class vtkProperty;
-class vtkImageData;
-class vtkOutlineFilter;
-class vtkFeatureEdges;
 class vtkPolyData;
 class vtkPolyDataAlgorithm;
+class vtkPolyDataMapper;
+class vtkProperty;
+class vtkSphereSource;
 class vtkTransform;
-class vtkBox;
-class vtkLookupTable;
+class vtkTubeFilter;
 
 class VTKINTERACTIONWIDGETS_EXPORT vtkImplicitPlaneRepresentation : public vtkWidgetRepresentation
 {
@@ -69,15 +71,15 @@ public:
    */
   static vtkImplicitPlaneRepresentation* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for the class.
    */
   vtkTypeMacro(vtkImplicitPlaneRepresentation, vtkWidgetRepresentation);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the origin of the plane.
    */
@@ -85,9 +87,9 @@ public:
   void SetOrigin(double x[3]);
   double* GetOrigin() VTK_SIZEHINT(3);
   void GetOrigin(double xyz[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the normal to the plane.
    */
@@ -96,9 +98,9 @@ public:
   void SetNormalToCamera();
   double* GetNormal() VTK_SIZEHINT(3);
   void GetNormal(double xyz[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Force the plane widget to be aligned with one of the x-y-z axes.
    * If one axis is set on, the other two will be set off.
@@ -115,9 +117,9 @@ public:
   void SetNormalToZAxis(vtkTypeBool);
   vtkGetMacro(NormalToZAxis, vtkTypeBool);
   vtkBooleanMacro(NormalToZAxis, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If enabled, and a vtkCamera is available through the renderer, then
    * LockNormalToCamera will cause the normal to follow the camera's
@@ -126,9 +128,9 @@ public:
   virtual void SetLockNormalToCamera(vtkTypeBool);
   vtkGetMacro(LockNormalToCamera, vtkTypeBool);
   vtkBooleanMacro(LockNormalToCamera, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off tubing of the wire outline of the plane. The tube thickens
    * the line by wrapping with a vtkTubeFilter.
@@ -136,9 +138,9 @@ public:
   vtkSetMacro(Tubing, vtkTypeBool);
   vtkGetMacro(Tubing, vtkTypeBool);
   vtkBooleanMacro(Tubing, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable the drawing of the plane. In some cases the plane
    * interferes with the object that it is operating on (i.e., the
@@ -148,18 +150,18 @@ public:
   void SetDrawPlane(vtkTypeBool plane);
   vtkGetMacro(DrawPlane, vtkTypeBool);
   vtkBooleanMacro(DrawPlane, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable the drawing of the outline.
    */
   void SetDrawOutline(vtkTypeBool plane);
   vtkGetMacro(DrawOutline, vtkTypeBool);
   vtkBooleanMacro(DrawOutline, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the ability to translate the bounding box by grabbing it
    * with the left mouse button.
@@ -167,9 +169,9 @@ public:
   vtkSetMacro(OutlineTranslation, vtkTypeBool);
   vtkGetMacro(OutlineTranslation, vtkTypeBool);
   vtkBooleanMacro(OutlineTranslation, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the ability to move the widget outside of the bounds
    * specified in the initial PlaceWidget() invocation.
@@ -177,9 +179,9 @@ public:
   vtkSetMacro(OutsideBounds, vtkTypeBool);
   vtkGetMacro(OutsideBounds, vtkTypeBool);
   vtkBooleanMacro(OutsideBounds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Toggles constraint translation axis on/off.
    */
@@ -187,16 +189,16 @@ public:
   void SetYTranslationAxisOn() { this->TranslationAxis = Axis::YAxis; }
   void SetZTranslationAxisOn() { this->TranslationAxis = Axis::ZAxis; }
   void SetTranslationAxisOff() { this->TranslationAxis = Axis::NONE; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Returns true if ContrainedAxis
+   * Returns true if ConstrainedAxis
    **/
   bool IsTranslationConstrained() { return this->TranslationAxis != Axis::NONE; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the bounds of the widget representation. PlaceWidget can also be
    * used to set the bounds of the widget but it may also have other effects
@@ -205,9 +207,9 @@ public:
    */
   vtkSetVector6Macro(WidgetBounds, double);
   vtkGetVector6Macro(WidgetBounds, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off whether the plane should be constrained to the widget bounds.
    * If on, the origin will not be allowed to move outside the set widget bounds.
@@ -218,16 +220,16 @@ public:
   vtkSetMacro(ConstrainToWidgetBounds, vtkTypeBool);
   vtkGetMacro(ConstrainToWidgetBounds, vtkTypeBool);
   vtkBooleanMacro(ConstrainToWidgetBounds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the ability to scale the widget with the mouse.
    */
   vtkSetMacro(ScaleEnabled, vtkTypeBool);
   vtkGetMacro(ScaleEnabled, vtkTypeBool);
   vtkBooleanMacro(ScaleEnabled, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Grab the polydata that defines the plane. The polydata contains a single
@@ -261,50 +263,65 @@ public:
    * Satisfies the superclass API.  This will change the state of the widget
    * to match changes that have been made to the underlying PolyDataSource
    */
-  void UpdatePlacement(void);
+  void UpdatePlacement();
 
-  //@{
+  ///@{
   /**
    * Get the properties on the normal (line and cone).
    */
   vtkGetObjectMacro(NormalProperty, vtkProperty);
   vtkGetObjectMacro(SelectedNormalProperty, vtkProperty);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the plane properties. The properties of the plane when selected
    * and unselected can be manipulated.
    */
   vtkGetObjectMacro(PlaneProperty, vtkProperty);
   vtkGetObjectMacro(SelectedPlaneProperty, vtkProperty);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the property of the outline.
    */
   vtkGetObjectMacro(OutlineProperty, vtkProperty);
   vtkGetObjectMacro(SelectedOutlineProperty, vtkProperty);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the property of the intersection edges. (This property also
    * applies to the edges when tubed.)
    */
   vtkGetObjectMacro(EdgesProperty, vtkProperty);
-  //@}
-  //@{
+  ///@}
+
+  ///@{
+  /**
+   * Set the color of all the widget's handles (edges, cone1, cone2, line, sphere, selected plane)
+   * and their color during interaction. Foreground color applies to the outlines and unselected
+   * plane.
+   */
+  void SetInteractionColor(double, double, double);
+  void SetInteractionColor(double c[3]) { this->SetInteractionColor(c[0], c[1], c[2]); }
+  void SetHandleColor(double, double, double);
+  void SetHandleColor(double c[3]) { this->SetHandleColor(c[0], c[1], c[2]); }
+  void SetForegroundColor(double, double, double);
+  void SetForegroundColor(double c[3]) { this->SetForegroundColor(c[0], c[1], c[2]); }
+  ///@}
+
+  ///@{
   /**
    * Set color to the edge
    */
   void SetEdgeColor(vtkLookupTable*);
   void SetEdgeColor(double, double, double);
   void SetEdgeColor(double c[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify a translation distance used by the BumpPlane() method. Note that the
    * distance is normalized; it is the fraction of the length of the bounding
@@ -312,7 +329,7 @@ public:
    */
   vtkSetClampMacro(BumpDistance, double, 0.000001, 1);
   vtkGetMacro(BumpDistance, double);
-  //@}
+  ///@}
 
   /**
    * Translate the plane in the direction of the normal by the
@@ -332,7 +349,7 @@ public:
    */
   void PushPlane(double distance);
 
-  //@{
+  ///@{
   /**
    * Methods to interface with the vtkImplicitPlaneWidget2.
    */
@@ -350,9 +367,9 @@ public:
     unsigned long event, void* calldata, int modify = 0) override;
   void EndComplexInteraction(vtkRenderWindowInteractor* iren, vtkAbstractWidget* widget,
     unsigned long event, void* calldata) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods supporting the rendering process.
    */
@@ -362,10 +379,10 @@ public:
   int RenderOpaqueGeometry(vtkViewport*) override;
   int RenderTranslucentPolygonalGeometry(vtkViewport*) override;
   vtkTypeBool HasTranslucentPolygonalGeometry() override;
-  //@}
+  ///@}
 
   // Manage the state of the widget
-  enum _InteractionState
+  enum InteractionStateType
   {
     Outside = 0,
     Moving,
@@ -375,8 +392,12 @@ public:
     Pushing,
     Scaling
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef InteractionStateType _InteractionState;
+#endif
 
-  //@{
+  ///@{
   /**
    * The interaction state may be set from a widget (e.g.,
    * vtkImplicitPlaneWidget2) or other object. This controls how the
@@ -387,22 +408,22 @@ public:
    * based on events, the widget may modify this further.
    */
   vtkSetClampMacro(InteractionState, int, Outside, Scaling);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets the visual appearance of the representation based on the
    * state it is in. This state is usually the same as InteractionState.
    */
   virtual void SetRepresentationState(int);
   vtkGetMacro(RepresentationState, int);
-  //@}
+  ///@}
 
   // Get the underlying implicit plane object used by this rep
   // that can be used as a cropping plane in vtkMapper.
   vtkPlane* GetUnderlyingPlane() { return this->Plane; }
 
-  //@{
+  ///@{
   /**
    * Control if the plane should be drawn cropped by the bounding box
    * or without cropping. Defaults to on.
@@ -410,18 +431,18 @@ public:
   virtual void SetCropPlaneToBoundingBox(bool);
   vtkGetMacro(CropPlaneToBoundingBox, bool);
   vtkBooleanMacro(CropPlaneToBoundingBox, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * For complex events should we snap orientations to
    * be aligned with the x y z axes
    */
   vtkGetMacro(SnapToAxes, bool);
   vtkSetMacro(SnapToAxes, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Forces the plane's normal to be aligned with x, y or z axis.
    * The alignment happens when calling SetNormal.
@@ -434,7 +455,7 @@ public:
     this->AlwaysSnapToNearestAxis = snap;
     this->SetNormal(this->GetNormal());
   }
-  //@}
+  ///@}
 
 protected:
   vtkImplicitPlaneRepresentation();
@@ -503,7 +524,7 @@ protected:
   vtkActor* ConeActor;
   void HighlightNormal(int highlight);
 
-  // The + normal line
+  // The normal line
   vtkLineSource* LineSource;
   vtkPolyDataMapper* LineMapper;
   vtkActor* LineActor;
@@ -513,11 +534,6 @@ protected:
   vtkPolyDataMapper* ConeMapper2;
   vtkActor* ConeActor2;
 
-  // The - normal line
-  vtkLineSource* LineSource2;
-  vtkPolyDataMapper* LineMapper2;
-  vtkActor* LineActor2;
-
   // The origin positioning handle
   vtkSphereSource* Sphere;
   vtkPolyDataMapper* SphereMapper;
@@ -535,7 +551,6 @@ protected:
   // Methods to manipulate the plane
   void Rotate(double X, double Y, double* p1, double* p2, double* vpn);
   void Rotate3D(double* p1, double* p2);
-  void TranslatePlane(double* p1, double* p2);
   void TranslateOutline(double* p1, double* p2);
   void TranslateOrigin(double* p1, double* p2);
   void UpdatePose(double* p1, double* d1, double* p2, double* d2);
@@ -554,8 +569,6 @@ protected:
   vtkProperty* EdgesProperty;
   virtual void CreateDefaultProperties();
 
-  void GeneratePlane();
-
   bool CropPlaneToBoundingBox;
 
   // Support GetBounds() method
@@ -566,4 +579,5 @@ private:
   void operator=(const vtkImplicitPlaneRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
