@@ -39,11 +39,11 @@
 #include "vtkTransform.h"
 #include "vtkTubeFilter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImplicitPlaneWidget);
 
 //------------------------------------------------------------------------------
 vtkImplicitPlaneWidget::vtkImplicitPlaneWidget()
-  : vtkPolyDataSourceWidget()
 {
   this->DiagonalRatio = 0.3;
   this->State = vtkImplicitPlaneWidget::Start;
@@ -1280,3 +1280,4 @@ void vtkImplicitPlaneWidget::SizeHandles()
 
   this->EdgesTuber->SetRadius(0.25 * radius);
 }
+VTK_ABI_NAMESPACE_END
