@@ -93,14 +93,16 @@
 #define vtkImplicitPlaneWidget2_h
 
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImplicitPlaneRepresentation;
-class vtkInteractionCallback;
+class vtkImplicitPlaneWidget2InteractionCallback;
 
 class VTKINTERACTIONWIDGETS_EXPORT vtkImplicitPlaneWidget2 : public vtkAbstractWidget
 {
-  friend class vtkInteractionCallback;
+  friend class vtkImplicitPlaneWidget2InteractionCallback;
 
 public:
   /**
@@ -108,13 +110,13 @@ public:
    */
   static vtkImplicitPlaneWidget2* New();
 
-  //@{
+  ///@{
   /**
    * Standard vtkObject methods
    */
   vtkTypeMacro(vtkImplicitPlaneWidget2, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Specify an instance of vtkWidgetRepresentation used to represent this
@@ -153,11 +155,15 @@ protected:
 
   // Manage the state of the widget
   int WidgetState;
-  enum _WidgetState
+  enum WidgetStateType
   {
     Start = 0,
     Active
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
 
   // These methods handle events
   static void SelectAction(vtkAbstractWidget*);
@@ -178,17 +184,18 @@ protected:
    */
   int UpdateCursorShape(int interactionState);
 
-  //@{
+  ///@{
   /**
    * Handle the interaction callback that may come from the representation.
    */
-  vtkInteractionCallback* InteractionCallback;
+  vtkImplicitPlaneWidget2InteractionCallback* InteractionCallback;
   void InvokeInteractionCallback();
-  //@}
+  ///@}
 
 private:
   vtkImplicitPlaneWidget2(const vtkImplicitPlaneWidget2&) = delete;
   void operator=(const vtkImplicitPlaneWidget2&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
