@@ -36,7 +36,7 @@
  *   LeftButtonReleaseEvent - release the handle widget associated with the point
  *   MouseMoveEvent - move the point
  * If the line is selected:
- *   LeftButtonPressEvent - activate a handle widget accociated with the line
+ *   LeftButtonPressEvent - activate a handle widget associated with the line
  *   LeftButtonReleaseEvent - release the handle widget associated with the line
  *   MouseMoveEvent - translate the line
  * In all the cases, independent of what is picked, the widget responds to the
@@ -83,8 +83,10 @@
 #define vtkLineWidget2_h
 
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLineRepresentation;
 class vtkHandleWidget;
 
@@ -96,13 +98,13 @@ public:
    */
   static vtkLineWidget2* New();
 
-  //@{
+  ///@{
   /**
    * Standard vtkObject methods
    */
   vtkTypeMacro(vtkLineWidget2, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Override superclasses' SetEnabled() method because the line
@@ -145,11 +147,16 @@ protected:
 
   // Manage the state of the widget
   int WidgetState;
-  enum _WidgetState
+  enum WidgetStateType
   {
     Start = 0,
     Active
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
+
   int CurrentHandle;
 
   // These methods handle events
@@ -172,4 +179,5 @@ private:
   void operator=(const vtkLineWidget2&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
