@@ -13,33 +13,34 @@
 
 =========================================================================*/
 #include "vtkLogoWidget.h"
-#include "vtkLogoRepresentation.h"
 #include "vtkCallbackCommand.h"
+#include "vtkLogoRepresentation.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkLogoWidget);
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLogoWidget::vtkLogoWidget()
 {
   this->Selectable = 0;
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLogoWidget::~vtkLogoWidget() = default;
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLogoWidget::CreateDefaultRepresentation()
 {
-  if ( ! this->WidgetRep )
+  if (!this->WidgetRep)
   {
     this->WidgetRep = vtkLogoRepresentation::New();
   }
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLogoWidget::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
-
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
