@@ -42,6 +42,7 @@
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMeasurementCubeHandleRepresentation3D);
 vtkCxxSetObjectMacro(vtkMeasurementCubeHandleRepresentation3D, Property, vtkProperty);
 vtkCxxSetObjectMacro(vtkMeasurementCubeHandleRepresentation3D, SelectedProperty, vtkProperty);
@@ -448,8 +449,8 @@ void vtkMeasurementCubeHandleRepresentation3D::UpdateHandle()
 
 namespace
 {
-static const int OpposingDiagonals[4][2][3] = { { { 0, 2, 4 }, { 1, 3, 5 } },
-  { { 1, 2, 4 }, { 0, 3, 5 } }, { { 0, 3, 4 }, { 1, 2, 5 } }, { { 0, 2, 5 }, { 1, 3, 4 } } };
+const int OpposingDiagonals[4][2][3] = { { { 0, 2, 4 }, { 1, 3, 5 } }, { { 1, 2, 4 }, { 0, 3, 5 } },
+  { { 0, 3, 4 }, { 1, 2, 5 } }, { { 0, 2, 5 }, { 1, 3, 4 } } };
 }
 
 //------------------------------------------------------------------------------
@@ -834,3 +835,4 @@ void vtkMeasurementCubeHandleRepresentation3D::PrintSelf(ostream& os, vtkIndent
   os << indent << "SideLength: " << this->SideLength << "\n";
   os << indent << "LengthUnit: " << this->LengthUnit << "\n";
 }
+VTK_ABI_NAMESPACE_END
