@@ -26,14 +26,16 @@
  *
  * @sa
  * vtkParallelopipedWidget
-*/
+ */
 
 #ifndef vtkParallelopipedRepresentation_h
 #define vtkParallelopipedRepresentation_h
 
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkPlane;
 class vtkPoints;
@@ -47,29 +49,28 @@ class vtkClosedSurfacePointPlacer;
 class vtkPlaneCollection;
 class vtkParallelopipedTopology;
 
-class VTKINTERACTIONWIDGETS_EXPORT vtkParallelopipedRepresentation
-                              : public vtkWidgetRepresentation
+class VTKINTERACTIONWIDGETS_EXPORT vtkParallelopipedRepresentation : public vtkWidgetRepresentation
 {
 public:
   /**
    * Instantiate the class.
    */
-  static vtkParallelopipedRepresentation *New();
+  static vtkParallelopipedRepresentation* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for instances of this class.
    */
-  vtkTypeMacro(vtkParallelopipedRepresentation,vtkWidgetRepresentation);
+  vtkTypeMacro(vtkParallelopipedRepresentation, vtkWidgetRepresentation);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Methods to satisfy the superclass.
    */
-  void GetActors(vtkPropCollection *pc) override;
+  void GetActors(vtkPropCollection* pc) override;
 
-  //@{
+  ///@{
   /**
    * Place the widget in the scene. You can use either of the two APIs :
    * 1) PlaceWidget( double bounds[6] )
@@ -86,16 +87,16 @@ public:
    */
   virtual void PlaceWidget(double corners[8][3]);
   void PlaceWidget(double bounds[6]) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The interaction state may be set from a widget (e.g., PointWidget)
    * or other object. This controls how the interaction with the
    * widget proceeds.
    */
-  vtkSetMacro(InteractionState,int);
-  //@}
+  vtkSetMacro(InteractionState, int);
+  ///@}
 
   /**
    * Get the bounding planes of the object. The first 6 planes will
@@ -103,59 +104,59 @@ public:
    * additional planes will be present. The last three planes will be those
    * of the chair. The normals of all the planes will point into the object.
    */
-  void GetBoundingPlanes( vtkPlaneCollection *pc );
+  void GetBoundingPlanes(vtkPlaneCollection* pc);
 
   /**
    * The parallelopiped polydata.
    */
-  void GetPolyData(vtkPolyData *pd);
+  void GetPolyData(vtkPolyData* pd);
 
   /**
    * The parallelopiped polydata.
    */
-  double *GetBounds() VTK_SIZEHINT(6) override;
+  double* GetBounds() VTK_SIZEHINT(6) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the handle properties.
    */
-  virtual void SetHandleProperty           (vtkProperty *);
-  virtual void SetHoveredHandleProperty    (vtkProperty *);
-  virtual void SetSelectedHandleProperty   (vtkProperty *);
-  vtkGetObjectMacro(HandleProperty,         vtkProperty  );
-  vtkGetObjectMacro(HoveredHandleProperty,  vtkProperty  );
-  vtkGetObjectMacro(SelectedHandleProperty, vtkProperty  );
-  //@}
+  virtual void SetHandleProperty(vtkProperty*);
+  virtual void SetHoveredHandleProperty(vtkProperty*);
+  virtual void SetSelectedHandleProperty(vtkProperty*);
+  vtkGetObjectMacro(HandleProperty, vtkProperty);
+  vtkGetObjectMacro(HoveredHandleProperty, vtkProperty);
+  vtkGetObjectMacro(SelectedHandleProperty, vtkProperty);
+  ///@}
 
-  void SetHandleRepresentation(vtkHandleRepresentation *handle);
+  void SetHandleRepresentation(vtkHandleRepresentation* handle);
   vtkHandleRepresentation* GetHandleRepresentation(int index);
 
-  //@{
+  ///@{
   /**
    * Turns the visibility of the handles on/off. Sometimes they may get in
    * the way of visualization.
    */
   void HandlesOn();
   void HandlesOff();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the face properties. When a face is being translated, the face gets
    * highlighted with the SelectedFaceProperty.
    */
-  vtkGetObjectMacro(FaceProperty,vtkProperty);
-  vtkGetObjectMacro(SelectedFaceProperty,vtkProperty);
-  //@}
+  vtkGetObjectMacro(FaceProperty, vtkProperty);
+  vtkGetObjectMacro(SelectedFaceProperty, vtkProperty);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the outline properties. These are the properties with which the
    * parallelopiped wireframe is rendered.
    */
-  vtkGetObjectMacro(OutlineProperty,vtkProperty);
-  vtkGetObjectMacro(SelectedOutlineProperty,vtkProperty);
-  //@}
+  vtkGetObjectMacro(OutlineProperty, vtkProperty);
+  vtkGetObjectMacro(SelectedOutlineProperty, vtkProperty);
+  ///@}
 
   /**
    * This actually constructs the geometry of the widget from the various
@@ -163,23 +164,23 @@ public:
    */
   void BuildRepresentation() override;
 
-  //@{
+  ///@{
   /**
    * Methods required by vtkProp superclass.
    */
-  void ReleaseGraphicsResources(vtkWindow *w) override;
-  int  RenderOverlay(vtkViewport *viewport) override;
-  int  RenderOpaqueGeometry(vtkViewport *viewport) override;
-  //@}
+  void ReleaseGraphicsResources(vtkWindow* w) override;
+  int RenderOverlay(vtkViewport* viewport) override;
+  int RenderOpaqueGeometry(vtkViewport* viewport) override;
+  ///@}
 
   /**
    * Given and x-y display coordinate, compute the interaction state of
    * the widget.
    */
-  int ComputeInteractionState(int X, int Y, int modify=0) override;
+  int ComputeInteractionState(int X, int Y, int modify = 0) override;
 
   // Manage the state of the widget
-  enum _InteractionState
+  enum InteractionStateType
   {
     Outside = 0,
     Inside,
@@ -196,11 +197,15 @@ public:
     ScalingParallelopiped,
     RotatingParallelopiped
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef InteractionStateType _InteractionState;
+#endif
 
   // Methods to manipulate the piped.
-  virtual void Translate( double translation[3] );
-  virtual void Translate( int X, int Y );
-  virtual void Scale( int X, int Y );
+  virtual void Translate(double translation[3]);
+  virtual void Translate(int X, int Y);
+  virtual void Scale(int X, int Y);
 
   /**
    * Synchronize the parallelopiped handle positions with the
@@ -208,16 +213,16 @@ public:
    */
   virtual void PositionHandles();
 
-  //@{
+  ///@{
   /**
    * Minimum thickness for the parallelopiped. User interactions cannot make
    * any individual axis of the parallopiped thinner than this value.
    * Default is 0.05 expressed as a fraction of the diagonal of the bounding
    * box used in the PlaceWidget() invocation.
    */
-  vtkSetMacro( MinimumThickness, double );
-  vtkGetMacro( MinimumThickness, double );
-  //@}
+  vtkSetMacro(MinimumThickness, double);
+  vtkGetMacro(MinimumThickness, double);
+  ///@}
 
 protected:
   vtkParallelopipedRepresentation();
@@ -226,27 +231,27 @@ protected:
   /**
    * Translate the nth PtId (0 <= n <= 15) by the specified amount.
    */
-  void TranslatePoint( int n, const double motionVector[3] );
+  void TranslatePoint(int n, const double motionVector[3]);
 
   /**
    * Set the highlight state of a handle.
    * If handleIdx is -1, the property is applied to all handles.
    */
-  void SetHandleHighlight( int handleIdx, vtkProperty *property );
+  void SetHandleHighlight(int handleIdx, vtkProperty* property);
 
-  //@{
+  ///@{
   /**
    * Highlight face defined by the supplied ptids with the specified property.
    */
-  void SetFaceHighlight( vtkCellArray * face, vtkProperty * );
+  void SetFaceHighlight(vtkCellArray* face, vtkProperty*);
   void HighlightAllFaces();
   void UnHighlightAllFaces();
-  //@}
+  ///@}
 
   // Node can be a value within [0,7]. This will create a chair one one of
-  // the handle corners. '0 < InitialChairDepth < 1' value dicates the starting
+  // the handle corners. '0 < InitialChairDepth < 1' value dictates the starting
   // depth of the cavity.
-  void UpdateChairAtNode( int node );
+  void UpdateChairAtNode(int node);
 
   // Removes any existing chairs.
   void RemoveExistingChairs();
@@ -256,55 +261,55 @@ protected:
   // If we are in chair mode, this will be the first 6 planes from amongst
   // those returned by "GetBoundingPlanes".
   // All planes have their normals pointing inwards.
-  void GetParallelopipedBoundingPlanes( vtkPlaneCollection * pc );
+  void GetParallelopipedBoundingPlanes(vtkPlaneCollection* pc);
 
   // Convenience method to edefine a plane passing through 3 points.
-  void DefinePlane( vtkPlane *, double p[3][3]);
+  void DefinePlane(vtkPlane*, double p[3][3]);
 
   // Convenience method to edefine a plane passing through 3 pointIds of the
   // parallelopiped. The point Ids must like in the range [0,15], ie the
   // 15 points comprising the parallelopiped and the chair (also modelled
   // as a parallelopiped)
-  void DefinePlane( vtkPlane *, vtkIdType, vtkIdType, vtkIdType);
+  void DefinePlane(vtkPlane*, vtkIdType, vtkIdType, vtkIdType);
 
-  vtkActor                          * HexActor;
-  vtkPolyDataMapper                 * HexMapper;
-  vtkPolyData                       * HexPolyData;
-  vtkPoints                         * Points;
-  vtkActor                          * HexFaceActor;
-  vtkPolyDataMapper                 * HexFaceMapper;
-  vtkPolyData                       * HexFacePolyData;
+  vtkActor* HexActor;
+  vtkPolyDataMapper* HexMapper;
+  vtkPolyData* HexPolyData;
+  vtkPoints* Points;
+  vtkActor* HexFaceActor;
+  vtkPolyDataMapper* HexFaceMapper;
+  vtkPolyData* HexFacePolyData;
 
-  double                              LastEventPosition[2];
+  double LastEventPosition[2];
 
   // Cache the axis index used for face aligned resize.
-  int                                 LastResizeAxisIdx;
-
-  vtkHandleRepresentation           * HandleRepresentation;
-  vtkHandleRepresentation          ** HandleRepresentations;
-  int                                 CurrentHandleIdx;
-  int                                 ChairHandleIdx;
+  int LastResizeAxisIdx;
 
+  vtkHandleRepresentation* HandleRepresentation;
+  vtkHandleRepresentation** HandleRepresentations;
+  int CurrentHandleIdx;
+  int ChairHandleIdx;
 
   // When a chair is carved out for the first time, this is the initial
   // depth of the chair
-  double                              InitialChairDepth;
+  double InitialChairDepth;
 
-  vtkProperty                       * HandleProperty;
-  vtkProperty                       * HoveredHandleProperty;
-  vtkProperty                       * FaceProperty;
-  vtkProperty                       * OutlineProperty;
-  vtkProperty                       * SelectedHandleProperty;
-  vtkProperty                       * SelectedFaceProperty;
-  vtkProperty                       * SelectedOutlineProperty;
-  vtkClosedSurfacePointPlacer       * ChairPointPlacer;
-  vtkParallelopipedTopology         * Topology;
-  double                              MinimumThickness;
-  double                              AbsoluteMinimumThickness;
+  vtkProperty* HandleProperty;
+  vtkProperty* HoveredHandleProperty;
+  vtkProperty* FaceProperty;
+  vtkProperty* OutlineProperty;
+  vtkProperty* SelectedHandleProperty;
+  vtkProperty* SelectedFaceProperty;
+  vtkProperty* SelectedOutlineProperty;
+  vtkClosedSurfacePointPlacer* ChairPointPlacer;
+  vtkParallelopipedTopology* Topology;
+  double MinimumThickness;
+  double AbsoluteMinimumThickness;
 
 private:
   vtkParallelopipedRepresentation(const vtkParallelopipedRepresentation&) = delete;
   void operator=(const vtkParallelopipedRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
