@@ -32,6 +32,7 @@
 #include "vtkWidgetEventTranslator.h"
 #include "vtkWidgetSet.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkParallelopipedWidget);
 
 //------------------------------------------------------------------------------
@@ -265,7 +266,7 @@ void vtkParallelopipedWidget ::RequestResizeAlongAnAxisCallback(vtkAbstractWidge
     // We did not select any of the handles, nevertheless we are at least
     // inside the parallelopiped. We could do things like Translate etc. So
     // we will delegate responsibility to those callbacks
-    self->TranslateCallback(self);
+    vtkParallelopipedWidget::TranslateCallback(self);
   }
 
   else if (interactionState != vtkParallelopipedRepresentation::Outside)
@@ -472,3 +473,4 @@ void vtkParallelopipedWidget::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Chair Creation: " << (this->EnableChairCreation ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
