@@ -34,6 +34,7 @@
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPointHandleRepresentation3D);
 
 vtkCxxSetObjectMacro(vtkPointHandleRepresentation3D, Property, vtkProperty);
@@ -506,22 +507,6 @@ void vtkPointHandleRepresentation3D::WidgetInteraction(double eventPos[2])
           if (this->PointPlacer->ComputeWorldPosition(
                 this->Renderer, newCenterPointRequested, newCenterPoint, worldOrient))
           {
-
-            // Once the placer has validated us, update the handle
-            // position and its bounds.
-            double* p = this->GetWorldPosition();
-
-            // Get the motion vector
-            double v[3] = { newCenterPoint[0] - p[0], newCenterPoint[1] - p[1],
-              newCenterPoint[2] - p[2] };
-            double *bounds = this->Cursor3D->GetModelBounds(), newBounds[6];
-            for (int i = 0; i < 3; i++)
-            {
-              newBounds[2 * i] = bounds[2 * i] + v[i];
-              newBounds[2 * i + 1] = bounds[2 * i + 1] + v[i];
-            }
-
-            this->Cursor3D->SetModelBounds(newBounds);
             this->SetWorldPosition(newCenterPoint);
           }
         }
@@ -639,17 +624,16 @@ void vtkPointHandleRepresentation3D::SetTranslationMode(vtkTypeBool mode)
 void vtkPointHandleRepresentation3D::Translate(const double* p1, const double* p2)
 {
   double v[3] = { 0, 0, 0 };
-  vtkHandleRepresentation::Translate(p1, p2);
   this->GetTranslationVector(p1, p2, v);
+  this->vtkHandleRepresentation::Translate(v);
 
   double* bounds = this->Cursor3D->GetModelBounds();
   double* pos = this->Cursor3D->GetFocalPoint();
   double newBounds[6], newFocus[3];
-  int i;
 
   if (this->ConstraintAxis >= 0)
-  { // move along axis
-    for (i = 0; i < 3; i++)
+  {
+    for (int i = 0; i < 3; i++)
     {
       if (i != this->ConstraintAxis)
       {
@@ -658,7 +642,7 @@ void vtkPointHandleRepresentation3D::Translate(const double* p1, const double* p
     }
   }
 
-  for (i = 0; i < 3; i++)
+  for (int i = 0; i < 3; i++)
   {
     newBounds[2 * i] = bounds[2 * i] + v[i];
     newBounds[2 * i + 1] = bounds[2 * i + 1] + v[i];
@@ -740,15 +724,27 @@ void vtkPointHandleRepresentation3D::CreateDefaultProperties()
 {
   this->Property = vtkProperty::New();
   this->Property->SetAmbient(1.0);
-  this->Property->SetAmbientColor(1.0, 1.0, 1.0);
+  this->Property->SetColor(1.0, 1.0, 1.0);
   this->Property->SetLineWidth(0.5);
 
   this->SelectedProperty = vtkProperty::New();
   this->SelectedProperty->SetAmbient(1.0);
-  this->SelectedProperty->SetAmbientColor(0.0, 1.0, 0.0);
+  this->SelectedProperty->SetColor(0.0, 1.0, 0.0);
   this->SelectedProperty->SetLineWidth(2.0);
 }
 
+//------------------------------------------------------------------------------
+void vtkPointHandleRepresentation3D::SetInteractionColor(double r, double g, double b)
+{
+  this->SelectedProperty->SetColor(r, g, b);
+}
+
+//------------------------------------------------------------------------------
+void vtkPointHandleRepresentation3D::SetForegroundColor(double r, double g, double b)
+{
+  this->Property->SetColor(r, g, b);
+}
+
 //------------------------------------------------------------------------------
 void vtkPointHandleRepresentation3D::SetVisibility(vtkTypeBool visible)
 {
@@ -818,7 +814,12 @@ void vtkPointHandleRepresentation3D::DeepCopy(vtkProp* prop)
 //------------------------------------------------------------------------------
 void vtkPointHandleRepresentation3D::GetActors(vtkPropCollection* pc)
 {
-  this->Actor->GetActors(pc);
+  if (!pc)
+  {
+    return;
+  }
+  pc->AddItem(this->Actor);
+  this->Superclass::GetActors(pc);
 }
 
 //------------------------------------------------------------------------------
@@ -897,3 +898,4 @@ void vtkPointHandleRepresentation3D::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Translation Mode: " << (this->TranslationMode ? "On\n" : "Off\n");
   os << indent << "SmoothMotion: " << this->SmoothMotion << endl;
 }
+VTK_ABI_NAMESPACE_END
