@@ -20,15 +20,16 @@
 #include "vtkCamera.h"
 #include "vtkCellPicker.h"
 #include "vtkMath.h"
+#include "vtkObjectFactory.h"
 #include "vtkPickingManager.h"
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
 #include "vtkProperty.h"
-#include "vtkRenderer.h"
-#include "vtkRenderWindowInteractor.h"
 #include "vtkRenderWindow.h"
-#include "vtkObjectFactory.h"
+#include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPointWidget);
 
 vtkPointWidget::vtkPointWidget()
@@ -39,8 +40,7 @@ vtkPointWidget::vtkPointWidget()
   // Represent the line
   this->Cursor3D = vtkCursor3D::New();
   this->Mapper = vtkPolyDataMapper::New();
-  this->Mapper->SetInputConnection(
-    this->Cursor3D->GetOutputPort());
+  this->Mapper->SetInputConnection(this->Cursor3D->GetOutputPort());
   this->Actor = vtkActor::New();
   this->Actor->SetMapper(this->Mapper);
 
@@ -56,11 +56,11 @@ vtkPointWidget::vtkPointWidget()
   // Initial creation of the widget, serves to initialize it
   this->PlaceWidget(bounds);
 
-  //Manage the picking stuff
+  // Manage the picking stuff
   this->CursorPicker = vtkCellPicker::New();
   this->CursorPicker->PickFromListOn();
   this->CursorPicker->AddPickList(this->Actor);
-  this->CursorPicker->SetTolerance(0.005); //need some fluff
+  this->CursorPicker->SetTolerance(0.005); // need some fluff
 
   // Set up the initial properties
   this->CreateDefaultProperties();
@@ -90,26 +90,25 @@ vtkPointWidget::~vtkPointWidget()
 
 void vtkPointWidget::SetEnabled(int enabling)
 {
-  if ( ! this->Interactor )
+  if (!this->Interactor)
   {
-    vtkErrorMacro(<<"The interactor must be set prior to enabling/disabling widget");
+    vtkErrorMacro(<< "The interactor must be set prior to enabling/disabling widget");
     return;
   }
 
-  if ( enabling ) //-----------------------------------------------------------
+  if (enabling) //-----------------------------------------------------------
   {
-    vtkDebugMacro(<<"Enabling point widget");
+    vtkDebugMacro(<< "Enabling point widget");
 
-    if ( this->Enabled ) //already enabled, just return
+    if (this->Enabled) // already enabled, just return
     {
       return;
     }
 
-    if ( ! this->CurrentRenderer )
+    if (!this->CurrentRenderer)
     {
       this->SetCurrentRenderer(this->Interactor->FindPokedRenderer(
-        this->Interactor->GetLastEventPosition()[0],
-        this->Interactor->GetLastEventPosition()[1]));
+        this->Interactor->GetLastEventPosition()[0], this->Interactor->GetLastEventPosition()[1]));
       if (this->CurrentRenderer == nullptr)
       {
         return;
@@ -119,21 +118,15 @@ void vtkPointWidget::SetEnabled(int enabling)
     this->Enabled = 1;
 
     // listen for the following events
-    vtkRenderWindowInteractor *i = this->Interactor;
-    i->AddObserver(vtkCommand::MouseMoveEvent, this->EventCallbackCommand,
-                   this->Priority);
-    i->AddObserver(vtkCommand::LeftButtonPressEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::LeftButtonReleaseEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::MiddleButtonPressEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::MiddleButtonReleaseEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::RightButtonPressEvent,
-                   this->EventCallbackCommand, this->Priority);
-    i->AddObserver(vtkCommand::RightButtonReleaseEvent,
-                   this->EventCallbackCommand, this->Priority);
+    vtkRenderWindowInteractor* i = this->Interactor;
+    i->AddObserver(vtkCommand::MouseMoveEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::LeftButtonPressEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::LeftButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::MiddleButtonPressEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(
+      vtkCommand::MiddleButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::RightButtonPressEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::RightButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
 
     // Add the line
     this->CurrentRenderer->AddActor(this->Actor);
@@ -141,14 +134,14 @@ void vtkPointWidget::SetEnabled(int enabling)
     this->Cursor3D->Update();
     this->RegisterPickers();
 
-    this->InvokeEvent(vtkCommand::EnableEvent,nullptr);
+    this->InvokeEvent(vtkCommand::EnableEvent, nullptr);
   }
 
-  else //disabling----------------------------------------------------------
+  else // disabling----------------------------------------------------------
   {
-    vtkDebugMacro(<<"Disabling point widget");
+    vtkDebugMacro(<< "Disabling point widget");
 
-    if ( ! this->Enabled ) //already disabled, just return
+    if (!this->Enabled) // already disabled, just return
     {
       return;
     }
@@ -161,7 +154,7 @@ void vtkPointWidget::SetEnabled(int enabling)
     // turn off the line
     this->CurrentRenderer->RemoveActor(this->Actor);
 
-    this->InvokeEvent(vtkCommand::DisableEvent,nullptr);
+    this->InvokeEvent(vtkCommand::DisableEvent, nullptr);
     this->SetCurrentRenderer(nullptr);
     this->UnRegisterPickers();
   }
@@ -180,15 +173,13 @@ void vtkPointWidget::RegisterPickers()
   pm->AddPicker(this->CursorPicker, this);
 }
 
-void vtkPointWidget::ProcessEvents(vtkObject* vtkNotUsed(object),
-                                   unsigned long event,
-                                   void* clientdata,
-                                   void* vtkNotUsed(calldata))
+void vtkPointWidget::ProcessEvents(
+  vtkObject* vtkNotUsed(object), unsigned long event, void* clientdata, void* vtkNotUsed(calldata))
 {
-  vtkPointWidget* self = reinterpret_cast<vtkPointWidget *>( clientdata );
+  vtkPointWidget* self = reinterpret_cast<vtkPointWidget*>(clientdata);
 
-  //okay, let's do the right thing
-  switch(event)
+  // okay, let's do the right thing
+  switch (event)
   {
     case vtkCommand::LeftButtonPressEvent:
       self->OnLeftButtonDown();
@@ -216,9 +207,9 @@ void vtkPointWidget::ProcessEvents(vtkObject* vtkNotUsed(object),
 
 void vtkPointWidget::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
-  if ( this->Property )
+  if (this->Property)
   {
     os << indent << "Property: " << this->Property << "\n";
   }
@@ -226,7 +217,7 @@ void vtkPointWidget::PrintSelf(ostream& os, vtkIndent indent)
   {
     os << indent << "Property: (none)\n";
   }
-  if ( this->SelectedProperty )
+  if (this->SelectedProperty)
   {
     os << indent << "Selected Property: " << this->SelectedProperty << "\n";
   }
@@ -235,24 +226,22 @@ void vtkPointWidget::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Selected Property: (none)\n";
   }
 
-  double *pos = this->Cursor3D->GetFocalPoint();
-  os << indent << "Position: (" << pos[0] << ", "
-               << pos[1] << ", " << pos[2] << ")\n";
+  double* pos = this->Cursor3D->GetFocalPoint();
+  os << indent << "Position: (" << pos[0] << ", " << pos[1] << ", " << pos[2] << ")\n";
 
   os << indent << "Outline: " << (this->GetOutline() ? "On\n" : "Off\n");
   os << indent << "XShadows: " << (this->GetXShadows() ? "On\n" : "Off\n");
   os << indent << "YShadows: " << (this->GetYShadows() ? "On\n" : "Off\n");
   os << indent << "ZShadows: " << (this->GetZShadows() ? "On\n" : "Off\n");
 
-  os << indent << "Translation Mode: "
-     << (this->Cursor3D->GetTranslationMode() ? "On\n" : "Off\n");
+  os << indent << "Translation Mode: " << (this->Cursor3D->GetTranslationMode() ? "On\n" : "Off\n");
 
   os << indent << "Hot Spot Size: " << this->HotSpotSize << "\n";
 }
 
 void vtkPointWidget::Highlight(int highlight)
 {
-  if ( highlight )
+  if (highlight)
   {
     this->Actor->SetProperty(this->SelectedProperty);
     this->CursorPicker->GetPickPosition(this->LastPickPosition);
@@ -264,27 +253,27 @@ void vtkPointWidget::Highlight(int highlight)
   }
 }
 
-int vtkPointWidget::DetermineConstraintAxis(int constraint, double *x)
+int vtkPointWidget::DetermineConstraintAxis(int constraint, double* x)
 {
   // Look for trivial cases
-  if ( ! this->Interactor->GetShiftKey() )
+  if (!this->Interactor->GetShiftKey())
   {
     return -1;
   }
-  else if ( constraint >= 0 && constraint < 3 )
+  else if (constraint >= 0 && constraint < 3)
   {
     return constraint;
   }
 
   // Okay, figure out constraint. First see if the choice is
   // outside the hot spot
-  if ( ! this->WaitingForMotion )
+  if (!this->WaitingForMotion)
   {
     double p[3], d2, tol;
     this->CursorPicker->GetPickPosition(p);
-    d2 = vtkMath::Distance2BetweenPoints(p,this->LastPickPosition);
-    tol = this->HotSpotSize*this->InitialLength;
-    if ( d2 > (tol*tol) )
+    d2 = vtkMath::Distance2BetweenPoints(p, this->LastPickPosition);
+    tol = this->HotSpotSize * this->InitialLength;
+    if (d2 > (tol * tol))
     {
       this->WaitingForMotion = 0;
       return this->CursorPicker->GetCellId();
@@ -296,14 +285,14 @@ int vtkPointWidget::DetermineConstraintAxis(int constraint, double *x)
       return -1;
     }
   }
-  else if ( this->WaitingForMotion && x )
+  else if (this->WaitingForMotion && x)
   {
     double v[3];
     this->WaitingForMotion = 0;
     v[0] = fabs(x[0] - this->LastPickPosition[0]);
     v[1] = fabs(x[1] - this->LastPickPosition[1]);
     v[2] = fabs(x[2] - this->LastPickPosition[2]);
-    return ( v[0]>v[1] ? (v[0]>v[2]?0:2) : (v[1]>v[2]?1:2));
+    return (v[0] > v[1] ? (v[0] > v[2] ? 0 : 2) : (v[1] > v[2] ? 1 : 2));
   }
   else
   {
@@ -325,11 +314,11 @@ void vtkPointWidget::OnLeftButtonDown()
 
   vtkAssemblyPath* path = this->GetAssemblyPath(X, Y, 0., this->CursorPicker);
 
-  if ( path != nullptr )
+  if (path != nullptr)
   {
     this->State = vtkPointWidget::Moving;
     this->Highlight(1);
-    this->ConstraintAxis = this->DetermineConstraintAxis(-1,nullptr);
+    this->ConstraintAxis = this->DetermineConstraintAxis(-1, nullptr);
   }
   else
   {
@@ -341,14 +330,13 @@ void vtkPointWidget::OnLeftButtonDown()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->StartInteraction();
-  this->InvokeEvent(vtkCommand::StartInteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::StartInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
 void vtkPointWidget::OnLeftButtonUp()
 {
-  if ( this->State == vtkPointWidget::Outside ||
-       this->State == vtkPointWidget::Start )
+  if (this->State == vtkPointWidget::Outside || this->State == vtkPointWidget::Start)
   {
     return;
   }
@@ -358,7 +346,7 @@ void vtkPointWidget::OnLeftButtonUp()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->EndInteraction();
-  this->InvokeEvent(vtkCommand::EndInteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::EndInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
@@ -377,11 +365,11 @@ void vtkPointWidget::OnMiddleButtonDown()
   // Okay, we can process this.
   vtkAssemblyPath* path = this->GetAssemblyPath(X, Y, 0., this->CursorPicker);
 
-  if ( path != nullptr )
+  if (path != nullptr)
   {
     this->State = vtkPointWidget::Translating;
     this->Highlight(1);
-    this->ConstraintAxis = this->DetermineConstraintAxis(-1,nullptr);
+    this->ConstraintAxis = this->DetermineConstraintAxis(-1, nullptr);
   }
   else
   {
@@ -392,14 +380,13 @@ void vtkPointWidget::OnMiddleButtonDown()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->StartInteraction();
-  this->InvokeEvent(vtkCommand::StartInteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::StartInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
 void vtkPointWidget::OnMiddleButtonUp()
 {
-  if ( this->State == vtkPointWidget::Outside ||
-       this->State == vtkPointWidget::Start )
+  if (this->State == vtkPointWidget::Outside || this->State == vtkPointWidget::Start)
   {
     return;
   }
@@ -409,7 +396,7 @@ void vtkPointWidget::OnMiddleButtonUp()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->EndInteraction();
-  this->InvokeEvent(vtkCommand::EndInteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::EndInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
@@ -428,11 +415,11 @@ void vtkPointWidget::OnRightButtonDown()
   // Okay, we can process this. Pick the cursor.
   vtkAssemblyPath* path = this->GetAssemblyPath(X, Y, 0., this->CursorPicker);
 
-  if ( path != nullptr )
+  if (path != nullptr)
   {
     this->State = vtkPointWidget::Scaling;
     int idx = this->CursorPicker->GetCellId();
-    if ( idx >= 0 && idx < 3 )
+    if (idx >= 0 && idx < 3)
     {
       this->ConstraintAxis = idx;
     }
@@ -447,14 +434,13 @@ void vtkPointWidget::OnRightButtonDown()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->StartInteraction();
-  this->InvokeEvent(vtkCommand::StartInteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::StartInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
 void vtkPointWidget::OnRightButtonUp()
 {
-  if ( this->State == vtkPointWidget::Outside ||
-       this->State == vtkPointWidget::Start )
+  if (this->State == vtkPointWidget::Outside || this->State == vtkPointWidget::Start)
   {
     return;
   }
@@ -464,15 +450,14 @@ void vtkPointWidget::OnRightButtonUp()
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->EndInteraction();
-  this->InvokeEvent(vtkCommand::EndInteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::EndInteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
 void vtkPointWidget::OnMouseMove()
 {
   // See whether we're active
-  if ( this->State == vtkPointWidget::Outside ||
-       this->State == vtkPointWidget::Start )
+  if (this->State == vtkPointWidget::Outside || this->State == vtkPointWidget::Start)
   {
     return;
   }
@@ -485,63 +470,61 @@ void vtkPointWidget::OnMouseMove()
   double focalPoint[4], pickPoint[4], prevPickPoint[4];
   double z;
 
-  vtkCamera *camera = this->CurrentRenderer->GetActiveCamera();
-  if ( !camera )
+  vtkCamera* camera = this->CurrentRenderer->GetActiveCamera();
+  if (!camera)
   {
     return;
   }
 
   // Compute the two points defining the motion vector
-  this->ComputeWorldToDisplay(this->LastPickPosition[0], this->LastPickPosition[1],
-                              this->LastPickPosition[2], focalPoint);
+  this->ComputeWorldToDisplay(
+    this->LastPickPosition[0], this->LastPickPosition[1], this->LastPickPosition[2], focalPoint);
   z = focalPoint[2];
-  this->ComputeDisplayToWorld(double(this->Interactor->GetLastEventPosition()[0]),double(this->Interactor->GetLastEventPosition()[1]),
-                              z, prevPickPoint);
+  this->ComputeDisplayToWorld(double(this->Interactor->GetLastEventPosition()[0]),
+    double(this->Interactor->GetLastEventPosition()[1]), z, prevPickPoint);
   this->ComputeDisplayToWorld(double(X), double(Y), z, pickPoint);
 
   // Process the motion
-  if ( this->State == vtkPointWidget::Moving )
+  if (this->State == vtkPointWidget::Moving)
   {
-    if ( !this->WaitingForMotion || this->WaitCount++ > 3 )
+    if (!this->WaitingForMotion || this->WaitCount++ > 3)
     {
-      this->ConstraintAxis =
-        this->DetermineConstraintAxis(this->ConstraintAxis,pickPoint);
+      this->ConstraintAxis = this->DetermineConstraintAxis(this->ConstraintAxis, pickPoint);
       this->MoveFocus(prevPickPoint, pickPoint);
     }
     else
     {
-      return; //avoid the extra render
+      return; // avoid the extra render
     }
   }
 
-  else if ( this->State == vtkPointWidget::Scaling )
+  else if (this->State == vtkPointWidget::Scaling)
   {
     this->Scale(prevPickPoint, pickPoint, X, Y);
   }
 
-  else if ( this->State == vtkPointWidget::Translating )
+  else if (this->State == vtkPointWidget::Translating)
   {
-    if ( !this->WaitingForMotion || this->WaitCount++ > 3 )
+    if (!this->WaitingForMotion || this->WaitCount++ > 3)
     {
-      this->ConstraintAxis =
-        this->DetermineConstraintAxis(this->ConstraintAxis,pickPoint);
+      this->ConstraintAxis = this->DetermineConstraintAxis(this->ConstraintAxis, pickPoint);
       this->Translate(prevPickPoint, pickPoint);
     }
     else
     {
-      return; //avoid the extra render
+      return; // avoid the extra render
     }
   }
 
   // Interact, if desired
   this->EventCallbackCommand->SetAbortFlag(1);
-  this->InvokeEvent(vtkCommand::InteractionEvent,nullptr);
+  this->InvokeEvent(vtkCommand::InteractionEvent, nullptr);
   this->Interactor->Render();
 }
 
-void vtkPointWidget::MoveFocus(double *p1, double *p2)
+void vtkPointWidget::MoveFocus(double* p1, double* p2)
 {
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
@@ -549,7 +532,7 @@ void vtkPointWidget::MoveFocus(double *p1, double *p2)
 
   double focus[3];
   this->Cursor3D->GetFocalPoint(focus);
-  if ( this->ConstraintAxis >= 0 )
+  if (this->ConstraintAxis >= 0)
   {
     focus[this->ConstraintAxis] += v[this->ConstraintAxis];
   }
@@ -564,34 +547,34 @@ void vtkPointWidget::MoveFocus(double *p1, double *p2)
 }
 
 // Translate everything
-void vtkPointWidget::Translate(double *p1, double *p2)
+void vtkPointWidget::Translate(double* p1, double* p2)
 {
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
   v[2] = p2[2] - p1[2];
 
-  double *bounds = this->Cursor3D->GetModelBounds();
-  double *pos = this->Cursor3D->GetFocalPoint();
+  double* bounds = this->Cursor3D->GetModelBounds();
+  double* pos = this->Cursor3D->GetFocalPoint();
   double newBounds[6], newFocus[3];
   int i;
 
-  if ( this->ConstraintAxis >= 0 )
-  {//move along axis
-    for (i=0; i<3; i++)
+  if (this->ConstraintAxis >= 0)
+  { // move along axis
+    for (i = 0; i < 3; i++)
     {
-      if ( i != this->ConstraintAxis )
+      if (i != this->ConstraintAxis)
       {
         v[i] = 0.0;
       }
     }
   }
 
-  for (i=0; i<3; i++)
+  for (i = 0; i < 3; i++)
   {
-    newBounds[2*i] = bounds[2*i] + v[i];
-    newBounds[2*i+1] = bounds[2*i+1] + v[i];
+    newBounds[2 * i] = bounds[2 * i] + v[i];
+    newBounds[2 * i + 1] = bounds[2 * i + 1] + v[i];
     newFocus[i] = pos[i] + v[i];
   }
 
@@ -599,25 +582,25 @@ void vtkPointWidget::Translate(double *p1, double *p2)
   this->Cursor3D->SetFocalPoint(newFocus);
 }
 
-void vtkPointWidget::Scale(double *p1, double *p2, int vtkNotUsed(X), int Y)
+void vtkPointWidget::Scale(double* p1, double* p2, int vtkNotUsed(X), int Y)
 {
-  //Get the motion vector
+  // Get the motion vector
   double v[3];
   v[0] = p2[0] - p1[0];
   v[1] = p2[1] - p1[1];
   v[2] = p2[2] - p1[2];
 
-  //int res = this->Cursor3D->GetResolution();
-  double *bounds = this->Cursor3D->GetModelBounds();
-  double *focus = this->Cursor3D->GetFocalPoint();
+  // int res = this->Cursor3D->GetResolution();
+  double* bounds = this->Cursor3D->GetModelBounds();
+  double* focus = this->Cursor3D->GetFocalPoint();
 
   // Compute the scale factor
   double sf = vtkMath::Norm(v) /
-    sqrt( (bounds[1]-bounds[0])*(bounds[1]-bounds[0]) +
-          (bounds[3]-bounds[2])*(bounds[3]-bounds[2]) +
-          (bounds[5]-bounds[4])*(bounds[5]-bounds[4]));
+    sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
+      (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
+      (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
 
-  if ( Y > this->Interactor->GetLastEventPosition()[1] )
+  if (Y > this->Interactor->GetLastEventPosition()[1])
   {
     sf = 1.0 + sf;
   }
@@ -628,10 +611,10 @@ void vtkPointWidget::Scale(double *p1, double *p2, int vtkNotUsed(X), int Y)
 
   // Move the end points
   double newBounds[6];
-  for (int i=0; i<3; i++)
+  for (int i = 0; i < 3; i++)
   {
-    newBounds[2*i] = sf * (bounds[2*i] - focus[i]) + focus[i];
-    newBounds[2*i+1] = sf * (bounds[2*i+1] - focus[i]) + focus[i];
+    newBounds[2 * i] = sf * (bounds[2 * i] - focus[i]) + focus[i];
+    newBounds[2 * i + 1] = sf * (bounds[2 * i + 1] - focus[i]) + focus[i];
   }
 
   this->Cursor3D->SetModelBounds(newBounds);
@@ -642,12 +625,12 @@ void vtkPointWidget::CreateDefaultProperties()
 {
   this->Property = vtkProperty::New();
   this->Property->SetAmbient(1.0);
-  this->Property->SetAmbientColor(1.0,1.0,1.0);
+  this->Property->SetAmbientColor(1.0, 1.0, 1.0);
   this->Property->SetLineWidth(0.5);
 
   this->SelectedProperty = vtkProperty::New();
   this->SelectedProperty->SetAmbient(1.0);
-  this->SelectedProperty->SetAmbientColor(0.0,1.0,0.0);
+  this->SelectedProperty->SetAmbientColor(0.0, 1.0, 0.0);
   this->SelectedProperty->SetLineWidth(2.0);
 }
 
@@ -662,18 +645,18 @@ void vtkPointWidget::PlaceWidget(double bds[6])
   this->Cursor3D->SetFocalPoint(center);
   this->Cursor3D->Update();
 
-  for (i=0; i<6; i++)
+  for (i = 0; i < 6; i++)
   {
     this->InitialBounds[i] = bounds[i];
   }
-  this->InitialLength = sqrt((bounds[1]-bounds[0])*(bounds[1]-bounds[0]) +
-                             (bounds[3]-bounds[2])*(bounds[3]-bounds[2]) +
-                             (bounds[5]-bounds[4])*(bounds[5]-bounds[4]));
-
+  this->InitialLength = sqrt((bounds[1] - bounds[0]) * (bounds[1] - bounds[0]) +
+    (bounds[3] - bounds[2]) * (bounds[3] - bounds[2]) +
+    (bounds[5] - bounds[4]) * (bounds[5] - bounds[4]));
 }
 
-void vtkPointWidget::GetPolyData(vtkPolyData *pd)
+void vtkPointWidget::GetPolyData(vtkPolyData* pd)
 {
   this->Cursor3D->Update();
   pd->DeepCopy(this->Cursor3D->GetFocus());
 }
+VTK_ABI_NAMESPACE_END
