@@ -37,6 +37,7 @@
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkPointPlacer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkRenderer;
 class vtkPropCollection;
 class vtkProp;
@@ -50,16 +51,16 @@ public:
    */
   static vtkPolyDataPointPlacer* New();
 
-  //@{
+  ///@{
   /**
    * Standard methods for instances of this class.
    */
   vtkTypeMacro(vtkPolyDataPointPlacer, vtkPointPlacer);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  // Descuription:
-  // Add an actor (that represents a terrain in a rendererd scene) to the
+  // Description:
+  // Add an actor (that represents a terrain in a rendered scene) to the
   // list. Only props in this list are considered by the PointPlacer
   virtual void AddProp(vtkProp*);
   virtual void RemoveViewProp(vtkProp* prop);
@@ -104,12 +105,12 @@ public:
    */
   int ValidateWorldPosition(double worldPos[3], double worldOrient[9]) override;
 
-  //@{
+  ///@{
   /**
    * Get the Prop picker.
    */
   vtkGetObjectMacro(PropPicker, vtkPropPicker);
-  //@}
+  ///@}
 
 protected:
   vtkPolyDataPointPlacer();
@@ -125,4 +126,5 @@ private:
   void operator=(const vtkPolyDataPointPlacer&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
