@@ -13,22 +13,23 @@
 
 =========================================================================*/
 #include "vtkProgressBarWidget.h"
-#include "vtkProgressBarRepresentation.h"
 #include "vtkCallbackCommand.h"
 #include "vtkObjectFactory.h"
+#include "vtkProgressBarRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkProgressBarWidget);
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkProgressBarWidget::vtkProgressBarWidget()
 {
   this->Selectable = 0;
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkProgressBarWidget::~vtkProgressBarWidget() = default;
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkProgressBarWidget::CreateDefaultRepresentation()
 {
   if (!this->WidgetRep)
@@ -37,8 +38,9 @@ void vtkProgressBarWidget::CreateDefaultRepresentation()
   }
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkProgressBarWidget::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
