@@ -48,6 +48,7 @@
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkResliceCursorLineRepresentation);
 
 //------------------------------------------------------------------------------
@@ -56,7 +57,7 @@ vtkResliceCursorLineRepresentation::vtkResliceCursorLineRepresentation()
   this->ResliceCursorActor = vtkResliceCursorActor::New();
 
   this->Picker = vtkResliceCursorPicker::New();
-  this->Picker->SetTolerance(0.025);
+  this->ApplyTolerance();
 
   this->MatrixReslice = vtkMatrix4x4::New();
   this->MatrixView = vtkMatrix4x4::New();
@@ -327,7 +328,7 @@ double vtkResliceCursorLineRepresentation ::RotateAxis(double e[2], int axis)
   vtkMath::Normalize(lastVector);
   vtkMath::Normalize(currVector);
 
-  // compute the angle betweem both vectors. This is the amount to
+  // compute the angle between both vectors. This is the amount to
   // rotate by.
   double angle = acos(vtkMath::Dot(lastVector, currVector));
   double crossVector[3];
@@ -473,6 +474,22 @@ void vtkResliceCursorLineRepresentation::SetUserMatrix(vtkMatrix4x4* m)
   this->ResliceCursorActor->SetUserMatrix(m);
 }
 
+//------------------------------------------------------------------------------
+void vtkResliceCursorLineRepresentation::SetTolerance(int t)
+{
+  this->Superclass::SetTolerance(t);
+  this->ApplyTolerance();
+}
+
+//------------------------------------------------------------------------------
+void vtkResliceCursorLineRepresentation::ApplyTolerance()
+{
+  // Tolerance is clamped to 100 in superclass. Picker expects tolerance values
+  // between 0.0 and 1.0 (fraction of the window size)
+  // dividing by 200.0 to allow specifying tolerance smaller than 0.01
+  this->Picker->SetTolerance(this->Tolerance / 200.0);
+}
+
 //------------------------------------------------------------------------------
 int vtkResliceCursorLineRepresentation ::RenderOpaqueGeometry(vtkViewport* viewport)
 {
@@ -589,3 +606,4 @@ void vtkResliceCursorLineRepresentation::PrintSelf(ostream& os, vtkIndent indent
   // this->StartPickPosition;
   // this->StartCenterPosition;
 }
+VTK_ABI_NAMESPACE_END
