@@ -51,6 +51,7 @@
 
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkResliceCursorRepresentation, ColorMap, vtkImageMapToColors);
 
 //------------------------------------------------------------------------------
@@ -104,7 +105,7 @@ vtkResliceCursorRepresentation::vtkResliceCursorRepresentation()
 
   vtkPolyDataMapper* texturePlaneMapper = vtkPolyDataMapper::New();
   texturePlaneMapper->SetInputConnection(this->PlaneSource->GetOutputPort());
-  texturePlaneMapper->SetResolveCoincidentTopologyToPolygonOffset();
+  vtkPolyDataMapper::SetResolveCoincidentTopologyToPolygonOffset();
 
   this->Texture->SetQualityTo32Bit();
   this->Texture->SetColorMode(VTK_COLOR_MODE_DEFAULT);
@@ -269,17 +270,64 @@ void vtkResliceCursorRepresentation::ResetCamera()
 
   if (this->Renderer)
   {
-    double center[3], camPos[3], n[3];
+    const int planeOrientation = this->GetCursorAlgorithm()->GetReslicePlaneNormal();
+    double* normal = this->GetResliceCursor()->GetPlane(planeOrientation)->GetNormal();
+
+    double center[3], focalPoint[3], cameraPosition[3];
     this->GetResliceCursor()->GetCenter(center);
-    this->Renderer->GetActiveCamera()->SetFocalPoint(center);
+    this->Renderer->GetActiveCamera()->GetFocalPoint(focalPoint);
+    this->Renderer->GetActiveCamera()->GetPosition(cameraPosition);
 
-    const int normalAxis = this->GetCursorAlgorithm()->GetReslicePlaneNormal();
-    this->GetResliceCursor()->GetPlane(normalAxis)->GetNormal(n);
-    vtkMath::Add(center, n, camPos);
-    this->Renderer->GetActiveCamera()->SetPosition(camPos);
+    this->Renderer->SetWorldPoint(focalPoint[0], focalPoint[1], focalPoint[2], 1.0);
+    this->Renderer->WorldToDisplay();
+    double displayFocalPoint[3];
+    this->Renderer->GetDisplayPoint(displayFocalPoint);
+
+    this->Renderer->SetWorldPoint(center[0], center[1], center[2], 1.0);
+    this->Renderer->WorldToDisplay();
+    double displayResliceCenter[3];
+    this->Renderer->GetDisplayPoint(displayResliceCenter);
+
+    double centerOffset[3];
+    vtkMath::Subtract(displayFocalPoint, displayResliceCenter, centerOffset);
+
+    double distance = this->Renderer->GetActiveCamera()->GetDistance();
+
+    double newCameraPosition[3] = { focalPoint[0] + normal[0] * distance,
+      focalPoint[1] + normal[1] * distance, focalPoint[2] + normal[2] * distance };
+    this->Renderer->GetActiveCamera()->SetPosition(newCameraPosition);
+
+    double* viewUp = this->GetResliceCursor()->GetViewUp(planeOrientation);
+    this->Renderer->GetActiveCamera()->SetViewUp(viewUp);
+
+    this->Renderer->SetWorldPoint(center[0], center[1], center[2], 1.0);
+    this->Renderer->WorldToDisplay();
+    this->Renderer->GetDisplayPoint(displayResliceCenter);
+    vtkMath::Add(displayResliceCenter, centerOffset, displayFocalPoint);
+
+    this->Renderer->SetDisplayPoint(displayFocalPoint);
+    this->Renderer->DisplayToWorld();
+    double worldFocalPoint[4];
+    this->Renderer->GetWorldPoint(worldFocalPoint);
+
+    vtkNew<vtkPlane> plane;
+    plane->SetNormal(normal);
+    plane->SetOrigin(center);
+    double t;
+    double x[3];
+    if (plane->IntersectWithLine(newCameraPosition, worldFocalPoint, t, x))
+    {
+      this->Renderer->GetActiveCamera()->SetFocalPoint(x);
+    }
+    else
+    {
+      this->Renderer->GetActiveCamera()->SetFocalPoint(worldFocalPoint);
+    }
+
+    this->Renderer->GetActiveCamera()->GetFocalPoint(focalPoint);
+    this->Renderer->GetActiveCamera()->SetPosition(focalPoint[0] + normal[0] * distance,
+      focalPoint[1] + normal[1] * distance, focalPoint[2] + normal[2] * distance);
 
-    // Reset the camera in response to changes.
-    this->Renderer->ResetCamera();
     this->Renderer->ResetCameraClippingRange();
   }
 }
@@ -424,8 +472,11 @@ void vtkResliceCursorRepresentation::UpdateReslicePlane()
 
   this->ComputeReslicePlaneOrigin();
 
-  this->PlaneSource->SetNormal(planeNormal);
-  this->PlaneSource->SetCenter(plane->GetOrigin());
+  double* viewUp = this->GetResliceCursor()->GetViewUp(planeOrientation);
+  double center[3];
+  this->GetResliceCursor()->GetCenter(center);
+
+  vtkResliceCursorRepresentation::TransformPlane(this->PlaneSource, center, planeNormal, viewUp);
 
   // Clip to bounds
   double* imageBounds = this->GetResliceCursor()->GetImage()->GetBounds();
@@ -553,6 +604,7 @@ void vtkResliceCursorRepresentation::UpdateReslicePlane()
   }
 
   this->SetResliceParameters(outputSpacingX, outputSpacingY, extentX, extentY);
+  this->ResetCamera();
 }
 
 //------------------------------------------------------------------------------
@@ -742,19 +794,19 @@ int vtkResliceCursorRepresentation::BoundPlane(
 {
   double v1[3];
   vtkMath::Subtract(p1, origin, v1);
+  vtkMath::Normalize(v1);
 
   double v2[3];
   vtkMath::Subtract(p2, origin, v2);
+  vtkMath::Normalize(v2);
 
   double n[3] = { 0, 0, 1 };
   vtkMath::Cross(v1, v2, n);
+  vtkMath::Normalize(n);
 
   vtkNew<vtkPlane> plane;
   plane->SetOrigin(origin);
   plane->SetNormal(n);
-  vtkMath::Normalize(v1);
-  vtkMath::Normalize(v2);
-  vtkMath::Normalize(n);
 
   vtkNew<vtkCubeSource> cubeSource;
   cubeSource->SetBounds(bounds);
@@ -782,6 +834,18 @@ int vtkResliceCursorRepresentation::BoundPlane(
   return 1;
 }
 
+//------------------------------------------------------------------------------
+void vtkResliceCursorRepresentation::TransformPlane(vtkPlaneSource* planeToTransform,
+  double targetCenter[3], double targetNormal[3], double targetViewUp[3])
+{
+  planeToTransform->SetNormal(targetNormal);
+  double currentViewUp[3];
+  vtkMath::Subtract(planeToTransform->GetPoint2(), planeToTransform->GetOrigin(), currentViewUp);
+  double angle = vtkMath::SignedAngleBetweenVectors(currentViewUp, targetViewUp, targetNormal);
+  planeToTransform->Rotate(vtkMath::DegreesFromRadians(angle), targetNormal);
+  planeToTransform->SetCenter(targetCenter);
+}
+
 //----------------------------------------------------------------------------
 void vtkResliceCursorRepresentation::CreateDefaultResliceAlgorithm()
 {
@@ -877,15 +941,18 @@ void vtkResliceCursorRepresentation::GenerateText()
 //------------------------------------------------------------------------------
 // Prints an object if it exists.
 #define vtkPrintMemberObjectMacro(obj, os, indent)                                                 \
-  os << indent << #obj << ": ";                                                                    \
-  if (this->obj)                                                                                   \
+  do                                                                                               \
   {                                                                                                \
-    os << this->obj << "\n";                                                                       \
-  }                                                                                                \
-  else                                                                                             \
-  {                                                                                                \
-    os << "(null)\n";                                                                              \
-  }
+    os << indent << #obj << ": ";                                                                  \
+    if (this->obj)                                                                                 \
+    {                                                                                              \
+      os << this->obj << "\n";                                                                     \
+    }                                                                                              \
+    else                                                                                           \
+    {                                                                                              \
+      os << "(null)\n";                                                                            \
+    }                                                                                              \
+  } while (false)
 
 //------------------------------------------------------------------------------
 void vtkResliceCursorRepresentation::PrintSelf(ostream& os, vtkIndent indent)
@@ -941,3 +1008,4 @@ void vtkResliceCursorRepresentation::PrintSelf(ostream& os, vtkIndent indent)
   // this->Texture;
   // this->TextActor;
 }
+VTK_ABI_NAMESPACE_END
