@@ -30,6 +30,7 @@
 #include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkWidgetRepresentation.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkTextProperty;
 class vtkActor2D;
 class vtkTextMapper;
@@ -54,15 +55,15 @@ class vtkImageAlgorithm;
 class VTKINTERACTIONWIDGETS_EXPORT vtkResliceCursorRepresentation : public vtkWidgetRepresentation
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard VTK methods.
    */
   vtkTypeMacro(vtkResliceCursorRepresentation, vtkWidgetRepresentation);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The tolerance representing the distance to the representation (in
    * pixels) in which the cursor is considered near enough to the
@@ -70,18 +71,18 @@ public:
    */
   vtkSetClampMacro(Tolerance, int, 1, 100);
   vtkGetMacro(Tolerance, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Show the resliced image ?
    */
   vtkSetMacro(ShowReslicedImage, vtkTypeBool);
   vtkGetMacro(ShowReslicedImage, vtkTypeBool);
   vtkBooleanMacro(ShowReslicedImage, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Make sure that the resliced image remains within the volume.
    * Default is On.
@@ -89,9 +90,9 @@ public:
   vtkSetMacro(RestrictPlaneToVolume, vtkTypeBool);
   vtkGetMacro(RestrictPlaneToVolume, vtkTypeBool);
   vtkBooleanMacro(RestrictPlaneToVolume, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the format to use for labelling the distance. Note that an empty
    * string results in no label, or a format string without a "%" character
@@ -99,7 +100,7 @@ public:
    */
   vtkSetStringMacro(ThicknessLabelFormat);
   vtkGetStringMacro(ThicknessLabelFormat);
-  //@}
+  ///@}
 
   // Used to communicate about the state of the representation
   enum
@@ -118,7 +119,8 @@ public:
     PanAndRotate,
     RotateBothAxes,
     ResizeThickness,
-    WindowLevelling
+    WindowLevelling,
+    TranslateSingleAxis
   };
 
   /**
@@ -126,36 +128,36 @@ public:
    */
   virtual char* GetThicknessLabelText();
 
-  //@{
+  ///@{
   /**
    * Get the position of the widget's label in display coordinates.
    */
   virtual double* GetThicknessLabelPosition();
   virtual void GetThicknessLabelPosition(double pos[3]);
   virtual void GetWorldThicknessLabelPosition(double pos[3]);
-  //@}
+  ///@}
 
   /**
    * These are methods that satisfy vtkWidgetRepresentation's API.
    */
   void BuildRepresentation() override;
 
-  //@{
+  ///@{
   /**
    * Get the current reslice class and reslice axes
    */
   vtkGetObjectMacro(ResliceAxes, vtkMatrix4x4);
   vtkGetObjectMacro(Reslice, vtkImageAlgorithm);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the displayed image actor
    */
   vtkGetObjectMacro(ImageActor, vtkImageActor);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the internal lookuptable (lut) to one defined by the user, or,
    * alternatively, to the lut of another Reslice cusror widget.  In this way,
@@ -165,9 +167,9 @@ public:
    */
   virtual void SetLookupTable(vtkScalarsToColors*);
   vtkGetObjectMacro(LookupTable, vtkScalarsToColors);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convenience method to get the vtkImageMapToColors filter used by this
    * widget.  The user can properly render other transparent actors in a
@@ -176,9 +178,9 @@ public:
    */
   vtkGetObjectMacro(ColorMap, vtkImageMapToColors);
   virtual void SetColorMap(vtkImageMapToColors*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the current window and level values.  SetWindowLevel should
    * only be called after SetInput.  If a shared lookup table is being used,
@@ -189,11 +191,11 @@ public:
   void GetWindowLevel(double wl[2]);
   double GetWindow() { return this->CurrentWindow; }
   double GetLevel() { return this->CurrentLevel; }
-  //@}
+  ///@}
 
   virtual vtkResliceCursor* GetResliceCursor() = 0;
 
-  //@{
+  ///@{
   /**
    * Enable/disable text display of window-level, image coordinates and
    * scalar values in a render window.
@@ -201,17 +203,17 @@ public:
   vtkSetMacro(DisplayText, vtkTypeBool);
   vtkGetMacro(DisplayText, vtkTypeBool);
   vtkBooleanMacro(DisplayText, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the text property for the image data and window-level annotation.
    */
   void SetTextProperty(vtkTextProperty* tprop);
   vtkTextProperty* GetTextProperty();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Render as a 2D image, or render as a plane with a texture in physical
    * space.
@@ -219,18 +221,18 @@ public:
   vtkSetMacro(UseImageActor, vtkTypeBool);
   vtkGetMacro(UseImageActor, vtkTypeBool);
   vtkBooleanMacro(UseImageActor, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * INTERNAL - Do not use
    * Set the manipulation mode. This is done by the widget
    */
   void SetManipulationMode(int m);
   vtkGetMacro(ManipulationMode, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * INTERNAL - Do not use.
    * Internal methods used by the widget to manage text displays
@@ -238,29 +240,29 @@ public:
    */
   void ActivateText(int);
   void ManageTextDisplay();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Initialize the reslice planes and the camera center. This is done
    * automatically, the first time we render.
    */
   virtual void InitializeReslicePlane();
   virtual void ResetCamera();
-  //@}
+  ///@}
 
   /**
    * Get the underlying cursor source.
    */
   virtual vtkResliceCursorPolyDataAlgorithm* GetCursorAlgorithm() = 0;
 
-  //@{
+  ///@{
   /**
    * Get the plane source on which the texture (the thin/thick resliced
    * image is displayed)
    */
   vtkGetObjectMacro(PlaneSource, vtkPlaneSource);
-  //@}
+  ///@}
 
   /**
    * Fit the plane defined by origin, p1, p2 onto the bounds.
@@ -268,20 +270,28 @@ public:
    * return 1 if the bounds is intersected, else 0
    */
   static int BoundPlane(double bounds[6], double origin[3], double p1[3], double p2[3]);
+  /**
+   * First rotate planeToTransform to match targetPlane normal.
+   * Then rotate around targetNormal to enforce targetViewUp "up" vector (i.e. Origin->p2 ).
+   * There is an infinite number of options to rotate a plane normal to another. Here we attempt to
+   * preserve Origin, P1 and P2 when rotating around targetPlane.
+   */
+  static void TransformPlane(vtkPlaneSource* planeToTransform, double targetCenter[3],
+    double targetNormal[3], double targetViewUp[3]);
 
 protected:
   vtkResliceCursorRepresentation();
   ~vtkResliceCursorRepresentation() override;
 
-  //@{
+  ///@{
   /**
-   * Create New Reslice plane. Allows subclasses to override and crate
+   * Create New Reslice plane. Allows subclasses to override and create
    * their own reslice filters to respond to the widget.
    */
   virtual void CreateDefaultResliceAlgorithm();
   virtual void SetResliceParameters(
     double outputSpacingX, double outputSpacingY, int extentX, int extentY);
-  //@}
+  ///@}
 
   /**
    * Process window level
@@ -305,10 +315,10 @@ protected:
   // with its physical location
   virtual void ComputeOrigin(vtkMatrix4x4*);
 
-  //@{
+  ///@{
   void GetVector1(double d[3]);
   void GetVector2(double d[3]);
-  //@}
+  ///@}
 
   /**
    * The widget sets the manipulation mode. This can be one of :
@@ -359,4 +369,5 @@ private:
   void operator=(const vtkResliceCursorRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
