@@ -34,6 +34,7 @@
 #include <cmath>
 
 //=============================================================================
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkScalarBarRepresentation);
 //------------------------------------------------------------------------------
 vtkScalarBarRepresentation::vtkScalarBarRepresentation()
@@ -197,7 +198,7 @@ void vtkScalarBarRepresentation::SwapOrientation()
 }
 
 //------------------------------------------------------------------------------
-vtkTypeBool vtkScalarBarRepresentation::GetVisibility()
+vtkTypeBool vtkScalarBarRepresentation::GetVisibility() VTK_FUTURE_CONST
 {
   return this->ScalarBarActor->GetVisibility();
 }
@@ -272,3 +273,4 @@ vtkTypeBool vtkScalarBarRepresentation::HasTranslucentPolygonalGeometry()
   }
   return result;
 }
+VTK_ABI_NAMESPACE_END
