@@ -27,19 +27,21 @@
 #include <iterator>
 #include <list>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSeedRepresentation);
 
-vtkCxxSetObjectMacro(vtkSeedRepresentation,HandleRepresentation,vtkHandleRepresentation);
+vtkCxxSetObjectMacro(vtkSeedRepresentation, HandleRepresentation, vtkHandleRepresentation);
 
 // The vtkHandleList is a PIMPLed list<T>.
-class vtkHandleList : public std::list<vtkHandleRepresentation*> {};
+class vtkHandleList : public std::list<vtkHandleRepresentation*>
+{
+};
 typedef std::list<vtkHandleRepresentation*>::iterator vtkHandleListIterator;
 
-
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSeedRepresentation::vtkSeedRepresentation()
 {
-  this->HandleRepresentation  = nullptr;
+  this->HandleRepresentation = nullptr;
 
   // The representation for the seed handles
   this->Handles = new vtkHandleList;
@@ -48,63 +50,62 @@ vtkSeedRepresentation::vtkSeedRepresentation()
   this->Tolerance = 5;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSeedRepresentation::~vtkSeedRepresentation()
 {
-  if ( this->HandleRepresentation )
+  if (this->HandleRepresentation)
   {
     this->HandleRepresentation->Delete();
   }
 
   // Loop over all handles releasing their observes and deleting them
   vtkHandleListIterator iter;
-  for ( iter = this->Handles->begin(); iter != this->Handles->end(); ++iter )
+  for (iter = this->Handles->begin(); iter != this->Handles->end(); ++iter)
   {
     (*iter)->Delete();
   }
   delete this->Handles;
 }
 
-//----------------------------------------------------------------------
-vtkHandleRepresentation *vtkSeedRepresentation
-::GetHandleRepresentation(unsigned int num)
+//------------------------------------------------------------------------------
+vtkHandleRepresentation* vtkSeedRepresentation ::GetHandleRepresentation(unsigned int num)
 {
-  if ( num < this->Handles->size() )
+  if (num < this->Handles->size())
   {
     vtkHandleListIterator iter = this->Handles->begin();
-    std::advance(iter,num);
+    std::advance(iter, num);
     return (*iter);
   }
-  else //create one
+  else // create one
   {
     if (this->HandleRepresentation == nullptr)
     {
-      vtkErrorMacro("GetHandleRepresentation " << num << ", no handle representation has been set yet, cannot create a new handle.");
+      vtkErrorMacro("GetHandleRepresentation "
+        << num << ", no handle representation has been set yet, cannot create a new handle.");
       return nullptr;
     }
-    vtkHandleRepresentation *rep = this->HandleRepresentation->NewInstance();
+    vtkHandleRepresentation* rep = this->HandleRepresentation->NewInstance();
     rep->DeepCopy(this->HandleRepresentation);
-    this->Handles->push_back( rep );
+    this->Handles->push_back(rep);
     return rep;
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::GetSeedWorldPosition(unsigned int seedNum, double pos[3])
 {
-  if ( seedNum >= this->Handles->size() )
+  if (seedNum >= this->Handles->size())
   {
     vtkErrorMacro("Trying to access non-existent handle");
     return;
   }
   vtkHandleListIterator iter = this->Handles->begin();
-  std::advance(iter,seedNum);
+  std::advance(iter, seedNum);
   (*iter)->GetWorldPosition(pos);
 }
 
-//----------------------------------------------------------------------------
-void vtkSeedRepresentation::SetSeedWorldPosition(unsigned int seedNum,
-                                                 double pos[3])
+//------------------------------------------------------------------------------
+void vtkSeedRepresentation::SetSeedWorldPosition(unsigned int seedNum, double pos[3])
 {
   if (seedNum >= this->Handles->size())
   {
@@ -116,50 +117,50 @@ void vtkSeedRepresentation::SetSeedWorldPosition(unsigned int seedNum,
   (*iter)->SetWorldPosition(pos);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::SetSeedDisplayPosition(unsigned int seedNum, double pos[3])
 {
-  if ( seedNum >= this->Handles->size() )
+  if (seedNum >= this->Handles->size())
   {
     vtkErrorMacro("Trying to access non-existent handle");
     return;
   }
   vtkHandleListIterator iter = this->Handles->begin();
-  std::advance(iter,seedNum);
+  std::advance(iter, seedNum);
   (*iter)->SetDisplayPosition(pos);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::GetSeedDisplayPosition(unsigned int seedNum, double pos[3])
 {
-  if ( seedNum >= this->Handles->size() )
+  if (seedNum >= this->Handles->size())
   {
     vtkErrorMacro("Trying to access non-existent handle");
     return;
   }
   vtkHandleListIterator iter = this->Handles->begin();
-  std::advance(iter,seedNum);
+  std::advance(iter, seedNum);
   (*iter)->GetDisplayPosition(pos);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSeedRepresentation::GetNumberOfSeeds()
 {
   return static_cast<int>(this->Handles->size());
 }
 
-//----------------------------------------------------------------------
-int vtkSeedRepresentation::
-ComputeInteractionState(int vtkNotUsed(X), int vtkNotUsed(Y), int vtkNotUsed(modify))
+//------------------------------------------------------------------------------
+int vtkSeedRepresentation::ComputeInteractionState(
+  int vtkNotUsed(X), int vtkNotUsed(Y), int vtkNotUsed(modify))
 {
   // Loop over all the seeds to see if the point is close to any of them.
   int i;
   vtkHandleListIterator iter;
-  for ( i = 0, iter = this->Handles->begin(); iter != this->Handles->end(); ++iter, ++i )
+  for (i = 0, iter = this->Handles->begin(); iter != this->Handles->end(); ++iter, ++i)
   {
-    if ( *iter != nullptr )
+    if (*iter != nullptr)
     {
-      if ( (*iter)->GetInteractionState() != vtkHandleRepresentation::Outside )
+      if ((*iter)->GetInteractionState() != vtkHandleRepresentation::Outside)
       {
         this->ActiveHandle = i;
         this->InteractionState = vtkSeedRepresentation::NearSeed;
@@ -173,13 +174,13 @@ ComputeInteractionState(int vtkNotUsed(X), int vtkNotUsed(Y), int vtkNotUsed(mod
   return this->InteractionState;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSeedRepresentation::GetActiveHandle()
 {
   return this->ActiveHandle;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::SetActiveHandle(int handleId)
 {
   if (handleId >= static_cast<int>(this->Handles->size()))
@@ -189,7 +190,7 @@ void vtkSeedRepresentation::SetActiveHandle(int handleId)
   this->ActiveHandle = handleId;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSeedRepresentation::CreateHandle(double e[2])
 {
   double pos[3];
@@ -197,23 +198,23 @@ int vtkSeedRepresentation::CreateHandle(double e[2])
   pos[1] = e[1];
   pos[2] = 0.0;
 
-  vtkHandleRepresentation *rep = this->GetHandleRepresentation(
-    static_cast<int>(this->Handles->size()));
+  vtkHandleRepresentation* rep =
+    this->GetHandleRepresentation(static_cast<int>(this->Handles->size()));
   if (rep == nullptr)
   {
     vtkErrorMacro("CreateHandle: no handle representation set yet! Cannot create a new handle.");
     return -1;
   }
   rep->SetDisplayPosition(pos);
-  rep->SetTolerance(this->Tolerance); //needed to ensure that picking is consistent
+  rep->SetTolerance(this->Tolerance); // needed to ensure that picking is consistent
   this->ActiveHandle = static_cast<int>(this->Handles->size()) - 1;
   return this->ActiveHandle;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::RemoveLastHandle()
 {
-  if ( this->Handles->empty() )
+  if (this->Handles->empty())
   {
     return;
   }
@@ -223,8 +224,8 @@ void vtkSeedRepresentation::RemoveLastHandle()
   this->Handles->pop_back();
 }
 
-//----------------------------------------------------------------------
-void vtkSeedRepresentation::RemoveHandle( int n )
+//------------------------------------------------------------------------------
+void vtkSeedRepresentation::RemoveHandle(int n)
 {
   // Remove nth handle
 
@@ -234,55 +235,71 @@ void vtkSeedRepresentation::RemoveHandle( int n )
     return;
   }
 
-  if (static_cast<int>(this->Handles->size()) <= n )
+  if (static_cast<int>(this->Handles->size()) <= n)
   {
     return;
   }
 
   vtkHandleListIterator iter = this->Handles->begin();
-  std::advance( iter, n );
-  vtkHandleRepresentation *hr = *iter;
-  this->Handles->erase( iter );
+  std::advance(iter, n);
+  vtkHandleRepresentation* hr = *iter;
+  this->Handles->erase(iter);
   hr->Delete();
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::RemoveActiveHandle()
 {
-  if ( this->Handles->empty() )
+  if (this->Handles->empty())
   {
     return;
   }
-  if ( this->ActiveHandle >= 0 && this->ActiveHandle < static_cast<int>(this->Handles->size()) )
+  if (this->ActiveHandle >= 0 && this->ActiveHandle < static_cast<int>(this->Handles->size()))
   {
     vtkHandleListIterator iter = this->Handles->begin();
-    std::advance( iter, this->ActiveHandle );
-    vtkHandleRepresentation *hr = *iter;
-    this->Handles->erase( iter );
+    std::advance(iter, this->ActiveHandle);
+    vtkHandleRepresentation* hr = *iter;
+    this->Handles->erase(iter);
     hr->Delete();
     this->ActiveHandle = -1;
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::BuildRepresentation()
 {
-  if ( this->ActiveHandle >=0 && this->ActiveHandle < static_cast<int>(this->Handles->size()) )
+  if (this->ActiveHandle >= 0 && this->ActiveHandle < static_cast<int>(this->Handles->size()))
   {
-    vtkHandleRepresentation *rep = this->GetHandleRepresentation(this->ActiveHandle);
-    if ( rep )
+    vtkHandleRepresentation* rep = this->GetHandleRepresentation(this->ActiveHandle);
+    if (rep)
     {
       rep->BuildRepresentation();
     }
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSeedRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
-  //Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
-  this->Superclass::PrintSelf(os,indent);
+  // Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
+  this->Superclass::PrintSelf(os, indent);
 
-  os << indent << "Tolerance: " << this->Tolerance <<"\n";
-  os << indent << "Number of Seeds: " << this->GetNumberOfSeeds() <<"\n";
+  os << indent << "Tolerance: " << this->Tolerance << "\n";
+  os << indent << "Number of Seeds: " << this->GetNumberOfSeeds() << "\n";
 }
+
+//------------------------------------------------------------------------------
+void vtkSeedRepresentation::GetActors(vtkPropCollection* pc)
+{
+  if (!pc)
+  {
+    return;
+  }
+  vtkHandleListIterator iter = this->Handles->begin();
+  for (; iter != this->Handles->end(); ++iter)
+  {
+    pc->AddItem(*iter);
+  }
+  this->Superclass::GetActors(pc);
+}
+VTK_ABI_NAMESPACE_END
