@@ -88,8 +88,10 @@
 #define vtkSphereWidget2_h
 
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSphereRepresentation;
 class vtkHandleWidget;
 
@@ -101,13 +103,13 @@ public:
    */
   static vtkSphereWidget2* New();
 
-  //@{
+  ///@{
   /**
    * Standard class methods for type information and printing.
    */
   vtkTypeMacro(vtkSphereWidget2, vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Specify an instance of vtkWidgetRepresentation used to represent this
@@ -119,7 +121,7 @@ public:
     this->Superclass::SetWidgetRepresentation(reinterpret_cast<vtkWidgetRepresentation*>(r));
   }
 
-  //@{
+  ///@{
   /**
    * Control the behavior of the widget (i.e., how it processes
    * events). Translation, and scaling can all be enabled and disabled.
@@ -130,7 +132,7 @@ public:
   vtkSetMacro(ScalingEnabled, vtkTypeBool);
   vtkGetMacro(ScalingEnabled, vtkTypeBool);
   vtkBooleanMacro(ScalingEnabled, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Create the default widget representation if one is not set. By default,
@@ -150,11 +152,15 @@ protected:
 
   // Manage the state of the widget
   int WidgetState;
-  enum _WidgetState
+  enum WidgetStateType
   {
     Start = 0,
     Active
   };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
 
   // These methods handle events
   static void SelectAction(vtkAbstractWidget*);
@@ -175,4 +181,5 @@ private:
   void operator=(const vtkSphereWidget2&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
