@@ -21,14 +21,16 @@
  * vtkSplineRepresentation. This is based on vtkSplineWidget.
  * @sa
  * vtkSplineRepresentation, vtkSplineWidget2
-*/
+ */
 
 #ifndef vtkSplineWidget2_h
 #define vtkSplineWidget2_h
 
-#include "vtkInteractionWidgetsModule.h" // For export macro
 #include "vtkAbstractWidget.h"
+#include "vtkDeprecation.h"              // For VTK_DEPRECATED_IN_9_2_0
+#include "vtkInteractionWidgetsModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSplineRepresentation;
 
 class VTKINTERACTIONWIDGETS_EXPORT vtkSplineWidget2 : public vtkAbstractWidget
@@ -43,10 +45,9 @@ public:
    * widget in the scene. Note that the representation is a subclass of
    * vtkProp so it can be added to the renderer independent of the widget.
    */
-  void SetRepresentation(vtkSplineRepresentation *r)
+  void SetRepresentation(vtkSplineRepresentation* r)
   {
-    this->Superclass::SetWidgetRepresentation(
-      reinterpret_cast<vtkWidgetRepresentation*>(r));
+    this->Superclass::SetWidgetRepresentation(reinterpret_cast<vtkWidgetRepresentation*>(r));
   }
 
   /**
@@ -66,7 +67,15 @@ protected:
   ~vtkSplineWidget2() override;
 
   int WidgetState;
-  enum _WidgetState {Start=0,Active};
+  enum WidgetStateType
+  {
+    Start = 0,
+    Active
+  };
+#if !defined(VTK_LEGACY_REMOVE)
+  VTK_DEPRECATED_IN_9_2_0("because leading underscore is reserved")
+  typedef WidgetStateType _WidgetState;
+#endif
 
   // These methods handle events
   static void SelectAction(vtkAbstractWidget*);
@@ -75,16 +84,13 @@ protected:
   static void ScaleAction(vtkAbstractWidget*);
   static void MoveAction(vtkAbstractWidget*);
 
-
-  vtkCallbackCommand *KeyEventCallbackCommand;
-  static void ProcessKeyEvents(vtkObject *, unsigned long, void *, void *);
+  vtkCallbackCommand* KeyEventCallbackCommand;
+  static void ProcessKeyEvents(vtkObject*, unsigned long, void*, void*);
 
 private:
   vtkSplineWidget2(const vtkSplineWidget2&) = delete;
   void operator=(const vtkSplineWidget2&) = delete;
-
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-
