@@ -15,10 +15,12 @@
 #include "vtkWidgetCallbackMapper.h"
 #include "vtkAbstractWidget.h"
 #include "vtkCommand.h"
+#include "vtkEventData.h"
 #include "vtkObjectFactory.h"
 #include "vtkWidgetEventTranslator.h"
 #include <map>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkWidgetCallbackMapper);
 
 // Callbacks are stored as a pair of (Object,Method) in the map.
@@ -105,6 +107,9 @@ void vtkWidgetCallbackMapper::SetCallbackMethod(unsigned long VTKEvent, int modi
 void vtkWidgetCallbackMapper::SetCallbackMethod(unsigned long VTKEvent, vtkEventData* edata,
   unsigned long widgetEvent, vtkAbstractWidget* w, CallbackType f)
 {
+  // make sure the type is set
+  edata->SetType(VTKEvent);
+
   this->EventTranslator->SetTranslation(VTKEvent, edata, widgetEvent);
   this->SetCallbackMethod(widgetEvent, w, f);
 }
@@ -144,3 +149,4 @@ void vtkWidgetCallbackMapper::PrintSelf(ostream& os, vtkIndent indent)
     os << "(none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
