@@ -31,6 +31,22 @@
  * way the representation responds to the registered widget events, so the API
  * may vary from widget to widget to reflect this complexity.
  *
+ * Clients of VTK, like ParaView, need a uniform way to set colors on widgets.
+ * Most widgets have standard color setters - new widgets should follow this pattern.
+ * The intended use of these colors is as follows:
+ * | Color       | Description |
+ * | ----------- | ----------- |
+ * | `HandleColor`      | Widget handles that are available to interact with via click+drag. | |
+ * `InteractionColor` | Widget handles the user is interacting with (via a click+drag) or hovering
+ * over.     | | `ForegroundColor`  | Widget elements meant to contrast with the background and
+ * which are not interactive. |
+ *
+ * When hovering, the `InteractionColor` can also be used to show which parts
+ * of the widget will change if this handle is dragged. For instance, using the
+ * `vtkDisplaySizedImplicitPlaneRepresentation`, hovering the axis also displays
+ * the plane disc in the `InteractionColor`, to show it will change when the
+ * axis is rotated.
+ *
  * @warning
  * The separation of the widget event handling and representation enables
  * users and developers to create new appearances for the widget. It also
@@ -47,6 +63,7 @@
 #include "vtkProp.h"
 #include "vtkWeakPointer.h" // needed for vtkWeakPointer iVar.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractPropPicker;
 class vtkAbstractWidget;
 class vtkMatrix4x4;
@@ -59,15 +76,15 @@ class vtkTransform;
 class VTKINTERACTIONWIDGETS_EXPORT vtkWidgetRepresentation : public vtkProp
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instances of this class.
    */
   vtkTypeMacro(vtkWidgetRepresentation, vtkProp);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/Disable the use of a manager to process the picking.
    * Enabled by default.
@@ -75,9 +92,9 @@ public:
   vtkBooleanMacro(PickingManaged, bool);
   void SetPickingManaged(bool managed);
   vtkGetMacro(PickingManaged, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Subclasses of vtkWidgetRepresentation must implement these methods. This is
    * considered the minimum API for a widget representation.
@@ -97,7 +114,7 @@ public:
   virtual void SetRenderer(vtkRenderer* ren);
   virtual vtkRenderer* GetRenderer();
   virtual void BuildRepresentation() = 0;
-  //@}
+  ///@}
 
   /**
    * The following is a suggested API for widget representations. These methods
@@ -131,7 +148,7 @@ public:
    * Note that subclasses may ignore some of these methods and implement their own
    * depending on the specifics of the widget.
    */
-  virtual void PlaceWidget(double* vtkNotUsed(bounds[6]));
+  virtual void PlaceWidget(double vtkNotUsed(bounds)[6]);
   virtual void StartWidgetInteraction(double eventPos[2]) { (void)eventPos; }
   virtual void WidgetInteraction(double newEventPos[2]) { (void)newEventPos; }
   virtual void EndWidgetInteraction(double newEventPos[2]) { (void)newEventPos; }
@@ -139,7 +156,7 @@ public:
   virtual int GetInteractionState() { return this->InteractionState; }
   virtual void Highlight(int vtkNotUsed(highlightOn)) {}
 
-  //@{
+  ///@{
   // Widgets were originally designed to be driven by 2D mouse events
   // With Virtual Reality and multitouch we get mnore complex events
   // that may involve multiple pointers as well as 3D pointers and
@@ -160,9 +177,9 @@ public:
   }
   virtual int ComputeComplexInteractionState(vtkRenderWindowInteractor* iren,
     vtkAbstractWidget* widget, unsigned long event, void* callData, int modify = 0);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get a factor representing the scaling of the widget upon placement
    * (via the PlaceWidget() method). Normally the widget is placed so that
@@ -172,9 +189,9 @@ public:
    */
   vtkSetClampMacro(PlaceFactor, double, 0.01, VTK_DOUBLE_MAX);
   vtkGetMacro(PlaceFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the factor that controls the size of the handles that appear as
    * part of the widget (if any). These handles (like spheres, etc.)  are
@@ -186,9 +203,9 @@ public:
    */
   vtkSetClampMacro(HandleSize, double, 0.001, 1000);
   vtkGetMacro(HandleSize, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Some subclasses use this data member to keep track of whether to render
    * or not (i.e., to minimize the total number of renders).
@@ -196,7 +213,7 @@ public:
   vtkGetMacro(NeedToRender, vtkTypeBool);
   vtkSetClampMacro(NeedToRender, vtkTypeBool, 0, 1);
   vtkBooleanMacro(NeedToRender, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Methods to make this class behave as a vtkProp. They are repeated here (from the
@@ -229,7 +246,7 @@ public:
    */
   virtual void UnRegisterPickers();
 
-  //@{
+  ///@{
   /**
    * Axis labels
    */
@@ -238,9 +255,10 @@ public:
     NONE = -1,
     XAxis = 0,
     YAxis = 1,
-    ZAxis = 2
+    ZAxis = 2,
+    Custom = 3
   };
-  //@}
+  ///@}
 
 protected:
   vtkWidgetRepresentation();
@@ -320,4 +338,5 @@ private:
   void operator=(const vtkWidgetRepresentation&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
