@@ -80,6 +80,7 @@
     vtkGenericWarningMacro(<< #name << " not supported for floating point numbers");               \
   }
 
+VTK_ABI_NAMESPACE_BEGIN
 STANDARD_OPERATION_DEFINITION(Max, (A[i] < B[i] ? B[i] : A[i]));
 STANDARD_OPERATION_DEFINITION(Min, (A[i] < B[i] ? A[i] : B[i]));
 STANDARD_OPERATION_DEFINITION(Sum, A[i] + B[i]);
@@ -203,6 +204,8 @@ int vtkCommunicator::Send(vtkDataObject* data, int remoteHandle, int tag)
     case VTK_MULTIBLOCK_DATA_SET:
     case VTK_UNIFORM_GRID_AMR:
     case VTK_OVERLAPPING_AMR:
+    case VTK_PARTITIONED_DATA_SET:
+    case VTK_PARTITIONED_DATA_SET_COLLECTION:
       return this->SendElementalDataObject(data, remoteHandle, tag);
   }
 }
@@ -396,6 +399,8 @@ int vtkCommunicator::ReceiveDataObject(vtkDataObject* data, int remoteHandle, in
     case VTK_MULTIBLOCK_DATA_SET:
     case VTK_UNIFORM_GRID_AMR:
     case VTK_OVERLAPPING_AMR:
+    case VTK_PARTITIONED_DATA_SET:
+    case VTK_PARTITIONED_DATA_SET_COLLECTION:
       return this->ReceiveElementalDataObject(data, remoteHandle, tag);
   }
 }
@@ -475,6 +480,7 @@ int vtkCommunicator::Receive(vtkDataArray* data, int remoteHandle, int tag)
     // Receive the name
     this->Receive(str, nameLength, remoteHandle, tag);
     data->SetName(str);
+    delete[] str;
   }
   else
   {
@@ -974,11 +980,13 @@ int vtkCommunicator::Gather(vtkDataArray* sendBuffer, vtkDataArray* recvBuffer,
 int vtkCommunicator::Gather(vtkDataObject* sendBuffer,
   std::vector<vtkSmartPointer<vtkDataObject>>& recvBuffer, int destProcessId)
 {
+  int status = 1;
   vtkNew<vtkCharArray> sendArray;
   if (vtkCommunicator::MarshalDataObject(sendBuffer, sendArray) == 0)
   {
     vtkErrorMacro("Marshalling failed! Cannot 'Gather' successfully!");
     sendArray->Initialize();
+    status = 0;
   }
 
   vtkNew<vtkCharArray> fullRecvArray;
@@ -992,7 +1000,7 @@ int vtkCommunicator::Gather(vtkDataObject* sendBuffer,
     }
   }
 
-  if (this->GatherV(sendArray, fullRecvArray, &recvArrays[0], destProcessId))
+  if (this->GatherV(sendArray, fullRecvArray, recvArrays.data(), destProcessId))
   {
     if (this->LocalProcessId == destProcessId)
     {
@@ -1003,7 +1011,7 @@ int vtkCommunicator::Gather(vtkDataObject* sendBuffer,
         recvBuffer[cc] = dobj;
       }
     }
-    return 1;
+    return status;
   }
   return 0;
 }
@@ -1014,7 +1022,7 @@ int vtkCommunicator::Gather(const vtkMultiProcessStream& sendBuffer,
 {
   vtkNew<vtkUnsignedCharArray> sendArray;
   auto rawData = sendBuffer.GetRawData();
-  sendArray->SetArray(&rawData[0], static_cast<vtkIdType>(rawData.size()), /*save*/ 1);
+  sendArray->SetArray(rawData.data(), static_cast<vtkIdType>(rawData.size()), /*save*/ 1);
 
   vtkNew<vtkUnsignedCharArray> fullRecvArray;
   std::vector<vtkSmartPointer<vtkDataArray>> recvArrays(this->NumberOfProcesses);
@@ -1027,7 +1035,7 @@ int vtkCommunicator::Gather(const vtkMultiProcessStream& sendBuffer,
     }
   }
 
-  if (this->GatherV(sendArray, fullRecvArray, &recvArrays[0], destProcessId))
+  if (this->GatherV(sendArray, fullRecvArray, recvArrays.data(), destProcessId))
   {
     if (this->LocalProcessId == destProcessId)
     {
@@ -1049,7 +1057,7 @@ int vtkCommunicator::AllGather(
 {
   vtkNew<vtkUnsignedCharArray> sendArray;
   auto rawData = sendBuffer.GetRawData();
-  sendArray->SetArray(&rawData[0], static_cast<vtkIdType>(rawData.size()), /*save*/ 1);
+  sendArray->SetArray(rawData.data(), static_cast<vtkIdType>(rawData.size()), /*save*/ 1);
 
   vtkNew<vtkUnsignedCharArray> fullRecvArray;
   std::vector<vtkSmartPointer<vtkDataArray>> recvArrays(this->NumberOfProcesses);
@@ -1059,7 +1067,7 @@ int vtkCommunicator::AllGather(
     recvArrays[cc] = vtkSmartPointer<vtkUnsignedCharArray>::New();
   }
 
-  if (this->AllGatherV(sendArray, fullRecvArray, &recvArrays[0]))
+  if (this->AllGatherV(sendArray, fullRecvArray, recvArrays.data()))
   {
     for (int cc = 0; cc < this->NumberOfProcesses; ++cc)
     {
@@ -1072,6 +1080,40 @@ int vtkCommunicator::AllGather(
   return 0;
 }
 
+//------------------------------------------------------------------------------
+int vtkCommunicator::AllGather(
+  vtkDataObject* sendBuffer, std::vector<vtkSmartPointer<vtkDataObject>>& recvBuffer)
+{
+  int status = 1;
+  vtkNew<vtkCharArray> sendArray;
+  if (vtkCommunicator::MarshalDataObject(sendBuffer, sendArray) == 0)
+  {
+    vtkErrorMacro("Marshalling failed! Cannot 'AllGather' successfully!");
+    sendArray->Initialize();
+    status = 0;
+  }
+
+  vtkNew<vtkCharArray> fullRecvArray;
+  std::vector<vtkSmartPointer<vtkDataArray>> recvArrays(this->NumberOfProcesses);
+  recvBuffer.resize(this->NumberOfProcesses);
+  for (int cc = 0; cc < this->NumberOfProcesses; ++cc)
+  {
+    recvArrays[cc] = vtkSmartPointer<vtkCharArray>::New();
+  }
+
+  if (this->AllGatherV(sendArray, fullRecvArray, recvArrays.data()))
+  {
+    for (int cc = 0; cc < this->NumberOfProcesses; ++cc)
+    {
+      vtkSmartPointer<vtkDataObject> dobj =
+        vtkCommunicator::UnMarshalDataObject(vtkArrayDownCast<vtkCharArray>(recvArrays[cc]));
+      recvBuffer[cc] = dobj;
+    }
+    return status;
+  }
+  return 0;
+}
+
 //------------------------------------------------------------------------------
 int vtkCommunicator::GatherV(vtkDataArray* sendBuffer, vtkDataArray* recvBuffer,
   vtkSmartPointer<vtkDataArray>* recvBuffers, int destProcessId)
@@ -1127,7 +1169,7 @@ int vtkCommunicator::GatherVElementalDataObject(
       recvBuffers[i] = vtkSmartPointer<vtkCharArray>::New();
     }
   }
-  if (this->GatherV(sendBuffer, recvBuffer, &recvBuffers[0], destProcessId))
+  if (this->GatherV(sendBuffer, recvBuffer, recvBuffers.data(), destProcessId))
   {
     if (this->LocalProcessId == destProcessId)
     {
@@ -1488,7 +1530,7 @@ int vtkCommunicator::ReduceVoidArray(const void* sendBuffer, void* recvBuffer, v
 #define OP_CASE(id, opclass)                                                                       \
   case id:                                                                                         \
     opClass = new vtkCommunicator##opclass##Class;                                                 \
-    break;
+    break
 
   vtkCommunicator::Operation* opClass = nullptr;
 
@@ -1671,7 +1713,7 @@ int vtkCommunicator::Broadcast(vtkMultiProcessStream& stream, int srcProcessId)
     }
     if (length > 0)
     {
-      return this->Broadcast(&data[0], length, srcProcessId);
+      return this->Broadcast(data.data(), length, srcProcessId);
     }
     return 1;
   }
@@ -1687,7 +1729,7 @@ int vtkCommunicator::Broadcast(vtkMultiProcessStream& stream, int srcProcessId)
     {
       std::vector<unsigned char> data;
       data.resize(length);
-      if (!this->Broadcast(&data[0], length, srcProcessId))
+      if (!this->Broadcast(data.data(), length, srcProcessId))
       {
         return 0;
       }
@@ -1709,7 +1751,7 @@ int vtkCommunicator::Send(const vtkMultiProcessStream& stream, int remoteId, int
   }
   if (length > 0)
   {
-    return this->Send(&data[0], length, remoteId, tag);
+    return this->Send(data.data(), length, remoteId, tag);
   }
   return 1;
 }
@@ -1729,7 +1771,7 @@ int vtkCommunicator::Receive(vtkMultiProcessStream& stream, int remoteId, int ta
   {
     std::vector<unsigned char> data;
     data.resize(length);
-    if (!this->Receive(&data[0], length, remoteId, tag))
+    if (!this->Receive(data.data(), length, remoteId, tag))
     {
       return 0;
     }
@@ -1737,3 +1779,4 @@ int vtkCommunicator::Receive(vtkMultiProcessStream& stream, int remoteId, int ta
   }
   return 1;
 }
+VTK_ABI_NAMESPACE_END
