@@ -29,7 +29,6 @@
 #include "vtkProcess.h"
 #include "vtkProcessGroup.h"
 #include "vtkSubCommunicator.h"
-#include "vtkToolkits.h"
 #include "vtkWeakPointer.h"
 
 #include <algorithm>
@@ -40,6 +39,7 @@
 //------------------------------------------------------------------------------
 // Stores internal members that cannot or should not be exposed in the header
 // file (for example, because they use templated types).
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController::vtkInternal
 {
 public:
@@ -294,10 +294,10 @@ vtkMultiProcessController* vtkMultiProcessController::PartitionController(
   int numProc = this->GetNumberOfProcesses();
 
   std::vector<int> allColors(numProc);
-  this->AllGather(&localColor, &allColors[0], 1);
+  this->AllGather(&localColor, allColors.data(), 1);
 
   std::vector<int> allKeys(numProc);
-  this->AllGather(&localKey, &allKeys[0], 1);
+  this->AllGather(&localKey, allKeys.data(), 1);
 
   std::vector<bool> inPartition;
   inPartition.assign(numProc, false);
@@ -932,3 +932,4 @@ void vtkMultiProcessController::SetGlobalController(vtkMultiProcessController* c
 {
   VTK_GLOBAL_MULTI_PROCESS_CONTROLLER = controller;
 }
+VTK_ABI_NAMESPACE_END
