@@ -26,6 +26,8 @@
 #include "vtkParallelDIYModule.h" // for export macros
 #include "vtkSmartPointer.h"      // needed for vtkSmartPointer
 
+#include <map>    // For Link
+#include <set>    // For Link
 #include <vector> // For GetDataSets
 
 // clang-format off
@@ -36,6 +38,7 @@
 #include VTK_DIY2(diy/types.hpp)
 // clang-format on
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataArray;
 class vtkBoundingBox;
 class vtkDataObject;
@@ -43,6 +46,7 @@ class vtkDataSet;
 class vtkFieldData;
 class vtkMultiProcessController;
 class vtkPoints;
+class vtkStringArray;
 
 class VTKPARALLELDIY_EXPORT vtkDIYUtilities : public vtkObject
 {
@@ -63,23 +67,37 @@ public:
    */
   static diy::mpi::communicator GetCommunicator(vtkMultiProcessController* controller);
 
-  //@{
+  ///@{
   /**
    * Load/Save a vtkDataSet in a diy::BinaryBuffer.
    */
   static void Save(diy::BinaryBuffer& bb, vtkDataSet*);
   static void Load(diy::BinaryBuffer& bb, vtkDataSet*&);
-  //@}
+  ///@}
 
+  ///@{
+  /**
+   * Load/Save a vtkFieldData in a diy::BinaryBuffer.
+   */
   static void Save(diy::BinaryBuffer& bb, vtkFieldData*);
   static void Load(diy::BinaryBuffer& bb, vtkFieldData*&);
-  //@{
+  ///@}
+
+  ///@{
+  /**
+   * Load/Save a vtkStringArray in a diy::BinaryBuffer.
+   */
+  static void Save(diy::BinaryBuffer& bb, vtkStringArray*);
+  static void Load(diy::BinaryBuffer& bb, vtkStringArray*&);
+  ///@}
+
+  ///@{
   /**
    * Load/Save a vtkDataArray in a diy::BinaryBuffer.
    */
   static void Save(diy::BinaryBuffer& bb, vtkDataArray*);
   static void Load(diy::BinaryBuffer& bb, vtkDataArray*&);
-  //@}
+  ///@}
 
   /**
    * Reduce bounding box.
@@ -109,16 +127,7 @@ public:
   static void Broadcast(
     diy::mpi::communicator& comm, std::vector<vtkBoundingBox>& boxes, int source);
 
-  /**
-   * Extract datasets from the given data object. This method returns a vector
-   * of DataSetT* from the `dobj`. If dobj is a DataSetT, the returned
-   * vector will have just 1 DataSetT. If dobj is a vtkCompositeDataSet, then
-   * we iterate over it and add all non-null leaf nodes to the returned vector.
-   */
-  template <class DataSetT = vtkDataSet>
-  static std::vector<DataSetT*> GetDataSets(vtkDataObject* dobj);
-
-  //@{
+  ///@{
   /**
    * Extracts points from the input. If input is not a vtkPointSet, it will use
    * an appropriate filter to extract the vtkPoints. If use_cell_centers is
@@ -127,7 +136,7 @@ public:
    */
   static std::vector<vtkSmartPointer<vtkPoints>> ExtractPoints(
     const std::vector<vtkDataSet*>& datasets, bool use_cell_centers);
-  //@}
+  ///@}
 
   /**
    * Convenience method to get local bounds for the data object.
@@ -137,18 +146,17 @@ public:
   /**
    * Links master such that there is communication between ranks as given
    * in `linksMap`.
-   *
-   * LinksMapT needs to have `Links& LinksMapT::operator[](int)` implemented, and each
-   * `Links` needs to have `Links::count(int)` implemented. A fitting class could
-   * be `std::vector<std::set<int>>`. Given an integer `localId` mapping to the
-   * the relative block position in the current rank, and given `globalId`
-   * the id of a block uniquely identified in all rank,
-   * block of local id `localId` in the current
-   * rank is to be linked to block of global id `globalId` if and
-   * only if `linksMap[localId].count(globalId) != 0`.
+   * `linksMap` is a vector of a list of global ids. The size of this vector should be the same as
+   * the number of blocks in the current rank and should map to the block of same local id.
+   * The associated list of global ids will tell which block is to be connected with the local
+   * block.
    */
-  template <class BlockT, class AssignerT, class LinksMapT>
-  static void Link(diy::Master& master, const AssignerT& assigner, const LinksMapT& linksMap);
+  template <class DummyT>
+  static void Link(diy::Master& master, const diy::Assigner& assigner,
+    const std::vector<std::map<int, DummyT>>& linksMap);
+
+  static void Link(
+    diy::Master& master, const diy::Assigner& assigner, const std::vector<std::set<int>>& linksMap);
 
 protected:
   vtkDIYUtilities();
@@ -158,6 +166,7 @@ private:
   vtkDIYUtilities(const vtkDIYUtilities&) = delete;
   void operator=(const vtkDIYUtilities&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 
 namespace diy
 {
@@ -183,6 +192,7 @@ struct Serialization<vtkFieldData*>
 };
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 // Implementation detail for Schwarz counter idiom.
 class VTKPARALLELDIY_EXPORT vtkDIYUtilitiesCleanup
 {
@@ -196,7 +206,7 @@ private:
 };
 static vtkDIYUtilitiesCleanup vtkDIYUtilitiesCleanupInstance;
 
-#include "vtkDIYUtilities.txx"
+VTK_ABI_NAMESPACE_END
+#include "vtkDIYUtilities.txx" // for template implementations
 
 #endif
-// VTK-HeaderTest-Exclude: vtkDIYUtilities.h
