@@ -23,12 +23,12 @@
 #include "vtkRectilinearGrid.h"
 #include "vtkSmartPointer.h"
 #include "vtkStructuredGrid.h"
-#include "vtkToolkits.h"
 #define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 static inline void vtkMPICommunicatorDebugBarrier(MPI_Comm* handle)
 {
   // If NDEBUG is defined, do nothing.
@@ -41,7 +41,7 @@ static inline void vtkMPICommunicatorDebugBarrier(MPI_Comm* handle)
 
 vtkStandardNewMacro(vtkMPICommunicator);
 
-vtkMPICommunicator* vtkMPICommunicator::WorldCommunicator = 0;
+vtkMPICommunicator* vtkMPICommunicator::WorldCommunicator = nullptr;
 
 vtkMPICommunicatorOpaqueComm::vtkMPICommunicatorOpaqueComm(MPI_Comm* handle)
 {
@@ -57,7 +57,7 @@ MPI_Comm* vtkMPICommunicatorOpaqueComm::GetHandle()
 // This MPI error handler basically does the same thing as the default error
 // handler, but also provides a convenient place to attach a debugger
 // breakpoint.
-extern "C" void vtkMPICommunicatorMPIErrorHandler(MPI_Comm* comm, int* errorcode, ...)
+static void vtkMPICommunicatorMPIErrorHandler(MPI_Comm* comm, int* errorcode, ...)
 {
   char ErrorMessage[MPI_MAX_ERROR_STRING];
   int len;
@@ -350,10 +350,10 @@ int vtkMPICommunicatorIprobe(int source, int tag, int* flag, int* actualSource,
 // with the __stdcall decoration.
 static vtkCommunicator::Operation* CurrentOperation;
 #ifdef MPIAPI
-extern "C" void MPIAPI vtkMPICommunicatorUserFunction(
+static void MPIAPI vtkMPICommunicatorUserFunction(
   void* invec, void* inoutvec, int* len, MPI_Datatype* datatype)
 #else
-extern "C" void vtkMPICommunicatorUserFunction(
+static void vtkMPICommunicatorUserFunction(
   void* invec, void* inoutvec, int* len, MPI_Datatype* datatype)
 #endif
 {
@@ -368,7 +368,7 @@ vtkMPICommunicator* vtkMPICommunicator::GetWorldCommunicator()
 {
   int err, size;
 
-  if (vtkMPICommunicator::WorldCommunicator == 0)
+  if (vtkMPICommunicator::WorldCommunicator == nullptr)
   {
     // Install an error handler
     MPI_Errhandler errhandler;
@@ -390,9 +390,9 @@ vtkMPICommunicator* vtkMPICommunicator::GetWorldCommunicator()
       vtkGenericWarningMacro("MPI error occurred: " << msg);
       delete[] msg;
       delete comm->MPIComm->Handle;
-      comm->MPIComm = 0;
+      comm->MPIComm = nullptr;
       comm->Delete();
-      return 0;
+      return nullptr;
     }
     comm->InitializeNumberOfProcesses();
     comm->Initialized = 1;
@@ -432,7 +432,6 @@ void vtkMPICommunicator::PrintSelf(ostream& os, vtkIndent indent)
     }
     os << endl;
   }
-  return;
 }
 
 //------------------------------------------------------------------------------
@@ -547,7 +546,7 @@ int vtkMPICommunicator::Initialize(vtkProcessGroup* group)
   {
     MPI_Group_free(&subGroup);
     delete this->MPIComm->Handle;
-    this->MPIComm->Handle = 0;
+    this->MPIComm->Handle = nullptr;
 
     char* msg = vtkMPIController::ErrorString(err);
     vtkErrorMacro("MPI error occurred: " << msg);
@@ -604,7 +603,7 @@ int vtkMPICommunicator::SplitInitialize(vtkCommunicator* oldcomm, int color, int
     MPI_SUCCESS)
   {
     delete this->MPIComm->Handle;
-    this->MPIComm->Handle = 0;
+    this->MPIComm->Handle = nullptr;
 
     char* msg = vtkMPIController::ErrorString(err);
     vtkErrorMacro("MPI error occurred: " << msg);
@@ -649,7 +648,7 @@ void vtkMPICommunicator::InitializeCopy(vtkMPICommunicator* source)
     MPI_Comm_free(this->MPIComm->Handle);
   }
   delete this->MPIComm->Handle;
-  this->MPIComm->Handle = 0;
+  this->MPIComm->Handle = nullptr;
 
   this->LocalProcessId = source->LocalProcessId;
   this->NumberOfProcesses = source->NumberOfProcesses;
@@ -1135,7 +1134,7 @@ int vtkMPICommunicator::GatherVVoidArray(const void* sendBuffer, void* recvBuffe
     }
     return CheckForMPIError(
       MPI_Gatherv(const_cast<void*>(sendBuffer), sendLength, mpiType, recvBuffer,
-        &mpiRecvLengths[0], &mpiOffsets[0], mpiType, destProcessId, *this->MPIComm->Handle));
+        mpiRecvLengths.data(), mpiOffsets.data(), mpiType, destProcessId, *this->MPIComm->Handle));
   }
   else
   {
@@ -1200,7 +1199,7 @@ int vtkMPICommunicator::ScatterVVoidArray(const void* sendBuffer, void* recvBuff
       mpiOffsets[i] = offsets[i];
     }
     return CheckForMPIError(
-      MPI_Scatterv(const_cast<void*>(sendBuffer), &mpiSendLengths[0], &mpiOffsets[0], mpiType,
+      MPI_Scatterv(const_cast<void*>(sendBuffer), mpiSendLengths.data(), mpiOffsets.data(), mpiType,
         recvBuffer, recvLength, mpiType, srcProcessId, *this->MPIComm->Handle));
   }
   else
@@ -1279,7 +1278,7 @@ int vtkMPICommunicator::AllGatherVVoidArray(const void* sendBuffer, void* recvBu
     mpiOffsets[i] = offsets[i];
   }
   return CheckForMPIError(MPI_Allgatherv(const_cast<void*>(sendBuffer), sendLength, mpiType,
-    recvBuffer, &mpiRecvLengths[0], &mpiOffsets[0], mpiType, *this->MPIComm->Handle));
+    recvBuffer, mpiRecvLengths.data(), mpiOffsets.data(), mpiType, *this->MPIComm->Handle));
 }
 
 //------------------------------------------------------------------------------
@@ -1539,7 +1538,7 @@ int vtkMPICommunicator::TestSome(
 int vtkMPICommunicator::Iprobe(int source, int tag, int* flag, int* actualSource)
 {
   return CheckForMPIError(vtkMPICommunicatorIprobe(
-    source, tag, flag, actualSource, MPI_INT, NULL, this->MPIComm->Handle));
+    source, tag, flag, actualSource, MPI_INT, nullptr, this->MPIComm->Handle));
 }
 
 //------------------------------------------------------------------------------
@@ -1581,3 +1580,4 @@ int vtkMPICommunicator::Iprobe(
   return CheckForMPIError(vtkMPICommunicatorIprobe(
     source, tag, flag, actualSource, MPI_DOUBLE, size, this->MPIComm->Handle));
 }
+VTK_ABI_NAMESPACE_END
