@@ -43,14 +43,15 @@
  * @sa
  * vtkAnnotatedCubeActor vtkOrientationMarkerWidget vtkCaptionActor2D
  * vtkTextProperty
-*/
+ */
 
 #ifndef vtkAxesActor_h
 #define vtkAxesActor_h
 
-#include "vtkRenderingAnnotationModule.h" // For export macro
 #include "vtkProp3D.h"
+#include "vtkRenderingAnnotationModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkCaptionActor2D;
 class vtkConeSource;
@@ -65,56 +66,56 @@ class vtkSphereSource;
 class VTKRENDERINGANNOTATION_EXPORT vtkAxesActor : public vtkProp3D
 {
 public:
-  static vtkAxesActor *New();
-  vtkTypeMacro(vtkAxesActor,vtkProp3D);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  static vtkAxesActor* New();
+  vtkTypeMacro(vtkAxesActor, vtkProp3D);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * For some exporters and other other operations we must be
    * able to collect all the actors or volumes. These methods
    * are used in that process.
    */
-  void GetActors(vtkPropCollection *) VTK_OVERRIDE;
+  void GetActors(vtkPropCollection*) override;
 
-  //@{
+  ///@{
   /**
    * Support the standard render methods.
    */
-  int RenderOpaqueGeometry(vtkViewport *viewport) VTK_OVERRIDE;
-  int RenderTranslucentPolygonalGeometry(vtkViewport *viewport) VTK_OVERRIDE;
-  int RenderOverlay(vtkViewport *viewport) VTK_OVERRIDE;
-  //@}
+  int RenderOpaqueGeometry(vtkViewport* viewport) override;
+  int RenderTranslucentPolygonalGeometry(vtkViewport* viewport) override;
+  int RenderOverlay(vtkViewport* viewport) override;
+  ///@}
 
   /**
    * Does this prop have some translucent polygonal geometry?
    */
-  int HasTranslucentPolygonalGeometry() VTK_OVERRIDE;
+  vtkTypeBool HasTranslucentPolygonalGeometry() override;
 
   /**
    * Shallow copy of an axes actor. Overloads the virtual vtkProp method.
    */
-  void ShallowCopy(vtkProp *prop) VTK_OVERRIDE;
+  void ShallowCopy(vtkProp* prop) override;
 
   /**
    * Release any graphics resources that are being consumed by this actor.
    * The parameter window could be used to determine which graphic
    * resources to release.
    */
-  void ReleaseGraphicsResources(vtkWindow *) VTK_OVERRIDE;
+  void ReleaseGraphicsResources(vtkWindow*) override;
 
-  //@{
+  ///@{
   /**
    * Get the bounds for this Actor as (Xmin,Xmax,Ymin,Ymax,Zmin,Zmax). (The
    * method GetBounds(double bounds[6]) is available from the superclass.)
    */
   void GetBounds(double bounds[6]);
-  double *GetBounds() VTK_OVERRIDE;
-  //@}
+  double* GetBounds() VTK_SIZEHINT(6) override;
+  ///@}
 
   /**
    * Get the actors mtime plus consider its properties and texture if set.
    */
-  vtkMTimeType GetMTime() VTK_OVERRIDE;
+  vtkMTimeType GetMTime() override;
 
   /**
    * Return the mtime of anything that would cause the rendered image to
@@ -122,51 +123,50 @@ public:
    * prop plus anything else it depends on such as properties, textures
    * etc.
    */
-  vtkMTimeType GetRedrawMTime() VTK_OVERRIDE;
+  vtkMTimeType GetRedrawMTime() override;
 
-  //@{
+  ///@{
   /**
    * Set the total length of the axes in 3 dimensions.
    */
-  void SetTotalLength( double v[3] )
-    { this->SetTotalLength( v[0], v[1], v[2] ); }
-  void SetTotalLength( double x, double y, double z );
-  vtkGetVectorMacro( TotalLength, double, 3 );
-  //@}
+  void SetTotalLength(double v[3]) { this->SetTotalLength(v[0], v[1], v[2]); }
+  void SetTotalLength(double x, double y, double z);
+  vtkGetVectorMacro(TotalLength, double, 3);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the normalized (0-1) length of the shaft.
    */
-  void SetNormalizedShaftLength( double v[3] )
-    { this->SetNormalizedShaftLength( v[0], v[1], v[2] ); }
-  void SetNormalizedShaftLength( double x, double y, double z );
-  vtkGetVectorMacro( NormalizedShaftLength, double, 3 );
-  //@}
+  void SetNormalizedShaftLength(double v[3]) { this->SetNormalizedShaftLength(v[0], v[1], v[2]); }
+  void SetNormalizedShaftLength(double x, double y, double z);
+  vtkGetVectorMacro(NormalizedShaftLength, double, 3);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the normalized (0-1) length of the tip.  Normally, this would be
    * 1 - the normalized length of the shaft.
    */
-  void SetNormalizedTipLength( double v[3] )
-    { this->SetNormalizedTipLength( v[0], v[1], v[2] ); }
-  void SetNormalizedTipLength( double x, double y, double z );
-  vtkGetVectorMacro( NormalizedTipLength, double, 3 );
-  //@}
+  void SetNormalizedTipLength(double v[3]) { this->SetNormalizedTipLength(v[0], v[1], v[2]); }
+  void SetNormalizedTipLength(double x, double y, double z);
+  vtkGetVectorMacro(NormalizedTipLength, double, 3);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the normalized (0-1) position of the label along the length of
    * the shaft.  A value > 1 is permissible.
    */
-  void SetNormalizedLabelPosition( double v[3] )
-    { this->SetNormalizedLabelPosition( v[0], v[1], v[2] ); }
-  void SetNormalizedLabelPosition( double x, double y, double z );
-  vtkGetVectorMacro( NormalizedLabelPosition, double, 3 );
-  //@}
+  void SetNormalizedLabelPosition(double v[3])
+  {
+    this->SetNormalizedLabelPosition(v[0], v[1], v[2]);
+  }
+  void SetNormalizedLabelPosition(double x, double y, double z);
+  vtkGetVectorMacro(NormalizedLabelPosition, double, 3);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the resolution of the pieces of the axes actor.
    */
@@ -176,9 +176,9 @@ public:
   vtkGetMacro(SphereResolution, int);
   vtkSetClampMacro(CylinderResolution, int, 3, 128);
   vtkGetMacro(CylinderResolution, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the radius of the pieces of the axes actor.
    */
@@ -188,101 +188,92 @@ public:
   vtkGetMacro(SphereRadius, double);
   vtkSetClampMacro(CylinderRadius, double, 0, VTK_FLOAT_MAX);
   vtkGetMacro(CylinderRadius, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the type of the shaft to a cylinder, line, or user defined geometry.
    */
-  void SetShaftType( int type );
-  void SetShaftTypeToCylinder()
-    { this->SetShaftType( vtkAxesActor::CYLINDER_SHAFT ); }
-  void SetShaftTypeToLine()
-    { this->SetShaftType( vtkAxesActor::LINE_SHAFT ); }
-  void SetShaftTypeToUserDefined()
-    { this->SetShaftType( vtkAxesActor::USER_DEFINED_SHAFT ); }
+  void SetShaftType(int type);
+  void SetShaftTypeToCylinder() { this->SetShaftType(vtkAxesActor::CYLINDER_SHAFT); }
+  void SetShaftTypeToLine() { this->SetShaftType(vtkAxesActor::LINE_SHAFT); }
+  void SetShaftTypeToUserDefined() { this->SetShaftType(vtkAxesActor::USER_DEFINED_SHAFT); }
   vtkGetMacro(ShaftType, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the type of the tip to a cone, sphere, or user defined geometry.
    */
-  void SetTipType( int type );
-  void SetTipTypeToCone()
-    { this->SetTipType( vtkAxesActor::CONE_TIP ); }
-  void SetTipTypeToSphere()
-    { this->SetTipType( vtkAxesActor::SPHERE_TIP ); }
-  void SetTipTypeToUserDefined()
-    { this->SetTipType( vtkAxesActor::USER_DEFINED_TIP ); }
+  void SetTipType(int type);
+  void SetTipTypeToCone() { this->SetTipType(vtkAxesActor::CONE_TIP); }
+  void SetTipTypeToSphere() { this->SetTipType(vtkAxesActor::SPHERE_TIP); }
+  void SetTipTypeToUserDefined() { this->SetTipType(vtkAxesActor::USER_DEFINED_TIP); }
   vtkGetMacro(TipType, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the user defined tip polydata.
    */
-  void SetUserDefinedTip( vtkPolyData * );
-  vtkGetObjectMacro( UserDefinedTip, vtkPolyData );
-  //@}
+  void SetUserDefinedTip(vtkPolyData*);
+  vtkGetObjectMacro(UserDefinedTip, vtkPolyData);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the user defined shaft polydata.
    */
-  void SetUserDefinedShaft( vtkPolyData * );
-  vtkGetObjectMacro( UserDefinedShaft, vtkPolyData );
-  //@}
+  void SetUserDefinedShaft(vtkPolyData*);
+  vtkGetObjectMacro(UserDefinedShaft, vtkPolyData);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the tip properties.
    */
-  vtkProperty *GetXAxisTipProperty();
-  vtkProperty *GetYAxisTipProperty();
-  vtkProperty *GetZAxisTipProperty();
-  //@}
+  vtkProperty* GetXAxisTipProperty();
+  vtkProperty* GetYAxisTipProperty();
+  vtkProperty* GetZAxisTipProperty();
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the shaft properties.
    */
-  vtkProperty *GetXAxisShaftProperty();
-  vtkProperty *GetYAxisShaftProperty();
-  vtkProperty *GetZAxisShaftProperty();
-  //@}
+  vtkProperty* GetXAxisShaftProperty();
+  vtkProperty* GetYAxisShaftProperty();
+  vtkProperty* GetZAxisShaftProperty();
+  ///@}
 
   /**
    * Retrieve handles to the X, Y and Z axis (so that you can set their text
    * properties for example)
    */
-  vtkCaptionActor2D *GetXAxisCaptionActor2D()
-    {return this->XAxisLabel;}
-  vtkCaptionActor2D *GetYAxisCaptionActor2D()
-    {return this->YAxisLabel;}
-  vtkCaptionActor2D *GetZAxisCaptionActor2D()
-    {return this->ZAxisLabel;}
+  vtkCaptionActor2D* GetXAxisCaptionActor2D() { return this->XAxisLabel; }
+  vtkCaptionActor2D* GetYAxisCaptionActor2D() { return this->YAxisLabel; }
+  vtkCaptionActor2D* GetZAxisCaptionActor2D() { return this->ZAxisLabel; }
 
-  //@{
+  ///@{
   /**
    * Set/get the label text.
    */
-  vtkSetStringMacro( XAxisLabelText );
-  vtkGetStringMacro( XAxisLabelText );
-  vtkSetStringMacro( YAxisLabelText );
-  vtkGetStringMacro( YAxisLabelText );
-  vtkSetStringMacro( ZAxisLabelText );
-  vtkGetStringMacro( ZAxisLabelText );
-  //@}
+  vtkSetStringMacro(XAxisLabelText);
+  vtkGetStringMacro(XAxisLabelText);
+  vtkSetStringMacro(YAxisLabelText);
+  vtkGetStringMacro(YAxisLabelText);
+  vtkSetStringMacro(ZAxisLabelText);
+  vtkGetStringMacro(ZAxisLabelText);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable drawing the axis labels.
    */
-  vtkSetMacro(AxisLabels, int);
-  vtkGetMacro(AxisLabels, int);
-  vtkBooleanMacro(AxisLabels, int);
-  //@}
+  vtkSetMacro(AxisLabels, vtkTypeBool);
+  vtkGetMacro(AxisLabels, vtkTypeBool);
+  vtkBooleanMacro(AxisLabels, vtkTypeBool);
+  ///@}
 
   enum
   {
@@ -300,57 +291,56 @@ public:
 
 protected:
   vtkAxesActor();
-  ~vtkAxesActor() VTK_OVERRIDE;
+  ~vtkAxesActor() override;
 
-  vtkCylinderSource *CylinderSource;
-  vtkLineSource     *LineSource;
-  vtkConeSource     *ConeSource;
-  vtkSphereSource   *SphereSource;
+  vtkCylinderSource* CylinderSource;
+  vtkLineSource* LineSource;
+  vtkConeSource* ConeSource;
+  vtkSphereSource* SphereSource;
 
-  vtkActor          *XAxisShaft;
-  vtkActor          *YAxisShaft;
-  vtkActor          *ZAxisShaft;
+  vtkActor* XAxisShaft;
+  vtkActor* YAxisShaft;
+  vtkActor* ZAxisShaft;
 
-  vtkActor          *XAxisTip;
-  vtkActor          *YAxisTip;
-  vtkActor          *ZAxisTip;
+  vtkActor* XAxisTip;
+  vtkActor* YAxisTip;
+  vtkActor* ZAxisTip;
 
-  void               UpdateProps();
+  void UpdateProps();
 
-  double             TotalLength[3];
-  double             NormalizedShaftLength[3];
-  double             NormalizedTipLength[3];
-  double             NormalizedLabelPosition[3];
+  double TotalLength[3];
+  double NormalizedShaftLength[3];
+  double NormalizedTipLength[3];
+  double NormalizedLabelPosition[3];
 
-  int                ShaftType;
-  int                TipType;
+  int ShaftType;
+  int TipType;
 
-  vtkPolyData       *UserDefinedTip;
-  vtkPolyData       *UserDefinedShaft;
+  vtkPolyData* UserDefinedTip;
+  vtkPolyData* UserDefinedShaft;
 
-  char              *XAxisLabelText;
-  char              *YAxisLabelText;
-  char              *ZAxisLabelText;
+  char* XAxisLabelText;
+  char* YAxisLabelText;
+  char* ZAxisLabelText;
 
-  vtkCaptionActor2D *XAxisLabel;
-  vtkCaptionActor2D *YAxisLabel;
-  vtkCaptionActor2D *ZAxisLabel;
+  vtkCaptionActor2D* XAxisLabel;
+  vtkCaptionActor2D* YAxisLabel;
+  vtkCaptionActor2D* ZAxisLabel;
 
-  int                AxisLabels;
+  vtkTypeBool AxisLabels;
 
+  int ConeResolution;
+  int SphereResolution;
+  int CylinderResolution;
 
-  int                ConeResolution;
-  int                SphereResolution;
-  int                CylinderResolution;
-
-  double             ConeRadius;
-  double             SphereRadius;
-  double             CylinderRadius;
+  double ConeRadius;
+  double SphereRadius;
+  double CylinderRadius;
 
 private:
-  vtkAxesActor(const vtkAxesActor&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkAxesActor&) VTK_DELETE_FUNCTION;
+  vtkAxesActor(const vtkAxesActor&) = delete;
+  void operator=(const vtkAxesActor&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
