@@ -35,6 +35,7 @@
 
 #define VTK_EXPONENT_AXES_ACTOR_RTOL (1. - 10. * VTK_DBL_EPSILON)
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolarAxesActor);
 vtkCxxSetObjectMacro(vtkPolarAxesActor, Camera, vtkCamera);
 vtkCxxSetObjectMacro(vtkPolarAxesActor, PolarAxisLabelTextProperty, vtkTextProperty);
@@ -214,7 +215,6 @@ void vtkPolarAxesActor::PrintSelf(ostream& os, vtkIndent indent)
 
 //------------------------------------------------------------------------------
 vtkPolarAxesActor::vtkPolarAxesActor()
-  : vtkActor()
 {
   // Default bounds
   this->Bounds[0] = -1.0;
@@ -994,7 +994,7 @@ void vtkPolarAxesActor::BuildAxes(vtkViewport* viewport)
   vtkAxisActor* axis = this->PolarAxis;
 
   // compute ellipse angle
-  double miniAngleEllipse = this->ComputeEllipseAngle(this->MinimumAngle, this->Ratio);
+  double miniAngleEllipse = vtkPolarAxesActor::ComputeEllipseAngle(this->MinimumAngle, this->Ratio);
 
   // Set the start point and end point (world coord system) of the Polar Axis.
   double startPt[3], endPt[3];
@@ -1367,7 +1367,7 @@ void vtkPolarAxesActor::BuildRadialAxes()
     }
 
     // Calculate startpoint coordinates
-    double thetaEllipse = this->ComputeEllipseAngle(currentAlpha, this->Ratio);
+    double thetaEllipse = vtkPolarAxesActor::ComputeEllipseAngle(currentAlpha, this->Ratio);
     double xStart = this->Pole[0] + this->MinimumRadius * cos(thetaEllipse);
     double yStart = this->Pole[1] + this->MinimumRadius * this->Ratio * sin(thetaEllipse);
 
@@ -2568,3 +2568,4 @@ double vtkPolarAxesActor::ComputeEllipseAngle(double angleInDegrees, double rati
   }
   return miniAngleEllipse;
 }
+VTK_ABI_NAMESPACE_END
