@@ -16,25 +16,25 @@
 #include "vtkAbstractContextBufferId.h"
 #include "vtkObjectFactory.h"
 
-vtkAbstractObjectFactoryNewMacro(vtkAbstractContextBufferId)
+VTK_ABI_NAMESPACE_BEGIN
+vtkAbstractObjectFactoryNewMacro(vtkAbstractContextBufferId);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractContextBufferId::vtkAbstractContextBufferId()
 {
-  this->Width=0;
-  this->Height=0;
+  this->Width = 0;
+  this->Height = 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractContextBufferId::~vtkAbstractContextBufferId() = default;
 
-// ----------------------------------------------------------------------------
-void vtkAbstractContextBufferId::ReleaseGraphicsResources()
-{
-}
+//------------------------------------------------------------------------------
+void vtkAbstractContextBufferId::ReleaseGraphicsResources() {}
 
-//-----------------------------------------------------------------------------
-void vtkAbstractContextBufferId::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkAbstractContextBufferId::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
