@@ -32,6 +32,7 @@
 #include <cassert>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkContext2D);
 
 //------------------------------------------------------------------------------
@@ -579,13 +580,6 @@ void vtkContext2D::DrawStringRect(vtkPoints2D* rect, const vtkStdString& string)
   this->DrawString(p.GetX(), p.GetY(), string);
 }
 
-//------------------------------------------------------------------------------
-void vtkContext2D::DrawStringRect(vtkPoints2D* rect, const vtkUnicodeString& string)
-{
-  vtkVector2f p = this->CalculateTextPosition(rect);
-  this->DrawString(p.GetX(), p.GetY(), string);
-}
-
 //------------------------------------------------------------------------------
 void vtkContext2D::DrawStringRect(vtkPoints2D* rect, const char* string)
 {
@@ -599,13 +593,6 @@ void vtkContext2D::DrawStringRect(const float rect[4], const vtkStdString& strin
   this->DrawString(p.GetX(), p.GetY(), string);
 }
 
-//------------------------------------------------------------------------------
-void vtkContext2D::DrawStringRect(const float rect[4], const vtkUnicodeString& string)
-{
-  vtkVector2f p = this->CalculateTextPosition(rect);
-  this->DrawString(p.GetX(), p.GetY(), string);
-}
-
 //------------------------------------------------------------------------------
 void vtkContext2D::DrawStringRect(const float rect[4], const char* string)
 {
@@ -635,29 +622,6 @@ void vtkContext2D::DrawString(float x, float y, const vtkStdString& string)
   this->Device->DrawString(f, string);
 }
 
-//------------------------------------------------------------------------------
-void vtkContext2D::DrawString(vtkPoints2D* point, const vtkUnicodeString& string)
-{
-  float* f = vtkArrayDownCast<vtkFloatArray>(point->GetData())->GetPointer(0);
-  this->DrawString(f[0], f[1], string);
-}
-
-//------------------------------------------------------------------------------
-void vtkContext2D::DrawString(float x, float y, const vtkUnicodeString& string)
-{
-  if (!this->Device)
-  {
-    vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
-    return;
-  }
-  if (string.empty())
-  {
-    return;
-  }
-  float f[] = { x, y };
-  this->Device->DrawString(&f[0], string);
-}
-
 //------------------------------------------------------------------------------
 void vtkContext2D::DrawString(vtkPoints2D* point, const char* string)
 {
@@ -690,25 +654,6 @@ void vtkContext2D::ComputeStringBounds(const vtkStdString& string, float bounds[
   this->Device->ComputeStringBounds(string, bounds);
 }
 
-//------------------------------------------------------------------------------
-void vtkContext2D::ComputeStringBounds(const vtkUnicodeString& string, vtkPoints2D* bounds)
-{
-  bounds->SetNumberOfPoints(2);
-  float* f = vtkArrayDownCast<vtkFloatArray>(bounds->GetData())->GetPointer(0);
-  this->ComputeStringBounds(string, f);
-}
-
-//------------------------------------------------------------------------------
-void vtkContext2D::ComputeStringBounds(const vtkUnicodeString& string, float bounds[4])
-{
-  if (!this->Device)
-  {
-    vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
-    return;
-  }
-  this->Device->ComputeStringBounds(string, bounds);
-}
-
 //------------------------------------------------------------------------------
 void vtkContext2D::ComputeStringBounds(const char* string, vtkPoints2D* bounds)
 {
@@ -1100,3 +1045,4 @@ void vtkContext2D::PrintSelf(ostream& os, vtkIndent indent)
     os << "(none)" << endl;
   }
 }
+VTK_ABI_NAMESPACE_END
