@@ -14,18 +14,21 @@
 =========================================================================*/
 
 #include "vtkContextItem.h"
+#include "vtkContextTransform.h"
+
+VTK_ABI_NAMESPACE_BEGIN
+vtkCxxSetObjectMacro(vtkContextItem, Transform, vtkContextTransform);
 
 //------------------------------------------------------------------------------
-vtkContextItem::vtkContextItem()
+vtkContextItem::~vtkContextItem()
 {
-  this->Opacity = 1.0;
+  this->SetTransform(nullptr);
 }
 
-//------------------------------------------------------------------------------
-vtkContextItem::~vtkContextItem() = default;
-
 //------------------------------------------------------------------------------
 void vtkContextItem::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
+  os << indent << "Opacity: " << this->Opacity << endl;
 }
+VTK_ABI_NAMESPACE_END
