@@ -15,30 +15,31 @@
 
 #include "vtkContextScene.h"
 
-#include "vtkContextItem.h"
 #include "vtkContext2D.h"
-#include "vtkTransform2D.h"
-#include "vtkMatrix3x3.h"
-#include "vtkContextScenePrivate.h"
-#include "vtkContextMouseEvent.h"
+#include "vtkContextItem.h"
 #include "vtkContextKeyEvent.h"
+#include "vtkContextMouseEvent.h"
+#include "vtkContextScenePrivate.h"
+#include "vtkMatrix3x3.h"
 #include "vtkNew.h"
+#include "vtkTransform2D.h"
 
 // Get my new commands
 #include "vtkCommand.h"
 
-#include "vtkAnnotationLink.h"
-#include "vtkRenderWindowInteractor.h"
-#include "vtkRenderWindow.h"
-#include "vtkRenderer.h"
-#include "vtkObjectFactory.h"
 #include "vtkAbstractContextBufferId.h"
+#include "vtkAnnotationLink.h"
+#include "vtkObjectFactory.h"
+#include "vtkRenderWindow.h"
+#include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 
 // My STL containers
 #include <cassert>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Minimal storage class for STL containers etc.
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContextScene::Private
 {
 public:
@@ -58,21 +59,21 @@ public:
   bool IsDirty;
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkContextScene);
 vtkCxxSetObjectMacro(vtkContextScene, AnnotationLink, vtkAnnotationLink);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkContextScene::vtkContextScene()
 {
   this->Storage = new Private;
   this->AnnotationLink = nullptr;
   this->Geometry[0] = 0;
   this->Geometry[1] = 0;
-  this->BufferId=nullptr;
-  this->BufferIdDirty=true;
-  this->BufferIdSupportTested=false;
-  this->BufferIdSupported=false;
+  this->BufferId = nullptr;
+  this->BufferIdDirty = true;
+  this->BufferIdSupportTested = false;
+  this->BufferIdSupported = false;
   this->UseBufferId = true;
   this->ScaleTiles = true;
   this->Transform = nullptr;
@@ -80,13 +81,13 @@ vtkContextScene::vtkContextScene()
   this->Children->SetScene(this);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkContextScene::~vtkContextScene()
 {
   delete this->Storage;
   this->Storage = nullptr;
   this->SetAnnotationLink(nullptr);
-  if(this->BufferId!=nullptr)
+  if (this->BufferId != nullptr)
   {
     this->BufferId->Delete();
   }
@@ -97,21 +98,21 @@ vtkContextScene::~vtkContextScene()
   delete this->Children;
 }
 
-//-----------------------------------------------------------------------------
-void vtkContextScene::SetRenderer(vtkRenderer *r)
+//------------------------------------------------------------------------------
+void vtkContextScene::SetRenderer(vtkRenderer* r)
 {
-  this->Renderer=r;
-  this->BufferIdSupportTested=false;
+  this->Renderer = r;
+  this->BufferIdSupportTested = false;
 }
 
-//-----------------------------------------------------------------------------
-vtkRenderer *vtkContextScene::GetRenderer()
+//------------------------------------------------------------------------------
+vtkRenderer* vtkContextScene::GetRenderer()
 {
   return this->Renderer;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::Paint(vtkContext2D *painter)
+//------------------------------------------------------------------------------
+bool vtkContextScene::Paint(vtkContext2D* painter)
 {
   vtkDebugMacro("Paint event called.");
   size_t size = this->Children->size();
@@ -125,54 +126,55 @@ bool vtkContextScene::Paint(vtkContext2D *painter)
   {
     painter->PopMatrix();
   }
-  if(this->Storage->IsDirty)
+  if (this->Storage->IsDirty)
   {
-    this->BufferIdDirty=true;
+    this->BufferIdDirty = true;
   }
   this->Storage->IsDirty = false;
-  this->LastPainter=painter;
+  this->LastPainter = painter;
   return true;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::PaintIds()
 {
   vtkDebugMacro("PaintId called.");
   size_t size = this->Children->size();
 
-  if(size>16777214) // 24-bit limit, 0 reserved for background encoding.
+  if (size > 16777214) // 24-bit limit, 0 reserved for background encoding.
   {
-    vtkWarningMacro(<<"picking will not work properly as there are two many items. Items over 16777214 will be ignored.");
-    size=16777214;
+    vtkWarningMacro(<< "picking will not work properly as there are two many items. Items over "
+                       "16777214 will be ignored.");
+    size = 16777214;
   }
   for (size_t i = 0; i < size; ++i)
   {
-    this->LastPainter->ApplyId(static_cast<vtkIdType>(i+1));
+    this->LastPainter->ApplyId(static_cast<vtkIdType>(i + 1));
     (*this->Children)[i]->Paint(this->LastPainter);
   }
   this->Storage->IsDirty = false;
 }
 
-//-----------------------------------------------------------------------------
-unsigned int vtkContextScene::AddItem(vtkAbstractContextItem *item)
+//------------------------------------------------------------------------------
+unsigned int vtkContextScene::AddItem(vtkAbstractContextItem* item)
 {
   return this->Children->AddItem(item);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::RemoveItem(vtkAbstractContextItem* item)
 {
   return this->Children->RemoveItem(item);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::RemoveItem(unsigned int index)
 {
   return this->Children->RemoveItem(index);
 }
 
-//-----------------------------------------------------------------------------
-vtkAbstractContextItem * vtkContextScene::GetItem(unsigned int index)
+//------------------------------------------------------------------------------
+vtkAbstractContextItem* vtkContextScene::GetItem(unsigned int index)
 {
   if (index < this->Children->size())
   {
@@ -184,20 +186,19 @@ vtkAbstractContextItem * vtkContextScene::GetItem(unsigned int index)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkContextScene::GetNumberOfItems()
 {
   return static_cast<unsigned int>(this->Children->size());
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::ClearItems()
 {
   this->Children->Clear();
 }
 
-
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetViewWidth()
 {
   if (this->Renderer)
@@ -210,7 +211,7 @@ int vtkContextScene::GetViewWidth()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetViewHeight()
 {
   if (this->Renderer)
@@ -223,19 +224,19 @@ int vtkContextScene::GetViewHeight()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetSceneWidth()
 {
   return this->Geometry[0];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetSceneHeight()
 {
   return this->Geometry[1];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVector2i vtkContextScene::GetLogicalTileScale()
 {
   vtkVector2i result(1);
@@ -246,7 +247,7 @@ vtkVector2i vtkContextScene::GetLogicalTileScale()
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::SetDirty(bool isDirty)
 {
   if (this->Storage->IsDirty == isDirty)
@@ -254,47 +255,46 @@ void vtkContextScene::SetDirty(bool isDirty)
     return;
   }
   this->Storage->IsDirty = isDirty;
-  if(this->Storage->IsDirty)
+  if (this->Storage->IsDirty)
   {
-    this->BufferIdDirty=true;
+    this->BufferIdDirty = true;
   }
   this->Modified();
 }
 
-
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::GetDirty() const
 {
   return this->Storage->IsDirty;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::ReleaseGraphicsResources()
 {
-  if(this->BufferId!=nullptr)
+  if (this->BufferId != nullptr)
   {
     this->BufferId->ReleaseGraphicsResources();
   }
-  for(vtkContextScenePrivate::const_iterator it = this->Children->begin();
-    it != this->Children->end(); ++it)
+  for (vtkContextScenePrivate::const_iterator it = this->Children->begin();
+       it != this->Children->end(); ++it)
   {
     (*it)->ReleaseGraphicsResources();
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkWeakPointer<vtkContext2D> vtkContextScene::GetLastPainter()
 {
   return this->LastPainter;
 }
 
-//-----------------------------------------------------------------------------
-vtkAbstractContextBufferId *vtkContextScene::GetBufferId()
+//------------------------------------------------------------------------------
+vtkAbstractContextBufferId* vtkContextScene::GetBufferId()
 {
   return this->BufferId;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::SetTransform(vtkTransform2D* transform)
 {
   if (this->Transform == transform)
@@ -306,7 +306,7 @@ void vtkContextScene::SetTransform(vtkTransform2D* transform)
   this->Transform->Register(this);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTransform2D* vtkContextScene::GetTransform()
 {
   if (this->Transform)
@@ -320,7 +320,7 @@ vtkTransform2D* vtkContextScene::GetTransform()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::ProcessSelectionEvent(unsigned int rect[5])
 {
   cout << "ProcessSelectionEvent called! " << endl;
@@ -333,7 +333,7 @@ bool vtkContextScene::ProcessSelectionEvent(unsigned int rect[5])
   return false;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::TestBufferIdSupport()
 {
   if (!this->BufferIdSupportTested)
@@ -346,18 +346,16 @@ void vtkContextScene::TestBufferIdSupport()
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::UpdateBufferId()
 {
   int lowerLeft[2];
   int width;
   int height;
-  this->Renderer->GetTiledSizeAndOrigin(&width,&height,lowerLeft,
-                                        lowerLeft+1);
+  this->Renderer->GetTiledSizeAndOrigin(&width, &height, lowerLeft, lowerLeft + 1);
 
-  if (this->BufferId==nullptr || this->BufferIdDirty ||
-      width!=this->BufferId->GetWidth() ||
-      height!=this->BufferId->GetHeight())
+  if (this->BufferId == nullptr || this->BufferIdDirty || width != this->BufferId->GetWidth() ||
+    height != this->BufferId->GetHeight())
   {
     if (this->BufferId == nullptr)
     {
@@ -376,12 +374,12 @@ void vtkContextScene::UpdateBufferId()
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractContextItem* vtkContextScene::GetPickedItem()
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
-  for(vtkContextScenePrivate::const_reverse_iterator it =
-      this->Children->rbegin(); it != this->Children->rend(); ++it)
+  vtkContextMouseEvent& event = this->Storage->Event;
+  for (vtkContextScenePrivate::const_reverse_iterator it = this->Children->rbegin();
+       it != this->Children->rend(); ++it)
   {
     vtkAbstractContextItem* item = (*it)->GetPickedItem(event);
     if (item)
@@ -392,7 +390,7 @@ vtkAbstractContextItem* vtkContextScene::GetPickedItem()
   return nullptr;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkContextScene::GetPickedItem(int x, int y)
 {
   vtkIdType result = -1;
@@ -400,14 +398,14 @@ vtkIdType vtkContextScene::GetPickedItem(int x, int y)
   if (this->UseBufferId && this->BufferIdSupported)
   {
     this->UpdateBufferId();
-    result=this->BufferId->GetPickedItem(x,y);
+    result = this->BufferId->GetPickedItem(x, y);
   }
   else
   {
-    size_t i = this->Children->size()-1;
-    vtkContextMouseEvent &event = this->Storage->Event;
-    for(vtkContextScenePrivate::const_reverse_iterator it =
-        this->Children->rbegin(); it != this->Children->rend(); ++it, --i)
+    size_t i = this->Children->size() - 1;
+    vtkContextMouseEvent& event = this->Storage->Event;
+    for (vtkContextScenePrivate::const_reverse_iterator it = this->Children->rbegin();
+         it != this->Children->rend(); ++it, --i)
     {
       if ((*it)->Hit(event))
       {
@@ -426,21 +424,21 @@ vtkIdType vtkContextScene::GetPickedItem(int x, int y)
   // As a workaround, any value out of the scope of
   // [-1,this->GetNumberOfItems()-1] is set to -1 (<=> no hit)
 
-  if(result<-1 || result>=static_cast<vtkIdType>(this->GetNumberOfItems()))
+  if (result < -1 || result >= static_cast<vtkIdType>(this->GetNumberOfItems()))
   {
-    result=-1;
+    result = -1;
   }
 
-  assert("post: valid_result" && result>=-1 &&
-         result<static_cast<vtkIdType>(this->GetNumberOfItems()));
+  assert("post: valid_result" && result >= -1 &&
+    result < static_cast<vtkIdType>(this->GetNumberOfItems()));
   return result;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent& e)
 {
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
 
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
@@ -478,7 +476,7 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
 
   // Check if there is a selected item that needs to receive a move event
   if (this->Storage->itemMousePressCurrent &&
-      this->Storage->itemMousePressCurrent->GetScene() == this)
+    this->Storage->itemMousePressCurrent->GetScene() == this)
   {
     vtkAbstractContextItem* cur = this->Storage->itemMousePressCurrent;
     res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseMoveEvent) || res;
@@ -496,8 +494,8 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent& e)
 {
   switch (e.GetButton())
   {
@@ -515,7 +513,7 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
   }
 
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
   event.SetLastScreenPos(event.GetScreenPos());
   event.SetLastScenePos(event.GetScenePos());
@@ -526,15 +524,14 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
   if (newItemPicked)
   {
     vtkAbstractContextItem* cur = newItemPicked;
-    res = this->ProcessItem(cur, event,
-                            &vtkAbstractContextItem::MouseButtonPressEvent);
+    res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseButtonPressEvent);
   }
   this->Storage->itemMousePressCurrent = newItemPicked;
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent& e)
 {
   switch (e.GetButton())
   {
@@ -554,23 +551,22 @@ bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
   bool res = false;
   if (this->Storage->itemMousePressCurrent)
   {
-    vtkContextMouseEvent &event = this->Storage->Event;
+    vtkContextMouseEvent& event = this->Storage->Event;
     this->EventCopy(e);
     event.SetButton(e.GetButton());
     vtkAbstractContextItem* cur = this->Storage->itemMousePressCurrent;
-    res = this->ProcessItem(cur, event,
-                            &vtkAbstractContextItem::MouseButtonReleaseEvent);
+    res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseButtonReleaseEvent);
     this->Storage->itemMousePressCurrent = nullptr;
   }
   this->Storage->Event.SetButton(vtkContextMouseEvent::NO_BUTTON);
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent& e)
 {
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
   event.SetLastScreenPos(event.GetScreenPos());
   event.SetLastScenePos(event.GetScenePos());
@@ -581,17 +577,16 @@ bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent &e)
   if (newItemPicked)
   {
     vtkAbstractContextItem* cur = newItemPicked;
-    res = this->ProcessItem(cur, event,
-                            &vtkAbstractContextItem::MouseDoubleClickEvent);
+    res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseDoubleClickEvent);
   }
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::MouseWheelEvent(int delta,const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::MouseWheelEvent(int delta, const vtkContextMouseEvent& e)
 {
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
   event.SetLastScreenPos(event.GetScreenPos());
   event.SetLastScenePos(event.GetScenePos());
@@ -619,10 +614,10 @@ bool vtkContextScene::MouseWheelEvent(int delta,const vtkContextMouseEvent &e)
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent &keyEvent)
+//------------------------------------------------------------------------------
+bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent& keyEvent)
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   event.SetScreenPos(keyEvent.GetPosition());
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
@@ -632,10 +627,10 @@ bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent &keyEvent)
   return false;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent &keyEvent)
+//------------------------------------------------------------------------------
+bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent& keyEvent)
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   event.SetScreenPos(keyEvent.GetPosition());
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
@@ -645,10 +640,9 @@ bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent &keyEvent)
   return false;
 }
 
-//-----------------------------------------------------------------------------
-inline bool vtkContextScene::ProcessItem(vtkAbstractContextItem* cur,
-                                         const vtkContextMouseEvent& event,
-                                         MouseEvents eventPtr)
+//------------------------------------------------------------------------------
+inline bool vtkContextScene::ProcessItem(
+  vtkAbstractContextItem* cur, const vtkContextMouseEvent& event, MouseEvents eventPtr)
 {
   bool res = false;
   vtkContextMouseEvent itemEvent = event;
@@ -667,21 +661,21 @@ inline bool vtkContextScene::ProcessItem(vtkAbstractContextItem* cur,
   return res;
 }
 
-//-----------------------------------------------------------------------------
-inline void vtkContextScene::EventCopy(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+inline void vtkContextScene::EventCopy(const vtkContextMouseEvent& e)
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   event.SetPos(e.GetPos());
   event.SetScreenPos(vtkVector2i(e.GetPos().Cast<int>().GetData()));
   event.SetScenePos(e.GetPos());
   event.SetInteractor(e.GetInteractor());
 }
 
-//-----------------------------------------------------------------------------
-void vtkContextScene::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkContextScene::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   // Print out the chart's geometry if it has been set
-  os << indent << "Widthxheight: " << this->Geometry[0] << "\t" << this->Geometry[1]
-     << endl;
+  os << indent << "Widthxheight: " << this->Geometry[0] << "\t" << this->Geometry[1] << endl;
 }
+VTK_ABI_NAMESPACE_END
