@@ -34,6 +34,7 @@
 // STL headers
 #include <vector> // Needed for STL vector.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContext2D;
 
 //-----------------------------------------------------------------------------
@@ -55,7 +56,7 @@ public:
    */
   ~vtkContextScenePrivate() { this->Clear(); }
 
-  //@{
+  ///@{
   /**
    * A few standard defines
    */
@@ -63,7 +64,7 @@ public:
   typedef std::vector<vtkAbstractContextItem*>::iterator iterator;
   typedef std::vector<vtkAbstractContextItem*>::const_reverse_iterator const_reverse_iterator;
   typedef std::vector<vtkAbstractContextItem*>::reverse_iterator reverse_iterator;
-  //@}
+  ///@}
 
   /**
    * Paint all items in the list.
@@ -79,7 +80,7 @@ public:
     }
   }
 
-  //@{
+  ///@{
   /**
    * Add an item to the list - ensure it is not already in the list.
    */
@@ -88,13 +89,13 @@ public:
     item->Register(this->Scene);
     item->SetScene(this->Scene);
     item->SetParent(this->Item);
-    //@}
+    ///@}
 
     this->push_back(item);
     return static_cast<unsigned int>(this->size() - 1);
   }
 
-  //@{
+  ///@{
   /**
    * Remove an item from the list.
    */
@@ -113,9 +114,9 @@ public:
     }
     return false;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Remove an item from the list.
    */
@@ -127,9 +128,9 @@ public:
     }
     return false;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Clear all items from the list - unregister.
    */
@@ -143,9 +144,9 @@ public:
     }
     this->clear();
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the scene for the instance (and its items).
    */
@@ -161,21 +162,22 @@ public:
       (*it)->SetScene(scene);
     }
   }
-  //@}
+  ///@}
 
   /**
    * Store a reference to the scene.
    */
   vtkContextScene* Scene;
 
-  //@{
+  ///@{
   /**
    * Store a reference to the item that these children are part of.
    * May be NULL for items in the scene itself.
    */
   vtkAbstractContextItem* Item;
-  //@}
+  ///@}
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkContextScenePrivate_h
 // VTK-HeaderTest-Exclude: vtkContextScenePrivate.h
