@@ -15,38 +15,40 @@
 
 #include "vtkPen.h"
 
-#include "vtkObjectFactory.h"
 #include "vtkColor.h"
+#include "vtkObjectFactory.h"
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPen);
 
-//-----------------------------------------------------------------------------
-vtkPen::vtkPen() : PenColor(0, 0, 0, 255)
+//------------------------------------------------------------------------------
+vtkPen::vtkPen()
+  : PenColor(0, 0, 0, 255)
 {
   this->Color = this->PenColor.GetData();
   this->Width = 1.0;
   this->LineType = this->SOLID_LINE;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPen::~vtkPen() = default;
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetLineType(int type)
 {
   this->LineType = type;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPen::GetLineType()
 {
   return this->LineType;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetColorF(double color[3])
 {
   this->Color[0] = static_cast<unsigned char>(color[0] * 255.0);
@@ -54,7 +56,7 @@ void vtkPen::SetColorF(double color[3])
   this->Color[2] = static_cast<unsigned char>(color[2] * 255.0);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetColorF(double r, double g, double b)
 {
   this->Color[0] = static_cast<unsigned char>(r * 255.0);
@@ -62,7 +64,7 @@ void vtkPen::SetColorF(double r, double g, double b)
   this->Color[2] = static_cast<unsigned char>(b * 255.0);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetColorF(double r, double g, double b, double a)
 {
   this->Color[0] = static_cast<unsigned char>(r * 255.0);
@@ -71,13 +73,13 @@ void vtkPen::SetColorF(double r, double g, double b, double a)
   this->Color[3] = static_cast<unsigned char>(a * 255.0);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetOpacityF(double a)
 {
   this->Color[3] = static_cast<unsigned char>(a * 255.0);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetColor(unsigned char color[3])
 {
   this->Color[0] = color[0];
@@ -85,7 +87,7 @@ void vtkPen::SetColor(unsigned char color[3])
   this->Color[2] = color[2];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b)
 {
   this->Color[0] = r;
@@ -93,9 +95,8 @@ void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b)
   this->Color[2] = b;
 }
 
-//-----------------------------------------------------------------------------
-void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b,
-                      unsigned char a)
+//------------------------------------------------------------------------------
+void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b, unsigned char a)
 {
   this->Color[0] = r;
   this->Color[1] = g;
@@ -103,18 +104,18 @@ void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b,
   this->Color[3] = a;
 }
 
-void vtkPen::SetColor(const vtkColor4ub &color)
+void vtkPen::SetColor(const vtkColor4ub& color)
 {
   this->PenColor = color;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::SetOpacity(unsigned char a)
 {
   this->Color[3] = a;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::GetColorF(double color[3])
 {
   for (int i = 0; i < 3; ++i)
@@ -123,7 +124,7 @@ void vtkPen::GetColorF(double color[3])
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPen::GetColor(unsigned char color[3])
 {
   for (int i = 0; i < 3; ++i)
@@ -137,14 +138,14 @@ vtkColor4ub vtkPen::GetColorObject()
   return this->PenColor;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned char vtkPen::GetOpacity()
 {
   return this->Color[3];
 }
 
-//-----------------------------------------------------------------------------
-void vtkPen::DeepCopy(vtkPen *pen)
+//------------------------------------------------------------------------------
+void vtkPen::DeepCopy(vtkPen* pen)
 {
   if (!pen)
   {
@@ -155,11 +156,12 @@ void vtkPen::DeepCopy(vtkPen *pen)
   this->LineType = pen->LineType;
 }
 
-//-----------------------------------------------------------------------------
-void vtkPen::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkPen::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "Color: " << this->Color[0] << ", " << this->Color[1]
-     << ", " << this->Color[2] << ", " << this->Color[3] << endl;
+  os << indent << "Color: " << this->Color[0] << ", " << this->Color[1] << ", " << this->Color[2]
+     << ", " << this->Color[3] << endl;
   os << indent << "Width: " << this->Width << endl;
 }
+VTK_ABI_NAMESPACE_END
