@@ -40,11 +40,9 @@
 #include "vtkColor.h"
 #include "vtkFreeTypeTools.h"
 #include "vtkGenericCell.h"
-#include "vtkStdString.h"
 #include "vtkTextProperty.h"
 #include "vtkTextRenderer.h"
 #include "vtkTexture.h"
-#include "vtkUnicodeString.h"
 #include "vtkUnsignedCharArray.h"
 
 #include <algorithm>
@@ -56,6 +54,7 @@
 // .SECTION Description
 // Creating and initializing a texture can be time consuming,
 // vtkTextureImageCache offers the ability to reuse them as much as possible.
+VTK_ABI_NAMESPACE_BEGIN
 template <class Key>
 class vtkTextureImageCache
 {
@@ -69,7 +68,7 @@ public:
     vtkTextRenderer::Metrics Metrics;
   };
 
-  //@{
+  ///@{
   /**
    * CacheElement associates a unique key to some cache.
    */
@@ -101,7 +100,7 @@ public:
       return this->first == other.first;
     }
   };
-  //@}
+  ///@}
 
   /**
    * Construct a texture image cache with a maximum number of texture of 50.
@@ -125,7 +124,7 @@ public:
    */
   CacheData& GetCacheData(const Key& key);
 
-  //@{
+  ///@{
   /**
    * Release all the OpenGL Pixel Buffer Object(PBO) associated with the
    * textures of the cache list.
@@ -138,10 +137,10 @@ public:
       it->second.Texture->ReleaseGraphicsResources(window);
     }
   }
-  //@}
+  ///@}
 
 protected:
-  //@{
+  ///@{
   /**
    * Add a new cache entry into the cache list. Enforce the MaxSize size of the
    * list by removing the least used cache if needed.
@@ -156,18 +155,18 @@ protected:
     this->Cache.push_front(CacheElement(key, cacheData));
     return this->Cache.begin()->second;
   }
-  //@}
+  ///@}
 
   /**
    * List of a pair of key and cache data.
    */
   std::list<CacheElement> Cache;
-  //@{
+  ///@{
   /**
    * Maximum size the cache list can be.
    */
   size_t MaxSize;
-  //@}
+  ///@}
 };
 
 template <class Key>
@@ -193,7 +192,7 @@ typename vtkTextureImageCache<Key>::CacheData& vtkTextureImageCache<Key>::GetCac
 template <class StringType>
 struct TextPropertyKey
 {
-  //@{
+  ///@{
   /**
    * Transform a text property into an unsigned long
    */
@@ -214,18 +213,27 @@ struct TextPropertyKey
     assert("Hash is really a uint32" && static_cast<size_t>(hash) == id);
 
     // Since we cache the text metrics (which includes orientation and alignment
-    // info), we'll need to store the alignment options, since
-    // MapTextPropertyToId intentionally ignores these:
+    // info), we'll need to store additional options, since MapTextPropertyToId
+    // intentionally ignores them.
+    // These include cell spacing and interior lines for multi cell text, as well
+    // as text justification.
     int tmp = tprop->GetJustification();
     hash = vtkFreeTypeTools::HashBuffer(&tmp, sizeof(int), hash);
     tmp = tprop->GetVerticalJustification();
     hash = vtkFreeTypeTools::HashBuffer(&tmp, sizeof(int), hash);
+    tmp = tprop->GetCellOffset();
+    hash = vtkFreeTypeTools::HashBuffer(&tmp, sizeof(int), hash);
+    tmp = tprop->GetInteriorLinesVisibility();
+    hash = vtkFreeTypeTools::HashBuffer(&tmp, sizeof(int), hash);
+    tmp = tprop->GetInteriorLinesWidth();
+    hash = vtkFreeTypeTools::HashBuffer(&tmp, sizeof(int), hash);
+    hash = vtkFreeTypeTools::HashBuffer(tprop->GetInteriorLinesColor(), 3 * sizeof(double), hash);
 
     return hash;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Creates a TextPropertyKey.
    */
@@ -241,7 +249,7 @@ struct TextPropertyKey
     this->Text = text;
     this->DPI = dpi;
   }
-  //@}
+  ///@}
 
   /**
    * Compares two TextPropertyKeys with each other. Returns true if they are
@@ -263,8 +271,7 @@ struct TextPropertyKey
   int DPI;
 };
 
-typedef TextPropertyKey<vtkStdString> UTF8TextPropertyKey;
-typedef TextPropertyKey<vtkUnicodeString> UTF16TextPropertyKey;
+typedef TextPropertyKey<std::string> UTF8TextPropertyKey;
 
 class vtkOpenGLContextDevice2D::Private
 {
@@ -494,14 +501,13 @@ public:
   bool GLSL;
   bool PowerOfTwoTextures;
 
-  //@{
+  ///@{
   /**
    * Cache for text images. Generating texture for strings is expensive,
    * we cache the textures here for a faster reuse.
    */
-  mutable vtkTextureImageCache<UTF16TextPropertyKey> TextTextureCache;
-  mutable vtkTextureImageCache<UTF8TextPropertyKey> MathTextTextureCache;
-  //@}
+  mutable vtkTextureImageCache<UTF8TextPropertyKey> TextTextureCache;
+  ///@}
 };
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -876,16 +882,17 @@ private:
   vtkIdType* PointIds;
   vtkUnsignedCharArray* Colors;
 
-  //@{
+  ///@{
   /**
    *  Current vtkPolyData cell.
    */
   vtkIdType NumPointsCell;
   std::vector<float> CellPoints;
   vtkNew<vtkUnsignedCharArray> CellColors;
-  //@}
+  ///@}
 
   PolyDataCache* cache;
 };
+VTK_ABI_NAMESPACE_END
 #endif // VTKOPENGLCONTEXTDEVICE2DPRIVATE_H
 // VTK-HeaderTest-Exclude: vtkOpenGLContextDevice2DPrivate.h
