@@ -14,9 +14,12 @@
 #include "vtkAbstractRenderDevice.h"
 #include "vtkObjectFactory.h"
 
-vtkAbstractObjectFactoryNewMacro(vtkAbstractRenderDevice)
+VTK_ABI_NAMESPACE_BEGIN
+vtkAbstractObjectFactoryNewMacro(vtkAbstractRenderDevice);
 
-vtkAbstractRenderDevice::vtkAbstractRenderDevice() : GLMajor(2), GLMinor(1)
+vtkAbstractRenderDevice::vtkAbstractRenderDevice()
+  : GLMajor(2)
+  , GLMinor(1)
 {
 }
 
@@ -32,3 +35,4 @@ void vtkAbstractRenderDevice::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
