@@ -16,8 +16,14 @@
 #include "vtkActor2DCollection.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkActor2DCollection);
 
+void vtkActor2DCollection::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 // protected function to delete an element. Internal use only.
 void vtkActor2DCollection::DeleteElement(vtkCollectionElement* e)
 {
@@ -169,3 +175,4 @@ void vtkActor2DCollection::Sort()
 
   delete[] actorPtrArr;
 }
+VTK_ABI_NAMESPACE_END
