@@ -15,8 +15,14 @@
 #include "vtkAssemblyPaths.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAssemblyPaths);
 
+void vtkAssemblyPaths::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 vtkMTimeType vtkAssemblyPaths::GetMTime()
 {
   vtkMTimeType mtime = this->vtkCollection::GetMTime();
@@ -32,3 +38,4 @@ vtkMTimeType vtkAssemblyPaths::GetMTime()
   }
   return mtime;
 }
+VTK_ABI_NAMESPACE_END
