@@ -14,14 +14,15 @@
 =========================================================================*/
 
 #include "vtkAvatar.h"
-#include "vtkObjectFactory.h"
 #include "vtkMath.h"
+#include "vtkObjectFactory.h"
 
 //------------------------------------------------------------------------------
-vtkObjectFactoryNewMacro(vtkAvatar)
+VTK_ABI_NAMESPACE_BEGIN
+vtkObjectFactoryNewMacro(vtkAvatar);
 
 //------------------------------------------------------------------------------
-void vtkAvatar::PrintSelf(std::ostream &os, vtkIndent indent)
+void vtkAvatar::PrintSelf(std::ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
@@ -53,7 +54,8 @@ vtkAvatar::vtkAvatar()
   this->LeftHandOrientation[1] = 0.0;
   this->LeftHandOrientation[2] = 0.0;
 
-  for (int i = 0; i < NUM_BODY; ++i) {
+  for (int i = 0; i < NUM_BODY; ++i)
+  {
     this->BodyPosition[i][0] = 0.0;
     this->BodyPosition[i][1] = 0.0;
     this->BodyPosition[i][2] = 0.0;
@@ -69,8 +71,8 @@ vtkAvatar::vtkAvatar()
   UseLeftHand = true;
   UseRightHand = true;
   ShowHandsOnly = false;
-
 }
 
 //------------------------------------------------------------------------------
 vtkAvatar::~vtkAvatar() = default;
+VTK_ABI_NAMESPACE_END
