@@ -26,6 +26,7 @@
 #include "vtkActor.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGCORE_EXPORT vtkAvatar : public vtkActor
 {
 public:
@@ -57,7 +58,7 @@ public:
   vtkGetVector3Macro(UpVector, double);
   vtkSetVector3Macro(UpVector, double);
 
-  //@{
+  ///@{
   /**
    * Normally, hand position/orientation is set explicitly.
    * If set to false, hand and arm will follow the torso
@@ -69,16 +70,16 @@ public:
   vtkSetMacro(UseRightHand, bool);
   vtkGetMacro(UseRightHand, bool);
   vtkBooleanMacro(UseRightHand, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Show just the hands. Default false.
    */
   vtkSetMacro(ShowHandsOnly, bool);
   vtkGetMacro(ShowHandsOnly, bool);
   vtkBooleanMacro(ShowHandsOnly, bool);
-  //@}
+  ///@}
 
 protected:
   vtkAvatar();
@@ -113,4 +114,5 @@ private:
   void operator=(const vtkAvatar&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkAvatar_h
