@@ -24,15 +24,16 @@
  * camera perspective.
  * @sa
  * vtkPerspectiveTransform
-*/
+ */
 
 #ifndef vtkCamera_h
 #define vtkCamera_h
 
-#include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkObject.h"
-#include "vtkRect.h" // for ivar
+#include "vtkRect.h"                // for ivar
+#include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkHomogeneousTransform;
 class vtkInformation;
 class vtkMatrix4x4;
@@ -53,40 +54,37 @@ public:
    * and position=(0,0,1). The view up is along the y-axis,
    * view angle is 30 degrees, and the clipping range is (.1,1000).
    */
-  static vtkCamera *New();
+  static vtkCamera* New();
 
-  //@{
+  ///@{
   /**
    * Set/Get the position of the camera in world coordinates.
    * The default position is (0,0,1).
    */
   void SetPosition(double x, double y, double z);
-  void SetPosition(const double a[3]) {
-    this->SetPosition(a[0], a[1], a[2]); };
+  void SetPosition(const double a[3]) { this->SetPosition(a[0], a[1], a[2]); }
   vtkGetVector3Macro(Position, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the focal of the camera in world coordinates.
    * The default focal point is the origin.
    */
   void SetFocalPoint(double x, double y, double z);
-  void SetFocalPoint(const double a[3]) {
-    this->SetFocalPoint(a[0], a[1], a[2]);};
+  void SetFocalPoint(const double a[3]) { this->SetFocalPoint(a[0], a[1], a[2]); }
   vtkGetVector3Macro(FocalPoint, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the view up direction for the camera.  The default
    * is (0,1,0).
    */
   void SetViewUp(double vx, double vy, double vz);
-  void SetViewUp(const double a[3]) {
-    this->SetViewUp(a[0], a[1], a[2]); }
+  void SetViewUp(const double a[3]) { this->SetViewUp(a[0], a[1], a[2]); }
   vtkGetVector3Macro(ViewUp, double);
-  //@}
+  ///@}
 
   /**
    * Recompute the ViewUp vector to force it to be perpendicular to
@@ -101,22 +99,22 @@ public:
    */
   void SetDistance(double);
 
-  //@{
+  ///@{
   /**
    * Return the distance from the camera position to the focal point.
    * This distance is positive.
    */
   vtkGetMacro(Distance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the vector in the direction from the camera position to the
    * focal point.  This is usually the opposite of the ViewPlaneNormal,
    * the vector perpendicular to the screen, unless the view is oblique.
    */
   vtkGetVector3Macro(DirectionOfProjection, double);
-  //@}
+  ///@}
 
   /**
    * Divide the camera's distance from the focal point by the given
@@ -126,13 +124,13 @@ public:
    */
   void Dolly(double value);
 
-  //@{
+  ///@{
   /**
    * Set the roll angle of the camera about the direction of projection.
    */
   void SetRoll(double angle);
   double GetRoll();
-  //@}
+  ///@}
 
   /**
    * Rotate the camera about the direction of projection.  This will
@@ -172,7 +170,7 @@ public:
    */
   void Pitch(double angle);
 
-  //@{
+  ///@{
   /**
    * Set/Get the value of the ParallelProjection instance variable. This
    * determines if the camera should do a perspective or parallel projection.
@@ -182,9 +180,9 @@ public:
   void SetParallelProjection(vtkTypeBool flag);
   vtkGetMacro(ParallelProjection, vtkTypeBool);
   vtkBooleanMacro(ParallelProjection, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the value of the UseHorizontalViewAngle instance variable. If
    * set, the camera's view angle represents a horizontal view angle, rather
@@ -198,9 +196,9 @@ public:
   void SetUseHorizontalViewAngle(vtkTypeBool flag);
   vtkGetMacro(UseHorizontalViewAngle, vtkTypeBool);
   vtkBooleanMacro(UseHorizontalViewAngle, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the camera view angle, which is the angular height of the
    * camera view measured in degrees.  The default angle is 30 degrees.
@@ -214,11 +212,11 @@ public:
    */
   void SetViewAngle(double angle);
   vtkGetMacro(ViewAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Set/Get the scaling used for a parallel projection, i.e. the height
+   * Set/Get the scaling used for a parallel projection, i.e. the half of the height
    * of the viewport in world-coordinate distances. The default is 1.
    * Note that the "scale" parameter works as an "inverse scale" ---
    * larger numbers produce smaller images.
@@ -227,8 +225,8 @@ public:
    * is true.
    */
   void SetParallelScale(double scale);
-  vtkGetMacro(ParallelScale ,double);
-  //@}
+  vtkGetMacro(ParallelScale, double);
+  ///@}
 
   /**
    * In perspective mode, decrease the view angle by the specified factor.
@@ -239,7 +237,7 @@ public:
    */
   void Zoom(double factor);
 
-  //@{
+  ///@{
   /**
    * Set/Get the location of the near and far clipping planes along the
    * direction of projection.  Both of these values must be positive.
@@ -254,12 +252,11 @@ public:
    * is true.
    */
   void SetClippingRange(double dNear, double dFar);
-  void SetClippingRange(const double a[2])
-    { this->SetClippingRange(a[0], a[1]); }
+  void SetClippingRange(const double a[2]) { this->SetClippingRange(a[0], a[1]); }
   vtkGetVector2Macro(ClippingRange, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the distance between clipping planes.  This method adjusts the
    * far clipping plane to be set a distance 'thickness' beyond the
@@ -269,9 +266,9 @@ public:
    */
   void SetThickness(double);
   vtkGetMacro(Thickness, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the center of the window in viewport coordinates.
    * The viewport coordinate range is ([-1,+1],[-1,+1]).  This method
@@ -283,7 +280,7 @@ public:
    */
   void SetWindowCenter(double x, double y);
   vtkGetVector2Macro(WindowCenter, double);
-  //@}
+  ///@}
 
   /**
    * Get/Set the oblique viewing angles.  The first angle, alpha, is the
@@ -305,18 +302,18 @@ public:
    * and view-up are re-calculated using the transform's matrix to
    * multiply the old points by the new transform.
    */
-  void ApplyTransform(vtkTransform *t);
+  void ApplyTransform(vtkTransform* t);
 
-  //@{
+  ///@{
   /**
    * Get the ViewPlaneNormal.  This vector will point opposite to
    * the direction of projection, unless you have created a sheared output
    * view using SetViewShear/SetObliqueAngles.
    */
   vtkGetVector3Macro(ViewPlaneNormal, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the shear transform of the viewing frustum.  Parameters are
    * dx/dz, dy/dz, and center.  center is a factor that describes where
@@ -328,18 +325,18 @@ public:
   void SetViewShear(double dxdz, double dydz, double center);
   void SetViewShear(double d[3]);
   vtkGetVector3Macro(ViewShear, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the separation between eyes (in degrees). This is used
    * when generating stereo images.
    */
   vtkSetMacro(EyeAngle, double);
   vtkGetMacro(EyeAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the size of the cameras lens in world coordinates. This is only
    * used when the renderer is doing focal depth rendering. When that is
@@ -348,9 +345,9 @@ public:
    */
   vtkSetMacro(FocalDisk, double);
   vtkGetMacro(FocalDisk, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sets the distance at which rendering is in focus. This is currently
    * only used by the ray tracing renderers. 0 (default) disables
@@ -361,9 +358,9 @@ public:
    */
   vtkSetMacro(FocalDistance, double);
   vtkGetMacro(FocalDistance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get use offaxis frustum.
    * OffAxis frustum is used for off-axis frustum calculations specifically
@@ -376,9 +373,9 @@ public:
   vtkSetMacro(UseOffAxisProjection, vtkTypeBool);
   vtkGetMacro(UseOffAxisProjection, vtkTypeBool);
   vtkBooleanMacro(UseOffAxisProjection, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get top left corner point of the screen.
    * This will be used only for offaxis frustum calculation.
@@ -386,9 +383,9 @@ public:
    */
   vtkSetVector3Macro(ScreenBottomLeft, double);
   vtkGetVector3Macro(ScreenBottomLeft, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get bottom left corner point of the screen.
    * This will be used only for offaxis frustum calculation.
@@ -396,9 +393,9 @@ public:
    */
   vtkSetVector3Macro(ScreenBottomRight, double);
   vtkGetVector3Macro(ScreenBottomRight, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get top right corner point of the screen.
    * This will be used only for offaxis frustum calculation.
@@ -406,9 +403,9 @@ public:
    */
   vtkSetVector3Macro(ScreenTopRight, double);
   vtkGetVector3Macro(ScreenTopRight, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get distance between the eyes.
    * This will be used only for offaxis frustum calculation.
@@ -416,9 +413,9 @@ public:
    */
   vtkSetMacro(EyeSeparation, double);
   vtkGetMacro(EyeSeparation, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the eye position (center point between two eyes).
    * This is a convenience function that sets the translation
@@ -427,7 +424,7 @@ public:
    */
   void SetEyePosition(double eyePosition[3]);
   void GetEyePosition(double eyePosition[3]);
-  //@}
+  ///@}
 
   /**
    * Get normal vector from eye to screen rotated by EyeTransformMatrix.
@@ -435,7 +432,7 @@ public:
    */
   void GetEyePlaneNormal(double normal[3]);
 
-  //@{
+  ///@{
   /**
    * Set/Get eye transformation matrix.
    * This is the transformation matrix for the point between eyes.
@@ -444,7 +441,7 @@ public:
    */
   void SetEyeTransformMatrix(vtkMatrix4x4* matrix);
   vtkGetObjectMacro(EyeTransformMatrix, vtkMatrix4x4);
-  //@}
+  ///@}
 
   /**
    * Set the eye transform matrix.
@@ -454,15 +451,15 @@ public:
    */
   void SetEyeTransformMatrix(const double elements[16]);
 
-  //@{
+  ///@{
   /**
    * Set/Get model transformation matrix.
    * This matrix could be used for model related transformations
    * such as scale, shear, rotations and translations.
    */
-  void SetModelTransformMatrix(vtkMatrix4x4 *matrix);
+  void SetModelTransformMatrix(vtkMatrix4x4* matrix);
   vtkGetObjectMacro(ModelTransformMatrix, vtkMatrix4x4);
-  //@}
+  ///@}
 
   /**
    * Set model transformation matrix.
@@ -474,12 +471,12 @@ public:
   /**
    * Return the model view matrix of model view transform.
    */
-  virtual vtkMatrix4x4 *GetModelViewTransformMatrix();
+  virtual vtkMatrix4x4* GetModelViewTransformMatrix();
 
   /**
    * Return the model view transform.
    */
-  virtual vtkTransform *GetModelViewTransformObject();
+  virtual vtkTransform* GetModelViewTransformObject();
 
   /**
    * For backward compatibility. Use GetModelViewTransformMatrix() now.
@@ -488,7 +485,7 @@ public:
    * FocalPoint, and the ViewUp vector.  All the other methods are there
    * simply for the sake of the users' convenience.
    */
-  virtual vtkMatrix4x4 *GetViewTransformMatrix();
+  virtual vtkMatrix4x4* GetViewTransformMatrix();
 
   /**
    * For backward compatibility. Use GetModelViewTransformObject() now.
@@ -499,7 +496,7 @@ public:
    * All the other methods are there simply for the sake of the users'
    * convenience.
    */
-  virtual vtkTransform *GetViewTransformObject();
+  virtual vtkTransform* GetViewTransformObject();
 
   /**
    * Set/get an explicit 4x4 projection matrix to use, rather than computing
@@ -508,7 +505,7 @@ public:
    * @{
    */
   virtual void SetExplicitProjectionTransformMatrix(vtkMatrix4x4*);
-  vtkGetObjectMacro(ExplicitProjectionTransformMatrix, vtkMatrix4x4)
+  vtkGetObjectMacro(ExplicitProjectionTransformMatrix, vtkMatrix4x4);
   /**@}*/
 
   /**
@@ -516,9 +513,29 @@ public:
    * transformation, rather than computing a transform from internal state.
    * @{
    */
-  vtkSetMacro(UseExplicitProjectionTransformMatrix, bool)
-  vtkGetMacro(UseExplicitProjectionTransformMatrix, bool)
-  vtkBooleanMacro(UseExplicitProjectionTransformMatrix, bool)
+  vtkSetMacro(UseExplicitProjectionTransformMatrix, bool);
+  vtkGetMacro(UseExplicitProjectionTransformMatrix, bool);
+  vtkBooleanMacro(UseExplicitProjectionTransformMatrix, bool);
+  /**@}*/
+
+  /**
+   * Set/get an explicit aspect to use, rather than computing it from the renderer.
+   * Only used when UseExplicitAspect is true.
+   * @{
+   */
+  vtkSetMacro(ExplicitAspectRatio, double);
+  vtkGetMacro(ExplicitAspectRatio, double);
+  /**@}*/
+
+  /**
+   * If true, the ExplicitAspect is used for the projection
+   * transformation, rather than computing it from the renderer.
+   * Default is false.
+   * @{
+   */
+  vtkSetMacro(UseExplicitAspectRatio, bool);
+  vtkGetMacro(UseExplicitAspectRatio, bool);
+  vtkBooleanMacro(UseExplicitAspectRatio, bool);
   /**@}*/
 
   /**
@@ -528,11 +545,10 @@ public:
    * Z-buffer values that map to the near and far clipping planes.
    * The viewport coordinates of a point located inside the frustum are in the
    * range ([-1,+1],[-1,+1],[nearz,farz]).
+   * aspect is ignored if UseExplicitAspectRatio is true.
    * @sa ExplicitProjectionTransformMatrix
    */
-   virtual vtkMatrix4x4 *GetProjectionTransformMatrix(double aspect,
-                                                      double nearz,
-                                                      double farz);
+  virtual vtkMatrix4x4* GetProjectionTransformMatrix(double aspect, double nearz, double farz);
 
   /**
    * Return the projection transform matrix, which converts from camera
@@ -541,11 +557,11 @@ public:
    * Z-buffer values that map to the near and far clipping planes.
    * The viewport coordinates of a point located inside the frustum are in the
    * range ([-1,+1],[-1,+1],[nearz,farz]).
+   * aspect is ignored if UseExplicitAspectRatio is true.
    * @sa ExplicitProjectionTransformMatrix
    */
-  virtual vtkPerspectiveTransform *GetProjectionTransformObject(double aspect,
-                                                                double nearz,
-                                                                double farz);
+  virtual vtkPerspectiveTransform* GetProjectionTransformObject(
+    double aspect, double nearz, double farz);
 
   /**
    * Return the concatenation of the ViewTransform and the
@@ -555,11 +571,11 @@ public:
    * Z-buffer values that map to the near and far clipping planes.
    * The viewport coordinates of a point located inside the frustum are in the
    * range ([-1,+1],[-1,+1],[nearz,farz]).
+   * aspect is ignored if UseExplicitAspectRatio is true.
    * @sa ExplicitProjectionTransformMatrix
    */
-  virtual vtkMatrix4x4 *GetCompositeProjectionTransformMatrix(double aspect,
-                                                              double nearz,
-                                                              double farz);
+  virtual vtkMatrix4x4* GetCompositeProjectionTransformMatrix(
+    double aspect, double nearz, double farz);
 
   /**
    * Return the projection transform matrix, which converts from camera
@@ -568,34 +584,34 @@ public:
    * signature of GetCompositeProjectionTransformMatrix
    * @sa ExplicitProjectionTransformMatrix
    */
-  virtual vtkMatrix4x4 *GetProjectionTransformMatrix(vtkRenderer *ren);
+  virtual vtkMatrix4x4* GetProjectionTransformMatrix(vtkRenderer* ren);
 
-  //@{
+  ///@{
   /**
    * In addition to the instance variables such as position and orientation,
    * you can add an additional transformation for your own use.  This
    * transformation is concatenated to the camera's ViewTransform
    */
-  void SetUserViewTransform(vtkHomogeneousTransform *transform);
-  vtkGetObjectMacro(UserViewTransform,vtkHomogeneousTransform);
-  //@}
+  void SetUserViewTransform(vtkHomogeneousTransform* transform);
+  vtkGetObjectMacro(UserViewTransform, vtkHomogeneousTransform);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * In addition to the instance variables such as position and orientation,
    * you can add an additional transformation for your own use. This
    * transformation is concatenated to the camera's ProjectionTransform
    */
-  void SetUserTransform(vtkHomogeneousTransform *transform);
-  vtkGetObjectMacro(UserTransform,vtkHomogeneousTransform);
-  //@}
+  void SetUserTransform(vtkHomogeneousTransform* transform);
+  vtkGetObjectMacro(UserTransform, vtkHomogeneousTransform);
+  ///@}
 
   /**
    * This method causes the camera to set up whatever is required for
    * viewing the scene. This is actually handled by an subclass of
    * vtkCamera, which is created through New()
    */
-  virtual void Render(vtkRenderer *) {}
+  virtual void Render(vtkRenderer*) {}
 
   /**
    * Return the MTime that concerns recomputing the view rays of the camera.
@@ -615,17 +631,38 @@ public:
    * values are (A,B,C,D) which repeats for each of the planes.
    * The planes are given in the following order: -x,+x,-y,+y,-z,+z.
    * Warning: it means left,right,bottom,top,far,near (NOT near,far)
-   * The aspect of the viewport is needed to correctly compute the planes
+   * The aspect of the viewport is needed to correctly compute the planes.
+   * aspect is ignored if UseExplicitAspectRatio is true.
    */
   virtual void GetFrustumPlanes(double aspect, double planes[24]);
 
-  //@{
+  ///@{
+  /**
+   * The following methods are used to support view dependent methods
+   * for normalizing data (typically point coordinates). When dealing with
+   * data that can exceed floating point resolution sometimes is it best
+   * to normalize that data based on the current camera view such that
+   * what is seen will be in the sweet spot for floating point resolution.
+   * Input datasets may be double precision but the rendering engine
+   * is currently single precision which also can lead to these issues.
+   * See vtkOpenGLVertexBufferObject for related information.
+   */
+  virtual void UpdateIdealShiftScale(double aspect);
+  vtkGetVector3Macro(FocalPointShift, double);
+  vtkGetMacro(FocalPointScale, double);
+  vtkGetVector3Macro(NearPlaneShift, double);
+  vtkGetMacro(NearPlaneScale, double);
+  vtkSetMacro(ShiftScaleThreshold, double);
+  vtkGetMacro(ShiftScaleThreshold, double);
+  ///@}
+
+  ///@{
   /**
    * Get the orientation of the camera.
    */
-  double *GetOrientation() VTK_SIZEHINT(3);
-  double *GetOrientationWXYZ() VTK_SIZEHINT(4);
-  //@}
+  double* GetOrientation() VTK_SIZEHINT(3);
+  double* GetOrientationWXYZ() VTK_SIZEHINT(4);
+  ///@}
 
   /**
    * This method is called automatically whenever necessary, it
@@ -638,20 +675,27 @@ public:
    * the camera, where the camera is located at (0, 0, 1) looking at the
    * focal point at (0, 0, 0), with up being (0, 1, 0).
    */
-  vtkMatrix4x4 *GetCameraLightTransformMatrix();
+  vtkMatrix4x4* GetCameraLightTransformMatrix();
 
   /**
    * Update the viewport
    */
-  virtual void UpdateViewport(vtkRenderer *vtkNotUsed(ren)) {}
+  virtual void UpdateViewport(vtkRenderer* vtkNotUsed(ren)) {}
 
-  //@{
+  ///@{
+  /**
+   * Get the stereo setting
+   */
+  vtkGetMacro(Stereo, int);
+  ///@}
+
+  ///@{
   /**
    * Set the Left Eye setting
    */
   vtkSetMacro(LeftEye, int);
   vtkGetMacro(LeftEye, int);
-  //@}
+  ///@}
 
   /**
    * Copy the properties of `source' into `this'.
@@ -659,7 +703,7 @@ public:
    * \pre source_exists!=0
    * \pre not_this: source!=this
    */
-  void ShallowCopy(vtkCamera *source);
+  void ShallowCopy(vtkCamera* source);
 
   /**
    * Copy the properties of `source' into `this'.
@@ -667,9 +711,9 @@ public:
    * \pre source_exists!=0
    * \pre not_this: source!=this
    */
-  void DeepCopy(vtkCamera *source);
+  void DeepCopy(vtkCamera* source);
 
-  //@{
+  ///@{
   /**
    * Set/Get the value of the FreezeDolly instance variable. This
    * determines if the camera should move the focal point with the camera position.
@@ -677,61 +721,56 @@ public:
    */
   vtkSetMacro(FreezeFocalPoint, bool);
   vtkGetMacro(FreezeFocalPoint, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/Disable the scissor
    */
   vtkSetMacro(UseScissor, bool);
   vtkGetMacro(UseScissor, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the vtkRect value of the scissor
    */
   void SetScissorRect(vtkRecti scissorRect);
   void GetScissorRect(vtkRecti& scissorRect);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the information object associated with this camera.
    */
   vtkGetObjectMacro(Information, vtkInformation);
   virtual void SetInformation(vtkInformation*);
-  //@}
+  ///@}
 
 protected:
   vtkCamera();
   ~vtkCamera() override;
 
-  //@{
+  ///@{
   /**
    * These methods should only be used within vtkCamera.cxx.
    */
   void ComputeDistance();
   virtual void ComputeViewTransform();
-  //@}
+  ///@}
 
   /**
    * These methods should only be used within vtkCamera.cxx.
    */
-  virtual void ComputeProjectionTransform(double aspect,
-                                          double nearz,
-                                          double farz);
+  virtual void ComputeProjectionTransform(double aspect, double nearz, double farz);
 
   /**
    * These methods should only be used within vtkCamera.cxx.
    */
-  void ComputeCompositeProjectionTransform(double aspect,
-                                           double nearz,
-                                           double farz);
+  void ComputeCompositeProjectionTransform(double aspect, double nearz, double farz);
 
   void ComputeCameraLightTransform();
 
-
   /**
    * Given screen screen top, bottom left and top right
    * calculate screen rotation.
@@ -754,7 +793,7 @@ protected:
    * \pre source_exists!=0
    * \pre not_this: source!=this
    */
-  void PartialCopy(vtkCamera *source);
+  void PartialCopy(vtkCamera* source);
 
   double WindowCenter[2];
   double ObliqueAngles[2];
@@ -764,18 +803,18 @@ protected:
   double ViewAngle;
   double ClippingRange[2];
   double EyeAngle;
-  vtkTypeBool    ParallelProjection;
+  vtkTypeBool ParallelProjection;
   double ParallelScale;
-  int    Stereo;
-  int    LeftEye;
+  int Stereo;
+  int LeftEye;
   double Thickness;
   double Distance;
   double DirectionOfProjection[3];
   double ViewPlaneNormal[3];
   double ViewShear[3];
-  vtkTypeBool    UseHorizontalViewAngle;
+  vtkTypeBool UseHorizontalViewAngle;
 
-  vtkTypeBool    UseOffAxisProjection;
+  vtkTypeBool UseOffAxisProjection;
 
   double ScreenBottomLeft[3];
   double ScreenBottomRight[3];
@@ -783,30 +822,39 @@ protected:
 
   double EyeSeparation;
 
-  vtkMatrix4x4 *WorldToScreenMatrix;
-  vtkTimeStamp  WorldToScreenMatrixMTime;
+  vtkMatrix4x4* WorldToScreenMatrix;
+  vtkTimeStamp WorldToScreenMatrixMTime;
 
-  vtkMatrix4x4 *EyeTransformMatrix;
+  vtkMatrix4x4* EyeTransformMatrix;
 
-  vtkMatrix4x4 *ModelTransformMatrix;
+  vtkMatrix4x4* ModelTransformMatrix;
 
-  vtkHomogeneousTransform *UserTransform;
-  vtkHomogeneousTransform *UserViewTransform;
+  vtkHomogeneousTransform* UserTransform;
+  vtkHomogeneousTransform* UserViewTransform;
 
-  vtkMatrix4x4 *ExplicitProjectionTransformMatrix;
+  vtkMatrix4x4* ExplicitProjectionTransformMatrix;
   bool UseExplicitProjectionTransformMatrix;
 
-  vtkTransform *ViewTransform;
-  vtkPerspectiveTransform *ProjectionTransform;
-  vtkPerspectiveTransform *Transform;
-  vtkTransform *CameraLightTransform;
+  double ExplicitAspectRatio;
+  bool UseExplicitAspectRatio;
 
-  vtkTransform *ModelViewTransform;
+  vtkTransform* ViewTransform;
+  vtkPerspectiveTransform* ProjectionTransform;
+  vtkPerspectiveTransform* Transform;
+  vtkTransform* CameraLightTransform;
+
+  vtkTransform* ModelViewTransform;
 
   double FocalDisk;
   double FocalDistance;
 
-  vtkCameraCallbackCommand *UserViewTransformCallbackCommand;
+  double FocalPointShift[3];
+  double FocalPointScale;
+  double NearPlaneShift[3];
+  double NearPlaneScale;
+  double ShiftScaleThreshold;
+
+  vtkCameraCallbackCommand* UserViewTransformCallbackCommand;
   friend class vtkCameraCallbackCommand;
 
   // ViewingRaysMtime keeps track of camera modifications which will
@@ -826,4 +874,5 @@ private:
   void operator=(const vtkCamera&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
