@@ -15,15 +15,18 @@
 #include "vtkColorTransferFunction.h"
 
 #include "vtkCIEDE2000.h"
+#include "vtkDoubleArray.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 
 #include <algorithm>
 #include <cmath>
 #include <iterator>
+#include <limits>
 #include <set>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkColorTransferFunction);
 
 #define MY_MAX(x, y) ((x) > (y) ? (x) : (y))
@@ -150,10 +153,8 @@ inline double vtkColorTransferFunctionAdjustHue(const double msh[3], double unsa
 }
 
 // Interpolate a diverging color map.
-inline void vtkColorTransferFunctionInterpolateDiverging(double s,
-  const double rgb1[3],
-  const double rgb2[3],
-  double result[3])
+inline void vtkColorTransferFunctionInterpolateDiverging(
+  double s, const double rgb1[3], const double rgb2[3], double result[3])
 {
   double lab1[3], lab2[3];
   vtkMath::RGBToLab(rgb1, lab1);
@@ -212,11 +213,8 @@ inline void vtkColorTransferFunctionInterpolateDiverging(double s,
 }
 
 // Interpolate a LAB/CIEDE2000 color map.
-inline void vtkColorTransferFunctionInterpolateLABCIEDE2000(double s,
-  const double rgb1[3],
-  const double rgb2[3],
-  double result[3],
-  vtkSmartPointer<vtkColorTransferFunction>& cachedPathCTF,
+inline void vtkColorTransferFunctionInterpolateLABCIEDE2000(double s, const double rgb1[3],
+  const double rgb2[3], double result[3], vtkSmartPointer<vtkColorTransferFunction>& cachedPathCTF,
   bool forceExactSupportColors = false)
 {
   if (!forceExactSupportColors)
@@ -268,7 +266,7 @@ inline void vtkColorTransferFunctionInterpolateLABCIEDE2000(double s,
   result[2] = rgba[2] / 255.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct a new vtkColorTransferFunction with default values
 vtkColorTransferFunction::vtkColorTransferFunction()
 {
@@ -313,7 +311,7 @@ vtkColorTransferFunction::vtkColorTransferFunction()
   this->Internal = new vtkColorTransferFunctionInternals;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Destruct a vtkColorTransferFunction
 vtkColorTransferFunction::~vtkColorTransferFunction()
 {
@@ -361,21 +359,17 @@ double* vtkColorTransferFunction::GetDataPointer()
   return this->Function;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a point defined in RGB
 int vtkColorTransferFunction::AddRGBPoint(double x, double r, double g, double b)
 {
   return this->AddRGBPoint(x, r, g, b, 0.5, 0.0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a point defined in RGB
-int vtkColorTransferFunction::AddRGBPoint(double x,
-  double r,
-  double g,
-  double b,
-  double midpoint,
-  double sharpness)
+int vtkColorTransferFunction::AddRGBPoint(
+  double x, double r, double g, double b, double midpoint, double sharpness)
 {
   // Error check
   if (midpoint < 0.0 || midpoint > 1.0)
@@ -437,6 +431,84 @@ int vtkColorTransferFunction::AddRGBPoint(double x,
 }
 
 //----------------------------------------------------------------------------
+// Bulk add points defined in RGB
+int vtkColorTransferFunction::AddRGBPoints(vtkDoubleArray* x, vtkDoubleArray* rgbColors)
+{
+  return this->AddRGBPoints(x, rgbColors, 0.5, 0.0);
+}
+
+//----------------------------------------------------------------------------
+// Bulk add points defined in RGB
+int vtkColorTransferFunction::AddRGBPoints(
+  vtkDoubleArray* x, vtkDoubleArray* rgbColors, double midpoint, double sharpness)
+{
+  if (x == nullptr)
+  {
+    vtkErrorMacro("Points array is null");
+    return -1;
+  }
+  if (rgbColors == nullptr)
+  {
+    vtkErrorMacro("Colors array is null");
+    return -1;
+  }
+  if (x->GetNumberOfTuples() != rgbColors->GetNumberOfTuples())
+  {
+    vtkErrorMacro("Bulk arrays are of unequal length: x=" << x->GetNumberOfTuples() << " Colors="
+                                                          << rgbColors->GetNumberOfTuples());
+    return -1;
+  }
+  if (rgbColors->GetNumberOfComponents() != 3)
+  {
+    vtkErrorMacro(
+      "rgbColors doesn't contain rgb values: Components=" << rgbColors->GetNumberOfComponents());
+    return -1;
+  }
+
+  // Error check
+  if (midpoint < 0.0 || midpoint > 1.0)
+  {
+    vtkErrorMacro("Midpoint " << midpoint << " outside range [0.0, 1.0]");
+    return -1;
+  }
+
+  if (sharpness < 0.0 || sharpness > 1.0)
+  {
+    vtkErrorMacro("Sharpness " << sharpness << " outside range [0.0, 1.0]");
+    return -1;
+  }
+
+  // remove any node already at this X location
+  if (!this->AllowDuplicateScalars)
+  {
+    vtkErrorMacro("Adding points in bulk doesn't support checking for duplicates");
+    return -1;
+  }
+
+  auto numNodes = x->GetNumberOfValues();
+  for (vtkIdType i = 0; i < numNodes; i++)
+  {
+    // Create the new node
+    vtkCTFNode* node = new vtkCTFNode;
+    node->X = x->GetValue(i);
+    auto rgb = rgbColors->GetTuple3(i);
+    node->R = rgb[0];
+    node->G = rgb[1];
+    node->B = rgb[2];
+    node->Midpoint = midpoint;
+    node->Sharpness = sharpness;
+
+    // Add it
+    this->Internal->Nodes.push_back(node);
+  }
+
+  // Then sort to get everything in order
+  this->SortAndUpdateRange();
+
+  return static_cast<int>(this->Internal->Nodes.size()) - 1;
+}
+
+//------------------------------------------------------------------------------
 // Add a point defined in HSV
 int vtkColorTransferFunction::AddHSVPoint(double x, double h, double s, double v)
 {
@@ -446,14 +518,10 @@ int vtkColorTransferFunction::AddHSVPoint(double x, double h, double s, double v
   return this->AddRGBPoint(x, r, g, b);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a point defined in HSV
-int vtkColorTransferFunction::AddHSVPoint(double x,
-  double h,
-  double s,
-  double v,
-  double midpoint,
-  double sharpness)
+int vtkColorTransferFunction::AddHSVPoint(
+  double x, double h, double s, double v, double midpoint, double sharpness)
 {
   double r, b, g;
 
@@ -461,12 +529,13 @@ int vtkColorTransferFunction::AddHSVPoint(double x,
   return this->AddRGBPoint(x, r, g, b, midpoint, sharpness);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Sort the vector in increasing order, then fill in
 // the Range
 void vtkColorTransferFunction::SortAndUpdateRange()
 {
-  std::sort(
+  // Use stable_sort to avoid shuffling of DuplicateScalars
+  std::stable_sort(
     this->Internal->Nodes.begin(), this->Internal->Nodes.end(), this->Internal->CompareNodes);
   bool modifiedInvoked = this->UpdateRange();
   // If range is updated, Modified() has been called, don't call it again.
@@ -476,7 +545,7 @@ void vtkColorTransferFunction::SortAndUpdateRange()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkColorTransferFunction::UpdateRange()
 {
   double oldRange[2];
@@ -505,7 +574,7 @@ bool vtkColorTransferFunction::UpdateRange()
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove a point
 int vtkColorTransferFunction::RemovePoint(double x)
 {
@@ -565,7 +634,7 @@ int vtkColorTransferFunction::RemovePoint(double x)
   return retVal;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::MovePoint(double oldX, double newX)
 {
   if (oldX == newX)
@@ -586,7 +655,7 @@ void vtkColorTransferFunction::MovePoint(double oldX, double newX)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove all points
 void vtkColorTransferFunction::RemoveAllPoints()
 {
@@ -599,16 +668,10 @@ void vtkColorTransferFunction::RemoveAllPoints()
   this->SortAndUpdateRange();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a line defined in RGB
-void vtkColorTransferFunction::AddRGBSegment(double x1,
-  double r1,
-  double g1,
-  double b1,
-  double x2,
-  double r2,
-  double g2,
-  double b2)
+void vtkColorTransferFunction::AddRGBSegment(
+  double x1, double r1, double g1, double b1, double x2, double r2, double g2, double b2)
 {
   int done;
 
@@ -638,16 +701,10 @@ void vtkColorTransferFunction::AddRGBSegment(double x1,
   this->AddRGBPoint(x2, r2, g2, b2, 0.5, 0.0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a line defined in HSV
-void vtkColorTransferFunction::AddHSVSegment(double x1,
-  double h1,
-  double s1,
-  double v1,
-  double x2,
-  double h2,
-  double s2,
-  double v2)
+void vtkColorTransferFunction::AddHSVSegment(
+  double x1, double h1, double s1, double v1, double x2, double h2, double s2, double v2)
 {
   double r1, r2, b1, b2, g1, g2;
 
@@ -656,7 +713,7 @@ void vtkColorTransferFunction::AddHSVSegment(double x1,
   this->AddRGBSegment(x1, r1, g1, b1, x2, r2, g2, b2);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the RGBA color evaluated at the specified location
 const unsigned char* vtkColorTransferFunction::MapValue(double x)
 {
@@ -670,7 +727,7 @@ const unsigned char* vtkColorTransferFunction::MapValue(double x)
   return this->UnsignedCharRGBAValue;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the RGB color evaluated at the specified location
 void vtkColorTransferFunction::GetColor(double x, double rgb[3])
 {
@@ -695,7 +752,7 @@ void vtkColorTransferFunction::GetColor(double x, double rgb[3])
   this->GetTable(x, x, 1, rgb);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the red color evaluated at the specified location
 double vtkColorTransferFunction::GetRedValue(double x)
 {
@@ -705,7 +762,7 @@ double vtkColorTransferFunction::GetRedValue(double x)
   return rgb[0];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the green color evaluated at the specified location
 double vtkColorTransferFunction::GetGreenValue(double x)
 {
@@ -715,7 +772,7 @@ double vtkColorTransferFunction::GetGreenValue(double x)
   return rgb[1];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the blue color evaluated at the specified location
 double vtkColorTransferFunction::GetBlueValue(double x)
 {
@@ -725,7 +782,7 @@ double vtkColorTransferFunction::GetBlueValue(double x)
   return rgb[2];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns a table of RGB colors at regular intervals along the function
 void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, double* table)
 {
@@ -1193,7 +1250,7 @@ void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, do
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, float* table)
 {
   double* tmpTable = new double[size * 3];
@@ -1213,7 +1270,7 @@ void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, fl
   delete[] tmpTable;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const unsigned char* vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size)
 {
   if (this->GetMTime() <= this->BuildTime && this->TableSize == size)
@@ -1255,11 +1312,9 @@ const unsigned char* vtkColorTransferFunction::GetTable(double xStart, double xE
   return this->Table;
 }
 
-//----------------------------------------------------------------------------
-void vtkColorTransferFunction::BuildFunctionFromTable(double xStart,
-  double xEnd,
-  int size,
-  double* table)
+//------------------------------------------------------------------------------
+void vtkColorTransferFunction::BuildFunctionFromTable(
+  double xStart, double xEnd, int size, double* table)
 {
   double inc = 0.0;
   double* tptr = table;
@@ -1289,7 +1344,7 @@ void vtkColorTransferFunction::BuildFunctionFromTable(double xStart,
   this->SortAndUpdateRange();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For a specified index value, get the node parameters
 int vtkColorTransferFunction::GetNodeValue(int index, double val[6])
 {
@@ -1311,7 +1366,7 @@ int vtkColorTransferFunction::GetNodeValue(int index, double val[6])
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For a specified index value, get the node parameters
 int vtkColorTransferFunction::SetNodeValue(int index, double val[6])
 {
@@ -1347,7 +1402,7 @@ int vtkColorTransferFunction::SetNodeValue(int index, double val[6])
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::DeepCopy(vtkScalarsToColors* o)
 {
   vtkColorTransferFunction* f = nullptr;
@@ -1376,7 +1431,7 @@ void vtkColorTransferFunction::DeepCopy(vtkScalarsToColors* o)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::ShallowCopy(vtkColorTransferFunction* f)
 {
   if (f != nullptr)
@@ -1400,19 +1455,14 @@ void vtkColorTransferFunction::ShallowCopy(vtkColorTransferFunction* f)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Accelerate the mapping by copying the data in 32-bit chunks instead
 // of 8-bit chunks.  The extra "long" argument is to help broken
 // compilers select the non-templates below for unsigned char
 // and unsigned short.
-template<class T>
-void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self,
-  T* input,
-  unsigned char* output,
-  int length,
-  int inIncr,
-  int outFormat,
-  long)
+template <class T>
+void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, T* input,
+  unsigned char* output, int length, int inIncr, int outFormat, long)
 {
   double x;
   int i = length;
@@ -1452,15 +1502,10 @@ void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Special implementation for unsigned char input.
-static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self,
-  unsigned char* input,
-  unsigned char* output,
-  int length,
-  int inIncr,
-  int outFormat,
-  int)
+static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, unsigned char* input,
+  unsigned char* output, int length, int inIncr, int outFormat, int)
 {
   int x;
   int i = length;
@@ -1517,15 +1562,10 @@ static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Special implementation for unsigned short input.
-static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self,
-  unsigned short* input,
-  unsigned char* output,
-  int length,
-  int inIncr,
-  int outFormat,
-  int)
+static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, unsigned short* input,
+  unsigned char* output, int length, int inIncr, int outFormat, int)
 {
   int x;
   int i = length;
@@ -1582,15 +1622,10 @@ static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self,
   }
 }
 
-//----------------------------------------------------------------------------
-template<class T>
-void vtkColorTransferFunctionIndexedMapData(vtkColorTransferFunction* self,
-  T* input,
-  unsigned char* output,
-  int length,
-  int inIncr,
-  int outFormat,
-  long)
+//------------------------------------------------------------------------------
+template <class T>
+void vtkColorTransferFunctionIndexedMapData(vtkColorTransferFunction* self, T* input,
+  unsigned char* output, int length, int inIncr, int outFormat, long)
 {
   int i = length;
   double nodeVal[6];
@@ -1749,13 +1784,9 @@ void vtkColorTransferFunctionIndexedMapData(vtkColorTransferFunction* self,
   } // alpha blending
 }
 
-//----------------------------------------------------------------------------
-void vtkColorTransferFunction::MapScalarsThroughTable2(void* input,
-  unsigned char* output,
-  int inputDataType,
-  int numberOfValues,
-  int inputIncrement,
-  int outputFormat)
+//------------------------------------------------------------------------------
+void vtkColorTransferFunction::MapScalarsThroughTable2(void* input, unsigned char* output,
+  int inputDataType, int numberOfValues, int inputIncrement, int outputFormat)
 {
   if (this->GetSize() == 0)
   {
@@ -1768,12 +1799,7 @@ void vtkColorTransferFunction::MapScalarsThroughTable2(void* input,
     {
       // Use vtkExtendedTemplateMacro to cover case of VTK_STRING input
       vtkExtendedTemplateMacro(vtkColorTransferFunctionIndexedMapData(this,
-        static_cast<VTK_TT*>(input),
-        output,
-        numberOfValues,
-        inputIncrement,
-        outputFormat,
-        1));
+        static_cast<VTK_TT*>(input), output, numberOfValues, inputIncrement, outputFormat, 1));
 
       default:
         vtkErrorMacro(<< "MapImageThroughTable: Unknown input ScalarType");
@@ -1784,13 +1810,8 @@ void vtkColorTransferFunction::MapScalarsThroughTable2(void* input,
   {
     switch (inputDataType)
     {
-      vtkTemplateMacro(vtkColorTransferFunctionMapData(this,
-        static_cast<VTK_TT*>(input),
-        output,
-        numberOfValues,
-        inputIncrement,
-        outputFormat,
-        1));
+      vtkTemplateMacro(vtkColorTransferFunctionMapData(this, static_cast<VTK_TT*>(input), output,
+        numberOfValues, inputIncrement, outputFormat, 1));
       default:
         vtkErrorMacro(<< "MapImageThroughTable: Unknown input ScalarType");
         return;
@@ -1798,7 +1819,7 @@ void vtkColorTransferFunction::MapScalarsThroughTable2(void* input,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkColorTransferFunction::GetNumberOfAvailableColors()
 {
   if (this->IndexedLookup && this->GetSize())
@@ -1815,7 +1836,7 @@ vtkIdType vtkColorTransferFunction::GetNumberOfAvailableColors()
   return 16777216; // 2^24
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::GetIndexedColor(vtkIdType idx, double rgba[4])
 {
   vtkIdType n = this->GetSize();
@@ -1834,7 +1855,7 @@ void vtkColorTransferFunction::GetIndexedColor(vtkIdType idx, double rgba[4])
   rgba[3] = this->GetNanOpacity();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::FillFromDataPointer(int nb, double* ptr)
 {
   if (nb <= 0 || !ptr)
@@ -1852,7 +1873,7 @@ void vtkColorTransferFunction::FillFromDataPointer(int nb, double* ptr)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkColorTransferFunction::AdjustRange(double range[2])
 {
   if (!range)
@@ -1899,8 +1920,7 @@ int vtkColorTransferFunction::AdjustRange(double range[2])
     this->Internal->FindNodeOutOfRange.X2 = range[1];
 
     std::vector<vtkCTFNode*>::iterator iter = std::find_if(this->Internal->Nodes.begin(),
-      this->Internal->Nodes.end(),
-      this->Internal->FindNodeOutOfRange);
+      this->Internal->Nodes.end(), this->Internal->FindNodeOutOfRange);
 
     if (iter != this->Internal->Nodes.end())
     {
@@ -1916,7 +1936,7 @@ int vtkColorTransferFunction::AdjustRange(double range[2])
   return 1;
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkColorTransferFunction::EstimateMinNumberOfSamples(double const& x1, double const& x2)
 {
   double const d = this->FindMinimumXDistance();
@@ -1925,7 +1945,7 @@ int vtkColorTransferFunction::EstimateMinNumberOfSamples(double const& x1, doubl
   return idealWidth;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkColorTransferFunction::FindMinimumXDistance()
 {
   std::vector<vtkCTFNode*> const& nodes = this->Internal->Nodes;
@@ -1946,7 +1966,7 @@ double vtkColorTransferFunction::FindMinimumXDistance()
   return distance;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Print method for vtkColorTransferFunction
 void vtkColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -2015,3 +2035,4 @@ void vtkColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
        << " Midpoint: " << this->Internal->Nodes[i]->Midpoint << endl;
   }
 }
+VTK_ABI_NAMESPACE_END
