@@ -24,6 +24,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkPolyData.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCompositeDataDisplayAttributes);
 
 vtkCompositeDataDisplayAttributes::vtkCompositeDataDisplayAttributes() = default;
@@ -323,7 +324,7 @@ void vtkCompositeDataDisplayAttributes::ComputeVisibleBoundsInternal(
         cda, child, bbox, blockVisible);
     }
   }
-  else if (dobj && blockVisible == true)
+  else if (dobj && blockVisible)
   {
     vtkDataSet* ds = vtkDataSet::SafeDownCast(dobj);
     vtkPolyData* pd = vtkPolyData::SafeDownCast(ds);
@@ -371,3 +372,4 @@ vtkDataObject* vtkCompositeDataDisplayAttributes::DataObjectFromIndex(
   }
   return nullptr;
 }
+VTK_ABI_NAMESPACE_END
