@@ -14,7 +14,8 @@
 =========================================================================*/
 /**
  * @class   vtkCoordinate
- * @brief   perform coordinate transformation, and represent position, in a variety of vtk coordinate systems
+ * @brief   perform coordinate transformation, and represent position, in a variety of vtk
+ * coordinate systems
  *
  * vtkCoordinate represents position in a variety of coordinate systems, and
  * converts position to other coordinate systems. It also supports relative
@@ -39,7 +40,9 @@
  *   NORMALIZED VIEWPORT - x-y (0,1) normalized value in viewport
  *      0, 0 is the lower left of the first pixel,
  *      1, 1 is the upper right of the last pixel
- *   VIEW -                x-y-z (-1,1) values in camera coordinates. (z is depth)
+ *   VIEW -                x-y-z (-1,1) values in pose coordinates. (z is depth)
+ *   POSE -                world coords translated and rotated to the camera
+ *                         position and view direction
  *   WORLD -               x-y-z global coordinate values
  *   USERDEFINED -         x-y-z in User defined space
  * </PRE>
@@ -52,36 +55,38 @@
  *
  * @sa
  * vtkActor2D vtkScalarBarActor
-*/
+ */
 
 #ifndef vtkCoordinate_h
 #define vtkCoordinate_h
 
-#include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkObject.h"
+#include "vtkRenderingCoreModule.h" // For export macro
+VTK_ABI_NAMESPACE_BEGIN
 class vtkViewport;
 
-#define VTK_DISPLAY             0
-#define VTK_NORMALIZED_DISPLAY  1
-#define VTK_VIEWPORT            2
+#define VTK_DISPLAY 0
+#define VTK_NORMALIZED_DISPLAY 1
+#define VTK_VIEWPORT 2
 #define VTK_NORMALIZED_VIEWPORT 3
-#define VTK_VIEW                4
-#define VTK_WORLD               5
-#define VTK_USERDEFINED         6
+#define VTK_VIEW 4
+#define VTK_POSE 5
+#define VTK_WORLD 6
+#define VTK_USERDEFINED 7
 
 class VTKRENDERINGCORE_EXPORT vtkCoordinate : public vtkObject
 {
 public:
   vtkTypeMacro(vtkCoordinate, vtkObject);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Creates an instance of this class with the following defaults:
-   * value of  (0,0,0) in world  coordinates.
+   * value of  (0,0,0) in world coordinates.
    */
   static vtkCoordinate* New();
 
-  //@{
+  ///@{
   /**
    * Set/get the coordinate system which this coordinate
    * is defined in. The options are Display, Normalized Display,
@@ -89,34 +94,34 @@ public:
    */
   vtkSetMacro(CoordinateSystem, int);
   vtkGetMacro(CoordinateSystem, int);
-  void SetCoordinateSystemToDisplay()
-    { this->SetCoordinateSystem(VTK_DISPLAY); }
+  void SetCoordinateSystemToDisplay() { this->SetCoordinateSystem(VTK_DISPLAY); }
   void SetCoordinateSystemToNormalizedDisplay()
-    { this->SetCoordinateSystem(VTK_NORMALIZED_DISPLAY); }
-  void SetCoordinateSystemToViewport()
-    { this->SetCoordinateSystem(VTK_VIEWPORT); }
+  {
+    this->SetCoordinateSystem(VTK_NORMALIZED_DISPLAY);
+  }
+  void SetCoordinateSystemToViewport() { this->SetCoordinateSystem(VTK_VIEWPORT); }
   void SetCoordinateSystemToNormalizedViewport()
-    { this->SetCoordinateSystem(VTK_NORMALIZED_VIEWPORT); }
-  void SetCoordinateSystemToView()
-    { this->SetCoordinateSystem(VTK_VIEW); }
-  void SetCoordinateSystemToWorld()
-    { this->SetCoordinateSystem(VTK_WORLD); }
-  //@}
+  {
+    this->SetCoordinateSystem(VTK_NORMALIZED_VIEWPORT);
+  }
+  void SetCoordinateSystemToView() { this->SetCoordinateSystem(VTK_VIEW); }
+  void SetCoordinateSystemToPose() { this->SetCoordinateSystem(VTK_POSE); }
+  void SetCoordinateSystemToWorld() { this->SetCoordinateSystem(VTK_WORLD); }
+  ///@}
 
-  const char *GetCoordinateSystemAsString ();
+  const char* GetCoordinateSystemAsString();
 
-  //@{
+  ///@{
   /**
    * Set/get the value of this coordinate. This can be thought of as
    * the position of this coordinate in its coordinate system.
    */
   vtkSetVector3Macro(Value, double);
   vtkGetVector3Macro(Value, double);
-  void SetValue(double a, double b)
-    { this->SetValue(a, b, 0.0); }
-  //@}
+  void SetValue(double a, double b) { this->SetValue(a, b, 0.0); }
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If this coordinate is relative to another coordinate,
    * then specify that coordinate as the ReferenceCoordinate.
@@ -124,9 +129,9 @@ public:
    */
   virtual void SetReferenceCoordinate(vtkCoordinate*);
   vtkGetObjectMacro(ReferenceCoordinate, vtkCoordinate);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If you want this coordinate to be relative to a specific
    * vtkViewport (vtkRenderer) then you can specify that here.
@@ -134,30 +139,30 @@ public:
    * object, to avoid reference cycle loop between rendering classes and filter
    * classes.
    */
-  void SetViewport(vtkViewport *viewport);
+  void SetViewport(vtkViewport* viewport);
   vtkGetObjectMacro(Viewport, vtkViewport);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return the computed value in a specified coordinate system.
    */
-  double *GetComputedWorldValue(vtkViewport *);
-  int *GetComputedViewportValue(vtkViewport *);
-  int *GetComputedDisplayValue(vtkViewport *);
-  int *GetComputedLocalDisplayValue(vtkViewport *);
-  //@}
+  double* GetComputedWorldValue(vtkViewport*) VTK_SIZEHINT(3);
+  int* GetComputedViewportValue(vtkViewport*) VTK_SIZEHINT(2);
+  int* GetComputedDisplayValue(vtkViewport*) VTK_SIZEHINT(2);
+  int* GetComputedLocalDisplayValue(vtkViewport*) VTK_SIZEHINT(2);
+  ///@}
 
-  double *GetComputedDoubleViewportValue(vtkViewport *);
-  double *GetComputedDoubleDisplayValue(vtkViewport *);
+  double* GetComputedDoubleViewportValue(vtkViewport*) VTK_SIZEHINT(2);
+  double* GetComputedDoubleDisplayValue(vtkViewport*) VTK_SIZEHINT(2);
 
   /**
    * GetComputedValue() will return either World, Viewport or
    * Display based on what has been set as the coordinate system.
    * This is good for objects like vtkLineSource, where the
-   * user might want to use them as World or Viewport coordinates
+   * user might want to use them as World or Viewport coordinates.
    */
-  double *GetComputedValue(vtkViewport *);
+  double* GetComputedValue(vtkViewport*) VTK_SIZEHINT(3);
 
   /**
    * GetComputedUserDefinedValue() is to be used only when
@@ -166,17 +171,16 @@ public:
    * when set as the TransformCoordinate in 2D-Mappers, the user
    * can customize display of 2D polygons
    */
-  virtual double *GetComputedUserDefinedValue(vtkViewport *)
-    { return this->Value; }
+  virtual double* GetComputedUserDefinedValue(vtkViewport*) VTK_SIZEHINT(3) { return this->Value; }
 
 protected:
   vtkCoordinate();
-  ~vtkCoordinate() VTK_OVERRIDE;
+  ~vtkCoordinate() override;
 
   double Value[3];
   int CoordinateSystem;
-  vtkCoordinate *ReferenceCoordinate;
-  vtkViewport *Viewport;
+  vtkCoordinate* ReferenceCoordinate;
+  vtkViewport* Viewport;
   double ComputedWorldValue[3];
   int ComputedDisplayValue[2];
   int ComputedViewportValue[2];
@@ -187,8 +191,9 @@ protected:
   double ComputedUserDefinedValue[3];
 
 private:
-  vtkCoordinate(const vtkCoordinate&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkCoordinate&) VTK_DELETE_FUNCTION;
+  vtkCoordinate(const vtkCoordinate&) = delete;
+  void operator=(const vtkCoordinate&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
