@@ -14,6 +14,7 @@
 =========================================================================*/
 #include "vtkCuller.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCuller::vtkCuller() = default;
 
 vtkCuller::~vtkCuller() = default;
@@ -23,3 +24,4 @@ void vtkCuller::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
