@@ -16,6 +16,7 @@
 #include "vtkFollower.h"
 
 #include "vtkCamera.h"
+#include "vtkInformation.h"
 #include "vtkMath.h"
 #include "vtkMatrix4x4.h"
 #include "vtkObjectFactory.h"
@@ -26,6 +27,7 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFollower);
 
 vtkCxxSetObjectMacro(vtkFollower, Camera, vtkCamera);
@@ -172,18 +174,7 @@ void vtkFollower::PrintSelf(ostream& os, vtkIndent indent)
 //------------------------------------------------------------------------------
 int vtkFollower::RenderOpaqueGeometry(vtkViewport* vp)
 {
-  if (!this->Mapper)
-  {
-    return 0;
-  }
-
-  if (!this->Property)
-  {
-    // force creation of a property
-    this->GetProperty();
-  }
-
-  if (this->GetIsOpaque())
+  if (this->HasOpaqueGeometry())
   {
     vtkRenderer* ren = static_cast<vtkRenderer*>(vp);
     this->Render(ren);
@@ -195,21 +186,14 @@ int vtkFollower::RenderOpaqueGeometry(vtkViewport* vp)
 //------------------------------------------------------------------------------
 int vtkFollower::RenderTranslucentPolygonalGeometry(vtkViewport* vp)
 {
-  if (!this->Mapper)
-  {
-    return 0;
-  }
-
-  if (!this->Property)
-  {
-    // force creation of a property
-    this->GetProperty();
-  }
-
-  if (!this->GetIsOpaque())
+  if (this->HasTranslucentPolygonalGeometry())
   {
     vtkRenderer* ren = static_cast<vtkRenderer*>(vp);
+
+    // Needed as we don't call this->Device->RenderTranslucentPolygonalGeometry
+    this->Device->SetIsRenderingTranslucentPolygonalGeometry(true);
     this->Render(ren);
+    this->Device->SetIsRenderingTranslucentPolygonalGeometry(false);
     return 1;
   }
   return 0;
@@ -222,56 +206,63 @@ void vtkFollower::ReleaseGraphicsResources(vtkWindow* w)
   this->Superclass::ReleaseGraphicsResources(w);
 }
 
-//------------------------------------------------------------------------------
-// Description:
-// Does this prop have some translucent polygonal geometry?
-vtkTypeBool vtkFollower::HasTranslucentPolygonalGeometry()
-{
-  if (!this->Mapper)
-  {
-    return 0;
-  }
-  // make sure we have a property
-  if (!this->Property)
-  {
-    // force creation of a property
-    this->GetProperty();
-  }
-
-  // is this actor opaque ?
-  return !this->GetIsOpaque();
-}
-
 //------------------------------------------------------------------------------
 // This causes the actor to be rendered. It, in turn, will render the actor's
 // property and then mapper.
 void vtkFollower::Render(vtkRenderer* ren)
 {
+  // Pre render actions
   this->Property->Render(this, ren);
-
   this->Device->SetProperty(this->Property);
-  this->Property->Render(this, ren);
   if (this->BackfaceProperty)
   {
     this->BackfaceProperty->BackfaceRender(this, ren);
     this->Device->SetBackfaceProperty(this->BackfaceProperty);
   }
-
-  /* render the texture */
   if (this->Texture)
   {
     this->Texture->Render(ren);
+    if (this->Texture->GetTransform())
+    {
+      vtkInformation* info = this->GetPropertyKeys();
+      if (!info)
+      {
+        info = vtkInformation::New();
+        this->SetPropertyKeys(info);
+        info->Delete();
+      }
+      info->Set(vtkProp::GeneralTextureTransform(),
+        &(this->Texture->GetTransform()->GetMatrix()->Element[0][0]), 16);
+    }
   }
   this->Device->SetTexture(this->GetTexture());
-
-  // make sure the device has the same matrix
-  this->ComputeMatrix();
-  this->Device->SetUserMatrix(this->Matrix);
   if (this->GetPropertyKeys())
   {
     this->Device->SetPropertyKeys(this->GetPropertyKeys());
   }
+  // make sure the device has the same matrix
+  this->ComputeMatrix();
+  this->Device->SetUserMatrix(this->Matrix);
+
+  // Render
   this->Device->Render(ren, this->Mapper);
+
+  // Post render actions
+  this->Property->PostRender(this, ren);
+  if (this->BackfaceProperty)
+  {
+    this->BackfaceProperty->PostRender(this, ren);
+  }
+  if (this->Texture)
+  {
+    this->Texture->PostRender(ren);
+    if (this->Texture->GetTransform())
+    {
+      vtkInformation* info = this->GetPropertyKeys();
+      info->Remove(vtkProp::GeneralTextureTransform());
+    }
+  }
+  this->EstimatedRenderTime = this->Device->GetEstimatedRenderTime();
 }
 
 //------------------------------------------------------------------------------
@@ -286,3 +277,4 @@ void vtkFollower::ShallowCopy(vtkProp* prop)
   // Now do superclass
   this->vtkActor::ShallowCopy(prop);
 }
+VTK_ABI_NAMESPACE_END
