@@ -23,6 +23,7 @@
 #include "vtkObject.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGCORE_EXPORT vtkGraphicsFactory : public vtkObject
 {
 public:
@@ -43,23 +44,23 @@ public:
    */
   static const char* GetRenderLibrary();
 
-  //@{
+  ///@{
   /**
    * This option enables the creation of Mesa classes
    * instead of the OpenGL classes when using mangled Mesa.
    */
   static void SetUseMesaClasses(int use);
   static int GetUseMesaClasses();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This option enables the off-screen only mode. In this mode no X calls will
    * be made even when interactor is used.
    */
   static void SetOffScreenOnlyMode(int use);
   static int GetOffScreenOnlyMode();
-  //@}
+  ///@}
 
 protected:
   vtkGraphicsFactory() = default;
@@ -72,4 +73,5 @@ private:
   void operator=(const vtkGraphicsFactory&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
