@@ -75,7 +75,7 @@
  * NOTE: This class has a complex interaction with parallel compositing
  * techniques such as IceT that are used on supercomputers. In those
  * cases the local nodes render each pass, process it, send it to icet
- * which composits it, and then must copy the result back to the hardware
+ * which composites it, and then must copy the result back to the hardware
  * selector. Be aware of these interactions  if you work on this class.
  *
  * NOTE: many mappers support remapping arrays from their local value to
@@ -114,6 +114,7 @@
 
 #include <string> // for std::string
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkRenderer;
 class vtkRenderWindow;
 class vtkSelection;
@@ -123,7 +124,7 @@ class vtkTextureObject;
 class VTKRENDERINGCORE_EXPORT vtkHardwareSelector : public vtkObject
 {
 public:
-  //@{
+  ///@{
   /**
    * Struct used to return information about a pixel location.
    */
@@ -145,30 +146,30 @@ public:
     {
     }
   };
-  //@}
+  ///@}
 
 public:
   static vtkHardwareSelector* New();
   vtkTypeMacro(vtkHardwareSelector, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the renderer to perform the selection on.
    */
   virtual void SetRenderer(vtkRenderer*);
   vtkGetObjectMacro(Renderer, vtkRenderer);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the area to select as (xmin, ymin, xmax, ymax).
    */
   vtkSetVector4Macro(Area, unsigned int);
   vtkGetVector4Macro(Area, unsigned int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the field type to select. Valid values are
    * \li vtkDataObject::FIELD_ASSOCIATION_POINTS
@@ -181,9 +182,9 @@ public:
    */
   vtkSetMacro(FieldAssociation, int);
   vtkGetMacro(FieldAssociation, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * In some parallel rendering setups, the process id for elements must be
    * obtained from the data itself, rather than the rendering process' id. In
@@ -191,15 +192,15 @@ public:
    */
   vtkSetMacro(UseProcessIdFromData, bool);
   vtkGetMacro(UseProcessIdFromData, bool);
-  //@}
+  ///@}
 
   /**
    * Perform the selection. Returns a new instance of vtkSelection containing
    * the selection on success.
    */
-  vtkSelection* Select();
+  VTK_NEWINSTANCE vtkSelection* Select();
 
-  //@{
+  ///@{
   /**
    * It is possible to use the vtkHardwareSelector for a custom picking. (Look
    * at vtkScenePicker). In that case instead of Select() on can use
@@ -223,13 +224,13 @@ public:
     unsigned int temp[2];
     return this->GetPixelInformation(display_position, maxDist, temp);
   }
-  PixelInformation GetPixelInformation(
+  virtual PixelInformation GetPixelInformation(
     const unsigned int display_position[2], int maxDist, unsigned int selected_position[2]);
   void ClearBuffers() { this->ReleasePixBuffers(); }
   // raw is before processing
   unsigned char* GetRawPixelBuffer(int passNo) { return this->RawPixBuffer[passNo]; }
   unsigned char* GetPixelBuffer(int passNo) { return this->PixBuffer[passNo]; }
-  //@}
+  ///@}
 
   /**
    * Called by any vtkMapper or vtkProp subclass to render a composite-index.
@@ -237,7 +238,7 @@ public:
    */
   virtual void RenderCompositeIndex(unsigned int index);
 
-  //@{
+  ///@{
   /**
    * Called by any vtkMapper or vtkProp subclass to indicate the
    * maximum cell or point attribute ID it uses. These values are
@@ -246,7 +247,7 @@ public:
    */
   virtual void UpdateMaximumCellId(vtkIdType attribid);
   virtual void UpdateMaximumPointId(vtkIdType attribid);
-  //@}
+  ///@}
 
   /**
    * Called by any vtkMapper or subclass to render process id. This has any
@@ -260,16 +261,16 @@ public:
    */
   int Render(vtkRenderer* renderer, vtkProp** propArray, int propArrayCount);
 
-  //@{
+  ///@{
   /**
    * Get/Set to only do the actor pass. If true all other passes will be
    * skipped resulting in a faster pick.
    */
   vtkGetMacro(ActorPassOnly, bool);
   vtkSetMacro(ActorPassOnly, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set to capture the zvalue. If true the closest zvalue is
    * stored for each prop that is in the selection. ZValue in this
@@ -278,40 +279,40 @@ public:
    */
   vtkGetMacro(CaptureZValues, bool);
   vtkSetMacro(CaptureZValues, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Called by the mapper before and after rendering each prop.
    */
   virtual void BeginRenderProp();
   virtual void EndRenderProp();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the process id. If process id < 0 (default -1), then the
    * PROCESS_PASS is not rendered.
    */
   vtkSetMacro(ProcessID, int);
   vtkGetMacro(ProcessID, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the color to be used by the prop when drawing
    */
   vtkGetVector3Macro(PropColorValue, float);
   vtkSetVector3Macro(PropColorValue, float);
   void SetPropColorValue(vtkIdType val);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the current pass number.
    */
   vtkGetMacro(CurrentPass, int);
-  //@}
+  ///@}
 
   /**
    * Generates the vtkSelection from pixel buffers.
@@ -432,7 +433,7 @@ protected:
     return val;
   }
 
-  //@{
+  ///@{
   /**
    * \c pos must be relative to the lower-left corner of this->Area.
    */
@@ -456,7 +457,7 @@ protected:
     val |= rgb[0];
     return val;
   }
-  //@}
+  ///@}
 
   vtkIdType GetID(int low24, int mid24, int high16)
   {
@@ -492,7 +493,7 @@ protected:
   virtual void ProcessPixelBuffers();
   void BuildPropHitList(unsigned char* rgbData);
 
-  //@{
+  ///@{
   /**
    * Clears all pixel buffers.
    */
@@ -503,7 +504,7 @@ protected:
   bool UseProcessIdFromData;
   vtkIdType MaximumPointId;
   vtkIdType MaximumCellId;
-  //@}
+  ///@}
 
   // At most 10 passes.
   unsigned char* PixBuffer[10];
@@ -527,4 +528,5 @@ private:
   vtkInternals* Internals;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
