@@ -14,52 +14,51 @@
 =========================================================================*/
 #include "vtkLookupTableWithEnabling.h"
 #include "vtkBitArray.h"
-#include "vtkObjectFactory.h"
 #include "vtkMath.h"
+#include "vtkObjectFactory.h"
 #include "vtkVariant.h"
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkLookupTableWithEnabling);
 
-vtkCxxSetObjectMacro(vtkLookupTableWithEnabling,EnabledArray,vtkDataArray);
+vtkCxxSetObjectMacro(vtkLookupTableWithEnabling, EnabledArray, vtkDataArray);
 
 // Construct with range=(0,1); and hsv ranges set up for rainbow color table
 // (from red to blue).
-vtkLookupTableWithEnabling::vtkLookupTableWithEnabling(int sze, int ext) :
-  vtkLookupTable(sze, ext)
+vtkLookupTableWithEnabling::vtkLookupTableWithEnabling(int sze, int ext)
+  : vtkLookupTable(sze, ext)
 {
   this->EnabledArray = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLookupTableWithEnabling::~vtkLookupTableWithEnabling()
 {
-  if(this->EnabledArray)
+  if (this->EnabledArray)
   {
     this->EnabledArray->Delete();
     this->EnabledArray = nullptr;
   }
 }
 
-void vtkLookupTableWithEnabling::DisableColor(
-          unsigned char r, unsigned char g, unsigned char b,
-          unsigned char *rd, unsigned char *gd, unsigned char *bd)
+void vtkLookupTableWithEnabling::DisableColor(unsigned char r, unsigned char g, unsigned char b,
+  unsigned char* rd, unsigned char* gd, unsigned char* bd)
 {
   double rgb[3], hsv[3];
   rgb[0] = static_cast<double>(r);
   rgb[1] = static_cast<double>(g);
   rgb[2] = static_cast<double>(b);
-  vtkMath::RGBToHSV(rgb,hsv);
+  vtkMath::RGBToHSV(rgb, hsv);
   hsv[1] = 0;
   hsv[2] = 0;
-  vtkMath::HSVToRGB(hsv,rgb);
+  vtkMath::HSVToRGB(hsv, rgb);
   *rd = static_cast<unsigned char>(rgb[0]);
   *gd = static_cast<unsigned char>(rgb[1]);
   *bd = static_cast<unsigned char>(rgb[2]);
 }
 
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // There is a little more to this than simply taking the log10 of the
 // two range values: we do conversion of negative ranges to positive
 // ranges, and conversion of zero to a 'very small number'
@@ -70,7 +69,7 @@ static void vtkLookupTableWithEnablingLogRange(double range[2], double logRange[
 
   if (rmin == 0)
   {
-    rmin = 1.0e-6*(rmax - rmin);
+    rmin = 1.0e-6 * (rmax - rmin);
     if (rmax < 0)
     {
       rmin = -rmin;
@@ -78,7 +77,7 @@ static void vtkLookupTableWithEnablingLogRange(double range[2], double logRange[
   }
   if (rmax == 0)
   {
-    rmax = 1.0e-6*(rmin - rmax);
+    rmax = 1.0e-6 * (rmin - rmax);
     if (rmin < 0)
     {
       rmax = -rmax;
@@ -101,10 +100,9 @@ static void vtkLookupTableWithEnablingLogRange(double range[2], double logRange[
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Apply log to value, with appropriate constraints.
-inline double vtkApplyLogScale(double v, double range[2],
-                               double logRange[2])
+inline double vtkApplyLogScale(double v, double range[2], double logRange[2])
 {
   // is the range set for negative numbers?
   if (range[0] < 0)
@@ -140,14 +138,12 @@ inline double vtkApplyLogScale(double v, double range[2],
   return v;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Apply shift/scale to the scalar value v and do table lookup.
-inline unsigned char *vtkLinearLookup(double v,
-                                      unsigned char *table,
-                                      double maxIndex,
-                                      double shift, double scale)
+inline unsigned char* vtkLinearLookup(
+  double v, unsigned char* table, double maxIndex, double shift, double scale)
 {
-  double findx = (v + shift)*scale;
+  double findx = (v + shift) * scale;
   if (findx < 0)
   {
     findx = 0;
@@ -156,37 +152,35 @@ inline unsigned char *vtkLinearLookup(double v,
   {
     findx = maxIndex;
   }
-  return &table[4*static_cast<int>(findx)];
+  return &table[4 * static_cast<int>(findx)];
   /* round
   return &table[4*(int)(findx + 0.5f)];
   */
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // accelerate the mapping by copying the data in 32-bit chunks instead
 // of 8-bit chunks
-template<class T>
-void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *input,
-                           unsigned char *output, int length,
-                           int inIncr, int outFormat)
+template <class T>
+void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling* self, T* input,
+  unsigned char* output, int length, int inIncr, int outFormat)
 {
   int i = length;
-  double *range = self->GetTableRange();
+  double* range = self->GetTableRange();
   double maxIndex = self->GetNumberOfColors() - 1;
   double shift, scale;
-  unsigned char *table = self->GetPointer(0);
-  unsigned char *cptr;
+  unsigned char* table = self->GetPointer(0);
+  unsigned char* cptr;
   double alpha;
   unsigned char r, g, b;
 
   bool hasEnabledArray = false;
-  if(self->GetEnabledArray() &&
-     self->GetEnabledArray()->GetNumberOfTuples() == length)
+  if (self->GetEnabledArray() && self->GetEnabledArray()->GetNumberOfTuples() == length)
   {
     hasEnabledArray = true;
   }
 
-  if ( (alpha=self->GetAlpha()) >= 1.0 ) //no blending required
+  if ((alpha = self->GetAlpha()) >= 1.0) // no blending required
   {
     if (self->GetScale() == VTK_SCALE_LOG10)
     {
@@ -202,7 +196,7 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
       {
         /* while this looks like the wrong scale, it is the correct scale
          * taking into account the truncation to int that happens below. */
-        scale = (maxIndex + 1)/(logRange[1] - logRange[0]);
+        scale = (maxIndex + 1) / (logRange[1] - logRange[0]);
       }
       if (outFormat == VTK_RGBA)
       {
@@ -210,14 +204,13 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-            !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
-            cptr+=3;
+            cptr += 3;
           }
           else
           {
@@ -235,10 +228,9 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-             !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
@@ -258,8 +250,8 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
           *output++ = cptr[3];
           input += inIncr;
         }
@@ -270,14 +262,14 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
           input += inIncr;
         }
       }
-    }//if log scale
+    } // if log scale
 
-    else //not log scale
+    else // not log scale
     {
       shift = -range[0];
       if (range[1] <= range[0])
@@ -288,7 +280,7 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
       {
         /* while this looks like the wrong scale, it is the correct scale
          * taking into account the truncation to int that happens below. */
-        scale = (maxIndex + 1)/(range[1] - range[0]);
+        scale = (maxIndex + 1) / (range[1] - range[0]);
       }
 
       if (outFormat == VTK_RGBA)
@@ -296,15 +288,15 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-            !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
-            cptr+=3;
-            *output++ = static_cast<unsigned char>((*cptr)*0.2); cptr++;
+            cptr += 3;
+            *output++ = static_cast<unsigned char>((*cptr) * 0.2);
+            cptr++;
           }
           else
           {
@@ -321,10 +313,9 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-             !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
@@ -343,8 +334,8 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
           *output++ = cptr[3];
           input += inIncr;
         }
@@ -354,15 +345,15 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
           input += inIncr;
         }
       }
-    }//if not log lookup
-  }//if blending not needed
+    } // if not log lookup
+  }   // if blending not needed
 
-  else //blend with the specified alpha
+  else // blend with the specified alpha
   {
     if (self->GetScale() == VTK_SCALE_LOG10)
     {
@@ -378,7 +369,7 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
       {
         /* while this looks like the wrong scale, it is the correct scale
          * taking into account the truncation to int that happens below. */
-        scale = (maxIndex + 1)/(logRange[1] - logRange[0]);
+        scale = (maxIndex + 1) / (logRange[1] - logRange[0]);
       }
       if (outFormat == VTK_RGBA)
       {
@@ -386,14 +377,13 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-             !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
-            cptr+=3;
+            cptr += 3;
           }
           else
           {
@@ -401,7 +391,8 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
             *output++ = *cptr++;
             *output++ = *cptr++;
           }
-          *output++ = static_cast<unsigned char>((*cptr)*alpha); cptr++;
+          *output++ = static_cast<unsigned char>((*cptr) * alpha);
+          cptr++;
           input += inIncr;
         }
       }
@@ -411,10 +402,9 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-             !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
@@ -434,9 +424,9 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
-          *output++ = static_cast<unsigned char>(alpha*cptr[3]);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
+          *output++ = static_cast<unsigned char>(alpha * cptr[3]);
           input += inIncr;
         }
       }
@@ -446,14 +436,14 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         {
           val = vtkApplyLogScale(*input, range, logRange);
           cptr = vtkLinearLookup(val, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
           input += inIncr;
         }
       }
-    }//log scale with blending
+    } // log scale with blending
 
-    else //no log scale with blending
+    else // no log scale with blending
     {
       shift = -range[0];
       if (range[1] <= range[0])
@@ -464,7 +454,7 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
       {
         /* while this looks like the wrong scale, it is the correct scale
          * taking into account the truncation to int that happens below. */
-        scale = (maxIndex + 1)/(range[1] - range[0]);
+        scale = (maxIndex + 1) / (range[1] - range[0]);
       }
 
       if (outFormat == VTK_RGBA)
@@ -472,28 +462,29 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-             !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
-            cptr+=3;
-            *output++ = static_cast<unsigned char>((*cptr)*alpha*0.2); cptr++;
+            cptr += 3;
+            *output++ = static_cast<unsigned char>((*cptr) * alpha * 0.2);
+            cptr++;
           }
           else
           {
             *output++ = *cptr++;
             *output++ = *cptr++;
             *output++ = *cptr++;
-            if(hasEnabledArray)
+            if (hasEnabledArray)
             {
               *output++ = *cptr++;
             }
             else
             {
-              *output++ = static_cast<unsigned char>((*cptr)*alpha); cptr++;
+              *output++ = static_cast<unsigned char>((*cptr) * alpha);
+              cptr++;
             }
           }
           input += inIncr;
@@ -504,10 +495,9 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          if(hasEnabledArray &&
-             !self->GetEnabledArray()->GetTuple1(length-i-1))
+          if (hasEnabledArray && !self->GetEnabledArray()->GetTuple1(length - i - 1))
           {
-            self->DisableColor(cptr[0],cptr[1],cptr[2],&r,&g,&b);
+            self->DisableColor(cptr[0], cptr[1], cptr[2], &r, &g, &b);
             *output++ = r;
             *output++ = g;
             *output++ = b;
@@ -526,9 +516,9 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
-          *output++ = static_cast<unsigned char>(cptr[3]*alpha);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
+          *output++ = static_cast<unsigned char>(cptr[3] * alpha);
           input += inIncr;
         }
       }
@@ -537,62 +527,54 @@ void vtkLookupTableWithEnablingMapData(vtkLookupTableWithEnabling *self, T *inpu
         while (--i >= 0)
         {
           cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale);
-          *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                                                 cptr[2]*0.11 + 0.5);
+          *output++ =
+            static_cast<unsigned char>(cptr[0] * 0.30 + cptr[1] * 0.59 + cptr[2] * 0.11 + 0.5);
           input += inIncr;
         }
       }
-    }//no log scale
-  }//alpha blending
+    } // no log scale
+  }   // alpha blending
 }
 
-//----------------------------------------------------------------------------
-void vtkLookupTableWithEnabling::MapScalarsThroughTable2(void *input,
-                                             unsigned char *output,
-                                             int inputDataType,
-                                             int numberOfValues,
-                                             int inputIncrement,
-                                             int outputFormat)
+//------------------------------------------------------------------------------
+void vtkLookupTableWithEnabling::MapScalarsThroughTable2(void* input, unsigned char* output,
+  int inputDataType, int numberOfValues, int inputIncrement, int outputFormat)
 {
   switch (inputDataType)
   {
     case VTK_BIT:
     {
       vtkIdType i, id;
-      vtkBitArray *bitArray = vtkBitArray::New();
-      bitArray->SetVoidArray(input,numberOfValues,1);
-      vtkUnsignedCharArray *newInput = vtkUnsignedCharArray::New();
+      vtkBitArray* bitArray = vtkBitArray::New();
+      bitArray->SetVoidArray(input, numberOfValues, 1);
+      vtkUnsignedCharArray* newInput = vtkUnsignedCharArray::New();
       newInput->SetNumberOfValues(numberOfValues);
-      for (id=i=0; i<numberOfValues; i++, id+=inputIncrement)
+      for (id = i = 0; i < numberOfValues; i++, id += inputIncrement)
       {
         newInput->SetValue(i, bitArray->GetValue(id));
       }
-      vtkLookupTableWithEnablingMapData(this,
-                            static_cast<unsigned char*>(newInput->GetPointer(0)),
-                            output,numberOfValues,
-                            inputIncrement,outputFormat);
+      vtkLookupTableWithEnablingMapData(this, static_cast<unsigned char*>(newInput->GetPointer(0)),
+        output, numberOfValues, inputIncrement, outputFormat);
       newInput->Delete();
       bitArray->Delete();
     }
-      break;
+    break;
 
-    vtkTemplateMacro(
-      vtkLookupTableWithEnablingMapData(this,static_cast<VTK_TT*>(input),output,
-                            numberOfValues,inputIncrement,outputFormat)
-      );
+      vtkTemplateMacro(vtkLookupTableWithEnablingMapData(
+        this, static_cast<VTK_TT*>(input), output, numberOfValues, inputIncrement, outputFormat));
     default:
       vtkErrorMacro(<< "MapImageThroughTable: Unknown input ScalarType");
       return;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLookupTableWithEnabling::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "EnabledArray: ";
-  if( this->EnabledArray )
+  if (this->EnabledArray)
   {
     this->EnabledArray->PrintSelf(os << "\n", indent.GetNextIndent());
   }
@@ -602,3 +584,4 @@ void vtkLookupTableWithEnabling::PrintSelf(ostream& os, vtkIndent indent)
     os << "(none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
