@@ -65,6 +65,7 @@
 #define VTK_MATERIALMODE_DIFFUSE 2
 #define VTK_MATERIALMODE_AMBIENT_AND_DIFFUSE 3
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkDataSet;
 class vtkDataObject;
@@ -108,13 +109,13 @@ public:
    */
   void ReleaseGraphicsResources(vtkWindow*) override {}
 
-  //@{
+  ///@{
   /**
    * Specify a lookup table for the mapper to use.
    */
   void SetLookupTable(vtkScalarsToColors* lut);
   vtkScalarsToColors* GetLookupTable();
-  //@}
+  ///@}
 
   /**
    * Create default lookup table. Generally used to create one when none
@@ -122,16 +123,16 @@ public:
    */
   virtual void CreateDefaultLookupTable();
 
-  //@{
+  ///@{
   /**
    * Turn on/off flag to control whether scalar data is used to color objects.
    */
   vtkSetMacro(ScalarVisibility, vtkTypeBool);
   vtkGetMacro(ScalarVisibility, vtkTypeBool);
   vtkBooleanMacro(ScalarVisibility, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off flag to control whether the mapper's data is static. Static data
    * means that the mapper does not propagate updates down the pipeline, greatly
@@ -141,9 +142,9 @@ public:
   vtkSetMacro(Static, vtkTypeBool);
   vtkGetMacro(Static, vtkTypeBool);
   vtkBooleanMacro(Static, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * default (ColorModeToDefault), unsigned char scalars are treated
    * as colors, and NOT mapped through the lookup table, while
@@ -161,14 +162,14 @@ public:
   void SetColorModeToDefault() { this->SetColorMode(VTK_COLOR_MODE_DEFAULT); }
   void SetColorModeToMapScalars() { this->SetColorMode(VTK_COLOR_MODE_MAP_SCALARS); }
   void SetColorModeToDirectScalars() { this->SetColorMode(VTK_COLOR_MODE_DIRECT_SCALARS); }
-  //@}
+  ///@}
 
   /**
    * Return the method of coloring scalar data.
    */
   const char* GetColorModeAsString();
 
-  //@{
+  ///@{
   /**
    * By default, vertex color is used to map colors to a surface.
    * Colors are interpolated after being mapped.
@@ -178,9 +179,9 @@ public:
   vtkSetMacro(InterpolateScalarsBeforeMapping, vtkTypeBool);
   vtkGetMacro(InterpolateScalarsBeforeMapping, vtkTypeBool);
   vtkBooleanMacro(InterpolateScalarsBeforeMapping, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control whether the mapper sets the lookuptable range based on its
    * own ScalarRange, or whether it will use the LookupTable ScalarRange
@@ -192,9 +193,9 @@ public:
   vtkSetMacro(UseLookupTableScalarRange, vtkTypeBool);
   vtkGetMacro(UseLookupTableScalarRange, vtkTypeBool);
   vtkBooleanMacro(UseLookupTableScalarRange, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify range in terms of scalar minimum and maximum (smin,smax). These
    * values are used to map scalars into lookup table. Has no effect when
@@ -202,7 +203,7 @@ public:
    */
   vtkSetVector2Macro(ScalarRange, double);
   vtkGetVectorMacro(ScalarRange, double, 2);
-  //@}
+  ///@}
 
   /**
    * Control how the filter works with scalar point data and cell attribute
@@ -244,7 +245,7 @@ public:
   }
   void SetScalarModeToUseFieldData() { this->SetScalarMode(VTK_SCALAR_MODE_USE_FIELD_DATA); }
 
-  //@{
+  ///@{
   /**
    * When ScalarMode is set to UsePointFieldData or UseCellFieldData,
    * you can specify which array to use for coloring using these methods.
@@ -252,7 +253,7 @@ public:
    */
   void SelectColorArray(int arrayNum);
   void SelectColorArray(const char* arrayName);
-  //@}
+  ///@}
 
   // When ScalarMode is set to UseFieldData, set the index of the
   // tuple by which to color the entire data set. By default, the
@@ -263,7 +264,7 @@ public:
   vtkSetMacro(FieldDataTupleId, vtkIdType);
   vtkGetMacro(FieldDataTupleId, vtkIdType);
 
-  //@{
+  ///@{
   /**
    * Legacy:
    * These methods used to be used to specify the array component.
@@ -271,7 +272,7 @@ public:
    */
   void ColorByArrayComponent(int arrayNum, int component);
   void ColorByArrayComponent(const char* arrayName, int component);
-  //@}
+  ///@}
 
   /**
    * Set/Get the array name or number and component to color by.
@@ -290,7 +291,7 @@ public:
    */
   const char* GetScalarModeAsString();
 
-  //@{
+  ///@{
   /**
    * Set/Get a global flag that controls whether coincident topology (e.g., a
    * line on top of a polygon) is shifted to avoid z-buffer resolution (and
@@ -313,9 +314,9 @@ public:
   {
     SetResolveCoincidentTopology(VTK_RESOLVE_SHIFT_ZBUFFER);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the polygon offset scale factor and units.
    * Used when ResolveCoincidentTopology is set to PolygonOffset.
@@ -323,18 +324,18 @@ public:
    */
   static void SetResolveCoincidentTopologyPolygonOffsetParameters(double factor, double units);
   static void GetResolveCoincidentTopologyPolygonOffsetParameters(double& factor, double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the polygon offset values relative to the global
    * Used when ResolveCoincidentTopology is set to PolygonOffset.
    */
   void SetRelativeCoincidentTopologyPolygonOffsetParameters(double factor, double units);
   void GetRelativeCoincidentTopologyPolygonOffsetParameters(double& factor, double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the line offset scale factor and units.
    * Used when ResolveCoincidentTopology is set to PolygonOffset.
@@ -342,18 +343,18 @@ public:
    */
   static void SetResolveCoincidentTopologyLineOffsetParameters(double factor, double units);
   static void GetResolveCoincidentTopologyLineOffsetParameters(double& factor, double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the line offset values relative to the global
    * Used when ResolveCoincidentTopology is set to PolygonOffset.
    */
   void SetRelativeCoincidentTopologyLineOffsetParameters(double factor, double units);
   void GetRelativeCoincidentTopologyLineOffsetParameters(double& factor, double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the point offset value
    * Used when ResolveCoincidentTopology is set to PolygonOffset.
@@ -361,18 +362,18 @@ public:
    */
   static void SetResolveCoincidentTopologyPointOffsetParameter(double units);
   static void GetResolveCoincidentTopologyPointOffsetParameter(double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the point offset value relative to the global
    * Used when ResolveCoincidentTopology is set to PolygonOffset.
    */
   void SetRelativeCoincidentTopologyPointOffsetParameter(double units);
   void GetRelativeCoincidentTopologyPointOffsetParameter(double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the net parameters for handling coincident topology
    * obtained by summing the global values with the relative values.
@@ -380,9 +381,9 @@ public:
   void GetCoincidentTopologyPolygonOffsetParameters(double& factor, double& units);
   void GetCoincidentTopologyLineOffsetParameters(double& factor, double& units);
   void GetCoincidentTopologyPointOffsetParameter(double& units);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used when ResolveCoincidentTopology is set to PolygonOffset. The polygon
    * offset can be applied either to the solid polygonal faces or the
@@ -392,16 +393,16 @@ public:
    */
   static void SetResolveCoincidentTopologyPolygonOffsetFaces(int faces);
   static int GetResolveCoincidentTopologyPolygonOffsetFaces();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Used to set the z-shift if ResolveCoincidentTopology is set to
    * ShiftZBuffer. This is a global variable.
    */
   static void SetResolveCoincidentTopologyZShift(double val);
   static double GetResolveCoincidentTopologyZShift();
-  //@}
+  ///@}
 
   /**
    * Return bounding box (array of six doubles) of data expressed as
@@ -432,7 +433,7 @@ public:
    */
   vtkDataSet* GetInputAsDataSet() { return this->GetInput(); }
 
-  //@{
+  ///@{
   /**
    * Map the scalars (if there are any scalars and ScalarVisibility is on)
    * through the lookup table, returning an unsigned char RGBA array. This is
@@ -444,9 +445,9 @@ public:
   virtual vtkUnsignedCharArray* MapScalars(double alpha, int& cellFlag);
   virtual vtkUnsignedCharArray* MapScalars(vtkDataSet* input, double alpha);
   virtual vtkUnsignedCharArray* MapScalars(vtkDataSet* input, double alpha, int& cellFlag);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Some introspection on the type of data the mapper will render
    * used by props to determine if they should invoke the mapper
@@ -454,7 +455,7 @@ public:
    */
   virtual bool HasOpaqueGeometry();
   virtual bool HasTranslucentPolygonalGeometry();
-  //@}
+  ///@}
 
   /**
    * WARNING: INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
@@ -504,14 +505,14 @@ public:
    */
   vtkImageData* GetColorTextureMap();
 
-  //@{
+  ///@{
   /**
    * Set/Get selection used to display particular points or cells in a second pass.
    * This can be use to efficiently display a selection.
    */
   vtkGetObjectMacro(Selection, vtkSelection);
   virtual void SetSelection(vtkSelection*);
-  //@}
+  ///@}
 
 protected:
   vtkMapper();
@@ -564,4 +565,5 @@ private:
   void operator=(const vtkMapper&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
