@@ -34,6 +34,7 @@
 #include "vtkObject.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkRenderWindowInteractor;
 class vtkInteractorObserver;
 class vtkObserverMap;
@@ -46,22 +47,22 @@ public:
    */
   static vtkObserverMediator* New();
 
-  //@{
+  ///@{
   /**
    * Standard macros.
    */
   vtkTypeMacro(vtkObserverMediator, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the instance of vtkRenderWindow whose cursor shape is
    * to be managed.
    */
   void SetInteractor(vtkRenderWindowInteractor* iren);
   vtkGetObjectMacro(Interactor, vtkRenderWindowInteractor);
-  //@}
+  ///@}
 
   /**
    * Method used to request a cursor shape. Note that the shape is specified
@@ -96,4 +97,5 @@ private:
   void operator=(const vtkObserverMediator&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
