@@ -73,6 +73,7 @@
 #include "vtkObject.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractPicker;
 class vtkAbstractPropPicker;
 class vtkAssemblyPath;
@@ -86,7 +87,7 @@ public:
   vtkTypeMacro(vtkPickingManager, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Enable/Disable management.
    * When disabled, it redirects every pick on the picker.
@@ -95,9 +96,9 @@ public:
   vtkBooleanMacro(Enabled, bool);
   vtkSetMacro(Enabled, bool);
   vtkGetMacro(Enabled, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/Disable optimization depending on the renderWindowInteractor events.
    * The mechanism keeps in cache the last selected picker as well as the last
@@ -109,15 +110,15 @@ public:
    */
   void SetOptimizeOnInteractorEvents(bool optimize);
   vtkGetMacro(OptimizeOnInteractorEvents, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the window interactor associated with the manager.
    */
   void SetInteractor(vtkRenderWindowInteractor* iren);
   vtkGetMacro(Interactor, vtkRenderWindowInteractor*);
-  //@}
+  ///@}
 
   /**
    * Register a picker into the picking manager.
@@ -203,4 +204,5 @@ private:
   vtkInternal* Internal;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
