@@ -32,11 +32,13 @@
 
 #include "vtkProp.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGCORE_EXPORT vtkPropCollection : public vtkCollection
 {
 public:
   static vtkPropCollection* New();
   vtkTypeMacro(vtkPropCollection, vtkCollection);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Add a Prop to the bottom of the list.
@@ -105,6 +107,5 @@ inline vtkProp* vtkPropCollection::GetLastProp()
   }
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkPropCollection.h
