@@ -29,6 +29,7 @@
 
 #include <vtksys/SystemTools.hxx>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkProperty, Information, vtkInformation);
 
 //------------------------------------------------------------------------------
@@ -107,6 +108,7 @@ vtkProperty::vtkProperty()
   this->Lighting = true;
   this->RenderPointsAsSpheres = false;
   this->RenderLinesAsTubes = false;
+  this->ShowTexturesOnBackface = true;
 
   this->Shading = 0;
   this->MaterialName = nullptr;
@@ -169,6 +171,7 @@ void vtkProperty::DeepCopy(vtkProperty* p)
     this->SetCoatStrength(p->GetCoatStrength());
     this->SetCoatNormalScale(p->GetCoatNormalScale());
     this->SetCoatColor(p->GetCoatColor());
+    this->SetShowTexturesOnBackface(p->GetShowTexturesOnBackface());
 
     this->RemoveAllTextures();
     auto iter = p->Textures.begin();
@@ -483,6 +486,8 @@ void vtkProperty::PrintSelf(ostream& os, vtkIndent indent)
   }
   os << indent << "RenderPointsAsSpheres: " << (this->RenderPointsAsSpheres ? "On" : "Off") << endl;
   os << indent << "RenderLinesAsTubes: " << (this->RenderLinesAsTubes ? "On" : "Off") << endl;
+  os << indent << "ShowTexturesOnBackface: " << (this->ShowTexturesOnBackface ? "On" : "Off")
+     << endl;
 
   os << indent << "Shading: " << (this->Shading ? "On" : "Off") << endl;
 
@@ -497,3 +502,4 @@ void vtkProperty::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Metallic: " << this->Metallic << endl;
   os << indent << "Roughness: " << this->Roughness << endl;
 }
+VTK_ABI_NAMESPACE_END
