@@ -47,6 +47,7 @@
 #define VTK_WIREFRAME 1
 #define VTK_SURFACE 2
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkInformation;
 class vtkRenderer;
@@ -101,16 +102,16 @@ public:
    */
   virtual void PostRender(vtkActor*, vtkRenderer*);
 
-  //@{
+  ///@{
   /**
    * Set/Get lighting flag for an object. Initial value is true.
    */
   vtkGetMacro(Lighting, bool);
   vtkSetMacro(Lighting, bool);
   vtkBooleanMacro(Lighting, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get rendering of points as spheres. The size of the
    * sphere in pixels is controlled by the PointSize
@@ -120,9 +121,9 @@ public:
   vtkGetMacro(RenderPointsAsSpheres, bool);
   vtkSetMacro(RenderPointsAsSpheres, bool);
   vtkBooleanMacro(RenderPointsAsSpheres, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get rendering of lines as tubes. The width of the
    * line in pixels is controlled by the LineWidth
@@ -133,9 +134,9 @@ public:
   vtkGetMacro(RenderLinesAsTubes, bool);
   vtkSetMacro(RenderLinesAsTubes, bool);
   vtkBooleanMacro(RenderLinesAsTubes, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the shading interpolation method for an object.
    */
@@ -146,9 +147,9 @@ public:
   void SetInterpolationToPhong() { this->SetInterpolation(VTK_PHONG); }
   void SetInterpolationToPBR() { this->SetInterpolation(VTK_PBR); }
   const char* GetInterpolationAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control the surface geometry representation for the object.
    */
@@ -158,9 +159,9 @@ public:
   void SetRepresentationToWireframe() { this->SetRepresentation(VTK_WIREFRAME); }
   void SetRepresentationToSurface() { this->SetRepresentation(VTK_SURFACE); }
   const char* GetRepresentationAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the color of the object. Has the side effect of setting the
    * ambient diffuse and specular colors as well. This is basically
@@ -171,9 +172,9 @@ public:
   double* GetColor() VTK_SIZEHINT(3);
   void GetColor(double rgb[3]);
   void GetColor(double& r, double& g, double& b);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the Index Of Refraction of the base layer.
    * It controls the amount of light reflected at normal incidence (the reflectance F0),
@@ -187,9 +188,9 @@ public:
    */
   vtkSetClampMacro(BaseIOR, double, 1.0, VTK_FLOAT_MAX);
   vtkGetMacro(BaseIOR, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the metallic coefficient.
    * Usually this value is either 0 or 1 for real material but any value in between is valid.
@@ -198,9 +199,9 @@ public:
    */
   vtkSetClampMacro(Metallic, double, 0.0, 1.0);
   vtkGetMacro(Metallic, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the roughness coefficient.
    * This value has to be between 0 (glossy) and 1 (rough).
@@ -210,9 +211,9 @@ public:
    */
   vtkSetClampMacro(Roughness, double, 0.0, 1.0);
   vtkGetMacro(Roughness, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the anisotropy coefficient.
    * This value controls the anisotropy of the material (0.0 means isotropic)
@@ -221,9 +222,9 @@ public:
    */
   vtkSetClampMacro(Anisotropy, double, 0.0, 1.0);
   vtkGetMacro(Anisotropy, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the anisotropy rotation coefficient.
    * This value controls the rotation of the direction of the anisotropy.
@@ -232,9 +233,9 @@ public:
    */
   vtkSetClampMacro(AnisotropyRotation, double, 0.0, 1.0);
   vtkGetMacro(AnisotropyRotation, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the coat layer Index Of Refraction.
    * This parameter is only used by PBR Interpolation.
@@ -242,9 +243,9 @@ public:
    */
   vtkSetClampMacro(CoatIOR, double, 1.0, VTK_FLOAT_MAX);
   vtkGetMacro(CoatIOR, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the coat layer roughness coefficient.
    * This value has to be between 0 (glossy) and 1 (rough).
@@ -253,9 +254,9 @@ public:
    */
   vtkSetClampMacro(CoatRoughness, double, 0.0, 1.0);
   vtkGetMacro(CoatRoughness, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the coat layer strength coefficient.
    * This value affects the strength of the coat layer reflection.
@@ -264,9 +265,9 @@ public:
    */
   vtkSetClampMacro(CoatStrength, double, 0.0, 1.0);
   vtkGetMacro(CoatStrength, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the color of the coat layer.
    * This value is only used by PBR Interpolation.
@@ -274,9 +275,9 @@ public:
    */
   vtkSetVector3Macro(CoatColor, double);
   vtkGetVector3Macro(CoatColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the coat layer normal scale coefficient.
    * This value affects the strength of the normal deviation from the coat normal texture.
@@ -285,9 +286,9 @@ public:
    */
   vtkSetClampMacro(CoatNormalScale, double, 0.0, 1.0);
   vtkGetMacro(CoatNormalScale, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the normal scale coefficient.
    * This value affects the strength of the normal deviation from the texture.
@@ -295,9 +296,9 @@ public:
    */
   vtkSetMacro(NormalScale, double);
   vtkGetMacro(NormalScale, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the occlusion strength coefficient.
    * This value affects the strength of the occlusion if a material texture is present.
@@ -306,9 +307,9 @@ public:
    */
   vtkSetClampMacro(OcclusionStrength, double, 0.0, 1.0);
   vtkGetMacro(OcclusionStrength, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the emissive factor.
    * This value is multiplied with the emissive color when an emissive texture is present.
@@ -317,9 +318,9 @@ public:
    */
   vtkSetVector3Macro(EmissiveFactor, double);
   vtkGetVector3Macro(EmissiveFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the edge tint (for metals only).
    * Set the color at grazing angle (fresnel reflectance).
@@ -328,50 +329,50 @@ public:
    */
   vtkSetVector3Macro(EdgeTint, double);
   vtkGetVector3Macro(EdgeTint, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the ambient lighting coefficient.
    */
   vtkSetClampMacro(Ambient, double, 0.0, 1.0);
   vtkGetMacro(Ambient, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the diffuse lighting coefficient.
    */
   vtkSetClampMacro(Diffuse, double, 0.0, 1.0);
   vtkGetMacro(Diffuse, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the specular lighting coefficient.
    */
   vtkSetClampMacro(Specular, double, 0.0, 1.0);
   vtkGetMacro(Specular, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the specular power.
    */
   vtkSetClampMacro(SpecularPower, double, 0.0, 128.0);
   vtkGetMacro(SpecularPower, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the object's opacity. 1.0 is totally opaque and 0.0 is completely
    * transparent.
    */
   vtkSetClampMacro(Opacity, double, 0.0, 1.0);
   vtkGetMacro(Opacity, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the ambient surface color. Not all renderers support separate
    * ambient and diffuse colors. From a physical standpoint it really
@@ -380,26 +381,26 @@ public:
    */
   vtkSetVector3Macro(AmbientColor, double);
   vtkGetVector3Macro(AmbientColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the diffuse surface color.
    * For PBR Interpolation, DiffuseColor is used as the base color
    */
   vtkSetVector3Macro(DiffuseColor, double);
   vtkGetVector3Macro(DiffuseColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the specular surface color.
    */
   vtkSetVector3Macro(SpecularColor, double);
   vtkGetVector3Macro(SpecularColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the visibility of edges. On some renderers it is
    * possible to render the edges of geometric primitives separately
@@ -408,17 +409,17 @@ public:
   vtkGetMacro(EdgeVisibility, vtkTypeBool);
   vtkSetMacro(EdgeVisibility, vtkTypeBool);
   vtkBooleanMacro(EdgeVisibility, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the color of primitive edges (if edge visibility is enabled).
    */
   vtkSetVector3Macro(EdgeColor, double);
   vtkGetVector3Macro(EdgeColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the visibility of vertices. On some renderers it is
    * possible to render the vertices of geometric primitives separately
@@ -427,53 +428,53 @@ public:
   vtkGetMacro(VertexVisibility, vtkTypeBool);
   vtkSetMacro(VertexVisibility, vtkTypeBool);
   vtkBooleanMacro(VertexVisibility, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the color of primitive vertices (if vertex visibility is enabled).
    */
   vtkSetVector3Macro(VertexColor, double);
   vtkGetVector3Macro(VertexColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the RGBA color of selection primitives (if a selection is active on the mapper).
    * Default is red and opaque.
    */
   vtkSetVector4Macro(SelectionColor, double);
   vtkGetVector4Macro(SelectionColor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the selection line width.
    * Default is 2.
    */
   vtkSetMacro(SelectionLineWidth, float);
   vtkGetMacro(SelectionLineWidth, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the selection point size.
    * Default is 2.
    */
   vtkSetMacro(SelectionPointSize, float);
   vtkGetMacro(SelectionPointSize, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the width of a Line. The width is expressed in screen units.
    * This is only implemented for OpenGL. The default is 1.0.
    */
   vtkSetClampMacro(LineWidth, float, 0, VTK_FLOAT_MAX);
   vtkGetMacro(LineWidth, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the stippling pattern of a Line, as a 16-bit binary pattern
    * (1 = pixel on, 0 = pixel off).
@@ -481,9 +482,9 @@ public:
    */
   vtkSetMacro(LineStipplePattern, int);
   vtkGetMacro(LineStipplePattern, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the stippling repeat factor of a Line, which specifies how
    * many times each bit in the pattern is to be repeated.
@@ -491,18 +492,18 @@ public:
    */
   vtkSetClampMacro(LineStippleRepeatFactor, int, 1, VTK_INT_MAX);
   vtkGetMacro(LineStippleRepeatFactor, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the diameter of a point. The size is expressed in screen units.
    * This is only implemented for OpenGL. The default is 1.0.
    */
   vtkSetClampMacro(PointSize, float, 0, VTK_FLOAT_MAX);
   vtkGetMacro(PointSize, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off fast culling of polygons based on orientation of normal
    * with respect to camera. If backface culling is on, polygons facing
@@ -511,9 +512,9 @@ public:
   vtkGetMacro(BackfaceCulling, vtkTypeBool);
   vtkSetMacro(BackfaceCulling, vtkTypeBool);
   vtkBooleanMacro(BackfaceCulling, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off fast culling of polygons based on orientation of normal
    * with respect to camera. If frontface culling is on, polygons facing
@@ -522,17 +523,17 @@ public:
   vtkGetMacro(FrontfaceCulling, vtkTypeBool);
   vtkSetMacro(FrontfaceCulling, vtkTypeBool);
   vtkBooleanMacro(FrontfaceCulling, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Returns the name of the material currently loaded, if any.
    */
   vtkSetStringMacro(MaterialName);
   vtkGetStringMacro(MaterialName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/Disable shading. When shading is enabled, the
    * Material must be set.
@@ -540,9 +541,9 @@ public:
   vtkSetMacro(Shading, vtkTypeBool);
   vtkGetMacro(Shading, vtkTypeBool);
   vtkBooleanMacro(Shading, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Provide values to initialize shader variables.
    * Useful to initialize shader variables that change over time
@@ -554,9 +555,9 @@ public:
   virtual void AddShaderVariable(const char* name, int numVars, int* x);
   virtual void AddShaderVariable(const char* name, int numVars, float* x);
   virtual void AddShaderVariable(const char* name, int numVars, double* x);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods to provide to add shader variables from wrappers.
    */
@@ -593,9 +594,19 @@ public:
     double v[3] = { v1, v2, v3 };
     this->AddShaderVariable(name, 3, v);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Show texture maps when the geometry is backfacing. Texture maps are
+   * always shown when frontfacing. By default this is true.
+   */
+  vtkSetMacro(ShowTexturesOnBackface, bool);
+  vtkGetMacro(ShowTexturesOnBackface, bool);
+  vtkBooleanMacro(ShowTexturesOnBackface, bool);
+  ///@}
+
+  ///@{
   /**
    * Set/Get the texture object to control rendering texture maps. This will
    * be a vtkTexture object. A property does not need to have an associated
@@ -611,7 +622,7 @@ public:
    */
   void SetTexture(const char* name, vtkTexture* texture);
   vtkTexture* GetTexture(const char* name);
-  //@}
+  ///@}
 
   /**
    * Set the base color texture. Also called albedo, this texture is only used while rendering
@@ -656,7 +667,7 @@ public:
 
   /**
    * Set the emissive texture. When present, this RGB texture provides location and color to the
-   * shader where the vtkPolyData should emit light. Emited light is scaled by EmissiveFactor.
+   * shader where the vtkPolyData should emit light. Emitted light is scaled by EmissiveFactor.
    * This is only supported by PBR interpolation model.
    * This texture must be in sRGB color space.
    * @sa SetInterpolationToPBR SetEmissiveFactor vtkTexture::UseSRGBColorSpaceOn
@@ -700,31 +711,31 @@ public:
    */
   virtual void ReleaseGraphicsResources(vtkWindow* win);
 
-  //@{
+  ///@{
   /**
    * Set/Get the information object associated with the Property.
    */
   vtkGetObjectMacro(Information, vtkInformation);
   virtual void SetInformation(vtkInformation*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * For PBR, calculate the reflectance from the refractive index of
    * ingoing and outgoing interfaces.
    */
   static double ComputeReflectanceFromIOR(double IORTo, double IORFrom);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * For PBR, calculate the refractive index from the reflectance of the interface
    * and the refractive index of one of both medium.
    */
   static double ComputeIORFromReflectance(double reflectance, double ior);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * For PBR, calculate the reflectance of the base layer depending on the presence
    * of a coat layer. If there is no coat layer, the reflectance is the one at the
@@ -732,7 +743,7 @@ public:
    * is the one at the interface between the base and the coat layer.
    */
   double ComputeReflectanceOfBaseLayer();
-  //@}
+  ///@}
 
 protected:
   vtkProperty();
@@ -785,6 +796,7 @@ protected:
   bool Lighting;
   bool RenderPointsAsSpheres;
   bool RenderLinesAsTubes;
+  bool ShowTexturesOnBackface;
 
   vtkTypeBool Shading;
 
@@ -801,11 +813,10 @@ private:
   void operator=(const vtkProperty&) = delete;
 };
 
-//@{
 /**
  * Return the method of shading as a descriptive character string.
  */
-inline const char* vtkProperty::GetInterpolationAsString(void)
+inline const char* vtkProperty::GetInterpolationAsString()
 {
   if (this->Interpolation == VTK_FLAT)
   {
@@ -824,13 +835,11 @@ inline const char* vtkProperty::GetInterpolationAsString(void)
     return "Physically based rendering";
   }
 }
-//@}
 
-//@{
 /**
  * Return the method of shading as a descriptive character string.
  */
-inline const char* vtkProperty::GetRepresentationAsString(void)
+inline const char* vtkProperty::GetRepresentationAsString()
 {
   if (this->Representation == VTK_POINTS)
   {
@@ -845,6 +854,6 @@ inline const char* vtkProperty::GetRepresentationAsString(void)
     return "Surface";
   }
 }
-//@}
 
+VTK_ABI_NAMESPACE_END
 #endif
