@@ -16,7 +16,7 @@
  * @class   vtkRenderState
  * @brief   Context in which a vtkRenderPass will render.
  *
- * vtkRenderState is a ligthweight effective class which gather information
+ * vtkRenderState is a lightweight effective class which gather information
  * used by a vtkRenderPass to perform its execution.
  * @attention
  * Get methods are const to enforce that a renderpass cannot modify the
@@ -32,6 +32,7 @@
 #include "vtkObject.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkRenderer;
 class vtkProp;
 class vtkFrameBufferObjectBase;
@@ -136,7 +137,7 @@ protected:
    */
   vtkFrameBufferObjectBase* FrameBuffer;
 
-  //@{
+  ///@{
   /**
    * Subset of props to render. A renderpass might ignore this filtered list
    * and access to all the props of the vtkRenderer object directly.
@@ -146,7 +147,7 @@ protected:
    */
   vtkProp** PropArray;
   int PropArrayCount;
-  //@}
+  ///@}
 
   /**
    * It tells that the current render pass it supposed to render only props
@@ -160,5 +161,6 @@ private:
   void operator=(const vtkRenderState&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkRenderState.h
