@@ -13,9 +13,6 @@
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_1_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtkRenderWindow.h"
 
 #include "vtkCamera.h"
@@ -38,6 +35,7 @@
 #include <utility> // for std::swap
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkRenderWindow);
 
 // Construct an instance of  vtkRenderWindow with its screen size
@@ -187,6 +185,20 @@ void vtkRenderWindow::SetInteractor(vtkRenderWindowInteractor* rwi)
   }
 }
 
+void vtkRenderWindow::GetPhysicalToWorldMatrix(vtkMatrix4x4* matrix)
+{
+  if (matrix)
+  {
+    matrix->Identity();
+  }
+}
+
+bool vtkRenderWindow::GetDeviceToWorldMatrixForDevice(
+  vtkEventDataDevice vtkNotUsed(device), vtkMatrix4x4* vtkNotUsed(deviceToWorldMatrix))
+{
+  return false;
+}
+
 //------------------------------------------------------------------------------
 void vtkRenderWindow::SetDesiredUpdateRate(double rate)
 {
@@ -671,29 +683,4 @@ const char* vtkRenderWindow::GetStereoTypeAsString(int type)
       return "";
   }
 }
-
-vtkTypeBool vtkRenderWindow::GetIsPicking()
-{
-  VTK_LEGACY_BODY(vtkRenderWindow::GetIsPicking, "VTK 9.0");
-  return false;
-}
-void vtkRenderWindow::SetIsPicking(vtkTypeBool)
-{
-  VTK_LEGACY_BODY(vtkRenderWindow::SetIsPicking, "VTK 9.0");
-}
-void vtkRenderWindow::IsPickingOn()
-{
-  VTK_LEGACY_BODY(vtkRenderWindow::IsPickingOn, "VTK 9.0");
-}
-void vtkRenderWindow::IsPickingOff()
-{
-  VTK_LEGACY_BODY(vtkRenderWindow::IsPickingOff, "VTK 9.0");
-}
-
-//----------------------------------------------------------------------------
-bool vtkRenderWindow::IsDrawable()
-{
-  VTK_LEGACY_BODY(vtkRenderWindow::IsDrawable, "VTK 9.1");
-
-  return true;
-}
+VTK_ABI_NAMESPACE_END
