@@ -38,6 +38,9 @@
 #include "vtkActorCollection.h"  // Needed for access in inline members
 #include "vtkVolumeCollection.h" // Needed for access in inline members
 
+#include <array> // To store matrices
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFXAAOptions;
 class vtkRenderWindow;
 class vtkVolume;
@@ -55,6 +58,9 @@ class vtkRendererDelegate;
 class vtkRenderPass;
 class vtkTexture;
 
+class vtkRecti;
+class vtkVector3d;
+
 class VTKRENDERINGCORE_EXPORT vtkRenderer : public vtkViewport
 {
 public:
@@ -68,7 +74,7 @@ public:
    */
   static vtkRenderer* New();
 
-  //@{
+  ///@{
   /**
    * Add/Remove different types of props to the renderer.
    * These methods are all synonyms to AddViewProp and RemoveViewProp.
@@ -78,7 +84,7 @@ public:
   void AddVolume(vtkProp* p);
   void RemoveActor(vtkProp* p);
   void RemoveVolume(vtkProp* p);
-  //@}
+  ///@}
 
   /**
    * Add a light to the list of lights.
@@ -111,7 +117,7 @@ public:
   /**
    * Create and add a light to renderer.
    */
-  void CreateLight(void);
+  void CreateLight();
 
   /**
    * Create a new Light sutible for use with this type of Renderer.
@@ -120,7 +126,7 @@ public:
    */
   virtual vtkLight* MakeLight();
 
-  //@{
+  ///@{
   /**
    * Turn on/off two-sided lighting of surfaces. If two-sided lighting is
    * off, then only the side of the surface facing the light(s) will be lit,
@@ -130,9 +136,9 @@ public:
   vtkGetMacro(TwoSidedLighting, vtkTypeBool);
   vtkSetMacro(TwoSidedLighting, vtkTypeBool);
   vtkBooleanMacro(TwoSidedLighting, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the automatic repositioning of lights as the camera moves.
    * If LightFollowCamera is on, lights that are designated as Headlights
@@ -149,9 +155,9 @@ public:
   vtkSetMacro(LightFollowCamera, vtkTypeBool);
   vtkGetMacro(LightFollowCamera, vtkTypeBool);
   vtkBooleanMacro(LightFollowCamera, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off a flag which disables the automatic light creation capability.
    * Normally in VTK if no lights are associated with the renderer, then a light
@@ -163,14 +169,14 @@ public:
   vtkGetMacro(AutomaticLightCreation, vtkTypeBool);
   vtkSetMacro(AutomaticLightCreation, vtkTypeBool);
   vtkBooleanMacro(AutomaticLightCreation, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Ask the lights in the scene that are not in world space
    * (for instance, Headlights or CameraLights that are attached to the
    * camera) to update their geometry to match the active camera.
    */
-  virtual vtkTypeBool UpdateLightsGeometryToFollowCamera(void);
+  virtual vtkTypeBool UpdateLightsGeometryToFollowCamera();
 
   /**
    * Return the collection of volumes.
@@ -201,7 +207,7 @@ public:
    */
   virtual vtkCamera* MakeCamera();
 
-  //@{
+  ///@{
   /**
    * When this flag is off, the renderer will not erase the background
    * or the Zbuffer.  It is used to have overlapping renderers.
@@ -211,9 +217,9 @@ public:
   vtkSetMacro(Erase, vtkTypeBool);
   vtkGetMacro(Erase, vtkTypeBool);
   vtkBooleanMacro(Erase, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When this flag is off, render commands are ignored.  It is used to either
    * multiplex a vtkRenderWindow or render only part of a vtkRenderWindow.
@@ -222,7 +228,7 @@ public:
   vtkSetMacro(Draw, vtkTypeBool);
   vtkGetMacro(Draw, vtkTypeBool);
   vtkBooleanMacro(Draw, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * This function is called to capture an instance of vtkProp that requires
@@ -252,22 +258,22 @@ public:
    */
   vtkCullerCollection* GetCullers();
 
-  //@{
+  ///@{
   /**
    * Set the intensity of ambient lighting.
    */
   vtkSetVector3Macro(Ambient, double);
   vtkGetVectorMacro(Ambient, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the amount of time this renderer is allowed to spend
    * rendering its scene. This is used by vtkLODActor's.
    */
   vtkSetMacro(AllocatedRenderTime, double);
   virtual double GetAllocatedRenderTime();
-  //@}
+  ///@}
 
   /**
    * Get the ratio between allocated time and actual render time.
@@ -313,7 +319,7 @@ public:
    * Internal method temporarily removes lights before reloading them
    * into graphics pipeline.
    */
-  virtual void ClearLights(void) {}
+  virtual void ClearLights() {}
 
   /**
    * Clear the image to the background color.
@@ -347,16 +353,16 @@ public:
    */
   virtual void ResetCameraClippingRange();
 
-  //@{
+  ///@{
   /**
    * Reset the camera clipping range based on a bounding box.
    */
   virtual void ResetCameraClippingRange(const double bounds[6]);
   virtual void ResetCameraClippingRange(
     double xmin, double xmax, double ymin, double ymax, double zmin, double zmax);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify tolerance for near clipping plane distance to the camera as a
    * percentage of the far clipping plane distance. By default this will be
@@ -364,9 +370,9 @@ public:
    */
   vtkSetClampMacro(NearClippingPlaneTolerance, double, 0, 0.99);
   vtkGetMacro(NearClippingPlaneTolerance, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify enlargement of bounds when resetting the
    * camera clipping range.  By default the range is not expanded by
@@ -374,7 +380,7 @@ public:
    */
   vtkSetClampMacro(ClippingRangeExpansion, double, 0, 0.99);
   vtkGetMacro(ClippingRangeExpansion, double);
-  //@}
+  ///@}
 
   /**
    * Automatically set up the camera based on the visible actors.
@@ -414,13 +420,27 @@ public:
    */
   virtual void ResetCameraScreenSpace(const double bounds[6]);
 
+  using vtkViewport::DisplayToWorld;
+
+  /**
+   * Convert a vtkVector3d from display space to world space.
+   */
+  vtkVector3d DisplayToWorld(const vtkVector3d& display);
+
+  /**
+   * Automatically set up the camera focal point and zoom factor to
+   * observe the \p box in display coordinates.
+   * \p OffsetRatio can be used to add a zoom offset.
+   */
+  void ZoomToBoxUsingViewAngle(const vtkRecti& box, const double offsetRatio = 1.0);
+
   /**
    * Alternative version of ResetCameraScreenSpace(bounds[6]);
    */
   virtual void ResetCameraScreenSpace(
     double xmin, double xmax, double ymin, double ymax, double zmin, double zmax);
 
-  //@{
+  ///@{
   /**
    * Specify the rendering window in which to draw. This is automatically set
    * when the renderer is created by MakeRenderer.  The user probably
@@ -429,9 +449,9 @@ public:
   void SetRenderWindow(vtkRenderWindow*);
   vtkRenderWindow* GetRenderWindow() { return this->RenderWindow; }
   vtkWindow* GetVTKWindow() override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off using backing store. This may cause the re-rendering
    * time to be slightly slower when the view changes. But it is
@@ -441,9 +461,9 @@ public:
   vtkSetMacro(BackingStore, vtkTypeBool);
   vtkGetMacro(BackingStore, vtkTypeBool);
   vtkBooleanMacro(BackingStore, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off interactive status.  An interactive renderer is one that
    * can receive events from an interactor.  Should only be set if
@@ -452,9 +472,9 @@ public:
   vtkSetMacro(Interactive, vtkTypeBool);
   vtkGetMacro(Interactive, vtkTypeBool);
   vtkBooleanMacro(Interactive, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the layer that this renderer belongs to.  This is only used if
    * there are layered renderers.
@@ -468,9 +488,9 @@ public:
    */
   virtual void SetLayer(int layer);
   vtkGetMacro(Layer, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * By default, the renderer at layer 0 is opaque, and all non-zero layer
    * renderers are transparent. This flag allows this behavior to be overridden.
@@ -484,9 +504,9 @@ public:
   vtkGetMacro(PreserveColorBuffer, vtkTypeBool);
   vtkSetMacro(PreserveColorBuffer, vtkTypeBool);
   vtkBooleanMacro(PreserveColorBuffer, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * By default, the depth buffer is reset for each renderer. If this flag is
    * true, this renderer will use the existing depth buffer for its rendering.
@@ -494,7 +514,7 @@ public:
   vtkSetMacro(PreserveDepthBuffer, vtkTypeBool);
   vtkGetMacro(PreserveDepthBuffer, vtkTypeBool);
   vtkBooleanMacro(PreserveDepthBuffer, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Returns a boolean indicating if this renderer is transparent.  It is
@@ -507,20 +527,20 @@ public:
    */
   void WorldToView() override;
 
-  //@{
+  ///@{
   /**
    * Convert view point coordinates to world coordinates.
    */
   void ViewToWorld() override;
   void ViewToWorld(double& wx, double& wy, double& wz) override;
-  //@}
+  ///@}
 
   /**
    * Convert world point coordinates to view coordinates.
    */
   void WorldToView(double& wx, double& wy, double& wz) override;
 
-  //@{
+  ///@{
   /**
    * Convert to from pose coordinates
    */
@@ -528,7 +548,7 @@ public:
   void PoseToWorld(double& wx, double& wy, double& wz) override;
   void ViewToPose(double& wx, double& wy, double& wz) override;
   void PoseToView(double& wx, double& wy, double& wz) override;
-  //@}
+  ///@}
 
   /**
    * Given a pixel location, return the Z value. The z value is
@@ -541,14 +561,14 @@ public:
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Get the time required, in seconds, for the last Render call.
    */
   vtkGetMacro(LastRenderTimeInSeconds, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Should be used internally only during a render
    * Get the number of props that were rendered using a
@@ -556,15 +576,15 @@ public:
    * This is used to know if something is in the frame buffer.
    */
   vtkGetMacro(NumberOfPropsRendered, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Return the prop (via a vtkAssemblyPath) that has the highest z value
    * at the given x, y position in the viewport.  Basically, the top most
    * prop that renders the pixel at selectionX, selectionY will be returned.
    * If nothing was picked then NULL is returned.  This method selects from
-   * the renderers Prop list.
+   * the renderer's Prop list.
    */
   vtkAssemblyPath* PickProp(double selectionX, double selectionY) override
   {
@@ -572,7 +592,27 @@ public:
   }
   vtkAssemblyPath* PickProp(
     double selectionX1, double selectionY1, double selectionX2, double selectionY2) override;
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * Return the prop (via a vtkAssemblyPath) that has the highest z value
+   * at the given x, y position in the viewport.  Basically, the top most
+   * prop that renders the pixel at selectionX, selectionY will be returned.
+   * If nothing was picked then NULL is returned.  This method selects from
+   * the renderer's Prop list. Additionally, you can set the field
+   * association of the hardware selector used internally, and get its selection
+   * result by passing a non-null vtkSmartPointer<vtkSelection>.
+   */
+  vtkAssemblyPath* PickProp(double selectionX, double selectionY, int fieldAssociation,
+    vtkSmartPointer<vtkSelection> selection) override
+  {
+    return this->PickProp(
+      selectionX, selectionY, selectionX, selectionY, fieldAssociation, selection);
+  }
+  vtkAssemblyPath* PickProp(double selectionX1, double selectionY1, double selectionX2,
+    double selectionY2, int fieldAssociation, vtkSmartPointer<vtkSelection> selection) override;
+  ///@}
 
   /**
    * Do anything necessary between rendering the left and right viewpoints
@@ -596,7 +636,7 @@ public:
    */
   vtkTypeBool IsActiveCameraCreated() { return (this->ActiveCamera != nullptr); }
 
-  //@{
+  ///@{
   /**
    * Turn on/off rendering of translucent material with depth peeling
    * technique. The render window must have alpha bits (ie call
@@ -610,7 +650,7 @@ public:
   vtkSetMacro(UseDepthPeeling, vtkTypeBool);
   vtkGetMacro(UseDepthPeeling, vtkTypeBool);
   vtkBooleanMacro(UseDepthPeeling, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * This flag is on and the GPU supports it, depth-peel volumes along with
@@ -621,7 +661,7 @@ public:
   vtkGetMacro(UseDepthPeelingForVolumes, bool);
   vtkBooleanMacro(UseDepthPeelingForVolumes, bool);
 
-  //@{
+  ///@{
   /**
    * In case of use of depth peeling technique for rendering translucent
    * material, define the threshold under which the algorithm stops to
@@ -633,9 +673,9 @@ public:
    */
   vtkSetClampMacro(OcclusionRatio, double, 0.0, 0.5);
   vtkGetMacro(OcclusionRatio, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * In case of depth peeling, define the maximum number of peeling layers.
    * Initial value is 4. A special value of 0 means no maximum limit.
@@ -643,18 +683,18 @@ public:
    */
   vtkSetMacro(MaximumNumberOfPeels, int);
   vtkGetMacro(MaximumNumberOfPeels, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Tells if the last call to DeviceRenderTranslucentPolygonalGeometry()
    * actually used depth peeling.
    * Initial value is false.
    */
   vtkGetMacro(LastRenderingUsedDepthPeeling, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable or disable Screen Space Ambient Occlusion.
    * SSAO darkens some pixels to improve depth perception.
@@ -662,36 +702,36 @@ public:
   vtkSetMacro(UseSSAO, bool);
   vtkGetMacro(UseSSAO, bool);
   vtkBooleanMacro(UseSSAO, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When using SSAO, define the SSAO hemisphere radius.
    * Default is 0.5
    */
   vtkSetMacro(SSAORadius, double);
   vtkGetMacro(SSAORadius, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When using SSAO, define the bias when comparing samples.
    * Default is 0.01
    */
   vtkSetMacro(SSAOBias, double);
   vtkGetMacro(SSAOBias, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When using SSAO, define the number of samples.
    * Default is 32
    */
   vtkSetMacro(SSAOKernelSize, unsigned int);
   vtkGetMacro(SSAOKernelSize, unsigned int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When using SSAO, define blurring of the ambient occlusion.
    * Blurring can help to improve the result if samples number is low.
@@ -700,9 +740,9 @@ public:
   vtkSetMacro(SSAOBlur, bool);
   vtkGetMacro(SSAOBlur, bool);
   vtkBooleanMacro(SSAOBlur, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get a custom Render call. Allows to hook a Render call from an
    * external project.It will be used in place of vtkRenderer::Render() if it
@@ -711,18 +751,18 @@ public:
    */
   void SetDelegate(vtkRendererDelegate* d);
   vtkGetObjectMacro(Delegate, vtkRendererDelegate);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the current hardware selector. If the Selector is set, it implies the
    * current render pass is for selection. Mappers/Properties may choose to
    * behave differently when rendering for hardware selection.
    */
   vtkGetObjectMacro(Selector, vtkHardwareSelector);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the texture to be used for the monocular or stereo left eye
    * background. If set and enabled this gets the priority over the gradient
@@ -732,18 +772,18 @@ public:
   vtkTexture* GetLeftBackgroundTexture();
   virtual void SetBackgroundTexture(vtkTexture*);
   vtkGetObjectMacro(BackgroundTexture, vtkTexture);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the texture to be used for the right eye background. If set
    * and enabled this gets the priority over the gradient background.
    */
   virtual void SetRightBackgroundTexture(vtkTexture*);
   vtkGetObjectMacro(RightBackgroundTexture, vtkTexture);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get whether this viewport should have a textured background.
    * Default is off.
@@ -751,29 +791,29 @@ public:
   vtkSetMacro(TexturedBackground, bool);
   vtkGetMacro(TexturedBackground, bool);
   vtkBooleanMacro(TexturedBackground, bool);
-  //@}
+  ///@}
 
   // method to release graphics resources in any derived renderers.
   virtual void ReleaseGraphicsResources(vtkWindow*);
 
-  //@{
+  ///@{
   /**
    * Turn on/off FXAA anti-aliasing, if supported. Initial value is off.
    */
   vtkSetMacro(UseFXAA, bool);
   vtkGetMacro(UseFXAA, bool);
   vtkBooleanMacro(UseFXAA, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The configuration object for FXAA antialiasing.
    */
   vtkGetObjectMacro(FXAAOptions, vtkFXAAOptions);
   virtual void SetFXAAOptions(vtkFXAAOptions*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off rendering of shadows if supported
    * Initial value is off.
@@ -781,9 +821,9 @@ public:
   vtkSetMacro(UseShadows, vtkTypeBool);
   vtkGetMacro(UseShadows, vtkTypeBool);
   vtkBooleanMacro(UseShadows, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If this flag is true and the rendering engine supports it, wireframe
    * geometry will be drawn using hidden line removal.
@@ -791,22 +831,22 @@ public:
   vtkSetMacro(UseHiddenLineRemoval, vtkTypeBool);
   vtkGetMacro(UseHiddenLineRemoval, vtkTypeBool);
   vtkBooleanMacro(UseHiddenLineRemoval, vtkTypeBool);
-  //@}
+  ///@}
 
   // Set/Get a custom render pass.
   // Initial value is NULL.
   void SetPass(vtkRenderPass* p);
   vtkGetObjectMacro(Pass, vtkRenderPass);
 
-  //@{
+  ///@{
   /**
    * Set/Get the information object associated with this algorithm.
    */
   vtkGetObjectMacro(Information, vtkInformation);
   virtual void SetInformation(vtkInformation*);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If this flag is true and the rendering engine supports it, image based
    * lighting is enabled and surface rendering displays environment reflections.
@@ -816,9 +856,9 @@ public:
   vtkSetMacro(UseImageBasedLighting, bool);
   vtkGetMacro(UseImageBasedLighting, bool);
   vtkBooleanMacro(UseImageBasedLighting, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the environment texture used for image based lighting.
    * This texture is supposed to represent the scene background.
@@ -832,23 +872,23 @@ public:
    */
   vtkGetObjectMacro(EnvironmentTexture, vtkTexture);
   virtual void SetEnvironmentTexture(vtkTexture* texture, bool isSRGB = false);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the environment up vector.
    */
   vtkGetVector3Macro(EnvironmentUp, double);
   vtkSetVector3Macro(EnvironmentUp, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the environment right vector.
    */
   vtkGetVector3Macro(EnvironmentRight, double);
   vtkSetVector3Macro(EnvironmentRight, double);
-  //@}
+  ///@}
 
 protected:
   vtkRenderer();
@@ -944,6 +984,24 @@ protected:
    */
   vtkPropCollection* GL2PSSpecialPropCollection;
 
+  /**
+   * Gets the ActiveCamera CompositeProjectionTransformationMatrix, only computing it if necessary.
+   * This function expects that this->ActiveCamera is not nullptr.
+   */
+  const std::array<double, 16>& GetCompositeProjectionTransformationMatrix();
+
+  /**
+   * Gets the ActiveCamera ProjectionTransformationMatrix, only computing it if necessary.
+   * This function expects that this->ActiveCamera is not nullptr.
+   */
+  const std::array<double, 16>& GetProjectionTransformationMatrix();
+
+  /**
+   * Gets the ActiveCamera ViewTransformMatrix, only computing it if necessary.
+   * This function expects that this->ActiveCamera is not nullptr.
+   */
+  const std::array<double, 16>& GetViewTransformMatrix();
+
   /**
    * Ask all props to update and draw any opaque and translucent
    * geometry. This includes both vtkActors and vtkVolumes
@@ -971,20 +1029,20 @@ protected:
    * Ask the active camera to do whatever it needs to do prior to rendering.
    * Creates a camera if none found active.
    */
-  virtual int UpdateCamera(void);
+  virtual int UpdateCamera();
 
   /**
    * Update the geometry of the lights in the scene that are not in world
    * space (for instance, Headlights or CameraLights that are attached to the
    * camera).
    */
-  virtual vtkTypeBool UpdateLightGeometry(void);
+  virtual vtkTypeBool UpdateLightGeometry();
 
   /**
    * Ask all lights to load themselves into rendering pipeline.
    * This method will return the actual number of lights that were on.
    */
-  virtual int UpdateLights(void) { return 0; }
+  virtual int UpdateLights() { return 0; }
 
   /**
    * Get the current camera and reset it only if it gets created
@@ -1097,6 +1155,46 @@ protected:
   double EnvironmentRight[3];
 
 private:
+  /**
+   * Cache of CompositeProjectionTransformationMatrix.
+   */
+  std::array<double, 16> CompositeProjectionTransformationMatrix;
+
+  /**
+   * Tiled Aspect Ratio used to get the transform in this->CompositeProjectionTransformationMatrix.
+   */
+  double LastCompositeProjectionTransformationMatrixTiledAspectRatio;
+
+  /**
+   * Modified time from the camera when this->CompositeProjectionTransformationMatrix was set.
+   */
+  vtkMTimeType LastCompositeProjectionTransformationMatrixCameraModified;
+
+  /**
+   * Cache of ProjectionTransformationMatrix.
+   */
+  std::array<double, 16> ProjectionTransformationMatrix;
+
+  /**
+   * Tiled Aspect Ratio used to get the transform in this->ProjectionTransformationMatrix.
+   */
+  double LastProjectionTransformationMatrixTiledAspectRatio;
+
+  /**
+   * Modified time from the camera when this->ProjectionTransformationMatrix was set.
+   */
+  vtkMTimeType LastProjectionTransformationMatrixCameraModified;
+
+  /**
+   * Cache of ViewTransformMatrix.
+   */
+  std::array<double, 16> ViewTransformMatrix;
+
+  /**
+   * Modified time from the camera when this->ViewTransformMatrix was set.
+   */
+  vtkMTimeType LastViewTransformCameraModified;
+
   vtkRenderer(const vtkRenderer&) = delete;
   void operator=(const vtkRenderer&) = delete;
 };
@@ -1114,4 +1212,5 @@ inline vtkCullerCollection* vtkRenderer::GetCullers()
   return this->Cullers;
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
