@@ -17,17 +17,18 @@
 
 #include "vtkObjectFactory.h"
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStringToImage::vtkStringToImage()
 {
   this->Antialias = true;
   this->ScaleToPowerOfTwo = false;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStringToImage::~vtkStringToImage() = default;
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStringToImage::SetScaleToPowerOfTwo(bool scale)
 {
   if (this->ScaleToPowerOfTwo != scale)
@@ -37,9 +38,10 @@ void vtkStringToImage::SetScaleToPowerOfTwo(bool scale)
   }
 }
 
-//-----------------------------------------------------------------------------
-void vtkStringToImage::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkStringToImage::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "ScaleToPowerOfTwo: " << this->ScaleToPowerOfTwo << endl;
 }
+VTK_ABI_NAMESPACE_END
