@@ -31,6 +31,7 @@
 #include "vtkObject.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGCORE_EXPORT vtkTDxInteractorStyleSettings : public vtkObject
 {
 public:
@@ -38,7 +39,7 @@ public:
   vtkTypeMacro(vtkTDxInteractorStyleSettings, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Sensitivity of the rotation angle. This can be any value:
    * positive, negative, null.
@@ -52,36 +53,36 @@ public:
    */
   vtkSetMacro(AngleSensitivity, double);
   vtkGetMacro(AngleSensitivity, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Use or mask the rotation component around the X-axis. Initial value is
    * true.
    */
   vtkSetMacro(UseRotationX, bool);
   vtkGetMacro(UseRotationX, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Use or mask the rotation component around the Y-axis. Initial value is
    * true.
    */
   vtkSetMacro(UseRotationY, bool);
   vtkGetMacro(UseRotationY, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Use or mask the rotation component around the Z-axis. Initial value is
    * true.
    */
   vtkSetMacro(UseRotationZ, bool);
   vtkGetMacro(UseRotationZ, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sensitivity of the translation along the X-axis. This can be any value:
    * positive, negative, null.
@@ -96,25 +97,25 @@ public:
    */
   vtkSetMacro(TranslationXSensitivity, double);
   vtkGetMacro(TranslationXSensitivity, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sensitivity of the translation along the Y-axis.
    * See comment of SetTranslationXSensitivity().
    */
   vtkSetMacro(TranslationYSensitivity, double);
   vtkGetMacro(TranslationYSensitivity, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Sensitivity of the translation along the Z-axis.
    * See comment of SetTranslationXSensitivity().
    */
   vtkSetMacro(TranslationZSensitivity, double);
   vtkGetMacro(TranslationZSensitivity, double);
-  //@}
+  ///@}
 
 protected:
   vtkTDxInteractorStyleSettings();
@@ -133,4 +134,5 @@ private:
   vtkTDxInteractorStyleSettings(const vtkTDxInteractorStyleSettings&) = delete;
   void operator=(const vtkTDxInteractorStyleSettings&) = delete;
 };
+VTK_ABI_NAMESPACE_END
 #endif
