@@ -14,31 +14,32 @@
 =========================================================================*/
 #include "vtkTextActor3D.h"
 
-#include "vtkObjectFactory.h"
 #include "vtkCamera.h"
 #include "vtkImageActor.h"
 #include "vtkImageData.h"
+#include "vtkMath.h"
+#include "vtkMatrix4x4.h"
+#include "vtkObjectFactory.h"
+#include "vtkRenderWindow.h"
+#include "vtkRenderer.h"
 #include "vtkStdString.h"
-#include "vtkTransform.h"
 #include "vtkTextProperty.h"
 #include "vtkTextRenderer.h"
-#include "vtkRenderer.h"
-#include "vtkRenderWindow.h"
+#include "vtkTransform.h"
 #include "vtkWindow.h"
-#include "vtkMatrix4x4.h"
-#include "vtkMath.h"
 
-vtkObjectFactoryNewMacro(vtkTextActor3D)
+VTK_ABI_NAMESPACE_BEGIN
+vtkObjectFactoryNewMacro(vtkTextActor3D);
 
 vtkCxxSetObjectMacro(vtkTextActor3D, TextProperty, vtkTextProperty);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTextActor3D::vtkTextActor3D()
 {
-  this->Input        = nullptr;
+  this->Input = nullptr;
   this->LastInputString = "";
-  this->ImageActor   = vtkImageActor::New();
-  this->ImageData    = nullptr;
+  this->ImageActor = vtkImageActor::New();
+  this->ImageData = nullptr;
   this->TextProperty = nullptr;
 
   this->BuildTime.Modified();
@@ -49,7 +50,7 @@ vtkTextActor3D::vtkTextActor3D()
   this->ImageActor->InterpolateOn();
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTextActor3D::~vtkTextActor3D()
 {
   this->SetTextProperty(nullptr);
@@ -65,10 +66,10 @@ vtkTextActor3D::~vtkTextActor3D()
   }
 }
 
-// --------------------------------------------------------------------------
-void vtkTextActor3D::ShallowCopy(vtkProp *prop)
+//------------------------------------------------------------------------------
+void vtkTextActor3D::ShallowCopy(vtkProp* prop)
 {
-  vtkTextActor3D *a = vtkTextActor3D::SafeDownCast(prop);
+  vtkTextActor3D* a = vtkTextActor3D::SafeDownCast(prop);
   if (a != nullptr)
   {
     this->SetInput(a->GetInput());
@@ -78,7 +79,7 @@ void vtkTextActor3D::ShallowCopy(vtkProp *prop)
   this->Superclass::ShallowCopy(prop);
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double* vtkTextActor3D::GetBounds()
 {
   // the culler could be asking our bounds, in which case it's possible
@@ -95,101 +96,99 @@ double* vtkTextActor3D::GetBounds()
   return this->Bounds;
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextActor3D::GetBoundingBox(int bbox[4])
 {
   if (!this->TextProperty)
   {
-    vtkErrorMacro(<<"Need valid vtkTextProperty.");
+    vtkErrorMacro(<< "Need valid vtkTextProperty.");
     return 0;
   }
 
   if (!bbox)
   {
-    vtkErrorMacro(<<"Need 4-element int array for bounding box.");
+    vtkErrorMacro(<< "Need 4-element int array for bounding box.");
     return 0;
   }
 
-  vtkTextRenderer *tRend = vtkTextRenderer::GetInstance();
+  vtkTextRenderer* tRend = vtkTextRenderer::GetInstance();
   if (!tRend)
   {
-    vtkErrorMacro(<<"Failed getting the TextRenderer instance.");
+    vtkErrorMacro(<< "Failed getting the TextRenderer instance.");
     return 0;
   }
 
-  if (!tRend->GetBoundingBox(this->TextProperty, this->Input, bbox,
-                             vtkTextActor3D::GetRenderedDPI()))
+  if (!tRend->GetBoundingBox(
+        this->TextProperty, this->Input, bbox, vtkTextActor3D::GetRenderedDPI()))
   {
-    vtkErrorMacro(<<"No text in input.");
+    vtkErrorMacro(<< "No text in input.");
     return 0;
   }
 
   return 1;
 }
 
-// --------------------------------------------------------------------------
-void vtkTextActor3D::ReleaseGraphicsResources(vtkWindow *win)
+//------------------------------------------------------------------------------
+void vtkTextActor3D::ReleaseGraphicsResources(vtkWindow* win)
 {
   this->ImageActor->ReleaseGraphicsResources(win);
   this->Superclass::ReleaseGraphicsResources(win);
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::SetForceOpaque(bool opaque)
 {
   this->ImageActor->SetForceOpaque(opaque);
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextActor3D::GetForceOpaque()
 {
   return this->ImageActor->GetForceOpaque();
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::ForceOpaqueOn()
 {
   this->ImageActor->ForceOpaqueOn();
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::ForceOpaqueOff()
 {
   this->ImageActor->ForceOpaqueOff();
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::SetForceTranslucent(bool trans)
 {
   this->ImageActor->SetForceTranslucent(trans);
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextActor3D::GetForceTranslucent()
 {
   return this->ImageActor->GetForceTranslucent();
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::ForceTranslucentOn()
 {
   this->ImageActor->ForceTranslucentOn();
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::ForceTranslucentOff()
 {
   this->ImageActor->ForceTranslucentOff();
 }
 
-// --------------------------------------------------------------------------
-int vtkTextActor3D::RenderOverlay(vtkViewport *viewport)
+//------------------------------------------------------------------------------
+int vtkTextActor3D::RenderOverlay(vtkViewport* viewport)
 {
   int rendered_something = 0;
 
-  if (this->UpdateImageActor() &&
-      this->ImageData &&
-      this->ImageData->GetNumberOfPoints() > 0)
+  if (this->UpdateImageActor() && this->ImageData && this->ImageData->GetNumberOfPoints() > 0)
   {
     rendered_something += this->ImageActor->RenderOverlay(viewport);
   }
@@ -197,23 +196,20 @@ int vtkTextActor3D::RenderOverlay(vtkViewport *viewport)
   return rendered_something;
 }
 
-// ----------------------------------------------------------------------------
-int vtkTextActor3D::RenderTranslucentPolygonalGeometry(vtkViewport *viewport)
+//------------------------------------------------------------------------------
+int vtkTextActor3D::RenderTranslucentPolygonalGeometry(vtkViewport* viewport)
 {
   int rendered_something = 0;
 
-  if (this->UpdateImageActor() &&
-      this->ImageData &&
-      this->ImageData->GetNumberOfPoints() > 0)
+  if (this->UpdateImageActor() && this->ImageData && this->ImageData->GetNumberOfPoints() > 0)
   {
-    rendered_something +=
-      this->ImageActor->RenderTranslucentPolygonalGeometry(viewport);
+    rendered_something += this->ImageActor->RenderTranslucentPolygonalGeometry(viewport);
   }
 
   return rendered_something;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Does this prop have some translucent polygonal geometry?
 vtkTypeBool vtkTextActor3D::HasTranslucentPolygonalGeometry()
@@ -222,14 +218,14 @@ vtkTypeBool vtkTextActor3D::HasTranslucentPolygonalGeometry()
   return this->ImageActor->HasTranslucentPolygonalGeometry();
 }
 
-// --------------------------------------------------------------------------
-int vtkTextActor3D::RenderOpaqueGeometry(vtkViewport *viewport)
+//------------------------------------------------------------------------------
+int vtkTextActor3D::RenderOpaqueGeometry(vtkViewport* viewport)
 {
   int rendered_something = 0;
 
-  if (vtkRenderer *renderer = vtkRenderer::SafeDownCast(viewport))
+  if (vtkRenderer* renderer = vtkRenderer::SafeDownCast(viewport))
   {
-    if (vtkRenderWindow *renderWindow = renderer->GetRenderWindow())
+    if (vtkRenderWindow* renderWindow = renderer->GetRenderWindow())
     {
       // Is the viewport's RenderWindow capturing GL2PS-special props?
       if (renderWindow->GetCapturingGL2PSSpecialProps())
@@ -239,8 +235,7 @@ int vtkTextActor3D::RenderOpaqueGeometry(vtkViewport *viewport)
     }
   }
 
-  if (this->UpdateImageActor() &&
-      this->ImageData && this->ImageData->GetNumberOfPoints() > 0)
+  if (this->UpdateImageActor() && this->ImageData && this->ImageData->GetNumberOfPoints() > 0)
   {
     rendered_something += this->ImageActor->RenderOpaqueGeometry(viewport);
   }
@@ -248,13 +243,13 @@ int vtkTextActor3D::RenderOpaqueGeometry(vtkViewport *viewport)
   return rendered_something;
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextActor3D::UpdateImageActor()
 {
   // Need text prop
   if (!this->TextProperty)
   {
-    vtkErrorMacro(<<"Need a text property to render text actor");
+    vtkErrorMacro(<< "Need a text property to render text actor");
     this->ImageActor->SetInputData(nullptr);
     return 0;
   }
@@ -267,7 +262,7 @@ int vtkTextActor3D::UpdateImageActor()
   }
 
   // copy information to the delegate
-  vtkInformation *info = this->GetPropertyKeys();
+  vtkInformation* info = this->GetPropertyKeys();
   this->ImageActor->SetPropertyKeys(info);
 
   // Do we need to (re-)render the text ?
@@ -275,9 +270,8 @@ int vtkTextActor3D::UpdateImageActor()
   //  - instance has been modified since last build
   //  - text prop has been modified since last build
   //  - ImageData ivar has not been allocated yet
-  if (this->GetMTime() > this->BuildTime ||
-      this->TextProperty->GetMTime() > this->BuildTime ||
-      !this->ImageData)
+  if (this->GetMTime() > this->BuildTime || this->TextProperty->GetMTime() > this->BuildTime ||
+    !this->ImageData)
   {
     // we have to give vtkFTU::RenderString something to work with
     if (!this->ImageData)
@@ -286,21 +280,20 @@ int vtkTextActor3D::UpdateImageActor()
       this->ImageData->SetSpacing(1.0, 1.0, 1.0);
     }
 
-    vtkTextRenderer *tRend = vtkTextRenderer::GetInstance();
+    vtkTextRenderer* tRend = vtkTextRenderer::GetInstance();
     if (!tRend)
     {
-      vtkErrorMacro(<<"Failed getting the TextRenderer instance.");
+      vtkErrorMacro(<< "Failed getting the TextRenderer instance.");
       this->ImageActor->SetInputData(nullptr);
       return 0;
     }
 
-    if (this->TextProperty->GetMTime() > this->BuildTime ||
-        this->LastInputString != this->Input)
+    if (this->TextProperty->GetMTime() > this->BuildTime || this->LastInputString != this->Input)
     {
-      if (!tRend->RenderString(this->TextProperty, this->Input, this->ImageData,
-                               nullptr, vtkTextActor3D::GetRenderedDPI()))
+      if (!tRend->RenderString(this->TextProperty, this->Input, this->ImageData, nullptr,
+            vtkTextActor3D::GetRenderedDPI()))
       {
-        vtkErrorMacro(<<"Failed rendering text to buffer");
+        vtkErrorMacro(<< "Failed rendering text to buffer");
         this->ImageActor->SetInputData(nullptr);
         return 0;
       }
@@ -309,7 +302,7 @@ int vtkTextActor3D::UpdateImageActor()
       this->ImageActor->SetInputData(this->ImageData);
 
       // Only render the visible portions of the texture.
-      int bbox[6] = {0, 0, 0, 0, 0, 0};
+      int bbox[6] = { 0, 0, 0, 0, 0, 0 };
       this->GetBoundingBox(bbox);
       this->ImageActor->SetDisplayExtent(bbox);
       this->LastInputString = this->Input;
@@ -319,7 +312,7 @@ int vtkTextActor3D::UpdateImageActor()
   } // if (this->GetMTime() ...
 
   // Position the actor
-  vtkMatrix4x4 *matrix = this->ImageActor->GetUserMatrix();
+  vtkMatrix4x4* matrix = this->ImageActor->GetUserMatrix();
   if (!matrix)
   {
     matrix = vtkMatrix4x4::New();
@@ -331,10 +324,10 @@ int vtkTextActor3D::UpdateImageActor()
   return 1;
 }
 
-// --------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextActor3D::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Input: " << (this->Input ? this->Input : "(none)") << "\n";
 
@@ -348,3 +341,4 @@ void vtkTextActor3D::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Text Property: (none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
