@@ -25,7 +25,6 @@
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper2D.h"
 #include "vtkRenderer.h"
-#include "vtkStdString.h"
 #include "vtkTextProperty.h"
 #include "vtkTextRenderer.h"
 #include "vtkTexture.h"
@@ -34,6 +33,7 @@
 #include <algorithm>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkTextMapper);
 //------------------------------------------------------------------------------
 vtkCxxSetObjectMacro(vtkTextMapper, TextProperty, vtkTextProperty);
@@ -169,7 +169,7 @@ int vtkTextMapper::GetHeight(vtkViewport* viewport)
 //------------------------------------------------------------------------------
 int vtkTextMapper::SetConstrainedFontSize(vtkViewport* viewport, int targetWidth, int targetHeight)
 {
-  return this->SetConstrainedFontSize(this, viewport, targetWidth, targetHeight);
+  return vtkTextMapper::SetConstrainedFontSize(this, viewport, targetWidth, targetHeight);
 }
 
 //------------------------------------------------------------------------------
@@ -523,3 +523,4 @@ void vtkTextMapper::UpdateImage(int dpi)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
