@@ -15,6 +15,7 @@
 #include "vtkTextProperty.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTextProperty);
 
 //------------------------------------------------------------------------------
@@ -105,6 +106,10 @@ void vtkTextProperty::ShallowCopy(vtkTextProperty* tprop)
   this->SetCellOffset(tprop->GetCellOffset());
 
   this->SetShadowOffset(tprop->GetShadowOffset());
+
+  this->SetInteriorLinesVisibility(tprop->GetInteriorLinesVisibility());
+  this->SetInteriorLinesWidth(tprop->GetInteriorLinesWidth());
+  this->SetInteriorLinesColor(tprop->GetInteriorLinesColor());
 }
 
 //------------------------------------------------------------------------------
@@ -160,4 +165,36 @@ void vtkTextProperty::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Line Offset: " << this->LineOffset << "\n";
   os << indent << "Line Spacing: " << this->LineSpacing << "\n";
   os << indent << "Cell Offset: " << this->CellOffset << "\n";
+  os << indent
+     << "Interior Lines Visibility: " << (this->InteriorLinesVisibility ? "On\n" : "Off\n");
+  os << indent << "Interior Lines Width: " << (this->InteriorLinesWidth ? "On\n" : "Off\n");
+  os << indent << "Interior Lines Color: (" << this->InteriorLinesColor[0] << ", "
+     << this->InteriorLinesColor[1] << ", " << this->InteriorLinesColor[2] << ")\n";
 }
+
+//------------------------------------------------------------------------------
+void vtkTextProperty::SetBackgroundRGBA(double rgba[4])
+{
+  this->SetBackgroundRGBA(rgba[0], rgba[1], rgba[2], rgba[3]);
+}
+
+//------------------------------------------------------------------------------
+void vtkTextProperty::SetBackgroundRGBA(double r, double g, double b, double a)
+{
+  this->SetBackgroundColor(r, g, b);
+  this->SetBackgroundOpacity(a);
+}
+
+//------------------------------------------------------------------------------
+void vtkTextProperty::GetBackgroundRGBA(double rgba[4])
+{
+  this->GetBackgroundRGBA(rgba[0], rgba[1], rgba[2], rgba[3]);
+}
+
+//------------------------------------------------------------------------------
+void vtkTextProperty::GetBackgroundRGBA(double& r, double& g, double& b, double& a)
+{
+  this->GetBackgroundColor(r, g, b);
+  a = this->GetBackgroundOpacity();
+}
+VTK_ABI_NAMESPACE_END
