@@ -21,12 +21,12 @@
 #include "vtkPath.h"
 #include "vtkStdString.h"
 #include "vtkTextProperty.h"
-#include "vtkUnicodeString.h"
 
 #include <vtksys/RegularExpression.hxx>
 
 //------------------------------------------------------------------------------
 // The singleton, and the singleton cleanup
+VTK_ABI_NAMESPACE_BEGIN
 vtkTextRenderer* vtkTextRenderer::Instance = nullptr;
 vtkTextRendererCleanup vtkTextRenderer::Cleanup;
 
@@ -109,6 +109,7 @@ vtkTextRenderer::~vtkTextRenderer()
 {
   delete this->MathTextRegExp;
   delete this->MathTextRegExp2;
+  delete this->MathTextRegExpColumn;
 }
 
 //------------------------------------------------------------------------------
@@ -134,30 +135,6 @@ int vtkTextRenderer::DetectBackend(const vtkStdString& str)
   return static_cast<int>(FreeType);
 }
 
-//------------------------------------------------------------------------------
-int vtkTextRenderer::DetectBackend(const vtkUnicodeString& str)
-{
-  if (!str.empty())
-  {
-    // the vtksys::RegularExpression class doesn't support {...|...} "or"
-    // branching, so we check the first character to see which regexp to use:
-    //
-    // Find unescaped "$...$" patterns where "$" is not the first character:
-    //   MathTextRegExp  = "[^\\]\\$.*[^\\]\\$"
-    // Find unescaped "$...$" patterns where "$" is the first character:
-    //   MathTextRegExp2 = "^\\$.*[^\\]\\$"
-    // Find unescaped "|" character that defines a multicolumn line
-    //  MathTextRegExpColumn = "[^\\]|"
-    if ((str[0] == '$' && this->MathTextRegExp2->find(str.utf8_str())) ||
-      this->MathTextRegExp->find(str.utf8_str()) ||
-      this->MathTextRegExpColumn->find(str.utf8_str()))
-    {
-      return static_cast<int>(MathText);
-    }
-  }
-  return static_cast<int>(FreeType);
-}
-
 //------------------------------------------------------------------------------
 void vtkTextRenderer::CleanUpFreeTypeEscapes(vtkStdString& str)
 {
@@ -168,46 +145,4 @@ void vtkTextRenderer::CleanUpFreeTypeEscapes(vtkStdString& str)
     ind = str.find("\\$", ind + 1);
   }
 }
-
-//------------------------------------------------------------------------------
-void vtkTextRenderer::CleanUpFreeTypeEscapes(vtkUnicodeString& str)
-{
-  // vtkUnicodeString has only a subset of the std::string API available, so
-  // this method is more complex than the std::string overload.
-  vtkUnicodeString::const_iterator begin = str.begin();
-  vtkUnicodeString::const_iterator end = str.end();
-  vtkUnicodeString tmp;
-
-  for (vtkUnicodeString::const_iterator it = begin; it != end; ++it)
-  {
-    if (*it != '\\')
-    {
-      continue;
-    }
-
-    // No operator+ in the unicode string iterator. Copy and advance it:
-    vtkUnicodeString::const_iterator nextChar = it;
-    std::advance(nextChar, 1);
-    if (*nextChar != '$')
-    {
-      continue;
-    }
-
-    // We found a "\$" in the string. Append [begin, it) into tmp.
-    tmp.append(begin, it);
-
-    // Add the dollar sign
-    tmp.append(vtkUnicodeString::from_utf8("$"));
-
-    // Reset the iterators to continue checking the rest of the string.
-    begin = it;
-    std::advance(it, 1);
-    std::advance(begin, 2);
-  }
-
-  // Append the last bit of the string to tmp
-  tmp.append(begin, end);
-
-  // Update the input with the cleaned up string:
-  str = tmp;
-}
+VTK_ABI_NAMESPACE_END
