@@ -46,23 +46,25 @@
 #ifndef vtkTextRenderer_h
 #define vtkTextRenderer_h
 
-#include "vtkDeprecation.h" // for deprecation macros
 #include "vtkObject.h"
 #include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkTuple.h"               // For metrics struct
 #include "vtkVector.h"              // For metrics struct
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 class vtkPath;
 class vtkStdString;
-class vtkUnicodeString;
 class vtkTextProperty;
+VTK_ABI_NAMESPACE_END
 
 namespace vtksys
 {
 class RegularExpression;
 }
 
+VTK_ABI_NAMESPACE_BEGIN
+
 class VTKRENDERINGCORE_EXPORT vtkTextRendererCleanup
 {
 public:
@@ -170,7 +172,6 @@ public:
    * Determine the appropriate back end needed to render the given string.
    */
   virtual int DetectBackend(const vtkStdString& str);
-  virtual int DetectBackend(const vtkUnicodeString& str);
   ///@}
 
   /**
@@ -192,10 +193,6 @@ public:
   {
     return this->GetBoundingBoxInternal(tprop, str, bbox, dpi, backend);
   }
-  VTK_DEPRECATED_IN_9_1_0("Use bool GetBoundingBox(vtkTextProperty* tprop, const vtkStdString& "
-                          "str, int bbox[4], int dpi, int backend)")
-  bool GetBoundingBox(vtkTextProperty* tprop, const vtkUnicodeString& str, int bbox[4], int dpi,
-    int backend = Default);
   ///@}
 
   ///@{
@@ -209,10 +206,6 @@ public:
   {
     return this->GetMetricsInternal(tprop, str, metrics, dpi, backend);
   }
-  VTK_DEPRECATED_IN_9_1_0("Use bool GetMetrics(vtkTextProperty* tprop, const vtkStdString& str, "
-                          "Metrics& metrics, int dpi, int backend)")
-  bool GetMetrics(vtkTextProperty* tprop, const vtkUnicodeString& str, Metrics& metrics, int dpi,
-    int backend = Default);
   ///@}
 
   ///@{
@@ -235,10 +228,6 @@ public:
   {
     return this->RenderStringInternal(tprop, str, data, textDims, dpi, backend);
   }
-  VTK_DEPRECATED_IN_9_1_0("Use bool RenderString(vtkTextProperty* tprop, const vtkStdString& str, "
-                          "vtkImageData* data, int textDims[2], int dpi, int backend)")
-  bool RenderString(vtkTextProperty* tprop, const vtkUnicodeString& str, vtkImageData* data,
-    int textDims[2], int dpi, int backend = Default);
   ///@}
 
   ///@{
@@ -254,11 +243,6 @@ public:
     return this->GetConstrainedFontSizeInternal(
       str, tprop, targetWidth, targetHeight, dpi, backend);
   }
-  VTK_DEPRECATED_IN_9_1_0(
-    "Use int GetConstrainedFontSize(const vtkStdString& str, vtkTextProperty* tprop, int "
-    "targetWidth, int targetHeight, int dpi, int backend)")
-  int GetConstrainedFontSize(const vtkUnicodeString& str, vtkTextProperty* tprop, int targetWidth,
-    int targetHeight, int dpi, int backend = Default);
   ///@}
 
   ///@{
@@ -274,10 +258,6 @@ public:
   {
     return this->StringToPathInternal(tprop, str, path, dpi, backend);
   }
-  VTK_DEPRECATED_IN_9_1_0("Use bool StringToPath(vtkTextProperty* tprop, const vtkStdString& str, "
-                          "vtkPath* path, int dpi, int backend)")
-  bool StringToPath(vtkTextProperty* tprop, const vtkUnicodeString& str, vtkPath* path, int dpi,
-    int backend = Default);
   ///@}
 
   /**
@@ -300,36 +280,14 @@ protected:
    */
   virtual bool GetBoundingBoxInternal(
     vtkTextProperty* tprop, const vtkStdString& str, int bbox[4], int dpi, int backend) = 0;
-  VTK_DEPRECATED_IN_9_1_0("Use bool GetBoundingBoxInternal(vtkTextProperty* tprop, const "
-                          "vtkStdString& str, int bbox[4], int dpi, int backend)")
-  virtual bool GetBoundingBoxInternal(
-    vtkTextProperty* tprop, const vtkUnicodeString& str, int bbox[4], int dpi, int backend) = 0;
   virtual bool GetMetricsInternal(
     vtkTextProperty* tprop, const vtkStdString& str, Metrics& metrics, int dpi, int backend) = 0;
-  VTK_DEPRECATED_IN_9_1_0("Use bool GetMetricsInternal(vtkTextProperty* tprop, const vtkStdString& "
-                          "str, Metrics& metrics, int dpi, int backend)")
-  virtual bool GetMetricsInternal(vtkTextProperty* tprop, const vtkUnicodeString& str,
-    Metrics& metrics, int dpi, int backend) = 0;
   virtual bool RenderStringInternal(vtkTextProperty* tprop, const vtkStdString& str,
     vtkImageData* data, int textDims[2], int dpi, int backend) = 0;
-  VTK_DEPRECATED_IN_9_1_0(
-    "Use bool RenderStringInternal(vtkTextProperty* tprop, const vtkStdString& str, vtkImageData* "
-    "data, int textDims[2], int dpi, int backend)")
-  virtual bool RenderStringInternal(vtkTextProperty* tprop, const vtkUnicodeString& str,
-    vtkImageData* data, int textDims[2], int dpi, int backend) = 0;
   virtual int GetConstrainedFontSizeInternal(const vtkStdString& str, vtkTextProperty* tprop,
     int targetWidth, int targetHeight, int dpi, int backend) = 0;
-  VTK_DEPRECATED_IN_9_1_0(
-    "Use int GetConstrainedFontSizeInternal(const vtkStdString& str, vtkTextProperty* tprop, int "
-    "targetWidth, int targetHeight, int dpi, int backend)")
-  virtual int GetConstrainedFontSizeInternal(const vtkUnicodeString& str, vtkTextProperty* tprop,
-    int targetWidth, int targetHeight, int dpi, int backend) = 0;
   virtual bool StringToPathInternal(
     vtkTextProperty* tprop, const vtkStdString& str, vtkPath* path, int dpi, int backend) = 0;
-  VTK_DEPRECATED_IN_9_1_0("Use bool StringToPathInternal(vtkTextProperty* tprop, const "
-                          "vtkStdString& str, vtkPath* path, int dpi, int backend)")
-  virtual bool StringToPathInternal(
-    vtkTextProperty* tprop, const vtkUnicodeString& str, vtkPath* path, int dpi, int backend) = 0;
   virtual void SetScaleToPowerOfTwoInternal(bool scale) = 0;
   ///@}
 
@@ -356,8 +314,6 @@ protected:
    * Replace all instances of "\$" with "$".
    */
   virtual void CleanUpFreeTypeEscapes(vtkStdString& str);
-  VTK_DEPRECATED_IN_9_1_0("Use void CleanUpFreeTypeEscapes(vtkStdString& str)")
-  virtual void CleanUpFreeTypeEscapes(vtkUnicodeString& str);
   ///@}
 
   /**
@@ -370,4 +326,5 @@ private:
   void operator=(const vtkTextRenderer&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkTextRenderer_h
