@@ -16,29 +16,29 @@
 
 #include "vtkDataSetAttributes.h"
 #include "vtkExecutive.h"
-#include "vtkObjectFactory.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkLookupTable.h"
-#include "vtkRenderer.h"
-#include "vtkRenderWindow.h"
-#include "vtkTransform.h"
+#include "vtkObjectFactory.h"
 #include "vtkPointData.h"
+#include "vtkRenderWindow.h"
+#include "vtkRenderer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkTransform.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkTexture, LookupTable, vtkScalarsToColors);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Return nullptr if no override is supplied.
-vtkAbstractObjectFactoryNewMacro(vtkTexture)
-//----------------------------------------------------------------------------
+vtkObjectFactoryNewMacro(vtkTexture);
+//------------------------------------------------------------------------------
 
 // Construct object and initialize.
 vtkTexture::vtkTexture()
 {
+  this->Wrap = Repeat;
   this->Mipmap = false;
-  this->Repeat = 1;
   this->Interpolate = 0;
-  this->EdgeClamp = 0;
   this->MaximumAnisotropicFiltering = 4.0;
   this->Quality = VTK_TEXTURE_QUALITY_DEFAULT;
   this->PremultipliedAlpha = false;
@@ -58,13 +58,17 @@ vtkTexture::vtkTexture()
 
   this->RestrictPowerOf2ImageSmaller = 0;
 
+  this->BorderColor[0] = 0.0f;
+  this->BorderColor[1] = 0.0f;
+  this->BorderColor[2] = 0.0f;
+  this->BorderColor[3] = 0.0f;
+
   // By default select active point scalars.
-  this->SetInputArrayToProcess(0,0,0,
-    vtkDataObject::FIELD_ASSOCIATION_POINTS_THEN_CELLS,
-    vtkDataSetAttributes::SCALARS);
+  this->SetInputArrayToProcess(
+    0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS_THEN_CELLS, vtkDataSetAttributes::SCALARS);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTexture::~vtkTexture()
 {
   if (this->MappedScalars)
@@ -77,14 +81,14 @@ vtkTexture::~vtkTexture()
     this->LookupTable->UnRegister(this);
   }
 
-  if(this->Transform != nullptr)
+  if (this->Transform != nullptr)
   {
     this->Transform->UnRegister(this);
   }
 }
 
-//----------------------------------------------------------------------------
-vtkImageData *vtkTexture::GetInput()
+//------------------------------------------------------------------------------
+vtkImageData* vtkTexture::GetInput()
 {
   if (this->GetNumberOfInputConnections(0) < 1)
   {
@@ -93,7 +97,7 @@ vtkImageData *vtkTexture::GetInput()
   return vtkImageData::SafeDownCast(this->GetExecutive()->GetInputData(0, 0));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTexture::SetCubeMap(bool val)
 {
   if (val == this->CubeMap)
@@ -106,9 +110,8 @@ void vtkTexture::SetCubeMap(bool val)
     this->SetNumberOfInputPorts(6);
     for (int i = 0; i < 6; ++i)
     {
-      this->SetInputArrayToProcess(i, i, 0,
-        vtkDataObject::FIELD_ASSOCIATION_POINTS_THEN_CELLS,
-        vtkDataSetAttributes::SCALARS);
+      this->SetInputArrayToProcess(
+        i, i, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS_THEN_CELLS, vtkDataSetAttributes::SCALARS);
     }
   }
   else
@@ -119,8 +122,8 @@ void vtkTexture::SetCubeMap(bool val)
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
-void vtkTexture::SetTransform(vtkTransform *transform)
+//------------------------------------------------------------------------------
+void vtkTexture::SetTransform(vtkTransform* transform)
 {
   if (transform == this->Transform)
   {
@@ -141,16 +144,15 @@ void vtkTexture::SetTransform(vtkTransform *transform)
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTexture::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
+  const int WrapAsString[4] = { ClampToEdge, Repeat, MirroredRepeat, ClampToBorder };
   os << indent << "MaximumAnisotropicFiltering: " << this->MaximumAnisotropicFiltering << "\n";
   os << indent << "Mipmap: " << (this->Mipmap ? "On\n" : "Off\n");
   os << indent << "Interpolate: " << (this->Interpolate ? "On\n" : "Off\n");
-  os << indent << "Repeat:      " << (this->Repeat ? "On\n" : "Off\n");
-  os << indent << "EdgeClamp:   " << (this->EdgeClamp ? "On\n" : "Off\n");
   os << indent << "CubeMap:   " << (this->CubeMap ? "On\n" : "Off\n");
   os << indent << "UseSRGBColorSpace:   " << (this->UseSRGBColorSpace ? "On\n" : "Off\n");
   os << indent << "Quality:     ";
@@ -181,28 +183,31 @@ void vtkTexture::PrintSelf(ostream& os, vtkIndent indent)
       break;
   }
   os << "\n";
+  os << indent << "Wrap: " << WrapAsString[this->Wrap] << "\n";
+  os << indent << "Border Color: { " << this->BorderColor[0] << ", " << this->BorderColor[1] << ", "
+     << this->BorderColor[2] << ", " << this->BorderColor[3] << " }\n";
 
   os << indent << "PremultipliedAlpha: " << (this->PremultipliedAlpha ? "On\n" : "Off\n");
 
-  if ( this->GetInput() )
+  if (this->GetInput())
   {
-    os << indent << "Input: (" << static_cast<void *>(this->GetInput()) << ")\n";
+    os << indent << "Input: (" << static_cast<void*>(this->GetInput()) << ")\n";
   }
   else
   {
     os << indent << "Input: (none)\n";
   }
-  if ( this->LookupTable )
+  if (this->LookupTable)
   {
     os << indent << "LookupTable:\n";
-    this->LookupTable->PrintSelf (os, indent.GetNextIndent ());
+    this->LookupTable->PrintSelf(os, indent.GetNextIndent());
   }
   else
   {
     os << indent << "LookupTable: (none)\n";
   }
 
-  if ( this->MappedScalars )
+  if (this->MappedScalars)
   {
     os << indent << "Mapped Scalars: " << this->MappedScalars << "\n";
   }
@@ -211,7 +216,7 @@ void vtkTexture::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Mapped Scalars: (none)\n";
   }
 
-  if ( this->Transform )
+  if (this->Transform)
   {
     os << indent << "Transform: " << this->Transform << "\n";
   }
@@ -244,11 +249,12 @@ void vtkTexture::PrintSelf(ostream& os, vtkIndent indent)
       os << "Subtract\n";
       break;
   }
-  os << indent << "RestrictPowerOf2ImageSmaller:   " << (this->RestrictPowerOf2ImageSmaller ? "On\n" : "Off\n");
+  os << indent << "RestrictPowerOf2ImageSmaller:   "
+     << (this->RestrictPowerOf2ImageSmaller ? "On\n" : "Off\n");
 }
 
-//----------------------------------------------------------------------------
-unsigned char *vtkTexture::MapScalarsToColors (vtkDataArray *scalars)
+//------------------------------------------------------------------------------
+unsigned char* vtkTexture::MapScalarsToColors(vtkDataArray* scalars)
 {
   // if there is no lookup table, create one
   if (this->LookupTable == nullptr)
@@ -256,7 +262,7 @@ unsigned char *vtkTexture::MapScalarsToColors (vtkDataArray *scalars)
     this->LookupTable = vtkLookupTable::New();
     this->LookupTable->Register(this);
     this->LookupTable->Delete();
-    this->LookupTable->Build ();
+    this->LookupTable->Build();
     this->SelfAdjustingTableRange = 1;
   }
   else
@@ -280,23 +286,23 @@ unsigned char *vtkTexture::MapScalarsToColors (vtkDataArray *scalars)
   // map the scalars to colors
   this->MappedScalars = this->LookupTable->MapScalars(scalars, this->ColorMode, -1);
 
-  return this->MappedScalars? reinterpret_cast<unsigned char*>(
-    this->MappedScalars->GetVoidPointer(0)): nullptr;
+  return this->MappedScalars
+    ? reinterpret_cast<unsigned char*>(this->MappedScalars->GetVoidPointer(0))
+    : nullptr;
 }
 
-//----------------------------------------------------------------------------
-void vtkTexture::Render(vtkRenderer *ren)
+//------------------------------------------------------------------------------
+void vtkTexture::Render(vtkRenderer* ren)
 {
   for (int i = 0; i < this->GetNumberOfInputPorts(); ++i)
   {
-    vtkAlgorithm* inputAlg = this->GetInputAlgorithm(i,0);
+    vtkAlgorithm* inputAlg = this->GetInputAlgorithm(i, 0);
 
-    if (inputAlg) //load texture map
+    if (inputAlg) // load texture map
     {
       vtkInformation* inInfo = this->GetInputInformation();
       // We do not want more than requested.
-      inInfo->Set(
-        vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(), 1);
+      inInfo->Set(vtkStreamingDemandDrivenPipeline::EXACT_EXTENT(), 1);
 
       // Updating the whole extent may not be necessary.
       inputAlg->UpdateWholeExtent();
@@ -305,24 +311,22 @@ void vtkTexture::Render(vtkRenderer *ren)
   this->Load(ren);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTexture::IsTranslucent()
 {
-  if(this->GetMTime() <= this->TranslucentComputationTime
-      && (this->GetInput() == nullptr ||
-          (this->GetInput()->GetMTime() <= this->TranslucentComputationTime)))
+  if (this->GetMTime() <= this->TranslucentComputationTime &&
+    (this->GetInput() == nullptr ||
+      (this->GetInput()->GetMTime() <= this->TranslucentComputationTime)))
     return this->TranslucentCachedResult;
 
-  if(this->GetInputAlgorithm())
+  if (this->GetInputAlgorithm())
   {
     vtkAlgorithm* inpAlg = this->GetInputAlgorithm();
     inpAlg->UpdateWholeExtent();
   }
 
-  if(this->GetInput() == nullptr ||
-      this->GetInput()->GetPointData()->GetScalars() == nullptr ||
-      this->GetInput()->GetPointData()->GetScalars()
-              ->GetNumberOfComponents()%2)
+  if (this->GetInput() == nullptr || this->GetInput()->GetPointData()->GetScalars() == nullptr ||
+    this->GetInput()->GetPointData()->GetScalars()->GetNumberOfComponents() % 2)
   {
     this->TranslucentCachedResult = 0;
   }
@@ -334,14 +338,16 @@ int vtkTexture::IsTranslucent()
     bool hasTransparentPixel = false;
     bool hasOpaquePixel = false;
     bool hasTranslucentPixel = false;
-    for(vtkIdType i = 0; i < scal->GetNumberOfTuples(); i++)
+    for (vtkIdType i = 0; i < scal->GetNumberOfTuples(); i++)
     {
       double alpha = scal->GetTuple(i)[alphaid];
-      if(alpha <= 0)
+      if (alpha <= 0)
       {
         hasTransparentPixel = true;
       }
-      else if(((scal->GetDataType() == VTK_FLOAT || scal->GetDataType() == VTK_DOUBLE) && alpha >= 1.0) || alpha == scal->GetDataTypeMax())
+      else if (((scal->GetDataType() == VTK_FLOAT || scal->GetDataType() == VTK_DOUBLE) &&
+                 alpha >= 1.0) ||
+        alpha == scal->GetDataTypeMax())
       {
         hasOpaquePixel = true;
       }
@@ -350,10 +356,10 @@ int vtkTexture::IsTranslucent()
         hasTranslucentPixel = true;
       }
       // stop the computation if there are translucent pixels
-      if(hasTranslucentPixel || (this->Interpolate && hasTransparentPixel && hasOpaquePixel))
+      if (hasTranslucentPixel || (this->Interpolate && hasTransparentPixel && hasOpaquePixel))
         break;
     }
-    if(hasTranslucentPixel || (this->Interpolate && hasTransparentPixel && hasOpaquePixel))
+    if (hasTranslucentPixel || (this->Interpolate && hasTransparentPixel && hasOpaquePixel))
     {
       this->TranslucentCachedResult = 1;
     }
@@ -366,3 +372,4 @@ int vtkTexture::IsTranslucent()
   this->TranslucentComputationTime.Modified();
   return this->TranslucentCachedResult;
 }
+VTK_ABI_NAMESPACE_END
