@@ -50,6 +50,7 @@
 #include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkSystemIncludes.h"      // For VTK_COLOR_MODE_*
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 class vtkScalarsToColors;
 class vtkRenderer;
@@ -96,25 +97,25 @@ public:
    */
   virtual void Load(vtkRenderer*) {}
 
-  //@{
+  ///@{
   /**
    * Turn on/off linear interpolation of the texture map when rendering.
    */
   vtkGetMacro(Interpolate, vtkTypeBool);
   vtkSetMacro(Interpolate, vtkTypeBool);
   vtkBooleanMacro(Interpolate, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off use of mipmaps when rendering.
    */
   vtkGetMacro(Mipmap, bool);
   vtkSetMacro(Mipmap, bool);
   vtkBooleanMacro(Mipmap, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the maximum anisotropic filtering to use. 1.0 means use no
    * anisotropic filtering. The default value is 4.0 and a high value would
@@ -123,9 +124,9 @@ public:
    */
   vtkSetMacro(MaximumAnisotropicFiltering, float);
   vtkGetMacro(MaximumAnisotropicFiltering, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Force texture quality to 16-bit or 32-bit.
    * This might not be supported on all machines.
@@ -135,9 +136,9 @@ public:
   void SetQualityToDefault() { this->SetQuality(VTK_TEXTURE_QUALITY_DEFAULT); }
   void SetQualityTo16Bit() { this->SetQuality(VTK_TEXTURE_QUALITY_16BIT); }
   void SetQualityTo32Bit() { this->SetQuality(VTK_TEXTURE_QUALITY_32BIT); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Default: ColorModeToDefault. unsigned char scalars are treated
    * as colors, and NOT mapped through the lookup table (set with SetLookupTable),
@@ -153,7 +154,7 @@ public:
   void SetColorModeToDefault() { this->SetColorMode(VTK_COLOR_MODE_DEFAULT); }
   void SetColorModeToMapScalars() { this->SetColorMode(VTK_COLOR_MODE_MAP_SCALARS); }
   void SetColorModeToDirectScalars() { this->SetColorMode(VTK_COLOR_MODE_DIRECT_SCALARS); }
-  //@}
+  ///@}
 
   /**
    * Get the input as a vtkImageData object.  This method is for
@@ -161,34 +162,34 @@ public:
    */
   vtkImageData* GetInput();
 
-  //@{
+  ///@{
   /**
    * Specify the lookup table to convert scalars if necessary
    */
   void SetLookupTable(vtkScalarsToColors*);
   vtkGetObjectMacro(LookupTable, vtkScalarsToColors);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get Mapped Scalars
    */
   vtkGetObjectMacro(MappedScalars, vtkUnsignedCharArray);
-  //@}
+  ///@}
 
   /**
    * Map scalar values into color scalars.
    */
   unsigned char* MapScalarsToColors(vtkDataArray* scalars);
 
-  //@{
+  ///@{
   /**
    * Set a transform on the texture which allows one to scale,
    * rotate and translate the texture.
    */
   void SetTransform(vtkTransform* transform);
   vtkGetObjectMacro(Transform, vtkTransform);
-  //@}
+  ///@}
 
   /**
    * Used to specify how the texture will blend its RGB and Alpha values
@@ -205,16 +206,16 @@ public:
     VTK_TEXTURE_BLENDING_MODE_SUBTRACT
   };
 
-  //@{
+  ///@{
   /**
    * Used to specify how the texture will blend its RGB and Alpha values
    * with other textures and the fragment the texture is rendered upon.
    */
   vtkGetMacro(BlendingMode, int);
   vtkSetMacro(BlendingMode, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Whether the texture colors are premultiplied by alpha.
    * Initial value is false.
@@ -222,9 +223,9 @@ public:
   vtkGetMacro(PremultipliedAlpha, bool);
   vtkSetMacro(PremultipliedAlpha, bool);
   vtkBooleanMacro(PremultipliedAlpha, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When the texture is forced to be a power of 2, the default behavior is
    * for the "new" image's dimensions to be greater than or equal to with
@@ -235,7 +236,7 @@ public:
   vtkGetMacro(RestrictPowerOf2ImageSmaller, vtkTypeBool);
   vtkSetMacro(RestrictPowerOf2ImageSmaller, vtkTypeBool);
   vtkBooleanMacro(RestrictPowerOf2ImageSmaller, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * Is this Texture Translucent?
@@ -250,7 +251,7 @@ public:
    */
   virtual int GetTextureUnit() { return 0; }
 
-  //@{
+  ///@{
   /**
    * Is this texture a cube map, if so it needs 6 inputs
    * one for each side of the cube. You must set this before
@@ -260,9 +261,9 @@ public:
   vtkGetMacro(CubeMap, bool);
   vtkBooleanMacro(CubeMap, bool);
   void SetCubeMap(bool val);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Is this texture using the sRGB color space. If you are using a
    * sRGB framebuffer or window then you probably also want to be
@@ -272,9 +273,9 @@ public:
   vtkGetMacro(UseSRGBColorSpace, bool);
   vtkSetMacro(UseSRGBColorSpace, bool);
   vtkBooleanMacro(UseSRGBColorSpace, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Border Color (RGBA). The values can be any valid float value,
    * if the gpu supports it. Initial value is (0.0f, 0.0f, 0.0f, 0.0f),
@@ -285,7 +286,7 @@ public:
    */
   vtkSetVector4Macro(BorderColor, float);
   vtkGetVector4Macro(BorderColor, float);
-  //@}
+  ///@}
 
   enum
   {
@@ -296,7 +297,7 @@ public:
     NumberOfWrapModes
   };
 
-  //@{
+  ///@{
   /**
    * Wrap mode for the texture coordinates
    * Valid values are:
@@ -312,9 +313,9 @@ public:
    */
   vtkGetMacro(Wrap, int);
   vtkSetClampMacro(Wrap, int, ClampToEdge, ClampToBorder);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convenience functions to maintain backwards compatibility.
    * For new code, use the SetWrap API.
@@ -329,7 +330,7 @@ public:
   virtual vtkTypeBool GetEdgeClamp() { return (this->GetWrap() == ClampToEdge); }
   virtual void EdgeClampOn() { this->SetEdgeClamp(true); }
   virtual void EdgeClampOff() { this->SetEdgeClamp(false); }
-  //@}
+  ///@}
 
 protected:
   vtkTexture();
@@ -367,4 +368,5 @@ private:
   void operator=(const vtkTexture&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
