@@ -65,6 +65,7 @@
 #include <set>           // For labelmap labels set
 #include <unordered_map> // For labelmap transfer function maps
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkColorTransferFunction;
 class vtkContourValues;
 class vtkImageData;
@@ -121,7 +122,7 @@ public:
   vtkGetMacro(InterpolationType, int);
   void SetInterpolationTypeToNearest() { this->SetInterpolationType(VTK_NEAREST_INTERPOLATION); }
   void SetInterpolationTypeToLinear() { this->SetInterpolationType(VTK_LINEAR_INTERPOLATION); }
-  const char* GetInterpolationTypeAsString(void);
+  const char* GetInterpolationTypeAsString();
   ///@}
 
   ///@{
@@ -383,6 +384,18 @@ public:
   vtkGetSmartPointerMacro(SliceFunction, vtkImplicitFunction);
   ///@}
 
+  ///@{
+  /**
+   * Get/Set the volume's scattering anisotropy.
+   * The model used is Henyey-Greenstein. The value should
+   * be between -1.0 (back-scattering) and 1.0 (forward-scattering),
+   * so the default value of 0.0 corresponds to an isotropic
+   * volume. For now, it is only used in vtkGPUVolumeRayCastMapper.
+   */
+  vtkSetClampMacro(ScatteringAnisotropy, float, -1.0, 1.0);
+  vtkGetMacro(ScatteringAnisotropy, float);
+  ///@}
+
   /**
    * WARNING: INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
    * UpdateMTimes performs a Modified() on all TimeStamps.
@@ -521,6 +534,8 @@ protected:
 
   int InterpolationType;
 
+  float ScatteringAnisotropy = 0.0;
+
   int ColorChannels[VTK_MAX_VRCOMP];
 
   vtkPiecewiseFunction* GrayTransferFunction[VTK_MAX_VRCOMP];
@@ -595,4 +610,5 @@ inline const char* vtkVolumeProperty::GetInterpolationTypeAsString()
   return "Unknown";
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
