@@ -33,6 +33,7 @@
 
 #define BORDER_PIXELS 2
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkWindowToImageFilter);
 
 class vtkWTI2DHelperClass
@@ -576,7 +577,7 @@ void vtkWindowToImageFilter::RequestData(vtkInformation* vtkNotUsed(request),
 
 //------------------------------------------------------------------------------
 // On each tile we must subtract the origin of each actor to ensure
-// it appears in the corrrect relative location
+// it appears in the correct relative location
 void vtkWindowToImageFilter::Restore2DActors()
 {
   vtkActor2D* actor;
@@ -722,3 +723,4 @@ void vtkWindowToImageFilter::Render()
     }
   }
 }
+VTK_ABI_NAMESPACE_END
