@@ -26,7 +26,7 @@
 #include "vtkVectorOperators.h"
 
 #include "vtkStdString.h"
-#include "vtkUnicodeString.h"
+#include <vtk_utf8.h>
 
 // The embedded fonts
 #include "fonts/vtkEmbeddedFonts.h"
@@ -55,6 +55,8 @@ void rotateVector2i(vtkVector2i& vec, float sinTheta, float cosTheta)
 
 } // end anon namespace
 
+VTK_ABI_NAMESPACE_BEGIN
+
 class vtkTextPropertyLookup : public std::map<size_t, vtkSmartPointer<vtkTextProperty>>
 {
 public:
@@ -257,7 +259,7 @@ vtkFreeTypeTools::FaceMetrics vtkFreeTypeTools::GetFaceMetrics(vtkTextProperty*
 
 //------------------------------------------------------------------------------
 vtkFreeTypeTools::GlyphOutline vtkFreeTypeTools::GetUnscaledGlyphOutline(
-  vtkTextProperty* tprop, vtkUnicodeStringValueType charId)
+  vtkTextProperty* tprop, vtkTypeUInt32 charId)
 {
   size_t tpropCacheId;
   this->MapTextPropertyToId(tprop, &tpropCacheId);
@@ -302,7 +304,7 @@ vtkFreeTypeTools::GlyphOutline vtkFreeTypeTools::GetUnscaledGlyphOutline(
 
 //------------------------------------------------------------------------------
 std::array<int, 2> vtkFreeTypeTools::GetUnscaledKerning(
-  vtkTextProperty* tprop, vtkUnicodeStringValueType leftChar, vtkUnicodeStringValueType rightChar)
+  vtkTextProperty* tprop, vtkTypeUInt32 leftChar, vtkTypeUInt32 rightChar)
 {
   std::array<int, 2> result{ { 0, 0 } };
   if (leftChar == 0 || rightChar == 0)
@@ -392,7 +394,7 @@ static FT_Error vtkFreeTypeToolsFaceRequester(
   vtkSmartPointer<vtkTextProperty> tprop = vtkSmartPointer<vtkTextProperty>::New();
   self->MapIdToTextProperty(reinterpret_cast<intptr_t>(face_id), tprop);
 
-  bool faceIsSet = self->LookupFace(tprop, lib, face);
+  bool faceIsSet = vtkFreeTypeTools::LookupFace(tprop, lib, face);
 
   if (!faceIsSet)
   {
@@ -508,36 +510,6 @@ bool vtkFreeTypeTools::GetBoundingBox(
   return result;
 }
 
-//------------------------------------------------------------------------------
-bool vtkFreeTypeTools::GetBoundingBox(
-  vtkTextProperty* tprop, const vtkUnicodeString& str, int dpi, int bbox[4])
-{
-  // We need the tprop and bbox
-  if (!tprop || !bbox)
-  {
-    vtkErrorMacro(<< "Wrong parameters, one of them is nullptr or zero");
-    return false;
-  }
-
-  if (str.empty())
-  {
-    std::fill(bbox, bbox + 4, 0);
-    return true;
-  }
-
-  MetaData metaData;
-  bool result = this->PrepareMetaData(tprop, dpi, metaData);
-  if (result)
-  {
-    result = this->CalculateBoundingBox(str, metaData);
-    if (result)
-    {
-      memcpy(bbox, metaData.bbox.GetData(), sizeof(int) * 4);
-    }
-  }
-  return result;
-}
-
 //------------------------------------------------------------------------------
 bool vtkFreeTypeTools::GetMetrics(
   vtkTextProperty* tprop, const vtkStdString& str, int dpi, vtkTextRenderer::Metrics& metrics)
@@ -573,41 +545,6 @@ bool vtkFreeTypeTools::GetMetrics(
   return result;
 }
 
-//------------------------------------------------------------------------------
-bool vtkFreeTypeTools::GetMetrics(
-  vtkTextProperty* tprop, const vtkUnicodeString& str, int dpi, vtkTextRenderer::Metrics& metrics)
-{
-  if (!tprop)
-  {
-    vtkErrorMacro(<< "nullptr text property.");
-    return false;
-  }
-
-  if (str.empty())
-  {
-    metrics = vtkTextRenderer::Metrics();
-    return true;
-  }
-
-  MetaData metaData;
-  bool result = this->PrepareMetaData(tprop, dpi, metaData);
-  if (result)
-  {
-    result = this->CalculateBoundingBox(str, metaData);
-    if (result)
-    {
-      metrics.BoundingBox = metaData.bbox;
-      metrics.TopLeft = metaData.TL;
-      metrics.TopRight = metaData.TR;
-      metrics.BottomLeft = metaData.BL;
-      metrics.BottomRight = metaData.BR;
-      metrics.Ascent = metaData.ascent;
-      metrics.Descent = metaData.descent;
-    }
-  }
-  return result;
-}
-
 //------------------------------------------------------------------------------
 bool vtkFreeTypeTools::RenderString(
   vtkTextProperty* tprop, const vtkStdString& str, int dpi, vtkImageData* data, int textDims[2])
@@ -615,13 +552,6 @@ bool vtkFreeTypeTools::RenderString(
   return this->RenderStringInternal(tprop, str, dpi, data, textDims);
 }
 
-//------------------------------------------------------------------------------
-bool vtkFreeTypeTools::RenderString(
-  vtkTextProperty* tprop, const vtkUnicodeString& str, int dpi, vtkImageData* data, int textDims[2])
-{
-  return this->RenderStringInternal(tprop, str, dpi, data, textDims);
-}
-
 //------------------------------------------------------------------------------
 bool vtkFreeTypeTools::StringToPath(
   vtkTextProperty* tprop, const vtkStdString& str, int dpi, vtkPath* path)
@@ -629,13 +559,6 @@ bool vtkFreeTypeTools::StringToPath(
   return this->StringToPathInternal(tprop, str, dpi, path);
 }
 
-//------------------------------------------------------------------------------
-bool vtkFreeTypeTools::StringToPath(
-  vtkTextProperty* tprop, const vtkUnicodeString& str, int dpi, vtkPath* path)
-{
-  return this->StringToPathInternal(tprop, str, dpi, path);
-}
-
 //------------------------------------------------------------------------------
 int vtkFreeTypeTools::GetConstrainedFontSize(
   const vtkStdString& str, vtkTextProperty* tprop, int dpi, int targetWidth, int targetHeight)
@@ -649,19 +572,6 @@ int vtkFreeTypeTools::GetConstrainedFontSize(
   return this->FitStringToBBox(str, metaData, targetWidth, targetHeight);
 }
 
-//------------------------------------------------------------------------------
-int vtkFreeTypeTools::GetConstrainedFontSize(
-  const vtkUnicodeString& str, vtkTextProperty* tprop, int dpi, int targetWidth, int targetHeight)
-{
-  MetaData metaData;
-  if (!this->PrepareMetaData(tprop, dpi, metaData))
-  {
-    vtkErrorMacro(<< "Could not prepare metadata.");
-    return false;
-  }
-  return this->FitStringToBBox(str, metaData, targetWidth, targetHeight);
-}
-
 //------------------------------------------------------------------------------
 vtkTypeUInt16 vtkFreeTypeTools::HashString(const char* str)
 {
@@ -759,9 +669,13 @@ void vtkFreeTypeTools::MapTextPropertyToId(vtkTextProperty* tprop, size_t* id)
   // We're dropping a bit here, but that should be okay.
   *id |= hash << 1;
 
-  // Insert the TextProperty into the lookup table
+  // Insert a copy of the TextProperty into the lookup table
   if (!this->TextPropertyLookup->contains(*id))
-    (*this->TextPropertyLookup)[*id] = tprop;
+  {
+    vtkNew<vtkTextProperty> cprop;
+    cprop->ShallowCopy(tprop);
+    (*this->TextPropertyLookup)[*id] = cprop;
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -831,7 +745,7 @@ bool vtkFreeTypeTools::GetSize(FTC_Scaler scaler, FT_Size* size)
     vtkErrorMacro(<< "Failed looking up a FreeType Size");
   }
 
-  return error ? false : true;
+  return !error;
 }
 
 //------------------------------------------------------------------------------
@@ -879,7 +793,7 @@ bool vtkFreeTypeTools::GetFace(size_t tprop_cache_id, FT_Face* face)
     vtkErrorMacro(<< "Failed looking up a FreeType Face");
   }
 
-  return error ? false : true;
+  return !error;
 }
 
 //------------------------------------------------------------------------------
@@ -924,7 +838,7 @@ bool vtkFreeTypeTools::GetGlyphIndex(size_t tprop_cache_id, FT_UInt32 c, FT_UInt
   // Lookup the glyph index
   *gindex = FTC_CMapCache_Lookup(*cmap_cache, face_id, 0, c);
 
-  return *gindex ? true : false;
+  return *gindex != 0;
 }
 
 //------------------------------------------------------------------------------
@@ -985,7 +899,7 @@ bool vtkFreeTypeTools::GetGlyph(
   // Lookup the glyph
   FT_Error error = FTC_ImageCache_Lookup(*image_cache, &image_type_rec, gindex, glyph, nullptr);
 
-  return error ? false : true;
+  return !error;
 }
 
 //------------------------------------------------------------------------------
@@ -1022,7 +936,7 @@ bool vtkFreeTypeTools::GetGlyph(FTC_Scaler scaler, FT_UInt gindex, FT_Glyph* gly
   FT_Error error =
     FTC_ImageCache_LookupScaler(*image_cache, scaler, loadFlags, gindex, glyph, nullptr);
 
-  return error ? false : true;
+  return !error;
 }
 
 //------------------------------------------------------------------------------
@@ -1245,9 +1159,8 @@ inline bool vtkFreeTypeTools::PrepareMetaData(vtkTextProperty* tprop, int dpi, M
 }
 
 //------------------------------------------------------------------------------
-template <typename StringType>
 bool vtkFreeTypeTools::RenderStringInternal(
-  vtkTextProperty* tprop, const StringType& str, int dpi, vtkImageData* data, int textDims[2])
+  vtkTextProperty* tprop, const std::string& str, int dpi, vtkImageData* data, int textDims[2])
 {
   // Check parameters
   if (!tprop || !data)
@@ -1374,9 +1287,8 @@ bool vtkFreeTypeTools::RenderStringInternal(
 }
 
 //------------------------------------------------------------------------------
-template <typename StringType>
 bool vtkFreeTypeTools::StringToPathInternal(
-  vtkTextProperty* tprop, const StringType& str, int dpi, vtkPath* path)
+  vtkTextProperty* tprop, const std::string& str, int dpi, vtkPath* path)
 {
   // Setup the metadata
   MetaData metaData;
@@ -1403,38 +1315,24 @@ bool vtkFreeTypeTools::StringToPathInternal(
   return true;
 }
 
+VTK_ABI_NAMESPACE_END
+
 namespace
 {
 const char* DEFAULT_HEIGHT_STRING = "_/7Agfy";
 }
 
-//------------------------------------------------------------------------------
-bool vtkFreeTypeTools::CalculateBoundingBox(const vtkUnicodeString& str, MetaData& metaData)
-{
-  return CalculateBoundingBox(str, metaData, vtkUnicodeString::from_utf8(DEFAULT_HEIGHT_STRING));
-}
+VTK_ABI_NAMESPACE_BEGIN
 
 //------------------------------------------------------------------------------
 bool vtkFreeTypeTools::CalculateBoundingBox(const vtkStdString& str, MetaData& metaData)
 {
-  return CalculateBoundingBox(str, metaData, vtkStdString(DEFAULT_HEIGHT_STRING));
-}
-
-namespace
-{
-
-template <typename T>
-constexpr typename T::value_type newline()
-{
-  return static_cast<typename T::value_type>('\n');
-}
-
+  return CalculateBoundingBox(str, metaData, DEFAULT_HEIGHT_STRING);
 }
 
 //------------------------------------------------------------------------------
-template <typename T>
 bool vtkFreeTypeTools::CalculateBoundingBox(
-  const T& str, MetaData& metaData, const T& defaultHeightString)
+  const std::string& str, MetaData& metaData, const std::string& defaultHeightString)
 {
   // Calculate the metrics for each line. These will be used to calculate
   // a bounding box, but first we need to know the maximum line length to
@@ -1443,8 +1341,8 @@ bool vtkFreeTypeTools::CalculateBoundingBox(
   metaData.maxLineWidth = 0;
 
   // Go through the string, line by line, and build the metrics data.
-  typename T::const_iterator beginLine = str.begin();
-  typename T::const_iterator endLine = std::find(beginLine, str.end(), newline<T>());
+  std::string::const_iterator beginLine = str.begin();
+  std::string::const_iterator endLine = std::find(beginLine, str.end(), '\n');
   while (endLine != str.end())
   {
     metaData.lineMetrics.emplace_back();
@@ -1453,7 +1351,7 @@ bool vtkFreeTypeTools::CalculateBoundingBox(
     metaData.maxLineWidth = std::max(metaData.maxLineWidth, metaData.lineMetrics.back().width);
     beginLine = endLine;
     ++beginLine;
-    endLine = std::find(beginLine, str.end(), newline<T>());
+    endLine = std::find(beginLine, str.end(), '\n');
   }
   // Last line...
   metaData.lineMetrics.emplace_back();
@@ -1462,7 +1360,7 @@ bool vtkFreeTypeTools::CalculateBoundingBox(
   metaData.maxLineWidth = std::max(metaData.maxLineWidth, metaData.lineMetrics.back().width);
 
   size_t numLines = metaData.lineMetrics.size();
-  T heightString;
+  std::string heightString;
   if (metaData.textProperty->GetUseTightBoundingBox() && numLines == 1)
   {
     // Calculate line height from actual characters. This works only for single line text
@@ -1478,7 +1376,7 @@ bool vtkFreeTypeTools::CalculateBoundingBox(
   }
   int ascent = 0;
   int descent = 0;
-  typename T::const_iterator it = heightString.begin();
+  std::string::const_iterator it = heightString.begin();
   while (it != heightString.end())
   {
     FT_BitmapGlyph bitmapGlyph;
@@ -1726,9 +1624,11 @@ void vtkFreeTypeTools::PrepareImageData(vtkImageData* data, int textBbox[4])
     (data->GetNumberOfPoints() * data->GetNumberOfScalarComponents()));
 }
 
+VTK_ABI_NAMESPACE_END
 // Helper functions for rasterizing the background/frame quad:
 namespace RasterScanQuad
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 // Return true and set t1 (if 0 <= t1 <= 1) for the intersection of lines:
 //
@@ -1837,8 +1737,10 @@ inline void clampToExtent(int extent[6], int dim, int& value)
   value = std::min(extent[2 * dim + 1], std::max(extent[2 * dim], value));
 }
 
+VTK_ABI_NAMESPACE_END
 } // end namespace RasterScanQuad
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 void vtkFreeTypeTools::RenderBackground(
   vtkTextProperty* tprop, vtkImageData* image, ImageMetaData& metaData)
@@ -1908,13 +1810,12 @@ void vtkFreeTypeTools::RenderBackground(
 }
 
 //------------------------------------------------------------------------------
-template <typename StringType, typename DataType>
-bool vtkFreeTypeTools::PopulateData(const StringType& str, DataType data, MetaData& metaData)
+template <typename DataType>
+bool vtkFreeTypeTools::PopulateData(const std::string& str, DataType data, MetaData& metaData)
 {
   // Go through the string, line by line
-  typename StringType::const_iterator beginLine = str.begin();
-  typename StringType::const_iterator endLine =
-    std::find(beginLine, str.end(), newline<StringType>());
+  std::string::const_iterator beginLine = str.begin();
+  std::string::const_iterator endLine = std::find(beginLine, str.end(), '\n');
 
   int lineIndex = 0;
   while (endLine != str.end())
@@ -1926,7 +1827,7 @@ bool vtkFreeTypeTools::PopulateData(const StringType& str, DataType data, MetaDa
 
     beginLine = endLine;
     ++beginLine;
-    endLine = std::find(beginLine, str.end(), newline<StringType>());
+    endLine = std::find(beginLine, str.end(), '\n');
     ++lineIndex;
   }
 
@@ -1935,32 +1836,32 @@ bool vtkFreeTypeTools::PopulateData(const StringType& str, DataType data, MetaDa
 }
 
 //------------------------------------------------------------------------------
-template <typename IteratorType, typename DataType>
-bool vtkFreeTypeTools::RenderLine(
-  IteratorType begin, IteratorType end, int lineIndex, DataType data, MetaData& metaData)
+template <typename DataType>
+bool vtkFreeTypeTools::RenderLine(std::string::const_iterator begin,
+  std::string::const_iterator end, int lineIndex, DataType data, MetaData& metaData)
 {
   int x = metaData.lineMetrics[lineIndex].origin.GetX();
   int y = metaData.lineMetrics[lineIndex].origin.GetY();
 
   // Render char by char
   FT_UInt previousGlyphIndex = 0; // for kerning
-  for (; begin != end; ++begin)
+  while (begin != end)
   {
-    this->RenderCharacter(*begin, x, y, previousGlyphIndex, data, metaData);
+    vtkTypeUInt32 codepoint = utf8::next(begin, end);
+    this->RenderCharacter(codepoint, x, y, previousGlyphIndex, data, metaData);
   }
 
   return true;
 }
 
 //------------------------------------------------------------------------------
-template <typename CharType>
-bool vtkFreeTypeTools::RenderCharacter(CharType character, int& x, int& y,
+bool vtkFreeTypeTools::RenderCharacter(FT_UInt32 codepoint, int& x, int& y,
   FT_UInt& previousGlyphIndex, vtkImageData* image, MetaData& metaData)
 {
   ImageMetaData* iMetaData = reinterpret_cast<ImageMetaData*>(&metaData);
   FT_BitmapGlyph bitmapGlyph = nullptr;
   FT_UInt glyphIndex;
-  FT_Bitmap* bitmap = this->GetBitmap(character, &iMetaData->scaler, glyphIndex, bitmapGlyph);
+  FT_Bitmap* bitmap = this->GetBitmap(codepoint, &iMetaData->scaler, glyphIndex, bitmapGlyph);
 
   // Add the kerning
   if (iMetaData->faceHasKerning && previousGlyphIndex && glyphIndex)
@@ -2064,13 +1965,12 @@ bool vtkFreeTypeTools::RenderCharacter(CharType character, int& x, int& y,
 }
 
 //------------------------------------------------------------------------------
-template <typename CharType>
-bool vtkFreeTypeTools::RenderCharacter(CharType character, int& x, int& y,
+bool vtkFreeTypeTools::RenderCharacter(FT_UInt32 codepoint, int& x, int& y,
   FT_UInt& previousGlyphIndex, vtkPath* path, MetaData& metaData)
 {
   FT_UInt glyphIndex = 0;
   FT_OutlineGlyph outlineGlyph = nullptr;
-  FT_Outline* outline = this->GetOutline(character, &metaData.scaler, glyphIndex, outlineGlyph);
+  FT_Outline* outline = this->GetOutline(codepoint, &metaData.scaler, glyphIndex, outlineGlyph);
 
   // Add the kerning
   if (metaData.faceHasKerning && previousGlyphIndex && glyphIndex)
@@ -2280,9 +2180,8 @@ void vtkFreeTypeTools::OutlineToPath(int x, int y, FT_Outline* outline, vtkPath*
 
 //------------------------------------------------------------------------------
 // Similar to implementations in vtkFreeTypeUtilities and vtkTextMapper.
-template <typename T>
 int vtkFreeTypeTools::FitStringToBBox(
-  const T& str, MetaData& metaData, int targetWidth, int targetHeight)
+  const std::string& str, MetaData& metaData, int targetWidth, int targetHeight)
 {
   if (str.empty() || targetWidth == 0 || targetHeight == 0 || metaData.textProperty == nullptr)
   {
@@ -2475,8 +2374,8 @@ FT_Outline* vtkFreeTypeTools::GetOutline(
 }
 
 //------------------------------------------------------------------------------
-template <typename T>
-void vtkFreeTypeTools::GetLineMetrics(T begin, T end, MetaData& metaData, int& width, int bbox[4])
+void vtkFreeTypeTools::GetLineMetrics(std::string::const_iterator begin,
+  std::string::const_iterator end, MetaData& metaData, int& width, int bbox[4])
 {
   FT_BitmapGlyph bitmapGlyph = nullptr;
   FT_UInt gindex = 0;
@@ -2487,10 +2386,11 @@ void vtkFreeTypeTools::GetLineMetrics(T begin, T end, MetaData& metaData, int& w
   bbox[0] = bbox[1] = pen[0];
   bbox[2] = bbox[3] = pen[1];
 
-  for (; begin != end; ++begin)
+  while (begin != end)
   {
     // Get the bitmap and glyph index:
-    FT_Bitmap* bitmap = this->GetBitmap(*begin, &metaData.scaler, gindex, bitmapGlyph);
+    vtkTypeUInt32 codepoint = utf8::next(begin, end);
+    FT_Bitmap* bitmap = this->GetBitmap(codepoint, &metaData.scaler, gindex, bitmapGlyph);
 
     // Adjust the pen location for kerning
     if (metaData.faceHasKerning && gindexLast && gindex)
@@ -2539,3 +2439,4 @@ void vtkFreeTypeTools::GetLineMetrics(T begin, T end, MetaData& metaData, int& w
     width += (delta.x + 0x8000) >> 16;
   }
 }
+VTK_ABI_NAMESPACE_END
