@@ -39,6 +39,7 @@
 #include <cassert>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenGLGL2PSHelperImpl);
 
 namespace
@@ -56,17 +57,13 @@ bool GetMetrics(
   vtkNew<vtkTextProperty> tpropTmp;
   tpropTmp->ShallowCopy(tprop);
   tpropTmp->SetOrientation(0.);
-  if (!tren->GetMetrics(tpropTmp, str, m, dpi))
-  {
-    return false;
-  }
-  return true;
+  return tren->GetMetrics(tpropTmp, str, m, dpi);
 }
 
 // replace \n with space as PS treats it as a space but PDF just removes them.
 // we also need this so that we get the correct bounding box for PDFs
 // considering that we do not address multi-line strings yet.
-void GetSpaceStr(const char* str, vtkStdString* spaceStr)
+void GetSpaceStr(const char* str, std::string* spaceStr)
 {
   *spaceStr = str;
   std::string::size_type eolPos = 0;
@@ -356,9 +353,9 @@ void vtkOpenGLGL2PSHelperImpl::DrawString(const std::string& str, vtkTextPropert
   // Export text as either a path or a text object.
   if (!isMath && !this->TextAsPath)
   {
-    const char* fontname = this->TextPropertyToPSFontName(tprop);
+    const char* fontname = vtkOpenGLGL2PSHelperImpl::TextPropertyToPSFontName(tprop);
 
-    GLint align = static_cast<GLint>(this->TextPropertyToGL2PSAlignment(tprop));
+    GLint align = static_cast<GLint>(vtkOpenGLGL2PSHelperImpl::TextPropertyToGL2PSAlignment(tprop));
 
     GLfloat angle = static_cast<GLfloat>(tprop->GetOrientation());
 
@@ -385,7 +382,7 @@ void vtkOpenGLGL2PSHelperImpl::DrawString(const std::string& str, vtkTextPropert
     // draw text by passing the bottom left corner as PDF does not support
     // alignment.
     double blpos[3];
-    vtkStdString spaceStr;
+    std::string spaceStr;
     // compute the bounding box and the string without \n
     vtkTextRenderer::Metrics m;
     ::GetSpaceStr(str.c_str(), &spaceStr);
@@ -427,7 +424,7 @@ void vtkOpenGLGL2PSHelperImpl::DrawString(const std::string& str, vtkTextPropert
       static_cast<unsigned char>(tprop->GetOpacity() * 255) };
 
     double devicePos[3] = { pos[0], pos[1], pos[2] };
-    this->ProjectPoint(devicePos, ren);
+    vtkOpenGLGL2PSHelperImpl::ProjectPoint(devicePos, ren);
 
     this->DrawPath(path, pos, devicePos, rgba, nullptr, 0.0, -1.f,
       (std::string("Pathified string: ") + str).c_str());
@@ -470,7 +467,7 @@ void vtkOpenGLGL2PSHelperImpl::Draw3DPath(vtkPath* path, vtkMatrix4x4* actorMatr
   double translation[2] = { 0.0, 0.0 };
   vtkNew<vtkPath> projPath;
   projPath->DeepCopy(path);
-  this->ProjectPoints(projPath->GetPoints(), ren, actorMatrix);
+  vtkOpenGLGL2PSHelperImpl::ProjectPoints(projPath->GetPoints(), ren, actorMatrix);
   this->DrawPath(projPath, rasterPos, translation, actorColor, nullptr, 0.0, -1.f, label);
 }
 
@@ -1245,3 +1242,4 @@ void vtkOpenGLGL2PSHelperImpl::DrawPathSVG(vtkPath* path, double rasterPos[3], d
   gl2psForceRasterPos(&gl2psRasterPos);
   gl2psSpecial(gl2psGetFileFormat(), out.str().c_str());
 }
+VTK_ABI_NAMESPACE_END
