@@ -18,8 +18,15 @@
 #include "vtkImageSlice.h"
 #include "vtkObjectFactory.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageSliceCollection);
 
+//------------------------------------------------------------------------------
+void vtkImageSliceCollection::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
 //------------------------------------------------------------------------------
 // protected function to delete an element. Internal use only.
 void vtkImageSliceCollection::DeleteElement(vtkCollectionElement* e)
@@ -152,3 +159,4 @@ void vtkImageSliceCollection::Sort()
     delete[] layerArray;
   }
 }
+VTK_ABI_NAMESPACE_END
