@@ -53,10 +53,11 @@
 
 #include "vtkSurfaceLICInterface.h"
 
-#include "vtkCompositePolyDataMapper2Internal.h"
+#include "vtkCompositeMapperHelper2.h"
 
 typedef std::map<vtkPolyData*, vtkCompositeMapperHelperData*>::iterator dataIter;
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeLICHelper : public vtkCompositeMapperHelper2
 {
 public:
@@ -73,9 +74,8 @@ protected:
   void AppendOneBufferObject(vtkRenderer* ren, vtkActor* act, vtkCompositeMapperHelperData* hdata,
     vtkIdType& flat_index, std::vector<unsigned char>& colors, std::vector<float>& norms) override;
 
-protected:
   /**
-   * Set the shader parameteres related to the mapper/input data, called by UpdateShader
+   * Set the shader parameters related to the mapper/input data, called by UpdateShader
    */
   void SetMapperShaderParameters(vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act) override;
 
@@ -119,10 +119,21 @@ void vtkCompositeLICHelper::ReplaceShaderValues(
   vtkShaderProgram::Substitute(FSSource, "//VTK::TCoord::Dec",
     // 0/1, when 1 V is projected to surface for |V| computation.
     "uniform int uMaskOnSurface;\n"
-    "uniform mat3 normalMatrix;\n"
-    "in vec3 tcoordVCVSOutput;");
+    "in vec3 tcoordVCVSOutput;\n"
+    "//VTK::TCoord::Dec");
 
-  if (this->LastLightComplexity[this->LastBoundBO] > 0)
+  // We need to create the uniform normalMatrix here as it will not be done in the superclass
+  // if the data does not contains normals or if drawing spheres / tubes is enabled.
+  if (this->VBOs->GetNumberOfComponents("normalMC") != 3 ||
+    this->DrawingSpheres(*this->LastBoundBO, actor) ||
+    this->DrawingTubes(*this->LastBoundBO, actor))
+  {
+    vtkShaderProgram::Substitute(FSSource, "//VTK::Normal::Dec",
+      "//VTK::Normal::Dec\n"
+      "uniform mat3 normalMatrix;");
+  }
+
+  if (this->PrimitiveInfo[this->LastBoundBO].LastLightComplexity > 0)
   {
     vtkShaderProgram::Substitute(FSSource, "//VTK::TCoord::Impl",
       // projected vectors
@@ -306,3 +317,4 @@ void vtkCompositeSurfaceLICMapper::Render(vtkRenderer* ren, vtkActor* actor)
 
   ostate->PopFramebufferBindings();
 }
+VTK_ABI_NAMESPACE_END
