@@ -41,6 +41,7 @@
 #include "vtkTextureObject.h"
 #include "vtkUnsignedCharArray.h"
 
+#include <cmath>
 #include <deque>
 using std::deque;
 
@@ -56,6 +57,7 @@ using std::deque;
   ext[0] << ", " << ext[1] << ", " << ext[2] << ", " << ext[3] << ", " << ext[4] << ", " << ext[5]
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageDataLIC2D);
 
 //------------------------------------------------------------------------------
@@ -326,8 +328,9 @@ int vtkImageDataLIC2D::RequestData(vtkInformation* vtkNotUsed(request),
     }
 
     double noiseRange[2];
+    vtkPointData* pd = noise->GetPointData();
     vtkDataArray* inVals = noise->GetPointData()->GetScalars();
-    inVals->GetRange(noiseRange);
+    pd->GetRange(inVals->GetName(), noiseRange);
     if ((noiseRange[0] < 0.0) || (noiseRange[1] > 1.0))
     {
       vtkErrorMacro("Noise dataset has values out of range 0.0 to 1.0."
@@ -617,3 +620,4 @@ void vtkImageDataLIC2D::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Magnification: " << this->Magnification << "\n";
   os << indent << "OpenGLExtensionsSupported: " << this->OpenGLExtensionsSupported << "\n";
 }
+VTK_ABI_NAMESPACE_END
