@@ -18,12 +18,12 @@
 
 #ifndef vtkLICNoiseHelper_h
 #define vtkLICNoiseHelper_h
-#ifndef __VTK_WRAP__
 
 #include "vtkRenderingLICOpenGL2Module.h" // for export
 
 #include "vtkMinimalStandardRandomSequence.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 
 /**
@@ -73,7 +73,7 @@ class vtkLICRandomNoise2D
 public:
   vtkLICRandomNoise2D() = default;
 
-  //@{
+  ///@{
   /**
    * Generate a patch of random gray scale values along with an
    * alpha channel (in vtk array format). The data should be
@@ -99,7 +99,7 @@ public:
   };
   float* Generate(int type, int& sideLen, int& grainLize, float minNoiseVal, float maxNoiseVal,
     int nLevels, double impulseProb, float impulseBgNoiseVal, int seed);
-  //@}
+  ///@}
 
   /**
    * Delete the passed in array of values.
@@ -147,6 +147,6 @@ private:
   vtkLICRandomNumberGeneratorInterface ProbGen;
 };
 
-#endif
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkLICNoiseHelper.h
