@@ -47,7 +47,7 @@ using std::vector;
 
 // Enable stream min/max computations. Streaming is accomplished
 // via PBO+glReadPixels to read just the regions we are updating.
-// Without streaming PBO+glGetTexImage is used to uplaod the entire
+// Without streaming PBO+glGetTexImage is used to upload the entire
 // screen sized texture, of which (in parallel) we are updating only
 // a small part of.
 #define STREAMING_MIN_MAX
@@ -70,12 +70,14 @@ using std::vector;
 #include <sstream>
 using std::ostringstream;
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 static string mpifn(int rank, const char* fn)
 {
   ostringstream oss;
   oss << rank << "_" << fn;
   return oss.str();
 }
+VTK_ABI_NAMESPACE_END
 #endif
 #if vtkLineIntegralConvolution2DDEBUG >= 3
 #define vtkLICCheckFrameBufferStatusMacro(mode) vtkCheckFrameBufferStatusMacro(mode)
@@ -106,6 +108,7 @@ employed during LIC integration. This class encapsulates all
 of the knowledge of our use of the FBO and texture units. Care
 is taken to avoid feedback loops.
 */
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLICPingPongBufferManager
 {
 public:
@@ -726,9 +729,11 @@ private:
   vtkTextureObject* PongTextures[2];
   vtkTextureObject** Textures[2];
 };
+VTK_ABI_NAMESPACE_END
 
 namespace vtkLineIntegralConvolution2DUtil
 {
+VTK_ABI_NAMESPACE_BEGIN
 /**
 glsl shader code for selecting vector comps.
 */
@@ -868,9 +873,11 @@ void StreamingFindMinMax(vtkOpenGLFramebufferObject* fbo, vtkTextureObject* tex,
 #endif
 }
 
-};
+VTK_ABI_NAMESPACE_END
+}
 using namespace vtkLineIntegralConvolution2DUtil;
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 vtkObjectFactoryNewMacro(vtkLineIntegralConvolution2D);
 
@@ -923,38 +930,14 @@ vtkLineIntegralConvolution2D::~vtkLineIntegralConvolution2D()
   this->SetAAHShader(nullptr);
   this->SetAAVShader(nullptr);
 
-  if (this->VTShader)
-  {
-    delete this->VTShader;
-  }
-  if (this->LIC0Shader)
-  {
-    delete this->LIC0Shader;
-  }
-  if (this->LICIShader)
-  {
-    delete this->LICIShader;
-  }
-  if (this->LICNShader)
-  {
-    delete this->LICNShader;
-  }
-  if (this->EEShader)
-  {
-    delete this->EEShader;
-  }
-  if (this->CEShader)
-  {
-    delete this->CEShader;
-  }
-  if (this->AAHShader)
-  {
-    delete this->AAHShader;
-  }
-  if (this->AAVShader)
-  {
-    delete this->AAVShader;
-  }
+  delete this->VTShader;
+  delete this->LIC0Shader;
+  delete this->LICIShader;
+  delete this->LICNShader;
+  delete this->EEShader;
+  delete this->CEShader;
+  delete this->AAHShader;
+  delete this->AAVShader;
 
   this->FBO->Delete();
 }
@@ -978,7 +961,7 @@ void vtkLineIntegralConvolution2D::SetContext(vtkOpenGLRenderWindow* renWin)
   this->FBO->SetContext(renWin);
   this->Modified();
 
-  if (renWin && !this->IsSupported(renWin))
+  if (renWin && !vtkLineIntegralConvolution2D::IsSupported(renWin))
   {
     vtkErrorMacro("The required OpenGL extensions are not present");
   }
@@ -1138,6 +1121,7 @@ void vtkLineIntegralConvolution2D::SetAAVShader(vtkShaderProgram* prog)
     this->AAVShader->Program = prog;
   }
 }
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
@@ -1158,6 +1142,7 @@ void BuildAShader(vtkOpenGLRenderWindow* renWin, vtkOpenGLHelper** cbor, const c
 }
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 void vtkLineIntegralConvolution2D::BuildShaders()
 {
@@ -1933,3 +1918,4 @@ void vtkLineIntegralConvolution2D::PrintSelf(ostream& os, vtkIndent indent)
     << indent << "NormalizeVectors=" << this->NormalizeVectors << endl
     << indent << "ComponentIds=" << this->ComponentIds[0] << ", " << this->ComponentIds[1] << endl;
 }
+VTK_ABI_NAMESPACE_END
