@@ -38,6 +38,7 @@
 #define vtkSurfaceLICMapperDEBUG 0
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkSurfaceLICMapper);
 
 //------------------------------------------------------------------------------
@@ -95,10 +96,21 @@ void vtkSurfaceLICMapper::ReplaceShaderValues(
   vtkShaderProgram::Substitute(FSSource, "//VTK::TCoord::Dec",
     // 0/1, when 1 V is projected to surface for |V| computation.
     "uniform int uMaskOnSurface;\n"
-    "uniform mat3 normalMatrix;\n"
-    "in vec3 tcoordVCVSOutput;");
+    "in vec3 tcoordVCVSOutput;\n"
+    "//VTK::TCoord::Dec");
 
-  if (this->LastLightComplexity[this->LastBoundBO] > 0)
+  // We need to create the uniform normalMatrix here as it will not be done in the superclass
+  // if the data does not contains normals or if drawing spheres / tubes is enabled.
+  if (this->VBOs->GetNumberOfComponents("normalMC") != 3 ||
+    this->DrawingSpheres(*this->LastBoundBO, actor) ||
+    this->DrawingTubes(*this->LastBoundBO, actor))
+  {
+    vtkShaderProgram::Substitute(FSSource, "//VTK::Normal::Dec",
+      "//VTK::Normal::Dec\n"
+      "uniform mat3 normalMatrix;");
+  }
+
+  if (this->PrimitiveInfo[this->LastBoundBO].LastLightComplexity > 0)
   {
     vtkShaderProgram::Substitute(FSSource, "//VTK::TCoord::Impl",
       // projected vectors
@@ -162,7 +174,7 @@ void vtkSurfaceLICMapper::RenderPiece(vtkRenderer* renderer, vtkActor* actor)
 
   this->CurrentInput = this->GetInput();
   vtkDataArray* vectors = this->GetInputArrayToProcess(0, this->CurrentInput);
-  this->LICInterface->SetHasVectors(vectors != nullptr ? true : false);
+  this->LICInterface->SetHasVectors(vectors != nullptr);
 
   if (!this->LICInterface->CanRenderSurfaceLIC(actor))
   {
@@ -244,3 +256,4 @@ void vtkSurfaceLICMapper::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
