@@ -29,6 +29,7 @@
 #include <deque>   // for deque
 #include <string>  // for string
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkTextureObject;
 
 class VTKRENDERINGLICOPENGL2_EXPORT vtkTextureIO
@@ -37,13 +38,13 @@ public:
   /**
    * Write to disk as image data with subset(optional) at dataset origin(optional)
    */
-  static void Write(const char* filename, vtkTextureObject* texture,
+  static void Write(VTK_FILEPATH const char* filename, vtkTextureObject* texture,
     const unsigned int* subset = nullptr, const double* origin = nullptr);
 
   /**
    * Write to disk as image data with subset(optional) at dataset origin(optional)
    */
-  static void Write(std::string filename, vtkTextureObject* texture,
+  static void Write(VTK_FILEPATH std::string filename, vtkTextureObject* texture,
     const unsigned int* subset = nullptr, const double* origin = nullptr)
   {
     Write(filename.c_str(), texture, subset, origin);
@@ -52,8 +53,8 @@ public:
   /**
    * Write to disk as image data with subset(optional) at dataset origin(optional)
    */
-  static void Write(std::string filename, vtkTextureObject* texture, const vtkPixelExtent& subset,
-    const double* origin = nullptr)
+  static void Write(VTK_FILEPATH std::string filename, vtkTextureObject* texture,
+    const vtkPixelExtent& subset, const double* origin = nullptr)
   {
     Write(filename.c_str(), texture, subset.GetDataU(), origin);
   }
@@ -61,20 +62,21 @@ public:
   /**
    * Write list of subsets to disk as multiblock image data at dataset origin(optional).
    */
-  static void Write(const char* filename, vtkTextureObject* texture,
+  static void Write(VTK_FILEPATH const char* filename, vtkTextureObject* texture,
     const std::deque<vtkPixelExtent>& exts, const double* origin = nullptr);
 
-  //@{
+  ///@{
   /**
    * Write list of subsets to disk as multiblock image data at dataset origin(optional).
    */
-  static void Write(std::string filename, vtkTextureObject* texture,
+  static void Write(VTK_FILEPATH std::string filename, vtkTextureObject* texture,
     const std::deque<vtkPixelExtent>& exts, const double* origin = nullptr)
   {
     Write(filename.c_str(), texture, exts, origin);
   }
-  //@}
+  ///@}
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkTextureIO.h
