@@ -72,6 +72,7 @@
 // in the VTK code base, this is one way to do it. Feel free to change it
 // if you have a better solution. But make sure it works on Borland 5.5...
 //
+VTK_ABI_NAMESPACE_BEGIN
 vtkLabelHierarchy* vtkLabelHierarchy::Implementation::Current;
 
 //------------------------------------------------------------------------------
@@ -438,7 +439,8 @@ void vtkLabelHierarchyFrustumIterator::Next()
           if (this->Level)
           {
             this->Path.resize(this->Level);
-            vtkLabelHierarchy::GetPathForNodalCoordinates(&this->Path[0], this->IjkG, this->Level);
+            vtkLabelHierarchy::GetPathForNodalCoordinates(
+              this->Path.data(), this->IjkG, this->Level);
           }
           else
           {
@@ -604,7 +606,9 @@ void vtkLabelHierarchyFullSortIterator::Begin(vtkIdTypeArray* vtkNotUsed(lastPla
   s.push_back(root);
   int numNodes = 0;
   int numLeaf = 0;
+#ifndef NDEBUG
   int totalLeafDepth = 0;
+#endif
   size_t numLabels = 0;
   int maxLabels = 10000;
   while (!s.empty())
@@ -676,7 +680,9 @@ void vtkLabelHierarchyFullSortIterator::Begin(vtkIdTypeArray* vtkNotUsed(lastPla
     else
     {
       ++numLeaf;
+#ifndef NDEBUG
       totalLeafDepth += level;
+#endif
     }
   }
   vtkDebugMacro("max level is " << maxLevel);
@@ -1639,7 +1645,7 @@ void vtkLabelHierarchy3DepthFirstIterator::Next()
         {
           this->Order.back().push_back(i);
         }
-        this->ReorderChildrenForView(&(this->Order.back()[0]));
+        this->ReorderChildrenForView(this->Order.back().data());
         this->Cursor.down(this->Order.back()[0]);
         this->Path.push_back(0);
         if (this->IsNodeInFrustum())
@@ -2607,3 +2613,4 @@ void vtkLabelHierarchy::GetAnchorFrustumPlanes(
   frustumPlanes[22] = 1.0;
   frustumPlanes[23] = VTK_DOUBLE_MAX;
 }
+VTK_ABI_NAMESPACE_END
