@@ -24,9 +24,10 @@
 #include "vtkObjectFactory.h"
 #include "vtkPath.h"
 #include "vtkPoints.h"
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
 #include "vtkPythonInterpreter.h"
+#endif
 #include "vtkSmartPyObject.h"
-#include "vtkStdString.h"
 #include "vtkTextProperty.h"
 #include "vtkTransform.h"
 
@@ -50,6 +51,7 @@ typedef Py_intptr_t Py_ssize_t;
 #endif
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkMatplotlibMathTextUtilities::Availability vtkMatplotlibMathTextUtilities::MPLMathTextAvailable =
   vtkMatplotlibMathTextUtilities::NOT_TESTED;
 
@@ -57,10 +59,13 @@ vtkMatplotlibMathTextUtilities::Availability vtkMatplotlibMathTextUtilities::MPL
 // is defined in the environment. Use vtkGenericWarningMacro to allow this to
 // work in release mode builds.
 #define vtkMplStartUpDebugMacro(x)                                                                 \
-  if (debug)                                                                                       \
+  do                                                                                               \
   {                                                                                                \
-    vtkGenericWarningMacro(x);                                                                     \
-  }
+    if (debug)                                                                                     \
+    {                                                                                              \
+      vtkGenericWarningMacro(x);                                                                   \
+    }                                                                                              \
+  } while (false)
 
 vtkObjectFactoryNewMacro(vtkMatplotlibMathTextUtilities);
 
@@ -77,10 +82,19 @@ vtkMatplotlibMathTextUtilities::Availability vtkMatplotlibMathTextUtilities::Che
   // VTK_MATPLOTLIB_DEBUG is defined in the process environment.
   bool debug = (vtksys::SystemTools::GetEnv("VTK_MATPLOTLIB_DEBUG") != nullptr);
 
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
   // Initialize the python interpreter if needed
   vtkMplStartUpDebugMacro("Initializing Python, if not already.");
   vtkPythonInterpreter::Initialize();
   vtkMplStartUpDebugMacro("Attempting to import matplotlib.");
+#endif
+  if (!Py_IsInitialized())
+  {
+    // Don't store the result; it might be available if Python is initialized
+    // elsewhere later.
+    return UNAVAILABLE;
+  }
+
   vtkPythonScopeGilEnsurer gilEnsurer;
   if (PyErr_Occurred() || !PyImport_ImportModule("matplotlib") || PyErr_Occurred())
   {
@@ -127,16 +141,25 @@ vtkMatplotlibMathTextUtilities::vtkMatplotlibMathTextUtilities()
   , FontPropertiesClass(nullptr)
   , ScaleToPowerOfTwo(true)
 {
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
   this->Interpreter = vtkPythonInterpreter::New();
   this->Interpreter->AddObserver(
     vtkCommand::ExitEvent, this, &vtkMatplotlibMathTextUtilities::CleanupPythonObjects);
+#else
+  this->Interpreter = nullptr;
+#endif
 }
 
 //------------------------------------------------------------------------------
 vtkMatplotlibMathTextUtilities::~vtkMatplotlibMathTextUtilities()
 {
   this->CleanupPythonObjects();
-  this->Interpreter->Delete();
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
+  if (this->Interpreter)
+  {
+    this->Interpreter->Delete();
+  }
+#endif
 }
 
 //------------------------------------------------------------------------------
@@ -158,8 +181,15 @@ void vtkMatplotlibMathTextUtilities::CleanupPythonObjects()
 //------------------------------------------------------------------------------
 bool vtkMatplotlibMathTextUtilities::InitializeMaskParser()
 {
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
   // ensure that Python is initialized.
   vtkPythonInterpreter::Initialize();
+#endif
+  if (!Py_IsInitialized())
+  {
+    return false;
+  }
+
   vtkPythonScopeGilEnsurer gilEnsurer;
   vtkSmartPyObject mplMathTextLib(PyImport_ImportModule("matplotlib.mathtext"));
   if (this->CheckForError(mplMathTextLib))
@@ -173,7 +203,7 @@ bool vtkMatplotlibMathTextUtilities::InitializeMaskParser()
     return false;
   }
 
-  this->MaskParser = PyObject_CallFunction(mathTextParserClass, const_cast<char*>("s"), "bitmap");
+  this->MaskParser = PyObject_CallFunction(mathTextParserClass, const_cast<char*>("s"), "agg");
   if (this->CheckForError(this->MaskParser))
   {
     Py_CLEAR(this->MaskParser);
@@ -186,8 +216,15 @@ bool vtkMatplotlibMathTextUtilities::InitializeMaskParser()
 //------------------------------------------------------------------------------
 bool vtkMatplotlibMathTextUtilities::InitializePathParser()
 {
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
   // ensure that Python is initialized.
   vtkPythonInterpreter::Initialize();
+#endif
+  if (!Py_IsInitialized())
+  {
+    return false;
+  }
+
   vtkPythonScopeGilEnsurer gilEnsurer;
   vtkSmartPyObject mplTextPathLib(PyImport_ImportModule("matplotlib.textpath"));
   if (this->CheckForError(mplTextPathLib))
@@ -214,8 +251,15 @@ bool vtkMatplotlibMathTextUtilities::InitializePathParser()
 //------------------------------------------------------------------------------
 bool vtkMatplotlibMathTextUtilities::InitializeFontPropertiesClass()
 {
+#if VTK_MODULE_ENABLE_VTK_PythonInterpreter
   // ensure that Python is initialized.
   vtkPythonInterpreter::Initialize();
+#endif
+  if (!Py_IsInitialized())
+  {
+    return false;
+  }
+
   vtkPythonScopeGilEnsurer gilEnsurer;
   vtkSmartPyObject mplFontManagerLib(PyImport_ImportModule("matplotlib.font_manager"));
   if (this->CheckForError(mplFontManagerLib))
@@ -682,7 +726,7 @@ bool vtkMatplotlibMathTextUtilities::ComputeCellRowsAndCols(const char* str, PyO
   }
 
   // Get ftimage
-  PyObject* ftImage = PyTuple_GetItem(resTupleParse, 0);
+  PyObject* ftImage = PyTuple_GetItem(resTupleParse, 5);
   if (this->CheckForError(ftImage))
   {
     return false;
@@ -788,6 +832,7 @@ void vtkMatplotlibMathTextUtilities::ComputeTextColors(vtkTextProperty* tprop, T
 //------------------------------------------------------------------------------
 bool vtkMatplotlibMathTextUtilities::SetMathTextFont(vtkTextProperty* tprop)
 {
+  vtkPythonScopeGilEnsurer gilEnsurer;
   vtkSmartPyObject mplBase(PyImport_ImportModule("matplotlib"));
   if (this->CheckForError(mplBase))
   {
@@ -955,7 +1000,8 @@ bool vtkMatplotlibMathTextUtilities::RenderOneCell(vtkImageData* image, int bbox
 }
 
 //------------------------------------------------------------------------------
-bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(vtkImageData* image, int bbox[4])
+bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(
+  vtkImageData* image, int bbox[4], vtkTextProperty* tprop)
 {
   if (!image)
   {
@@ -966,17 +1012,21 @@ bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(vtkImageData* image, int
   // Define line offsets to take line width into account
   int extraLinesMin = 0;
   int extraLinesMax = 0;
+  int width = tprop->GetInteriorLinesWidth();
+  double* doubleColor = tprop->GetInteriorLinesColor();
+  unsigned char color[3] = { static_cast<unsigned char>(doubleColor[0] * 255),
+    static_cast<unsigned char>(doubleColor[1] * 255),
+    static_cast<unsigned char>(doubleColor[2] * 255) };
 
   // Draw horizontal lines
   for (std::size_t lineIdx = 0; lineIdx < this->HorizontalLinesPosition.size(); ++lineIdx)
   {
     // Clamp line width to remain in bounds
-    extraLinesMin = ((this->HorizontalLinesPosition[lineIdx] - (this->InteriorLinesWidth / 2)) >= 0)
-      ? (-this->InteriorLinesWidth / 2)
+    extraLinesMin = ((this->HorizontalLinesPosition[lineIdx] - (width / 2)) >= 0)
+      ? (-width / 2)
       : (-this->HorizontalLinesPosition[lineIdx]);
-    extraLinesMax = ((this->HorizontalLinesPosition[lineIdx] + (this->InteriorLinesWidth / 2)) <=
-                      (bbox[3] - bbox[2]))
-      ? ((this->InteriorLinesWidth + 1) / 2)
+    extraLinesMax = ((this->HorizontalLinesPosition[lineIdx] + (width / 2)) <= (bbox[3] - bbox[2]))
+      ? ((width + 1) / 2)
       : ((bbox[3] - bbox[2]) - this->HorizontalLinesPosition[lineIdx]);
 
     for (int extraLineIdx = extraLinesMin; extraLineIdx < extraLinesMax; ++extraLineIdx)
@@ -985,9 +1035,9 @@ bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(vtkImageData* image, int
       {
         unsigned char* ptr = static_cast<unsigned char*>(image->GetScalarPointer(
           colIdx, bbox[2] + this->HorizontalLinesPosition[lineIdx] + extraLineIdx, 0));
-        ptr[0] = static_cast<unsigned char>(this->InteriorLinesColor[0]);
-        ptr[1] = static_cast<unsigned char>(this->InteriorLinesColor[1]);
-        ptr[2] = static_cast<unsigned char>(this->InteriorLinesColor[2]);
+        ptr[0] = static_cast<unsigned char>(color[0]);
+        ptr[1] = static_cast<unsigned char>(color[1]);
+        ptr[2] = static_cast<unsigned char>(color[2]);
         ptr[3] = 255;
       }
     }
@@ -997,12 +1047,11 @@ bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(vtkImageData* image, int
   for (std::size_t lineIdx = 0; lineIdx < this->VerticalLinesPosition.size(); ++lineIdx)
   {
     // Clamp line width to remain in bounds
-    extraLinesMin = ((this->VerticalLinesPosition[lineIdx] - (this->InteriorLinesWidth / 2)) >= 0)
-      ? (-this->InteriorLinesWidth / 2)
+    extraLinesMin = ((this->VerticalLinesPosition[lineIdx] - (width / 2)) >= 0)
+      ? (-width / 2)
       : (-this->VerticalLinesPosition[lineIdx]);
-    extraLinesMax = ((this->VerticalLinesPosition[lineIdx] + (this->InteriorLinesWidth / 2)) <=
-                      (bbox[1] - bbox[0]))
-      ? ((this->InteriorLinesWidth + 1) / 2)
+    extraLinesMax = ((this->VerticalLinesPosition[lineIdx] + (width / 2)) <= (bbox[1] - bbox[0]))
+      ? ((width + 1) / 2)
       : ((bbox[1] - bbox[0]) - this->VerticalLinesPosition[lineIdx]);
 
     for (int extraLineIdx = extraLinesMin; extraLineIdx < extraLinesMax; ++extraLineIdx)
@@ -1011,9 +1060,9 @@ bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(vtkImageData* image, int
       {
         unsigned char* ptr = static_cast<unsigned char*>(image->GetScalarPointer(
           bbox[0] + this->VerticalLinesPosition[lineIdx] + extraLineIdx, rowIdx, 0));
-        ptr[0] = static_cast<unsigned char>(this->InteriorLinesColor[0]);
-        ptr[1] = static_cast<unsigned char>(this->InteriorLinesColor[1]);
-        ptr[2] = static_cast<unsigned char>(this->InteriorLinesColor[2]);
+        ptr[0] = static_cast<unsigned char>(color[0]);
+        ptr[1] = static_cast<unsigned char>(color[1]);
+        ptr[2] = static_cast<unsigned char>(color[2]);
         ptr[3] = 255;
       }
     }
@@ -1026,7 +1075,7 @@ bool vtkMatplotlibMathTextUtilities::DrawInteriorLines(vtkImageData* image, int
 bool vtkMatplotlibMathTextUtilities::ParseString(
   const char* str, GridOfStrings& strGrid, std::size_t& maxNumberOfCells)
 {
-  // First, change all occurence of escaped pipe ("\|")
+  // First, change all occurrence of escaped pipe ("\|")
   // Into a special character and recover them after splitting
   std::string stdStr = std::string(str);
   this->FindAndReplaceInString(stdStr, "\\|", vtkMatplotlibMathTextUtilities::PipeProtectString);
@@ -1236,7 +1285,7 @@ bool vtkMatplotlibMathTextUtilities::RenderString(
       {
         vtkErrorMacro(<< "Failed to render cell number " << j);
         return false;
-      };
+      }
 
       colStart += cellCols;
     }
@@ -1251,9 +1300,9 @@ bool vtkMatplotlibMathTextUtilities::RenderString(
   }
 
   // Draw interior lines between cells
-  if (this->InteriorLinesVisibility)
+  if (tprop->GetInteriorLinesVisibility())
   {
-    if (!this->DrawInteriorLines(image, bbox))
+    if (!this->DrawInteriorLines(image, bbox, tprop))
     {
       vtkErrorMacro("Failed to draw interior lines.");
       return false;
@@ -1610,3 +1659,4 @@ void vtkMatplotlibMathTextUtilities::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "PathParser: " << this->PathParser << endl;
   os << indent << "FontPropertiesClass: " << this->FontPropertiesClass << endl;
 }
+VTK_ABI_NAMESPACE_END
