@@ -40,8 +40,7 @@
  *
  * The horizontal space between two cells can be set with vtkTextProperty::SetCellOffset
  *
- * Currently, it is not possible to draw separators between grid cells. Only exterior
- * edges can be drawn with vtkTextProperty::SetFrame
+ * Line separators between grid cells can also be drawn.
  */
 
 #ifndef vtkMatplotlibMathTextUtilities_h
@@ -50,14 +49,16 @@
 #include "vtkMathTextUtilities.h"
 #include "vtkRenderingMatplotlibModule.h" // For export macro
 
-#include <vector>
+#include <vector> // for std::vector
 
 struct _object;
 typedef struct _object PyObject;
-class vtkSmartPyObject;
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkImageData;
 class vtkPath;
 class vtkPythonInterpreter;
+class vtkSmartPyObject;
 class vtkTextProperty;
 struct TextColors;
 
@@ -106,7 +107,7 @@ public:
    */
   bool StringToPath(const char* str, vtkPath* path, vtkTextProperty* tprop, int dpi) override;
 
-  //@{
+  ///@{
   /**
    * Set to true if the graphics implementation requires texture image dimensions
    * to be a power of two. Default is true, but this member will be set
@@ -114,7 +115,7 @@ public:
    */
   void SetScaleToPowerOfTwo(bool val) override;
   bool GetScaleToPowerOfTwo() override;
-  //@}
+  ///@}
 
 protected:
   vtkMatplotlibMathTextUtilities();
@@ -128,7 +129,7 @@ protected:
   bool CheckForError(PyObject* object);
 
   /**
-   * Replace each occurence of strToFind in str by replacementStr.
+   * Replace each occurrence of strToFind in str by replacementStr.
    * Used to protect escaped pipe before the splitting process, and recover them
    * after.
    */
@@ -143,42 +144,10 @@ protected:
    */
   void ComputeTextColors(vtkTextProperty* tprop, TextColors& tcolors);
 
-  typedef std::vector<std::vector<std::string>> GridOfStrings;
-
   /**
-   * Parse the string to handle multiline and multicolumn.
-   * Divide it in lines (splitted with '\n') and cells (splitted with '|')
-   * and store each cell string in strGrid. Also compute the maximum number of cells of all
-   * lines to ensure that all lines have the same number of cells.
+   * Modify matplotlib.rcParams to customize math text font.
    */
-  bool ParseString(const char* str, GridOfStrings& strGrid, std::size_t& maxNumberOfCells);
-
-  /**
-   * Given a grid of string and its corresponding maximum number of cells,
-   * text property and dpi, compute the resulting number of rows and cols
-   * of the image.
-   * Precondition : Matplotlib rendering is available and mask parser is initialized.
-   */
-  bool ComputeRowsAndCols(const GridOfStrings& strGrid, const std::size_t& maxNumberOfCells,
-    vtkTextProperty* tprop, int dpi, long int& rows, long int& cols);
-
-  /**
-   * Given a cell string, text property and dpi, call python mathtext to render the cell and store
-   * it in list if list is not nullptr, and store in rows and cols the size of the python data.
-   * Precondition : Matplotlib rendering is available and mask parser is initialized.
-   */
-  bool ComputeCellRowsAndCols(const char* cellStr, vtkTextProperty* tprop, int dpi, long int& rows,
-    long int& cols, vtkSmartPyObject* list);
-
-  /**
-   * Render in the image starting from (rowStart, colStart) to (rowStart + cellRows, colStart +
-   * cellCols) a cell of size (pythonRows, pythonCols) with pixels value stored in pythonData. If
-   * the python cell size is inferior to the cell size, fill with background color.
-   */
-  bool RenderOneCell(vtkImageData* image, int bbox[4], const long int rowStart,
-    const long int colStart, vtkSmartPyObject& pythonData, const long int pythonRows,
-    const long int pythonCols, const long int cellRows, const long int cellCols,
-    vtkTextProperty* tprop, const TextColors& tcolors);
+  bool SetMathTextFont(vtkTextProperty* tprop);
 
   /**
    * Returns a matplotlib.font_manager.FontProperties PyObject, initialized from
@@ -207,6 +176,9 @@ protected:
   bool ScaleToPowerOfTwo;
   bool PrepareImageData(vtkImageData* data, int bbox[4]);
 
+  std::vector<int> VerticalLinesPosition;
+  std::vector<int> HorizontalLinesPosition;
+
 private:
   vtkMatplotlibMathTextUtilities(const vtkMatplotlibMathTextUtilities&) = delete;
   void operator=(const vtkMatplotlibMathTextUtilities&) = delete;
@@ -230,12 +202,56 @@ private:
    */
   static Availability CheckMPLAvailability();
 
-  //@{
+  ///@{
   /**
    * Cache the availability of matplotlib in the current python session.
    */
   static Availability MPLMathTextAvailable;
-  //@}
+  ///@}
+
+  typedef std::vector<std::vector<std::string>> GridOfStrings;
+
+  /**
+   * Parse the string to handle multiline and multicolumn.
+   * Divide it in lines (splitted with '\n') and cells (splitted with '|')
+   * and store each cell string in strGrid. Also compute the maximum number of cells of all
+   * lines to ensure that all lines have the same number of cells.
+   */
+  bool ParseString(const char* str, GridOfStrings& strGrid, std::size_t& maxNumberOfCells);
+
+  /**
+   * Given a grid of string and its corresponding maximum number of cells,
+   * text property and dpi, compute the resulting number of rows and cols
+   * of the image.
+   * Precondition : Matplotlib rendering is available and mask parser is initialized.
+   */
+  bool ComputeRowsAndCols(const GridOfStrings& strGrid, const std::size_t& maxNumberOfCells,
+    vtkTextProperty* tprop, PyObject* pyFontProp, int dpi, std::uint64_t& rows,
+    std::uint64_t& cols);
+
+  /**
+   * Given a cell string, text property and dpi, call python mathtext to render the cell and store
+   * it in list if list is not nullptr, and store in rows and cols the size of the python data.
+   * Precondition : Matplotlib rendering is available and mask parser is initialized.
+   */
+  bool ComputeCellRowsAndCols(const char* cellStr, PyObject* pyFontProp, int dpi,
+    std::uint64_t& rows, std::uint64_t& cols, vtkSmartPyObject* list);
+
+  /**
+   * Render in the image starting from (rowStart, colStart) to (rowStart + cellRows, colStart +
+   * cellCols) a cell of size (pythonRows, pythonCols) with pixels value stored in pythonData. If
+   * the python cell size is inferior to the cell size, fill with background color.
+   */
+  bool RenderOneCell(vtkImageData* image, int bbox[4], const std::int64_t rowStart,
+    const std::int64_t colStart, vtkSmartPyObject& pythonData, const std::uint64_t pythonRows,
+    const std::uint64_t pythonCols, const std::uint64_t cellRows, const std::uint64_t cellCols,
+    vtkTextProperty* tprop, const TextColors& tcolors);
+
+  /**
+   * Draw interior borders between cells.
+   */
+  bool DrawInteriorLines(vtkImageData* image, int bbox[4], vtkTextProperty* tprop);
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
