@@ -12,37 +12,35 @@
 
 =========================================================================*/
 
-#include "vtkCamera.h"
-#include "vtkRenderer.h"
-#include "vtkOpenGLRenderWindow.h"
 #include "vtkActor.h"
-#include "vtkPolyDataMapper.h"
-#include "vtkNew.h"
-#include "vtkProperty.h"
-#include "vtkSphereSource.h"
-#include "vtkRegressionTestImage.h"
-#include "vtkTestUtilities.h"
+#include "vtkCamera.h"
 #include "vtkLight.h"
+#include "vtkNew.h"
+#include "vtkOpenGLRenderWindow.h"
+#include "vtkPolyDataMapper.h"
+#include "vtkProperty.h"
+#include "vtkRegressionTestImage.h"
+#include "vtkRenderer.h"
+#include "vtkSphereSource.h"
+#include "vtkTestUtilities.h"
 
 #include "vtkRenderWindowInteractor.h"
 
-#include "vtkOpenGLRenderWindow.h"
-
-//----------------------------------------------------------------------------
-int TestSpherePoints(int argc, char *argv[])
+//------------------------------------------------------------------------------
+int TestSpherePoints(int argc, char* argv[])
 {
   vtkNew<vtkRenderer> renderer;
   renderer->SetBackground(0.0, 0.0, 0.0);
   vtkNew<vtkRenderWindow> renderWindow;
   renderWindow->SetSize(300, 300);
   renderWindow->AddRenderer(renderer);
-  vtkNew<vtkRenderWindowInteractor>  iren;
+  vtkNew<vtkRenderWindowInteractor> iren;
   iren->SetRenderWindow(renderWindow);
 
-  vtkNew<vtkLight>light;
-  light->SetPosition(0,1,0);
+  vtkNew<vtkLight> light;
+  light->SetPosition(0, 1, 0);
   light->SetLightTypeToSceneLight();
-//  renderer->AddLight(light);
+  //  renderer->AddLight(light);
 
   vtkNew<vtkSphereSource> sphere;
   sphere->SetThetaResolution(16);
@@ -50,51 +48,51 @@ int TestSpherePoints(int argc, char *argv[])
   sphere->SetEndTheta(270.0);
 
   {
-  vtkNew<vtkPolyDataMapper> mapper;
-  mapper->SetInputConnection(sphere->GetOutputPort());
-  vtkNew<vtkActor> actor;
-  renderer->AddActor(actor);
-  actor->SetMapper(mapper);
-  actor->GetProperty()->SetDiffuseColor(0.4, 1.0, 1.0);
-  vtkNew<vtkProperty> backProp;
-  backProp->SetDiffuseColor(0.4, 0.65, 0.8);
-  actor->SetBackfaceProperty(backProp);
-  actor->GetProperty()->EdgeVisibilityOn();
-  actor->GetProperty()->SetLineWidth(7.0);
-  actor->GetProperty()->RenderLinesAsTubesOn();
-  actor->GetProperty()->SetEdgeColor(1.0,1.0,1.0);
-//  actor->GetProperty()->SetRepresentationToWireframe();
+    vtkNew<vtkPolyDataMapper> mapper;
+    mapper->SetInputConnection(sphere->GetOutputPort());
+    vtkNew<vtkActor> actor;
+    renderer->AddActor(actor);
+    actor->SetMapper(mapper);
+    actor->GetProperty()->SetDiffuseColor(0.4, 1.0, 1.0);
+    vtkNew<vtkProperty> backProp;
+    backProp->SetDiffuseColor(0.4, 0.65, 0.8);
+    actor->SetBackfaceProperty(backProp);
+    actor->GetProperty()->EdgeVisibilityOn();
+    actor->GetProperty()->SetLineWidth(7.0);
+    actor->GetProperty()->RenderLinesAsTubesOn();
+    actor->GetProperty()->SetEdgeColor(1.0, 1.0, 1.0);
+    //  actor->GetProperty()->SetRepresentationToWireframe();
   }
 
   {
-  vtkNew<vtkPolyDataMapper> mapper;
-  mapper->SetInputConnection(sphere->GetOutputPort());
-  vtkNew<vtkActor> actor;
-  renderer->AddActor(actor);
-  actor->SetMapper(mapper);
-  actor->GetProperty()->SetDiffuseColor(1.0, 0.65, 0.7);
-  actor->GetProperty()->SetSpecular(0.5);
-  actor->GetProperty()->SetDiffuse(0.7);
-  actor->GetProperty()->SetSpecularPower(20.0);
-  actor->GetProperty()->RenderPointsAsSpheresOn();
-  actor->GetProperty()->SetPointSize(14.0);
-  actor->GetProperty()->SetRepresentationToPoints();
+    vtkNew<vtkPolyDataMapper> mapper;
+    mapper->SetInputConnection(sphere->GetOutputPort());
+    vtkNew<vtkActor> actor;
+    renderer->AddActor(actor);
+    actor->SetMapper(mapper);
+    actor->GetProperty()->SetDiffuseColor(1.0, 0.65, 0.7);
+    actor->GetProperty()->SetSpecular(0.5);
+    actor->GetProperty()->SetDiffuse(0.7);
+    actor->GetProperty()->SetSpecularPower(20.0);
+    actor->GetProperty()->RenderPointsAsSpheresOn();
+    actor->GetProperty()->SetPointSize(14.0);
+    actor->GetProperty()->SetRepresentationToPoints();
   }
 
   renderWindow->SetMultiSamples(0);
   renderer->ResetCamera();
-//  renderer->GetActiveCamera()->ParallelProjectionOn();
+  //  renderer->GetActiveCamera()->ParallelProjectionOn();
   renderer->GetActiveCamera()->Elevation(-45);
   renderer->GetActiveCamera()->OrthogonalizeViewUp();
   renderer->GetActiveCamera()->Zoom(1.5);
   renderer->ResetCameraClippingRange();
   renderWindow->Render();
 
-  int retVal = vtkRegressionTestImage( renderWindow );
-  if ( retVal == vtkRegressionTester::DO_INTERACTOR)
-    {
+  int retVal = vtkRegressionTestImageThreshold(renderWindow, 0.5);
+  if (retVal == vtkRegressionTester::DO_INTERACTOR)
+  {
     iren->Start();
-    }
+  }
 
   return !retVal;
 }
