@@ -13,18 +13,21 @@
 
 =========================================================================*/
 
-#import <Cocoa/Cocoa.h>
 #import "vtkCocoaMacOSXSDKCompatibility.h" // Needed to support old SDKs
+#import <Cocoa/Cocoa.h>
 
 #import "vtkCocoaGLView.h"
 #import "vtkCocoaRenderWindow.h"
 #import "vtkCocoaRenderWindowInteractor.h"
 #import "vtkCommand.h"
+#import "vtkNew.h"
+#import "vtkOpenGLState.h"
+#import "vtkStringArray.h"
 
 //----------------------------------------------------------------------------
 // Private
-@interface vtkCocoaGLView()
-@property(readwrite, retain, nonatomic) NSTrackingArea *rolloverTrackingArea;
+@interface vtkCocoaGLView ()
+@property (readwrite, retain, nonatomic) NSTrackingArea* rolloverTrackingArea;
 @end
 
 @implementation vtkCocoaGLView
@@ -39,6 +42,34 @@
 //----------------------------------------------------------------------------
 @synthesize rolloverTrackingArea = _rolloverTrackingArea;
 
+//------------------------------------------------------------------------------
+- (void)commonInit
+{
+  // Force Cocoa into "multi threaded mode" because VTK spawns pthreads.
+  // Apple's docs say: "If you intend to use Cocoa calls, you must force
+  // Cocoa into its multithreaded mode before detaching any POSIX threads.
+  // To do this, simply detach an NSThread and have it promptly exit.
+  // This is enough to ensure that the locks needed by the Cocoa
+  // frameworks are put in place"
+  if ([NSThread isMultiThreaded] == NO)
+  {
+    [NSThread detachNewThreadSelector:@selector(emptyMethod:) toTarget:self withObject:nil];
+  }
+
+  // kUTTypeFileURL is deprecated starting with macOS 12.0 but its replacement,
+  // UTTypeFileURL, is in UniformTypeIdentfiers.framework which doesn't exist
+  // on older versions of macOS.  Conditionally using it would require conditionally
+  // linking to that new framework, which just isn't worth the hassle when both
+  // are just syntactic sugar for the string "public.file-url".
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+  NSString* supportedDragType = (NSString*)kUTTypeFileURL;
+#pragma clang diagnostic pop
+
+  // Register the view for file drops.
+  [self registerForDraggedTypes:@[ supportedDragType ]];
+}
+
 //----------------------------------------------------------------------------
 // Overridden (from NSView).
 // designated initializer
@@ -47,18 +78,20 @@
   self = [super initWithFrame:frameRect];
   if (self)
   {
-    // Force Cocoa into "multi threaded mode" because VTK spawns pthreads.
-    // Apple's docs say: "If you intend to use Cocoa calls, you must force
-    // Cocoa into its multithreaded mode before detaching any POSIX threads.
-    // To do this, simply detach an NSThread and have it promptly exit.
-    // This is enough to ensure that the locks needed by the Cocoa
-    // frameworks are put in place"
-    if ([NSThread isMultiThreaded] == NO)
-    {
-      [NSThread detachNewThreadSelector:@selector(emptyMethod:)
-                               toTarget:self
-                             withObject:nil];
-    }
+    [self commonInit];
+  }
+  return self;
+}
+
+//----------------------------------------------------------------------------
+// Overridden (from NSView).
+// designated initializer
+- (/*nullable*/ id)initWithCoder:(NSCoder*)decoder
+{
+  self = [super initWithCoder:decoder];
+  if (self)
+  {
+    [self commonInit];
   }
   return self;
 }
@@ -73,23 +106,23 @@
 #endif
 
 //----------------------------------------------------------------------------
-- (vtkCocoaRenderWindow *)getVTKRenderWindow
+- (vtkCocoaRenderWindow*)getVTKRenderWindow
 {
   return _myVTKRenderWindow;
 }
 
 //----------------------------------------------------------------------------
-- (void)setVTKRenderWindow:(vtkCocoaRenderWindow *)theVTKRenderWindow
+- (void)setVTKRenderWindow:(vtkCocoaRenderWindow*)theVTKRenderWindow
 {
   _myVTKRenderWindow = theVTKRenderWindow;
 }
 
 //----------------------------------------------------------------------------
-- (vtkCocoaRenderWindowInteractor *)getInteractor
+- (vtkCocoaRenderWindowInteractor*)getInteractor
 {
   if (_myVTKRenderWindow)
   {
-    return (vtkCocoaRenderWindowInteractor *)_myVTKRenderWindow->GetInteractor();
+    return (vtkCocoaRenderWindowInteractor*)_myVTKRenderWindow->GetInteractor();
   }
   else
   {
@@ -105,6 +138,10 @@
 
   if (_myVTKRenderWindow && _myVTKRenderWindow->GetMapped())
   {
+    vtkOpenGLState* state = _myVTKRenderWindow->GetState();
+    state->ResetGLScissorState();
+    vtkOpenGLState::ScopedglScissor ss(state);
+
     _myVTKRenderWindow->Render();
   }
 }
@@ -113,22 +150,18 @@
 // Overridden (from NSView).
 - (void)updateTrackingAreas
 {
-  //clear out the old tracking area
-  NSTrackingArea *trackingArea = [self rolloverTrackingArea];
+  // clear out the old tracking area
+  NSTrackingArea* trackingArea = [self rolloverTrackingArea];
   if (trackingArea)
   {
     [self removeTrackingArea:trackingArea];
   }
 
-  //create a new tracking area
+  // create a new tracking area
   NSRect rect = [self visibleRect];
-  NSTrackingAreaOptions opts = (NSTrackingMouseEnteredAndExited |
-                                NSTrackingMouseMoved |
-                                NSTrackingActiveAlways);
-  trackingArea = [[NSTrackingArea alloc] initWithRect:rect
-                                              options:opts
-                                                owner:self
-                                             userInfo:nil];
+  NSTrackingAreaOptions opts =
+    (NSTrackingMouseEnteredAndExited | NSTrackingMouseMoved | NSTrackingActiveAlways);
+  trackingArea = [[NSTrackingArea alloc] initWithRect:rect options:opts owner:self userInfo:nil];
   [self addTrackingArea:trackingArea];
   [self setRolloverTrackingArea:trackingArea];
 #if !VTK_OBJC_IS_ARC
@@ -147,52 +180,40 @@
 
 //----------------------------------------------------------------------------
 // For generating keysyms that are compatible with other VTK interactors
-static const char *vtkMacCharCodeToKeySymTable[128] = {
-  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  "space", "exclam", "quotedbl", "numbersign",
-  "dollar", "percent", "ampersand", "quoteright",
-  "parenleft", "parenright", "asterisk", "plus",
-  "comma", "minus", "period", "slash",
-  "0", "1", "2", "3", "4", "5", "6", "7",
-  "8", "9", "colon", "semicolon", "less", "equal", "greater", "question",
-  "at", "A", "B", "C", "D", "E", "F", "G",
-  "H", "I", "J", "K", "L", "M", "N", "O",
-  "P", "Q", "R", "S", "T", "U", "V", "W",
-  "X", "Y", "Z", "bracketleft",
-  "backslash", "bracketright", "asciicircum", "underscore",
-  "quoteleft", "a", "b", "c", "d", "e", "f", "g",
-  "h", "i", "j", "k", "l", "m", "n", "o",
-  "p", "q", "r", "s", "t", "u", "v", "w",
-  "x", "y", "z", "braceleft", "bar", "braceright", "asciitilde", "Delete",
-};
+static const char* vtkMacCharCodeToKeySymTable[128] = { nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, "space", "exclam", "quotedbl", "numbersign",
+  "dollar", "percent", "ampersand", "quoteright", "parenleft", "parenright", "asterisk", "plus",
+  "comma", "minus", "period", "slash", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "colon",
+  "semicolon", "less", "equal", "greater", "question", "at", "A", "B", "C", "D", "E", "F", "G", "H",
+  "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z",
+  "bracketleft", "backslash", "bracketright", "asciicircum", "underscore", "quoteleft", "a", "b",
+  "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u",
+  "v", "w", "x", "y", "z", "braceleft", "bar", "braceright", "asciitilde", "Delete" };
 
 //----------------------------------------------------------------------------
 // For generating keysyms that are compatible with other VTK interactors
-static const char *vtkMacKeyCodeToKeySymTable[128] = {
-  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  nullptr, nullptr, nullptr, nullptr, "Return", nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  "Tab", nullptr, nullptr, "Backspace", nullptr, "Escape", nullptr, nullptr,
-  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  nullptr, "period", nullptr, "asterisk", nullptr, "plus", nullptr, "Clear",
-  nullptr, nullptr, nullptr, "slash", "KP_Enter", nullptr, "minus", nullptr,
-  nullptr, nullptr, "KP_0", "KP_1", "KP_2", "KP_3", "KP_4", "KP_5",
-  "KP_6", "KP_7", nullptr, "KP_8", "KP_9", nullptr, nullptr, nullptr,
-  "F5", "F6", "F7", "F3", "F8", nullptr, nullptr, nullptr,
-  nullptr, "Snapshot", nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
-  nullptr, nullptr, "Help", "Home", "Prior", "Delete", "F4", "End",
-  "F2", "Next", "F1", "Left", "Right", "Down", "Up", nullptr,
-};
+static const char* vtkMacKeyCodeToKeySymTable[128] = { nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, "Return",
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+  "Tab", nullptr, nullptr, "Backspace", nullptr, "Escape", nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, "period", nullptr, "asterisk",
+  nullptr, "plus", nullptr, "Clear", nullptr, nullptr, nullptr, "slash", "KP_Enter", nullptr,
+  "minus", nullptr, nullptr, nullptr, "KP_0", "KP_1", "KP_2", "KP_3", "KP_4", "KP_5", "KP_6",
+  "KP_7", nullptr, "KP_8", "KP_9", nullptr, nullptr, nullptr, "F5", "F6", "F7", "F3", "F8", nullptr,
+  nullptr, nullptr, nullptr, "Snapshot", nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,
+  nullptr, nullptr, "Help", "Home", "Prior", "Delete", "F4", "End", "F2", "Next", "F1", "Left",
+  "Right", "Down", "Up", nullptr };
 
 //----------------------------------------------------------------------------
 // Convert a Cocoa key event into a VTK key event
-- (void)invokeVTKKeyEvent:(unsigned long)theEventId
-               cocoaEvent:(NSEvent *)theEvent
+- (void)invokeVTKKeyEvent:(unsigned long)theEventId cocoaEvent:(NSEvent*)theEvent
 {
-  vtkCocoaRenderWindowInteractor *interactor = [self getInteractor];
-  vtkCocoaRenderWindow *renWin =
-    vtkCocoaRenderWindow::SafeDownCast([self getVTKRenderWindow]);
+  vtkCocoaRenderWindowInteractor* interactor = [self getInteractor];
+  vtkCocoaRenderWindow* renWin = vtkCocoaRenderWindow::SafeDownCast([self getVTKRenderWindow]);
 
   if (!interactor || !renWin)
   {
@@ -219,7 +240,7 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
   int altDown = ((flags & NSEventModifierFlagOption) != 0);
 
   unsigned char charCode = '\0';
-  const char *keySym = nullptr;
+  const char* keySym = nullptr;
 
   NSEventType type = [theEvent type];
   BOOL isPress = (type == NSEventTypeKeyDown);
@@ -266,9 +287,7 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
       return;
     }
 
-    theEventId = (isPress ?
-                  vtkCommand::KeyPressEvent :
-                  vtkCommand::KeyReleaseEvent);
+    theEventId = (isPress ? vtkCommand::KeyPressEvent : vtkCommand::KeyReleaseEvent);
   }
   else // No info from which to generate a VTK key event!
   {
@@ -280,10 +299,8 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
     keySym = "None";
   }
 
-  interactor->SetEventInformation(static_cast<int>(backingLoc.x),
-                                  static_cast<int>(backingLoc.y),
-                                  controlDown, shiftDown,
-                                  charCode, 1, keySym);
+  interactor->SetEventInformation(static_cast<int>(backingLoc.x), static_cast<int>(backingLoc.y),
+    controlDown, shiftDown, charCode, 1, keySym);
   interactor->SetAltKey(altDown);
 
   interactor->InvokeEvent(theEventId, nullptr);
@@ -295,12 +312,10 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
 
 //----------------------------------------------------------------------------
 // Convert a Cocoa motion event into a VTK button event
-- (void)invokeVTKMoveEvent:(unsigned long)theEventId
-                cocoaEvent:(NSEvent *)theEvent
+- (void)invokeVTKMoveEvent:(unsigned long)theEventId cocoaEvent:(NSEvent*)theEvent
 {
-  vtkCocoaRenderWindowInteractor *interactor = [self getInteractor];
-  vtkCocoaRenderWindow *renWin =
-    vtkCocoaRenderWindow::SafeDownCast([self getVTKRenderWindow]);
+  vtkCocoaRenderWindowInteractor* interactor = [self getInteractor];
+  vtkCocoaRenderWindow* renWin = vtkCocoaRenderWindow::SafeDownCast([self getVTKRenderWindow]);
 
   if (!interactor || !renWin)
   {
@@ -318,21 +333,18 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
   int controlDown = ((flags & (NSEventModifierFlagControl | NSEventModifierFlagCommand)) != 0);
   int altDown = ((flags & NSEventModifierFlagOption) != 0);
 
-  interactor->SetEventInformation(static_cast<int>(backingLoc.x),
-                                  static_cast<int>(backingLoc.y),
-                                  controlDown, shiftDown);
+  interactor->SetEventInformation(
+    static_cast<int>(backingLoc.x), static_cast<int>(backingLoc.y), controlDown, shiftDown);
   interactor->SetAltKey(altDown);
   interactor->InvokeEvent(theEventId, nullptr);
 }
 
 //----------------------------------------------------------------------------
 // Convert a Cocoa motion event into a VTK button event
-- (void)invokeVTKButtonEvent:(unsigned long)theEventId
-                  cocoaEvent:(NSEvent *)theEvent
+- (void)invokeVTKButtonEvent:(unsigned long)theEventId cocoaEvent:(NSEvent*)theEvent
 {
-  vtkCocoaRenderWindowInteractor *interactor = [self getInteractor];
-  vtkCocoaRenderWindow *renWin =
-    vtkCocoaRenderWindow::SafeDownCast([self getVTKRenderWindow]);
+  vtkCocoaRenderWindowInteractor* interactor = [self getInteractor];
+  vtkCocoaRenderWindow* renWin = vtkCocoaRenderWindow::SafeDownCast([self getVTKRenderWindow]);
 
   if (!interactor || !renWin)
   {
@@ -353,42 +365,37 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
   int controlDown = ((flags & (NSEventModifierFlagControl | NSEventModifierFlagCommand)) != 0);
   int altDown = ((flags & NSEventModifierFlagOption) != 0);
 
-  interactor->SetEventInformation(static_cast<int>(backingLoc.x),
-                                  static_cast<int>(backingLoc.y),
-                                  controlDown, shiftDown,
-                                  0, repeatCount);
+  interactor->SetEventInformation(static_cast<int>(backingLoc.x), static_cast<int>(backingLoc.y),
+    controlDown, shiftDown, 0, repeatCount);
   interactor->SetAltKey(altDown);
   interactor->InvokeEvent(theEventId, nullptr);
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)keyDown:(NSEvent *)theEvent
+- (void)keyDown:(NSEvent*)theEvent
 {
-  [self invokeVTKKeyEvent:vtkCommand::KeyPressEvent
-               cocoaEvent:theEvent];
+  [self invokeVTKKeyEvent:vtkCommand::KeyPressEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)keyUp:(NSEvent *)theEvent
+- (void)keyUp:(NSEvent*)theEvent
 {
-  [self invokeVTKKeyEvent:vtkCommand::KeyReleaseEvent
-               cocoaEvent:theEvent];
+  [self invokeVTKKeyEvent:vtkCommand::KeyReleaseEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)flagsChanged:(NSEvent *)theEvent
+- (void)flagsChanged:(NSEvent*)theEvent
 {
   // what kind of event it is will be decided by invokeVTKKeyEvent
-  [self invokeVTKKeyEvent:vtkCommand::AnyEvent
-               cocoaEvent:theEvent];
+  [self invokeVTKKeyEvent:vtkCommand::AnyEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)mouseMoved:(NSEvent *)theEvent
+- (void)mouseMoved:(NSEvent*)theEvent
 {
   // Note: this method will only be called if this view's NSWindow
   // is set to receive mouse moved events.  See setAcceptsMouseMovedEvents:
@@ -399,56 +406,50 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
   NSPoint viewLoc = [self convertPoint:windowLoc fromView:nil];
   if (NSPointInRect(viewLoc, [self visibleRect]))
   {
-    [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent
-                  cocoaEvent:theEvent];
+    [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent cocoaEvent:theEvent];
   }
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)mouseDragged:(NSEvent *)theEvent
+- (void)mouseDragged:(NSEvent*)theEvent
 {
-  [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent
-                cocoaEvent:theEvent];
+  [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)rightMouseDragged:(NSEvent *)theEvent
+- (void)rightMouseDragged:(NSEvent*)theEvent
 {
-  [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent
-                cocoaEvent:theEvent];
+  [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)otherMouseDragged:(NSEvent *)theEvent
+- (void)otherMouseDragged:(NSEvent*)theEvent
 {
-  [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent
-                cocoaEvent:theEvent];
+  [self invokeVTKMoveEvent:vtkCommand::MouseMoveEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)mouseEntered:(NSEvent *)theEvent
+- (void)mouseEntered:(NSEvent*)theEvent
 {
   // Note: the mouseEntered/mouseExited events depend on the maintenance of
   // the tracking area (updateTrackingAreas).
-  [self invokeVTKMoveEvent:vtkCommand::EnterEvent
-                cocoaEvent:theEvent];
+  [self invokeVTKMoveEvent:vtkCommand::EnterEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)mouseExited:(NSEvent *)theEvent
+- (void)mouseExited:(NSEvent*)theEvent
 {
-  [self invokeVTKMoveEvent:vtkCommand::LeaveEvent
-                cocoaEvent:theEvent];
+  [self invokeVTKMoveEvent:vtkCommand::LeaveEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)scrollWheel:(NSEvent *)theEvent
+- (void)scrollWheel:(NSEvent*)theEvent
 {
   CGFloat dy = [theEvent deltaY];
 
@@ -465,76 +466,136 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
 
   if (eventId != 0)
   {
-    [self invokeVTKMoveEvent:eventId
-                  cocoaEvent:theEvent];
+    [self invokeVTKMoveEvent:eventId cocoaEvent:theEvent];
   }
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)mouseDown:(NSEvent *)theEvent
+- (void)mouseDown:(NSEvent*)theEvent
 {
-  [self invokeVTKButtonEvent:vtkCommand::LeftButtonPressEvent
-                  cocoaEvent:theEvent];
+  [self invokeVTKButtonEvent:vtkCommand::LeftButtonPressEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)rightMouseDown:(NSEvent *)theEvent
+- (void)rightMouseDown:(NSEvent*)theEvent
 {
-  [self invokeVTKButtonEvent:vtkCommand::RightButtonPressEvent
-                  cocoaEvent:theEvent];
+  [self invokeVTKButtonEvent:vtkCommand::RightButtonPressEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)otherMouseDown:(NSEvent *)theEvent
+- (void)otherMouseDown:(NSEvent*)theEvent
 {
-  [self invokeVTKButtonEvent:vtkCommand::MiddleButtonPressEvent
-                  cocoaEvent:theEvent];
+  [self invokeVTKButtonEvent:vtkCommand::MiddleButtonPressEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)mouseUp:(NSEvent *)theEvent
+- (void)mouseUp:(NSEvent*)theEvent
 {
-  [self invokeVTKButtonEvent:vtkCommand::LeftButtonReleaseEvent
-                  cocoaEvent:theEvent];
+  [self invokeVTKButtonEvent:vtkCommand::LeftButtonReleaseEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)rightMouseUp:(NSEvent *)theEvent
+- (void)rightMouseUp:(NSEvent*)theEvent
 {
-  [self invokeVTKButtonEvent:vtkCommand::RightButtonReleaseEvent
-                  cocoaEvent:theEvent];
+  [self invokeVTKButtonEvent:vtkCommand::RightButtonReleaseEvent cocoaEvent:theEvent];
 }
 
 //----------------------------------------------------------------------------
 // Overridden (from NSResponder).
-- (void)otherMouseUp:(NSEvent *)theEvent
+- (void)otherMouseUp:(NSEvent*)theEvent
 {
-  [self invokeVTKButtonEvent:vtkCommand::MiddleButtonReleaseEvent
-                  cocoaEvent:theEvent];
+  [self invokeVTKButtonEvent:vtkCommand::MiddleButtonReleaseEvent cocoaEvent:theEvent];
+}
+
+//----------------------------------------------------------------------------
+// From NSDraggingDestination protocol.
+- (NSDragOperation)draggingEntered:(id<NSDraggingInfo>)sender
+{
+  NSArray* types = [[sender draggingPasteboard] types];
+
+  // kUTTypeFileURL is deprecated starting with macOS 12.0 but its replacement,
+  // UTTypeFileURL, is in UniformTypeIdentfiers.framework which doesn't exist
+  // on older versions of macOS.  Conditionally using it would require conditionally
+  // linking to that new framework, which just isn't worth the hassle when both
+  // are just syntactic sugar for the string "public.file-url".
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+  NSString* supportedDragType = (NSString*)kUTTypeFileURL;
+#pragma clang diagnostic pop
+
+  if ([types containsObject:supportedDragType])
+  {
+    return NSDragOperationCopy;
+  }
+  return NSDragOperationNone;
+}
+
+//----------------------------------------------------------------------------
+// From NSDraggingDestination protocol.
+- (BOOL)performDragOperation:(id<NSDraggingInfo>)sender
+{
+  vtkCocoaRenderWindowInteractor* interactor = [self getInteractor];
+
+  NSPoint pt = [sender draggingLocation];
+  NSPoint viewLoc = [self convertPoint:pt fromView:nil];
+  NSPoint backingLoc = [self convertPointToBacking:viewLoc];
+  double location[2];
+  location[0] = backingLoc.x;
+  location[1] = backingLoc.y;
+  interactor->InvokeEvent(vtkCommand::UpdateDropLocationEvent, location);
+
+  vtkNew<vtkStringArray> filePaths;
+  NSPasteboard* pboard = [sender draggingPasteboard];
+  NSArray* fileURLs = [pboard readObjectsForClasses:@ [[NSURL class]] options:nil];
+  for (NSURL* fileURL in fileURLs)
+  {
+    const char* filePath = [fileURL fileSystemRepresentation];
+    filePaths->InsertNextValue(filePath);
+  }
+
+  if (filePaths->GetNumberOfTuples() > 0)
+  {
+    interactor->InvokeEvent(vtkCommand::DropFilesEvent, filePaths);
+    return YES;
+  }
+
+  return NO;
 }
 
 //----------------------------------------------------------------------------
 // Private
-- (void)modifyDPIForBackingScaleFactorOfWindow:(/*nullable*/ NSWindow *)window
+- (void)modifyDPIForBackingScaleFactorOfWindow:(/*nullable*/ NSWindow*)window
 {
-  if (window)
+  // Convert from points to pixels.
+  NSRect viewRect = [self frame];
+  NSRect backingViewRect = [self convertRectToBacking:viewRect];
+  CGFloat viewHeight = NSHeight(viewRect);
+  CGFloat backingViewHeight = NSHeight(backingViewRect);
+  CGFloat backingScaleFactor = 1.0;
+  if (viewHeight > 0.0 && backingViewHeight > 0.0)
   {
-    CGFloat backingScaleFactor = [window backingScaleFactor];
-    assert(backingScaleFactor >= 1.0);
+    // the scale factor based on convertRectToBacking
+    backingScaleFactor = backingViewHeight / viewHeight;
+  }
+  else if (window)
+  {
+    // fall back to less reliable method
+    backingScaleFactor = [window backingScaleFactor];
+  }
+  assert(backingScaleFactor >= 1.0);
 
-    vtkCocoaRenderWindow *renderWindow = [self getVTKRenderWindow];
-    if (renderWindow)
-    {
-      // Ordinarily, DPI is hardcoded to 72, but in order for vtkTextActors
-      // to have the correct apparent size, we adjust it per the NSWindow's
-      // scaling factor.
-      renderWindow->SetDPI(lround(72.0 * backingScaleFactor));
-    }
+  vtkCocoaRenderWindow* renderWindow = [self getVTKRenderWindow];
+  if (renderWindow)
+  {
+    // Ordinarily, DPI is hardcoded to 72, but in order for vtkTextActors
+    // to have the correct apparent size, we adjust it per the NSWindow's
+    // scaling factor.
+    renderWindow->SetDPI(lround(72.0 * backingScaleFactor));
   }
 }
 
@@ -553,7 +614,7 @@ static const char *vtkMacKeyCodeToKeySymTable[128] = {
 {
   [super viewDidChangeBackingProperties];
 
-  NSWindow *window = [self window];
+  NSWindow* window = [self window];
   [self modifyDPIForBackingScaleFactorOfWindow:window];
 }
 
