@@ -46,6 +46,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include <stack>                       // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGOPENGL2_EXPORT vtkCocoaRenderWindow : public vtkOpenGLRenderWindow
 {
 public:
@@ -97,7 +98,7 @@ public:
    */
   virtual void PrefFullScreen();
 
-  //@{
+  ///@{
   /**
    * Set the size (width and height) of the rendering window in
    * screen coordinates (in pixels). This resizes the operating
@@ -108,7 +109,7 @@ public:
    */
   void SetSize(int width, int height) override;
   void SetSize(int a[2]) override { this->SetSize(a[0], a[1]); }
-  //@}
+  ///@}
 
   /**
    * Get the size (width and height) of the rendering window in
@@ -116,7 +117,7 @@ public:
    */
   int* GetSize() VTK_SIZEHINT(2) override;
 
-  //@{
+  ///@{
   /**
    * Set the position (x and y) of the rendering window in
    * screen coordinates (in pixels). This resizes the operating
@@ -124,7 +125,7 @@ public:
    */
   void SetPosition(int x, int y) override;
   void SetPosition(int a[2]) override { this->SetPosition(a[0], a[1]); }
-  //@}
+  ///@}
 
   /**
    * Get the current size of the screen in pixels.
@@ -215,21 +216,16 @@ public:
    */
   void MakeCurrent() override;
 
+  /**
+   * Release the current context.
+   */
+  void ReleaseCurrent() override;
+
   /**
    * Tells if this window is the current OpenGL context for the calling thread.
    */
   bool IsCurrent() override;
 
-  /**
-   * Test if the window has a valid drawable. This is
-   * currently only an issue on Mac OS X Cocoa where rendering
-   * to an invalid drawable results in all OpenGL calls to fail
-   * with "invalid framebuffer operation".
-   */
-  VTK_DEPRECATED_IN_9_1_0(
-    "Deprecated in 9.1 because no one knows what it's for and nothing uses it")
-  bool IsDrawable() override;
-
   /**
    * Update this window's OpenGL context, e.g. when the window is resized.
    */
@@ -258,20 +254,20 @@ public:
    */
   vtkTypeBool GetEventPending() override;
 
-  //@{
+  ///@{
   /**
    * Initialize OpenGL for this window.
    */
   virtual void SetupPalette(void* hDC);
   virtual void SetupPixelFormat(void* hDC, void* dwFlags, int debug, int bpp = 16, int zbpp = 16);
-  //@}
+  ///@}
 
   /**
    * Clean up device contexts, rendering contexts, etc.
    */
   void Finalize() override;
 
-  //@{
+  ///@{
   /**
    * Hide or Show the mouse cursor, it is nice to be able to hide the
    * default cursor if you want VTK to display a 3D cursor instead.
@@ -281,7 +277,7 @@ public:
   void HideCursor() override;
   void ShowCursor() override;
   void SetCursorPosition(int x, int y) override;
-  //@}
+  ///@}
 
   /**
    * Change the shape of the cursor.
@@ -300,14 +296,14 @@ public:
    */
   virtual vtkTypeBool GetWindowCreated();
 
-  //@{
+  ///@{
   /**
    * Accessors for the OpenGL context (Really an NSOpenGLContext*).
    */
   void SetContextId(void*);
   void* GetContextId();
   void* GetGenericContext() override { return this->GetContextId(); }
-  //@}
+  ///@}
 
   /**
    * Sets the NSWindow* associated with this vtkRenderWindow.
@@ -382,15 +378,15 @@ public:
   void SetConnectContextToNSView(bool connect);
   bool GetConnectContextToNSView();
 
-  //@{
+  ///@{
   /**
    * Accessors for the pixel format object (Really an NSOpenGLPixelFormat*).
    */
   void SetPixelFormat(void* pixelFormat);
   void* GetPixelFormat();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Ability to push and pop this window's context
    * as the current context. The idea being to
@@ -400,7 +396,7 @@ public:
    */
   void PushContext() override;
   void PopContext() override;
-  //@}
+  ///@}
 
 protected:
   vtkCocoaRenderWindow();
@@ -414,14 +410,14 @@ protected:
   void DestroyWindow() override;
   vtkTypeBool OnScreenInitialized;
 
-  //@{
+  ///@{
   /**
    * Accessors for the cocoa manager (Really an NSMutableDictionary*).
    * It manages all Cocoa objects in this C++ class.
    */
   void SetCocoaManager(void* manager);
   void* GetCocoaManager();
-  //@}
+  ///@}
 
   void SetCocoaServer(void* server); // Really a vtkCocoaServer*
   void* GetCocoaServer();
@@ -451,4 +447,5 @@ private:
   int DisplayIndex = 0;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
