@@ -13,9 +13,6 @@ PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
 
-// Hide VTK_DEPRECATED_IN_9_1_0() warnings for this class.
-#define VTK_DEPRECATION_LEVEL 0
-
 #include "vtk_glew.h"
 
 #import "vtkCocoaMacOSXSDKCompatibility.h" // Needed to support old SDKs
@@ -34,7 +31,9 @@ PURPOSE.  See the above copyright notice for more information.
 
 #import <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCocoaRenderWindow);
+VTK_ABI_NAMESPACE_END
 
 //----------------------------------------------------------------------------
 // This is a private class and an implementation detail, do not use it.
@@ -202,6 +201,7 @@ vtkStandardNewMacro(vtkCocoaRenderWindow);
 
 @end
 
+VTK_ABI_NAMESPACE_BEGIN
 //----------------------------------------------------------------------------
 vtkCocoaRenderWindow::vtkCocoaRenderWindow()
 {
@@ -228,6 +228,16 @@ vtkCocoaRenderWindow::vtkCocoaRenderWindow()
 //----------------------------------------------------------------------------
 vtkCocoaRenderWindow::~vtkCocoaRenderWindow()
 {
+  // If we created a vtkCocoaGLView, clear its reference back to us.
+  if (this->GetViewCreated())
+  {
+    NSView* glView = (NSView*)this->GetWindowId();
+    if ([glView isKindOfClass:[vtkCocoaGLView class]])
+    {
+      [(vtkCocoaGLView*)glView setVTKRenderWindow:nullptr];
+    }
+  }
+
   if (this->CursorHidden)
   {
     this->ShowCursor();
@@ -335,6 +345,12 @@ void vtkCocoaRenderWindow::MakeCurrent()
   }
 }
 
+//----------------------------------------------------------------------------
+void vtkCocoaRenderWindow::ReleaseCurrent()
+{
+  [NSOpenGLContext clearCurrentContext];
+}
+
 //----------------------------------------------------------------------------
 void vtkCocoaRenderWindow::PushContext()
 {
@@ -373,26 +389,6 @@ bool vtkCocoaRenderWindow::IsCurrent()
   return result;
 }
 
-//----------------------------------------------------------------------------
-bool vtkCocoaRenderWindow::IsDrawable()
-{
-  VTK_LEGACY_BODY(vtkCocoaRenderWindow::IsDrawable, "VTK 9.1");
-
-  // you must initialize it first
-  // else it always evaluates false
-  this->Initialize();
-
-  // first check that window is valid
-  NSView* theView = (NSView*)this->GetWindowId();
-  bool win = [[theView window] windowNumber] > 0;
-
-  // then check that the drawable is valid
-  NSOpenGLContext* context = (NSOpenGLContext*)this->GetContextId();
-  bool ok = [context view] != nil;
-
-  return win && ok;
-}
-
 //----------------------------------------------------------------------------
 void vtkCocoaRenderWindow::UpdateContext()
 {
@@ -743,12 +739,12 @@ void vtkCocoaRenderWindow::CreateAWindow()
     }
     else
     {
-      if ((this->Size[0] + this->Size[1]) == 0)
+      if ((this->Size[0] == 0) && (this->Size[1] == 0))
       {
         this->Size[0] = 300;
         this->Size[1] = 300;
       }
-      if ((this->Position[0] + this->Position[1]) == 0)
+      if ((this->Position[0] == 0) && (this->Position[1] == 0))
       {
         this->Position[0] = 50;
         this->Position[1] = 50;
@@ -859,7 +855,10 @@ void vtkCocoaRenderWindow::CreateAWindow()
       // SetParentId() was added for) then the Tk superview handles the events.
       NSRect glRect = NSMakeRect(x, y, width, height);
       NSView* glView = [[NSView alloc] initWithFrame:glRect];
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
       [glView setWantsBestResolutionOpenGLSurface:wantsBest];
+#pragma clang diagnostic pop
       [parent addSubview:glView];
       this->SetWindowId(glView);
       this->ViewCreated = 1;
@@ -879,7 +878,10 @@ void vtkCocoaRenderWindow::CreateAWindow()
 
       // Create a vtkCocoaGLView.
       vtkCocoaGLView* glView = [[vtkCocoaGLView alloc] initWithFrame:viewRect];
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
       [glView setWantsBestResolutionOpenGLSurface:wantsBest];
+#pragma clang diagnostic pop
       [window setContentView:glView];
       // We have to set the frame's view rect again to work around rounding
       // that occurs when setting the window's content view.
@@ -900,7 +902,10 @@ void vtkCocoaRenderWindow::CreateAWindow()
   if (connectContextToNSView)
   {
     NSView* view = (NSView*)this->GetWindowId();
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
     [context setView:view];
+#pragma clang diagnostic pop
   }
 
   // the error "invalid drawable" in the console from this call can appear
@@ -1022,7 +1027,10 @@ void vtkCocoaRenderWindow::CreateGLContext()
 
     // This syncs the OpenGL context to the VBL to prevent tearing
     GLint one = 1;
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
     [context setValues:&one forParameter:NSOpenGLCPSwapInterval];
+#pragma clang diagnostic pop
   }
 
   this->SetPixelFormat((void*)pixelFormat);
@@ -1058,7 +1066,10 @@ void vtkCocoaRenderWindow::Start()
     if (connectContextToNSView)
     {
       NSView* view = (NSView*)this->GetWindowId();
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
       [context setView:view];
+#pragma clang diagnostic pop
     }
 
     // the error "invalid drawable" in the console from this call can appear
@@ -1629,3 +1640,4 @@ void vtkCocoaRenderWindow::SetConnectContextToNSView(bool connect)
 {
   this->ConnectContextToNSView = connect;
 }
+VTK_ABI_NAMESPACE_END
