@@ -22,15 +22,15 @@
 #include "vtkCommand.h"
 #include "vtkCompositeDataDisplayAttributes.h"
 #include "vtkCompositeDataPipeline.h"
-#include "vtkCompositeDataSet.h"
-#include "vtkCompositeDataSetRange.h"
 #include "vtkDataObjectTree.h"
 #include "vtkDataObjectTreeRange.h"
+#include "vtkDataSetAttributes.h"
 #include "vtkFloatArray.h"
 #include "vtkHardwareSelector.h"
 #include "vtkIdTypeArray.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
+#include "vtkLogger.h"
 #include "vtkLookupTable.h"
 #include "vtkObjectFactory.h"
 #include "vtkOpenGLCellToVTKCellMap.h"
@@ -51,28 +51,38 @@
 #include "vtkShaderProgram.h"
 #include "vtkTextureObject.h"
 #include "vtkTransform.h"
+#include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 
 #include <algorithm>
 #include <sstream>
 
-#include "vtkCompositePolyDataMapper2Internal.h"
-
-typedef std::map<vtkPolyData*, vtkCompositeMapperHelperData*>::iterator dataIter;
-typedef std::map<const std::string, vtkCompositeMapperHelper2*>::iterator helpIter;
+#include "vtkCompositeMapperHelper2.h"
 
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCompositeMapperHelper2);
 
-vtkCompositeMapperHelper2::~vtkCompositeMapperHelper2()
+//------------------------------------------------------------------------------
+void vtkCompositeMapperHelper2::PrintSelf(ostream& os, vtkIndent indent)
 {
-  for (dataIter it = this->Data.begin(); it != this->Data.end(); ++it)
-  {
-    delete it->second;
-  }
-  this->Data.clear();
-  this->RenderedList.clear();
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "Marked: " << this->Marked << endl;
+  os << indent << "Primary ID Used: " << this->PrimIDUsed << endl;
+  os << indent << "Override Color Used: " << this->OverideColorUsed << endl;
 }
 
+//------------------------------------------------------------------------------
+vtkCompositeMapperHelper2::~vtkCompositeMapperHelper2()
+{
+  for (auto& data : this->Data)
+  {
+    delete data.second;
+  }
+  this->Data.clear();
+}
+
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::SetShaderValues(
   vtkShaderProgram* prog, vtkCompositeMapperHelperData* hdata, size_t primOffset)
 {
@@ -157,19 +167,10 @@ void vtkCompositeMapperHelper2::SetShaderValues(
   }
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::UpdateShaders(
   vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act)
 {
-  // in cases where LegacyShaderProperty is not nullptr, it means someone has used
-  // legacy shader replacement functions, so we make sure the actor uses the same
-  // shader property. NOTE: this implies that it is not possible to use both legacy
-  // and new functionality on the same actor/mapper.
-  if (this->Parent->LegacyShaderProperty &&
-    act->GetShaderProperty() != this->Parent->LegacyShaderProperty)
-  {
-    act->SetShaderProperty(this->Parent->LegacyShaderProperty);
-  }
-
   Superclass::UpdateShaders(cellBO, ren, act);
   if (cellBO.Program && this->Parent)
   {
@@ -178,6 +179,7 @@ void vtkCompositeMapperHelper2::UpdateShaders(
   }
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::ReplaceShaderColor(
   std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* actor)
 {
@@ -203,18 +205,20 @@ void vtkCompositeMapperHelper2::ReplaceShaderColor(
   this->Superclass::ReplaceShaderColor(shaders, ren, actor);
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::ClearMark()
 {
-  for (dataIter it = this->Data.begin(); it != this->Data.end(); ++it)
+  for (auto& data : this->Data)
   {
-    it->second->Marked = false;
+    data.second->Marked = false;
   }
   this->Marked = false;
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::RemoveUnused()
 {
-  for (dataIter it = this->Data.begin(); it != this->Data.end();)
+  for (auto it = this->Data.begin(); it != this->Data.end();)
   {
     if (!it->second->Marked)
     {
@@ -229,6 +233,17 @@ void vtkCompositeMapperHelper2::RemoveUnused()
   }
 }
 
+//------------------------------------------------------------------------------
+std::vector<vtkPolyData*> vtkCompositeMapperHelper2::GetRenderedList() const
+{
+  std::vector<vtkPolyData*> result;
+  for (const auto& pair : this->Data)
+  {
+    result.push_back(pair.first);
+  }
+  return result;
+}
+
 //------------------------------------------------------------------------------
 // Returns if we can use texture maps for scalar coloring. Note this doesn't say
 // we "will" use scalar coloring. It says, if we do use scalar coloring, we will
@@ -245,9 +260,9 @@ int vtkCompositeMapperHelper2::CanUseTextureMapForColoring(vtkDataObject*)
 
   int cellFlag = 0;
   vtkScalarsToColors* scalarsLookupTable = nullptr;
-  for (dataIter it = this->Data.begin(); it != this->Data.end(); ++it)
+  for (auto& data : this->Data)
   {
-    vtkPolyData* pd = it->second->Data;
+    vtkPolyData* pd = data.second->Data;
     vtkDataArray* scalars = vtkAbstractMapper::GetScalars(
       pd, this->ScalarMode, this->ArrayAccessMode, this->ArrayId, this->ArrayName, cellFlag);
 
@@ -316,6 +331,11 @@ void vtkCompositeMapperHelper2::RenderPiece(vtkRenderer* ren, vtkActor* actor)
 
 void vtkCompositeMapperHelper2::UpdateCameraShiftScale(vtkRenderer* ren, vtkActor* actor)
 {
+  if (this->PauseShiftScale)
+  {
+    return;
+  }
+
   // handle camera shift scale
   if (this->ShiftScaleMethod == vtkOpenGLVertexBufferObject::NEAR_PLANE_SHIFT_SCALE ||
     this->ShiftScaleMethod == vtkOpenGLVertexBufferObject::FOCAL_POINT_SHIFT_SCALE)
@@ -377,12 +397,12 @@ void vtkCompositeMapperHelper2::DrawIBO(vtkRenderer* ren, vtkActor* actor, int p
     //   prog->SetUniform3f("ambientColorUniform", ambientColor);
     // }
 
-    bool selecting = (this->CurrentSelector ? true : false);
+    bool selecting = this->CurrentSelector != nullptr;
     bool tpass = actor->IsRenderingTranslucentPolygonalGeometry();
 
-    for (dataIter it = this->Data.begin(); it != this->Data.end(); ++it)
+    for (auto& data : this->Data)
     {
-      vtkCompositeMapperHelperData* starthdata = it->second;
+      vtkCompositeMapperHelperData* starthdata = data.second;
       bool shouldDraw = starthdata->Visibility     // must be visible
         && (!selecting || starthdata->Pickability) // and pickable when selecting
         && (((selecting || starthdata->IsOpaque || actor->GetForceOpaque()) &&
@@ -437,7 +457,7 @@ void vtkCompositeMapperHelper2::RenderPieceDraw(vtkRenderer* ren, vtkActor* acto
                                   : vtkOpenGLPolyDataMapper::PrimitiveEnd);
        i++)
   {
-    this->DrawingVertices = (i > vtkOpenGLPolyDataMapper::PrimitiveTriStrips ? true : false);
+    this->DrawingVertices = i > vtkOpenGLPolyDataMapper::PrimitiveTriStrips;
     this->DrawingSelection = false;
     GLenum mode = this->GetOpenGLMode(representation, i);
     this->DrawIBO(ren, actor, i, this->Primitives[i], mode,
@@ -469,10 +489,11 @@ void vtkCompositeMapperHelper2::RenderPieceDraw(vtkRenderer* ren, vtkActor* acto
   }
 }
 
+//------------------------------------------------------------------------------
 vtkCompositeMapperHelperData* vtkCompositeMapperHelper2::AddData(
   vtkPolyData* pd, unsigned int flatIndex)
 {
-  dataIter found = this->Data.find(pd);
+  auto found = this->Data.find(pd);
   if (found == this->Data.end())
   {
     vtkCompositeMapperHelperData* hdata = new vtkCompositeMapperHelperData();
@@ -481,7 +502,6 @@ vtkCompositeMapperHelperData* vtkCompositeMapperHelper2::AddData(
     hdata->Marked = true;
     this->Data.insert(std::make_pair(pd, hdata));
     this->Modified();
-    this->RenderedList.push_back(pd);
     return hdata;
   }
   found->second->FlatIndex = flatIndex;
@@ -489,6 +509,29 @@ vtkCompositeMapperHelperData* vtkCompositeMapperHelper2::AddData(
   return found->second;
 }
 
+//------------------------------------------------------------------------------
+bool vtkCompositeMapperHelper2::GetNeedToRebuildBufferObjects(
+  vtkRenderer* vtkNotUsed(ren), vtkActor* act)
+{
+  // Same as vtkOpenGLPolyDataMapper::GetNeedToRebuildBufferObjects(), but
+  // we need to check all inputs, not just this->CurrentInput
+  this->TempState.Clear();
+  this->TempState.Append(act->GetProperty()->GetMTime(), "actor mtime");
+  for (auto data : this->Data)
+  {
+    this->TempState.Append(data.first ? data.first->GetMTime() : 0, "input mtime");
+  }
+  this->TempState.Append(act->GetTexture() ? act->GetTexture()->GetMTime() : 0, "texture mtime");
+
+  if (this->VBOBuildState != this->TempState || this->VBOBuildTime < this->GetMTime())
+  {
+    this->VBOBuildState = this->TempState;
+    return true;
+  }
+
+  return false;
+}
+
 //------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::BuildBufferObjects(vtkRenderer* ren, vtkActor* act)
 {
@@ -498,7 +541,6 @@ void vtkCompositeMapperHelper2::BuildBufferObjects(vtkRenderer* ren, vtkActor* a
   std::vector<unsigned char> newColors;
   std::vector<float> newNorms;
 
-  dataIter iter;
   this->VBOs->ClearAllVBOs();
 
   if (this->Data.begin() == this->Data.end())
@@ -514,9 +556,9 @@ void vtkCompositeMapperHelper2::BuildBufferObjects(vtkRenderer* ren, vtkActor* a
   this->Data.begin()->second->Data->GetPoints()->GetBounds(bounds);
   bbox.SetBounds(bounds);
   vtkCompositeMapperHelperData* prevhdata = nullptr;
-  for (iter = this->Data.begin(); iter != this->Data.end(); ++iter)
+  for (auto& data : this->Data)
   {
-    vtkCompositeMapperHelperData* hdata = iter->second;
+    vtkCompositeMapperHelperData* hdata = data.second;
 
     hdata->Data->GetPoints()->GetBounds(bounds);
     bbox.AddBounds(bounds);
@@ -604,7 +646,7 @@ void vtkCompositeMapperHelper2::BuildBufferObjects(vtkRenderer* ren, vtkActor* a
     }
   }
 
-  if (this->EdgeValues.size())
+  if (!this->EdgeValues.empty())
   {
     if (!this->EdgeTexture)
     {
@@ -801,7 +843,7 @@ void vtkCompositeMapperHelper2::AppendOneBufferObject(vtkRenderer* ren, vtkActor
   if (c)
   {
     int cellFlag = 0; // not used
-    vtkAbstractArray* abstractArray = this->GetAbstractScalars(
+    vtkAbstractArray* abstractArray = vtkCompositeMapperHelper2::GetAbstractScalars(
       poly, this->ScalarMode, this->ArrayAccessMode, this->ArrayId, this->ArrayName, cellFlag);
 
     auto iter = this->ColorArrayMap.find(abstractArray);
@@ -928,6 +970,7 @@ void vtkCompositeMapperHelper2::AppendOneBufferObject(vtkRenderer* ren, vtkActor
   }
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::ProcessSelectorPixelBuffers(
   vtkHardwareSelector* sel, std::vector<unsigned int>& pixeloffsets, vtkProp* prop)
 {
@@ -957,9 +1000,10 @@ void vtkCompositeMapperHelper2::ProcessSelectorPixelBuffers(
     }
 
     size_t maxFlatIndex = 0;
-    for (dataIter it = this->Data.begin(); it != this->Data.end(); ++it)
+    for (auto& data : this->Data)
     {
-      maxFlatIndex = (it->second->FlatIndex > maxFlatIndex) ? it->second->FlatIndex : maxFlatIndex;
+      maxFlatIndex =
+        (data.second->FlatIndex > maxFlatIndex) ? data.second->FlatIndex : maxFlatIndex;
     }
 
     this->PickPixels.resize(maxFlatIndex + 1);
@@ -979,16 +1023,17 @@ void vtkCompositeMapperHelper2::ProcessSelectorPixelBuffers(
   }
 
   // for each block update the image
-  for (dataIter it = this->Data.begin(); it != this->Data.end(); ++it)
+  for (auto& data : this->Data)
   {
-    if (!this->PickPixels[it->second->FlatIndex].empty())
+    if (!this->PickPixels[data.second->FlatIndex].empty())
     {
       this->ProcessCompositePixelBuffers(
-        sel, prop, it->second, this->PickPixels[it->second->FlatIndex]);
+        sel, prop, data.second, this->PickPixels[data.second->FlatIndex]);
     }
   }
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositeMapperHelper2::ProcessCompositePixelBuffers(vtkHardwareSelector* sel,
   vtkProp* prop, vtkCompositeMapperHelperData* hdata, std::vector<unsigned int>& pixeloffsets)
 {
@@ -1261,10 +1306,13 @@ void vtkCompositeMapperHelper2::ProcessCompositePixelBuffers(vtkHardwareSelector
   }
 }
 
-//===================================================================
+//------------------------------------------------------------------------------
 // Now the main class methods
+//------------------------------------------------------------------------------
 
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkCompositePolyDataMapper2);
+
 //------------------------------------------------------------------------------
 vtkCompositePolyDataMapper2::vtkCompositePolyDataMapper2()
 {
@@ -1275,10 +1323,9 @@ vtkCompositePolyDataMapper2::vtkCompositePolyDataMapper2()
 //------------------------------------------------------------------------------
 vtkCompositePolyDataMapper2::~vtkCompositePolyDataMapper2()
 {
-  helpIter miter = this->Helpers.begin();
-  for (; miter != this->Helpers.end(); ++miter)
+  for (auto& helper : this->Helpers)
   {
-    miter->second->Delete();
+    helper.second->Delete();
   }
   this->Helpers.clear();
 }
@@ -1288,7 +1335,7 @@ int vtkCompositePolyDataMapper2::FillInputPortInformation(
   int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPolyData");
-  info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkCompositeDataSet");
+  info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataObjectTree");
   return 1;
 }
 
@@ -1302,7 +1349,7 @@ vtkExecutive* vtkCompositePolyDataMapper2::CreateDefaultExecutive()
 // Looks at each DataSet and finds the union of all the bounds
 void vtkCompositePolyDataMapper2::ComputeBounds()
 {
-  vtkCompositeDataSet* input = vtkCompositeDataSet::SafeDownCast(this->GetInputDataObject(0, 0));
+  vtkDataObjectTree* input = vtkDataObjectTree::SafeDownCast(this->GetInputDataObject(0, 0));
 
   // If we don't have hierarchical data, test to see if we have
   // plain old polydata. In this case, the bounds are simply
@@ -1332,18 +1379,11 @@ bool vtkCompositePolyDataMapper2::HasOpaqueGeometry()
   return true;
 }
 
+//------------------------------------------------------------------------------
 bool vtkCompositePolyDataMapper2::RecursiveHasTranslucentGeometry(
   vtkDataObject* dobj, unsigned int& flat_index)
 {
   vtkCompositeDataDisplayAttributes* cda = this->GetCompositeDataDisplayAttributes();
-  bool overrides_visibility = (cda && cda->HasBlockVisibility(dobj));
-  if (overrides_visibility)
-  {
-    if (!cda->GetBlockVisibility(dobj))
-    {
-      return false;
-    }
-  }
   bool overrides_opacity = (cda && cda->HasBlockOpacity(dobj));
   if (overrides_opacity)
   {
@@ -1357,8 +1397,7 @@ bool vtkCompositePolyDataMapper2::RecursiveHasTranslucentGeometry(
   // block.
   flat_index++;
 
-  auto dObjTree = vtkDataObjectTree::SafeDownCast(dobj);
-  if (dObjTree)
+  if (auto dObjTree = vtkDataObjectTree::SafeDownCast(dobj))
   {
     using Opts = vtk::DataObjectTreeOptions;
     for (vtkDataObject* child : vtk::Range(dObjTree, Opts::None))
@@ -1377,18 +1416,35 @@ bool vtkCompositePolyDataMapper2::RecursiveHasTranslucentGeometry(
     }
     return false;
   }
-
-  vtkPolyData* pd = vtkPolyData::SafeDownCast(dobj);
-  // if we think it is opaque check the scalars
-  if (this->ScalarVisibility)
+  else
   {
-    vtkScalarsToColors* lut = this->GetLookupTable();
-    int cellFlag;
-    vtkDataArray* scalars = this->GetScalars(
-      pd, this->ScalarMode, this->ArrayAccessMode, this->ArrayId, this->ArrayName, cellFlag);
-    if (lut->IsOpaque(scalars, this->ColorMode, this->ArrayComponent) == 0)
+    bool overrides_visibility = (cda && cda->HasBlockVisibility(dobj));
+    if (overrides_visibility)
     {
-      return true;
+      if (!cda->GetBlockVisibility(dobj))
+      {
+        return false;
+      }
+    }
+
+    vtkPolyData* pd = vtkPolyData::SafeDownCast(dobj);
+
+    // if we think it is opaque check the scalars
+    if (this->ScalarVisibility)
+    {
+      vtkScalarsToColors* lut = this->GetLookupTable();
+      int cellFlag;
+      vtkDataArray* scalars = vtkCompositePolyDataMapper2::GetScalars(
+        pd, this->ScalarMode, this->ArrayAccessMode, this->ArrayId, this->ArrayName, cellFlag);
+
+      unsigned char ghostsToSkip;
+      vtkUnsignedCharArray* ghosts =
+        vtkAbstractMapper::GetGhostArray(pd, this->ScalarMode, ghostsToSkip);
+
+      if (lut->IsOpaque(scalars, this->ColorMode, this->ArrayComponent, ghosts, ghostsToSkip) == 0)
+      {
+        return true;
+      }
     }
   }
 
@@ -1501,7 +1557,7 @@ void vtkCompositePolyDataMapper2::RemoveBlockVisibilities()
 }
 
 //------------------------------------------------------------------------------
-void vtkCompositePolyDataMapper2::SetBlockColor(unsigned int index, double color[3])
+void vtkCompositePolyDataMapper2::SetBlockColor(unsigned int index, const double color[3])
 {
   if (this->CompositeAttributes)
   {
@@ -1646,6 +1702,7 @@ void vtkCompositePolyDataMapper2::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositePolyDataMapper2::CopyMapperValuesToHelper(vtkCompositeMapperHelper2* helper)
 {
   // We avoid PolyDataMapper::ShallowCopy because it copies the input
@@ -1661,6 +1718,7 @@ void vtkCompositePolyDataMapper2::CopyMapperValuesToHelper(vtkCompositeMapperHel
   helper->SetVBOShiftScaleMethod(this->GetVBOShiftScaleMethod());
 }
 
+//------------------------------------------------------------------------------
 void vtkCompositePolyDataMapper2::SetVBOShiftScaleMethod(int m)
 {
   if (this->ShiftScaleMethod == m)
@@ -1670,24 +1728,34 @@ void vtkCompositePolyDataMapper2::SetVBOShiftScaleMethod(int m)
 
   this->Superclass::SetVBOShiftScaleMethod(m);
 
-  for (helpIter hiter = this->Helpers.begin(); hiter != this->Helpers.end(); ++hiter)
+  for (auto& helper : this->Helpers)
   {
-    hiter->second->SetVBOShiftScaleMethod(m);
+    helper.second->SetVBOShiftScaleMethod(m);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkCompositePolyDataMapper2::SetPauseShiftScale(bool pauseShiftScale)
+{
+  if (pauseShiftScale == this->PauseShiftScale)
+  {
+    return;
+  }
+
+  this->Superclass::SetPauseShiftScale(pauseShiftScale);
+  for (auto& helper : this->Helpers)
+  {
+    helper.second->SetPauseShiftScale(pauseShiftScale);
   }
 }
 
 //------------------------------------------------------------------------------
 void vtkCompositePolyDataMapper2::ReleaseGraphicsResources(vtkWindow* win)
 {
-  helpIter miter = this->Helpers.begin();
-  for (; miter != this->Helpers.end(); ++miter)
+  for (auto& helper : this->Helpers)
   {
-    miter->second->ReleaseGraphicsResources(win);
-  }
-  miter = this->Helpers.begin();
-  for (; miter != this->Helpers.end(); ++miter)
-  {
-    miter->second->Delete();
+    helper.second->ReleaseGraphicsResources(win);
+    helper.second->Delete();
   }
   this->Helpers.clear();
   this->Modified();
@@ -1732,26 +1800,22 @@ void vtkCompositePolyDataMapper2::Render(vtkRenderer* ren, vtkActor* actor)
     this->HelperMTime < this->GetMTime())
   {
     // clear old helpers
-    for (helpIter hiter = this->Helpers.begin(); hiter != this->Helpers.end(); ++hiter)
+    for (auto& helper : this->Helpers)
     {
-      hiter->second->ClearMark();
+      helper.second->ClearMark();
     }
     this->HelperDataMap.clear();
 
-    vtkCompositeDataSet* input = vtkCompositeDataSet::SafeDownCast(this->GetInputDataObject(0, 0));
-
-    if (input)
+    if (auto dObjTree = vtkDataObjectTree::SafeDownCast(this->GetInputDataObject(0, 0)))
     {
-      vtkSmartPointer<vtkDataObjectTreeIterator> iter =
-        vtkSmartPointer<vtkDataObjectTreeIterator>::New();
-      iter->SetDataSet(input);
+      vtkNew<vtkDataObjectTreeIterator> iter;
+      iter->SetDataSet(dObjTree);
       iter->SkipEmptyNodesOn();
       iter->VisitOnlyLeavesOn();
       for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
       {
         unsigned int flatIndex = iter->GetCurrentFlatIndex();
-        vtkDataObject* dso = iter->GetCurrentDataObject();
-        vtkPolyData* pd = vtkPolyData::SafeDownCast(dso);
+        vtkPolyData* pd = vtkPolyData::SafeDownCast(iter->GetCurrentDataObject());
 
         if (!pd || !pd->GetPoints())
         {
@@ -1773,7 +1837,7 @@ void vtkCompositePolyDataMapper2::Render(vtkRenderer* ren, vtkActor* actor)
                  << (hasTCoords ? 1 : 0);
 
         vtkCompositeMapperHelper2* helper = nullptr;
-        helpIter found = this->Helpers.find(toString.str());
+        auto found = this->Helpers.find(toString.str());
         if (found == this->Helpers.end())
         {
           helper = this->CreateHelper();
@@ -1810,7 +1874,7 @@ void vtkCompositePolyDataMapper2::Render(vtkRenderer* ren, vtkActor* actor)
                  << (hasTCoords ? 1 : 0);
 
         vtkCompositeMapperHelper2* helper = nullptr;
-        helpIter found = this->Helpers.find(toString.str());
+        auto found = this->Helpers.find(toString.str());
         if (found == this->Helpers.end())
         {
           helper = this->CreateHelper();
@@ -1828,7 +1892,7 @@ void vtkCompositePolyDataMapper2::Render(vtkRenderer* ren, vtkActor* actor)
     }
 
     // delete unused old helpers/data
-    for (helpIter hiter = this->Helpers.begin(); hiter != this->Helpers.end();)
+    for (auto hiter = this->Helpers.begin(); hiter != this->Helpers.end();)
     {
       hiter->second->RemoveUnused();
       if (!hiter->second->GetMarked())
@@ -1890,13 +1954,13 @@ void vtkCompositePolyDataMapper2::Render(vtkRenderer* ren, vtkActor* actor)
 
   this->InitializeHelpersBeforeRendering(ren, actor);
 
-  for (helpIter hiter = this->Helpers.begin(); hiter != this->Helpers.end(); ++hiter)
+  for (auto& helper : this->Helpers)
   {
-    vtkCompositeMapperHelper2* helper = hiter->second;
-    helper->RenderPiece(ren, actor);
+    vtkCompositeMapperHelper2* helper2 = helper.second;
+    helper2->RenderPiece(ren, actor);
 
     // update the list of rendered polydata that vtkValuePass relies on
-    std::vector<vtkPolyData*> pdl = helper->GetRenderedList();
+    std::vector<vtkPolyData*> pdl = helper2->GetRenderedList();
     for (unsigned int i = 0; i < pdl.size(); ++i)
     {
       this->RenderedList.push_back(pdl[i]);
@@ -1950,8 +2014,7 @@ void vtkCompositePolyDataMapper2::BuildRenderValues(
     textureOpaque = false;
   }
 
-  auto dObjTree = vtkDataObjectTree::SafeDownCast(dobj);
-  if (dObjTree)
+  if (auto dObjTree = vtkDataObjectTree::SafeDownCast(dobj))
   {
     using Opts = vtk::DataObjectTreeOptions;
     for (vtkDataObject* child : vtk::Range(dObjTree, Opts::None))
@@ -1969,7 +2032,7 @@ void vtkCompositePolyDataMapper2::BuildRenderValues(
   else
   {
     vtkPolyData* pd = vtkPolyData::SafeDownCast(dobj);
-    dataIter dit = this->HelperDataMap.find(pd);
+    auto dit = this->HelperDataMap.find(pd);
     if (dit != this->HelperDataMap.end())
     {
       vtkCompositeMapperHelperData* helperData = dit->second;
@@ -1987,9 +2050,15 @@ void vtkCompositePolyDataMapper2::BuildRenderValues(
       {
         vtkScalarsToColors* lut = this->GetLookupTable();
         int cellFlag;
-        vtkDataArray* scalars = this->GetScalars(
+        vtkDataArray* scalars = vtkCompositePolyDataMapper2::GetScalars(
           pd, this->ScalarMode, this->ArrayAccessMode, this->ArrayId, this->ArrayName, cellFlag);
-        if (lut->IsOpaque(scalars, this->ColorMode, this->ArrayComponent) == 0)
+
+        unsigned char ghostsToSkip;
+        vtkUnsignedCharArray* ghosts =
+          vtkAbstractMapper::GetGhostArray(pd, this->ScalarMode, ghostsToSkip);
+
+        if (lut->IsOpaque(scalars, this->ColorMode, this->ArrayComponent, ghosts, ghostsToSkip) ==
+          0)
         {
           helperData->IsOpaque = false;
         }
@@ -2064,3 +2133,14 @@ void vtkCompositePolyDataMapper2::ProcessSelectorPixelBuffers(
     helper.second->ProcessSelectorPixelBuffers(sel, pixeloffsets, prop);
   }
 }
+
+//-----------------------------------------------------------------------------
+vtkMTimeType vtkCompositePolyDataMapper2::GetMTime()
+{
+  if (this->CompositeAttributes)
+  {
+    return std::max(this->Superclass::GetMTime(), this->CompositeAttributes->GetMTime());
+  }
+  return this->Superclass::GetMTime();
+}
+VTK_ABI_NAMESPACE_END
