@@ -34,6 +34,7 @@
 #include <stack>      // used for ivars
 #include <vector>     // used for ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataDisplayAttributes;
 class vtkCompositeMapperHelper2;
 class vtkCompositeMapperHelperData;
@@ -45,7 +46,7 @@ public:
   vtkTypeMacro(vtkCompositePolyDataMapper2, vtkOpenGLPolyDataMapper);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Some introspection on the type of data the mapper will render
    * used by props to determine if they should invoke the mapper
@@ -53,17 +54,17 @@ public:
    */
   bool HasOpaqueGeometry() override;
   bool HasTranslucentPolygonalGeometry() override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the composite data set attributes.
    */
   void SetCompositeDataDisplayAttributes(vtkCompositeDataDisplayAttributes* attributes);
   vtkCompositeDataDisplayAttributes* GetCompositeDataDisplayAttributes();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the visibility for a block given its flat index.
    */
@@ -71,13 +72,13 @@ public:
   bool GetBlockVisibility(unsigned int index);
   void RemoveBlockVisibility(unsigned int index);
   void RemoveBlockVisibilities();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the color for a block given its flat index.
    */
-  void SetBlockColor(unsigned int index, double color[3]);
+  void SetBlockColor(unsigned int index, const double color[3]);
   void SetBlockColor(unsigned int index, double r, double g, double b)
   {
     double color[3] = { r, g, b };
@@ -86,9 +87,9 @@ public:
   double* GetBlockColor(unsigned int index);
   void RemoveBlockColor(unsigned int index);
   void RemoveBlockColors();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the opacity for a block given its flat index.
    */
@@ -96,7 +97,7 @@ public:
   double GetBlockOpacity(unsigned int index);
   void RemoveBlockOpacity(unsigned int index);
   void RemoveBlockOpacities();
-  //@}
+  ///@}
 
   /**
    * If the current 'color by' array is missing on some datasets, color these
@@ -126,7 +127,13 @@ public:
    */
   void SetVBOShiftScaleMethod(int m) override;
 
-  //@{
+  /**\brief Pause updates of shift-scale parameters based on camera position.
+   *
+   * This override passes the information to all instances in \a Helpers .
+   */
+  void SetPauseShiftScale(bool pauseShiftScale) override;
+
+  ///@{
   /**
    * Call SetInputArrayToProcess on helpers.
    */
@@ -136,7 +143,7 @@ public:
   void SetInputArrayToProcess(
     int idx, int port, int connection, int fieldAssociation, int fieldAttributeType) override;
   void SetInputArrayToProcess(int idx, vtkInformation* info) override;
-  //@}
+  ///@}
 
   /**
    * Accessor to the ordered list of PolyData that we end last drew.
@@ -150,6 +157,11 @@ public:
   void ProcessSelectorPixelBuffers(
     vtkHardwareSelector* sel, std::vector<unsigned int>& pixeloffsets, vtkProp* prop) override;
 
+  /**
+   * Overridden to include vtkCompositeDataDisplayAttributes' mtime.
+   */
+  vtkMTimeType GetMTime() override;
+
 protected:
   vtkCompositePolyDataMapper2();
   ~vtkCompositePolyDataMapper2() override;
@@ -243,4 +255,5 @@ private:
   void operator=(const vtkCompositePolyDataMapper2&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
