@@ -40,6 +40,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkDepthPeelingPassFinalFS.h"
 #include "vtkDepthPeelingPassIntermediateFS.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkDepthPeelingPass);
 vtkCxxSetObjectMacro(vtkDepthPeelingPass, TranslucentPass, vtkRenderPass);
 
@@ -231,7 +232,7 @@ void vtkDepthPeelingPassCreateTexture(vtkTextureObject* to, vtkOpenGLRenderWindo
   int width, int height, int numComponents, bool isDepth, int depthFormat)
 {
   to->SetContext(context);
-  if (isDepth == true)
+  if (isDepth)
   {
     to->AllocateDepth(width, height, depthFormat);
   }
@@ -597,10 +598,10 @@ void vtkDepthPeelingPass::Render(const vtkRenderState* s)
   if (this->PeelCount > 1 || this->ColorDrawCount != 0)
   {
     this->State->PushReadFramebufferBinding();
-    this->Framebuffer->Bind(this->Framebuffer->GetReadMode());
+    this->Framebuffer->Bind(vtkOpenGLFramebufferObject::GetReadMode());
 
-    glBlitFramebuffer(0, 0, this->ViewportWidth, this->ViewportHeight, this->ViewportX,
-      this->ViewportY, this->ViewportX + this->ViewportWidth,
+    this->State->vtkglBlitFramebuffer(0, 0, this->ViewportWidth, this->ViewportHeight,
+      this->ViewportX, this->ViewportY, this->ViewportX + this->ViewportWidth,
       this->ViewportY + this->ViewportHeight, GL_COLOR_BUFFER_BIT, GL_LINEAR);
 
     this->State->PopReadFramebufferBinding();
@@ -691,3 +692,4 @@ bool vtkDepthPeelingPass::SetShaderParameters(vtkShaderProgram* program, vtkAbst
 
   return true;
 }
+VTK_ABI_NAMESPACE_END
