@@ -54,6 +54,7 @@
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include <vector>                      // STL Header
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLFramebufferObject;
 class vtkTextureObject;
 class vtkOpenGLRenderWindow;
@@ -80,7 +81,7 @@ public:
    */
   void ReleaseGraphicsResources(vtkWindow* w) override;
 
-  //@{
+  ///@{
   /**
    * Delegate for rendering the translucent polygonal geometry.
    * If it is NULL, nothing will be rendered and a warning will be emitted.
@@ -89,9 +90,9 @@ public:
    */
   vtkGetObjectMacro(TranslucentPass, vtkRenderPass);
   virtual void SetTranslucentPass(vtkRenderPass* translucentPass);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * In case of use of depth peeling technique for rendering translucent
    * material, define the threshold under which the algorithm stops to
@@ -103,9 +104,9 @@ public:
    */
   vtkSetClampMacro(OcclusionRatio, double, 0.0, 0.5);
   vtkGetMacro(OcclusionRatio, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * In case of depth peeling, define the maximum number of peeling layers.
    * Initial value is 4. A special value of 0 means no maximum limit.
@@ -113,7 +114,7 @@ public:
    */
   vtkSetMacro(MaximumNumberOfPeels, int);
   vtkGetMacro(MaximumNumberOfPeels, int);
-  //@}
+  ///@}
 
   // vtkOpenGLRenderPass virtuals:
   bool PostReplaceShaderValues(std::string& vertexShader, std::string& geometryShader,
@@ -147,7 +148,7 @@ protected:
   vtkRenderPass* TranslucentPass;
   vtkTimeStamp CheckTime;
 
-  //@{
+  ///@{
   /**
    * Cache viewport values for depth peeling.
    */
@@ -155,7 +156,7 @@ protected:
   int ViewportY;
   int ViewportWidth;
   int ViewportHeight;
-  //@}
+  ///@}
 
   /**
    * In case of use of depth peeling technique for rendering translucent
@@ -206,4 +207,5 @@ private:
   void operator=(const vtkDepthPeelingPass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
