@@ -20,31 +20,33 @@
 #include "vtkObjectFactory.h"
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkDummyGPUInfoList);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Build the list of vtkInfoGPU if not done yet.
 // \post probed: IsProbed()
 void vtkDummyGPUInfoList::Probe()
 {
-  if(!this->Probed)
+  if (!this->Probed)
   {
-    this->Probed=true;
-    this->Array=new vtkGPUInfoListArray;
+    this->Probed = true;
+    this->Array = new vtkGPUInfoListArray;
     this->Array->v.resize(0); // no GPU.
   }
   assert("post: probed" && this->IsProbed());
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDummyGPUInfoList::vtkDummyGPUInfoList() = default;
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDummyGPUInfoList::~vtkDummyGPUInfoList() = default;
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDummyGPUInfoList::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
