@@ -29,6 +29,7 @@
 #include "vtkGPUInfoList.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGOPENGL2_EXPORT vtkDummyGPUInfoList : public vtkGPUInfoList
 {
 public:
@@ -43,17 +44,18 @@ public:
   void Probe() override;
 
 protected:
-  //@{
+  ///@{
   /**
    * Default constructor.
    */
   vtkDummyGPUInfoList();
   ~vtkDummyGPUInfoList() override;
-  //@}
+  ///@}
 
 private:
   vtkDummyGPUInfoList(const vtkDummyGPUInfoList&) = delete;
   void operator=(const vtkDummyGPUInfoList&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
