@@ -47,6 +47,7 @@ Ph.D. thesis of Christian BOUCHENY.
 
 //#define VTK_EDL_SHADING_DEBUG
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 void annotate(const std::string& str)
@@ -75,13 +76,12 @@ vtkEDLShading::vtkEDLShading()
   // init neighbours in image space
   for (int c = 0; c < 8; c++)
   {
-    float x, y;
-    x = cos(2 * vtkMath::Pi() * float(c) / 8.);
-    y = sin(2 * vtkMath::Pi() * float(c) / 8.);
+    double x = cos(2.0 * vtkMath::Pi() * static_cast<double>(c) / 8.0);
+    double y = sin(2.0 * vtkMath::Pi() * static_cast<double>(c) / 8.0);
     this->EDLNeighbours[c][0] = x / sqrt(x * x + y * y);
     this->EDLNeighbours[c][1] = y / sqrt(x * x + y * y);
-    this->EDLNeighbours[c][2] = 0.;
-    this->EDLNeighbours[c][3] = 0.;
+    this->EDLNeighbours[c][2] = 0.0;
+    this->EDLNeighbours[c][3] = 0.0;
   }
   this->EDLLowResFactor = 2;
   this->Zn = 0.1;
@@ -698,6 +698,9 @@ void vtkEDLShading::Render(const vtkRenderState* s)
       this->EDLBlurLow(s2, renWin);
       annotate("End vtkEDLShading::BlurLow");
     }
+    // Low-res processing reduces the viewport dimensions.
+    // Reset the viewport after to ensure that following passes get the right viewport size.
+    renWin->GetState()->vtkglViewport(this->Origin[0], this->Origin[1], this->Width, this->Height);
 #endif // EDL_LOW_RESOLUTION_ON
 
     //////////////////////////////////////////////////////
@@ -784,3 +787,4 @@ void vtkEDLShading::ReleaseGraphicsResources(vtkWindow* w)
 
   this->Superclass::ReleaseGraphicsResources(w);
 }
+VTK_ABI_NAMESPACE_END
