@@ -21,7 +21,6 @@
 #include "vtkOpenGLRenderer.h"
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRendererCollection.h"
-#include "vtkToolkits.h"
 #include "vtkType.h"
 #include "vtk_glew.h"
 #include "vtksys/SystemTools.hxx"
@@ -31,17 +30,18 @@
 #include <cassert>
 #include <sstream>
 
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
 #include <android/native_window.h>
+#include <vtkAndroidRenderWindowInteractor.h>
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 typedef void* EGLDeviceEXT;
 typedef EGLBoolean (*EGLQueryDevicesType)(EGLint, EGLDeviceEXT*, EGLint*);
 typedef EGLDisplay (*EGLGetPlatformDisplayType)(EGLenum, void*, const EGLint*);
 const EGLenum EGL_PLATFORM_DEVICE_EXT = 0x313F;
-
 /**
  * EGLDisplay provided by eglGetDisplay() call can be same handle for multiple
  * instances of vtkEGLRenderWindow. In which case, while it's safe to call
@@ -69,9 +69,12 @@ public:
     }
     return EGL_TRUE;
   }
+
+  static int DefaultDeviceIndex;
 };
 
 std::map<EGLDisplay, std::atomic<int64_t>> vtkEGLDisplayInitializationHelper::DisplayUsageCounts;
+int vtkEGLDisplayInitializationHelper::DefaultDeviceIndex = VTK_DEFAULT_EGL_DEVICE_INDEX;
 
 struct vtkEGLDeviceExtensions
 {
@@ -139,14 +142,14 @@ struct vtkEGLRenderWindow::vtkInternals
 vtkEGLRenderWindow::vtkEGLRenderWindow()
 {
   this->Internals = new vtkInternals();
-  this->OwnWindow = 1;
+  this->OwnWindow = true;
   this->ScreenSize[0] = 1920;
   this->ScreenSize[1] = 1080;
 
   // this is initialized in vtkRenderWindow
   // so we don't need to initialize on else
+  this->DeviceIndex = -1;
 #ifdef VTK_USE_OFFSCREEN_EGL
-  this->DeviceIndex = VTK_DEFAULT_EGL_DEVICE_INDEX;
   this->ShowWindow = false;
 #endif
 
@@ -154,11 +157,33 @@ vtkEGLRenderWindow::vtkEGLRenderWindow()
   char* EGLDefaultDeviceIndexEnv = std::getenv("VTK_DEFAULT_EGL_DEVICE_INDEX");
   if (EGLDefaultDeviceIndexEnv)
   {
-    // If parsing the environment variable fails and throws an exception we
-    // can safely ignore it since a default is already set above.
     try
     {
-      this->DeviceIndex = atoi(EGLDefaultDeviceIndexEnv);
+      int index = atoi(EGLDefaultDeviceIndexEnv);
+      if (index >= 0)
+      {
+        vtkEGLDisplayInitializationHelper::DefaultDeviceIndex = index;
+      }
+    }
+    catch (const std::out_of_range&)
+    {
+    }
+    catch (const std::invalid_argument&)
+    {
+    }
+  }
+
+  // If the device index is explicitly set then we need to use it.
+  char* EGLDeviceIndexEnv = std::getenv("VTK_EGL_DEVICE_INDEX");
+  if (EGLDeviceIndexEnv)
+  {
+    try
+    {
+      int index = atoi(EGLDeviceIndexEnv);
+      if (index >= 0)
+      {
+        this->DeviceIndex = index;
+      }
     }
     catch (const std::out_of_range&)
     {
@@ -282,10 +307,13 @@ int vtkEGLRenderWindow::GetNumberOfDevices()
   return 0;
 }
 
-void vtkEGLRenderWindow::SetDeviceAsDisplay(int deviceIndex)
+bool vtkEGLRenderWindow::SetDeviceAsDisplay(int deviceIndex)
 {
   vtkInternals* impl = this->Internals;
   vtkEGLDeviceExtensions* ext = vtkEGLDeviceExtensions::GetInstance();
+  bool foundWorkingDisplay = false;
+  EGLint major = 0, minor = 0;
+
   if (ext->Available())
   {
     EGLint num_devices = 0;
@@ -295,20 +323,89 @@ void vtkEGLRenderWindow::SetDeviceAsDisplay(int deviceIndex)
       vtkWarningMacro("EGL device index: " << deviceIndex
                                            << " is greater than "
                                               "the number of supported deviced in the system: "
-                                           << num_devices << ". Using device 0 ...");
-      return;
+                                           << num_devices);
+    }
+
+    std::vector<EGLDeviceEXT> devices(num_devices);
+    ext->eglQueryDevices(num_devices, devices.data(), &num_devices);
+
+    if (deviceIndex >= 0)
+    {
+      impl->Display =
+        ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT, devices[deviceIndex], nullptr);
+
+      if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) == EGL_FALSE)
+      {
+        vtkWarningMacro(
+          "EGL device index: " << deviceIndex << " could not be initialized. Exiting...");
+      }
+
+      foundWorkingDisplay = true;
+    }
+    else
+    {
+      impl->Display = ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT,
+        devices[vtkEGLDisplayInitializationHelper::DefaultDeviceIndex], nullptr);
+
+      if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) == EGL_FALSE)
+      {
+        vtkWarningMacro(
+          "EGL device index: " << vtkEGLDisplayInitializationHelper::DefaultDeviceIndex
+                               << " could not be initialized. Trying other devices...");
+
+        for (int i = 0; i < num_devices; i++)
+        {
+          // Don't check DefaultDeviceIndex again
+          if (i == vtkEGLDisplayInitializationHelper::DefaultDeviceIndex)
+          {
+            continue;
+          }
+
+          impl->Display = ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT, devices[i], nullptr);
+          if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) ==
+            EGL_TRUE)
+          {
+            foundWorkingDisplay = true;
+            break;
+          }
+        }
+      }
+      else
+      {
+        foundWorkingDisplay = true;
+      }
     }
-    EGLDeviceEXT* devices = new EGLDeviceEXT[num_devices];
-    ext->eglQueryDevices(num_devices, devices, &num_devices);
-    impl->Display =
-      ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT, devices[deviceIndex], nullptr);
-    delete[] devices;
-    return;
   }
-  vtkWarningMacro("Setting an EGL display to device index: "
-    << deviceIndex
-    << " require "
-       "EGL_EXT_device_base EGL_EXT_platform_device EGL_EXT_platform_base extensions");
+
+  if (!foundWorkingDisplay)
+  {
+    // eglGetDisplay(EGL_DEFAULT_DISPLAY) does not seem to work
+    // if there are several cards on a system.
+    vtkWarningMacro("Setting an EGL display to device index: "
+      << deviceIndex
+      << " require "
+         "EGL_EXT_device_base EGL_EXT_platform_device EGL_EXT_platform_base extensions");
+
+    vtkWarningMacro("Attempting to use EGL_DEFAULT_DISPLAY...");
+    impl->Display = eglGetDisplay(EGL_DEFAULT_DISPLAY);
+
+    if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) == EGL_FALSE)
+    {
+      vtkErrorMacro("Could not initialize a device. Exiting...");
+      return false;
+    }
+  }
+#if !defined(__ANDROID__) && !defined(ANDROID)
+  if (major <= 1 && minor < 4)
+  {
+    vtkErrorMacro("Only EGL 1.4 and greater allows OpenGL as client API. "
+                  "See eglBindAPI for more information.");
+    return false;
+  }
+  eglBindAPI(EGL_OPENGL_API);
+#endif
+
+  return true;
 }
 
 void vtkEGLRenderWindow::SetShowWindow(bool val)
@@ -338,7 +435,7 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
    */
   EGLint surfaceType, clientAPI;
   const EGLint* contextAttribs;
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
   surfaceType = EGL_WINDOW_BIT;
   clientAPI = EGL_OPENGL_ES2_BIT;
   const EGLint contextES2[] = { EGL_CONTEXT_CLIENT_VERSION, 2, EGL_NONE };
@@ -354,7 +451,7 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
     EGL_RED_SIZE, 8, EGL_ALPHA_SIZE, 8, EGL_DEPTH_SIZE, 8, EGL_RENDERABLE_TYPE, clientAPI,
     EGL_NONE };
 
-#if !defined(ANDROID)
+#if !defined(__ANDROID__) && !defined(ANDROID)
   const EGLint surface_attribs[] = { EGL_WIDTH, width, EGL_HEIGHT, height, EGL_NONE };
 #endif
 
@@ -363,27 +460,10 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
 
   if (impl->Display == EGL_NO_DISPLAY)
   {
-    // eglGetDisplay(EGL_DEFAULT_DISPLAY) does not seem to work
-    // if there are several cards on a system.
-    this->SetDeviceAsDisplay(this->DeviceIndex);
-
-    // try to use the default display
-    if (impl->Display == EGL_NO_DISPLAY)
+    if (!this->SetDeviceAsDisplay(this->DeviceIndex))
     {
-      impl->Display = eglGetDisplay(EGL_DEFAULT_DISPLAY);
-    }
-
-    EGLint major = 0, minor = 0;
-    vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor);
-#if !defined(ANDROID)
-    if (major <= 1 && minor < 4)
-    {
-      vtkErrorMacro("Only EGL 1.4 and greater allows OpenGL as client API. "
-                    "See eglBindAPI for more information.");
       return;
     }
-    eglBindAPI(EGL_OPENGL_API);
-#endif
   }
 
   /* Here, the application chooses the configuration it desires. In this
@@ -396,7 +476,7 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
     return;
   }
 
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
   EGLint format = 0;
   /* EGL_NATIVE_VISUAL_ID is an attribute of the EGLConfig that is
    * guaranteed to be accepted by ANativeWindow_setBuffersGeometry().
@@ -417,13 +497,22 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
     eglDestroySurface(impl->Display, impl->Surface);
   }
 
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
   impl->Surface = eglCreateWindowSurface(impl->Display, config, impl->Window, nullptr);
 #else
   impl->Surface = eglCreatePbufferSurface(impl->Display, config, surface_attribs);
 #endif
   this->Mapped = this->ShowWindow;
-  this->OwnWindow = 1;
+  this->OwnWindow = true;
+
+#if defined(__ANDROID__) || defined(ANDROID)
+  vtkAndroidRenderWindowInteractor* interactor =
+    vtkAndroidRenderWindowInteractor::SafeDownCast(this->Interactor);
+  if (interactor)
+  {
+    interactor->SetOwnWindow(this->OwnWindow);
+  }
+#endif
 
   this->MakeCurrent();
 
@@ -485,9 +574,18 @@ void vtkEGLRenderWindow::WindowInitialize(void)
   this->OpenGLInit();
 
   // for offscreen EGL always turn on point sprites
-#if !defined(ANDROID) && defined(GL_POINT_SPRITE)
+#if !defined(__ANDROID__) && !defined(ANDROID) && defined(GL_POINT_SPRITE)
   glEnable(GL_POINT_SPRITE);
 #endif
+
+#if defined(__ANDROID__) || defined(ANDROID)
+  vtkAndroidRenderWindowInteractor* interactor =
+    vtkAndroidRenderWindowInteractor::SafeDownCast(this->Interactor);
+  if (interactor)
+  {
+    interactor->SetOwnWindow(this->OwnWindow);
+  }
+#endif
 }
 
 // Initialize the rendering window.
@@ -572,6 +670,15 @@ void vtkEGLRenderWindow::MakeCurrent()
   }
 }
 
+void vtkEGLRenderWindow::ReleaseCurrent()
+{
+  vtkInternals* impl = this->Internals;
+  if (impl->Display != EGL_NO_DISPLAY)
+  {
+    eglMakeCurrent(impl->Display, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
+  }
+}
+
 //------------------------------------------------------------------------------
 // Description:
 // Tells if this window is the current OpenGL context for the calling thread.
@@ -608,8 +715,17 @@ void vtkEGLRenderWindow::SetPosition(int x, int y)
 // Set this RenderWindow to a pre-existing window.
 void vtkEGLRenderWindow::SetWindowInfo(const char*)
 {
-  this->OwnWindow = 0;
   this->Mapped = 1;
+  this->OwnWindow = false;
+
+#if defined(__ANDROID__) || defined(ANDROID)
+  vtkAndroidRenderWindowInteractor* interactor =
+    vtkAndroidRenderWindowInteractor::SafeDownCast(this->Interactor);
+  if (interactor)
+  {
+    interactor->SetOwnWindow(this->OwnWindow);
+  }
+#endif
 }
 
 void vtkEGLRenderWindow::SetWindowName(const char* name)
@@ -670,3 +786,4 @@ void vtkEGLRenderWindow::SetWindowId(void* window)
   vtkInternals* impl = this->Internals;
   impl->Window = reinterpret_cast<EGLNativeWindowType>(window);
 }
+VTK_ABI_NAMESPACE_END
