@@ -32,6 +32,7 @@
 
 #include "vtkOpenGLHelper.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFramebufferPass);
 
 //------------------------------------------------------------------------------
@@ -148,13 +149,13 @@ void vtkFramebufferPass::Render(const vtkRenderState* s)
 
   // now copy the result to the outer FO
   ostate->PushReadFramebufferBinding();
-  this->FrameBufferObject->Bind(this->FrameBufferObject->GetReadMode());
+  this->FrameBufferObject->Bind(vtkOpenGLFramebufferObject::GetReadMode());
 
   ostate->vtkglViewport(
     this->ViewportX, this->ViewportY, this->ViewportWidth, this->ViewportHeight);
   ostate->vtkglScissor(this->ViewportX, this->ViewportY, this->ViewportWidth, this->ViewportHeight);
 
-  glBlitFramebuffer(0, 0, this->ViewportWidth, this->ViewportHeight, this->ViewportX,
+  ostate->vtkglBlitFramebuffer(0, 0, this->ViewportWidth, this->ViewportHeight, this->ViewportX,
     this->ViewportY, this->ViewportX + this->ViewportWidth, this->ViewportY + this->ViewportHeight,
     GL_COLOR_BUFFER_BIT, GL_LINEAR);
 
@@ -188,3 +189,4 @@ void vtkFramebufferPass::ReleaseGraphicsResources(vtkWindow* w)
     this->DepthTexture->ReleaseGraphicsResources(w);
   }
 }
+VTK_ABI_NAMESPACE_END
