@@ -15,35 +15,37 @@
 
 #include "vtkLightsPass.h"
 #include "vtkObjectFactory.h"
-#include <cassert>
 #include "vtkRenderState.h"
 #include "vtkRenderer.h"
+#include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkLightsPass);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLightsPass::vtkLightsPass() = default;
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLightsPass::~vtkLightsPass() = default;
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLightsPass::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Perform rendering according to a render state \p s.
 // \pre s_exists: s!=0
-void vtkLightsPass::Render(const vtkRenderState *s)
+void vtkLightsPass::Render(const vtkRenderState* s)
 {
-  assert("pre: s_exists" && s!=nullptr);
+  assert("pre: s_exists" && s != nullptr);
 
-  this->NumberOfRenderedProps=0;
+  this->NumberOfRenderedProps = 0;
 
   this->ClearLights(s->GetRenderer());
   this->UpdateLightGeometry(s->GetRenderer());
   this->UpdateLights(s->GetRenderer());
 }
+VTK_ABI_NAMESPACE_END
