@@ -44,6 +44,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtksys/SystemTools.hxx"
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOSOpenGLRenderWindow;
 class vtkRenderWindow;
 
@@ -92,6 +93,7 @@ vtkOSOpenGLRenderWindow::vtkOSOpenGLRenderWindow()
   this->ForceMakeCurrent = 0;
   this->OwnWindow = 0;
   this->ShowWindow = false;
+  this->UseOffScreenBuffers = true;
 
   this->Internal = new vtkOSOpenGLRenderWindowInternal();
 }
@@ -101,7 +103,6 @@ vtkOSOpenGLRenderWindow::~vtkOSOpenGLRenderWindow()
 {
   // close-down all system-specific drawing resources
   this->Finalize();
-
   vtkRenderer* ren;
   vtkCollectionSimpleIterator rit;
   this->Renderers->InitTraversal(rit);
@@ -229,10 +230,17 @@ void vtkOSOpenGLRenderWindow::DestroyOffScreenWindow()
 
 void vtkOSOpenGLRenderWindow::ResizeOffScreenWindow(int width, int height)
 {
-  if (this->Internal->OffScreenContextId)
+  auto& internal = (*this->Internal);
+  if (internal.OffScreenContextId)
   {
-    this->DestroyOffScreenWindow();
-    this->CreateOffScreenWindow(width, height);
+    // in past, we used to destroy the context and recreate one on resize. this
+    // is totally unnecessary; we just recreate the buffer and make it current.
+    vtkOSMesaDestroyWindow(internal.OffScreenWindow);
+    internal.OffScreenWindow = vtkOSMesaCreateWindow(width, height);
+
+    // Call MakeCurrent to ensure that we're no longer using the old memory
+    // buffer.
+    this->MakeCurrent();
   }
 }
 
@@ -295,10 +303,7 @@ void vtkOSOpenGLRenderWindow::SetSize(int width, int height)
   if ((this->Size[0] != width) || (this->Size[1] != height))
   {
     this->Superclass::SetSize(width, height);
-    if (!this->UseOffScreenBuffers)
-    {
-      this->ResizeOffScreenWindow(width, height);
-    }
+    this->ResizeOffScreenWindow(width, height);
     this->Modified();
   }
 }
@@ -473,3 +478,4 @@ void* vtkOSOpenGLRenderWindow::GetGenericWindowId()
 {
   return (void*)this->Internal->OffScreenWindow;
 }
+VTK_ABI_NAMESPACE_END
