@@ -32,6 +32,7 @@
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkOSOpenGLRenderWindowInternal;
 
@@ -45,12 +46,12 @@ public:
   /**
    * End the rendering process and display the image.
    */
-  virtual void Frame(void);
+  virtual void Frame();
 
   /**
    * Initialize the window for rendering.
    */
-  virtual void WindowInitialize(void);
+  virtual void WindowInitialize();
 
   /**
    * Initialize the rendering window.  This will setup all system-specific
@@ -58,21 +59,21 @@ public:
    * should be possible to call them multiple times, even changing WindowId
    * in-between.  This is what WindowRemap does.
    */
-  void Initialize(void) override;
+  void Initialize() override;
 
   /**
    * "Deinitialize" the rendering window.  This will shutdown all system-specific
    * resources.  After having called this, it should be possible to destroy
    * a window that was used for a SetWindowId() call without any ill effects.
    */
-  virtual void Finalize(void);
+  virtual void Finalize();
 
   /**
    * Change the window to fill the entire screen.
    */
   virtual void SetFullScreen(vtkTypeBool);
 
-  //@{
+  ///@{
   /**
    * Set the size of the window in screen coordinates in pixels.
    * This resizes the operating system's window and redraws it.
@@ -82,7 +83,7 @@ public:
    */
   void SetSize(int width, int height) override;
   void SetSize(int a[2]) override { this->SetSize(a[0], a[1]); }
-  //@}
+  ///@}
 
   /**
    * Get the current size of the screen in pixels.
@@ -96,13 +97,13 @@ public:
    */
   int* GetPosition() VTK_SIZEHINT(2) override;
 
-  //@{
+  ///@{
   /**
    * Move the window to a new position on the display.
    */
   void SetPosition(int x, int y) override;
   void SetPosition(int a[2]) override { this->SetPosition(a[0], a[1]); }
-  //@}
+  ///@}
 
   /**
    * Prescribe that the window be created in a stereo-capable mode. This
@@ -147,9 +148,9 @@ public:
   /**
    * Resize the window.
    */
-  virtual void WindowRemap(void);
+  virtual void WindowRemap();
 
-  //@{
+  ///@{
   /**
    * Xwindow get set functions
    */
@@ -158,7 +159,7 @@ public:
   virtual void* GetGenericParentId() { return 0; }
   virtual void* GetGenericContext();
   virtual void* GetGenericDrawable() { return 0; }
-  //@}
+  ///@}
 
   /**
    * Set the X display id for this RenderWindow to use to a pre-existing
@@ -236,4 +237,5 @@ private:
   void operator=(const vtkOSOpenGLRenderWindow&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
