@@ -30,6 +30,7 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFOInfo
 {
 public:
@@ -1149,7 +1150,7 @@ void vtkOpenGLFramebufferObject::DisplayBuffer(int value)
   else
   {
 #ifdef GL_ES_VERSION_3_0
-    vtkErrorMacro("Attempt to use bad display destintation");
+    vtkErrorMacro("Attempt to use bad display destination");
 #else
     if (value >= GL_AUX0)
     {
@@ -1616,3 +1617,4 @@ int vtkOpenGLFramebufferObject::GetNumberOfColorAttachments()
 {
   return static_cast<int>(this->ColorBuffers.size());
 }
+VTK_ABI_NAMESPACE_END
