@@ -22,7 +22,7 @@
  * framebuffer such as created with a standard window/context or
  * it can be a user created Framebuffer objects. When draw and read
  * commands are invoked, they apply to the current draw and/or read
- * frambuffers.
+ * framebuffers.
  *
  * A framebuffer consists of color buffers and an optional depth buffer.
  * The FramebufferObject does not hold the memory for these buffers, it
@@ -167,6 +167,7 @@
 #include <map>                         // for the maps
 #include <vector>                      // for the lists of logical buffers.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFOInfo;
 class vtkGenericOpenGLResourceFreeCallback;
 class vtkOpenGLRenderWindow;
@@ -185,7 +186,7 @@ public:
   vtkTypeMacro(vtkOpenGLFramebufferObject, vtkFrameBufferObjectBase);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the context. Context must be a vtkOpenGLRenderWindow.
    * This does not increase the reference count of the
@@ -195,7 +196,7 @@ public:
    */
   void SetContext(vtkRenderWindow* context);
   vtkOpenGLRenderWindow* GetContext();
-  //@}
+  ///@}
 
   /**
    * Make the draw frame buffer active.
@@ -209,7 +210,7 @@ public:
   void UnBind();
   void UnBind(unsigned int mode);
 
-  //@{
+  ///@{
   /**
    * Store/Restore the current framebuffer bindings and buffers.
    */
@@ -217,9 +218,9 @@ public:
   void SaveCurrentBindingsAndBuffers(unsigned int mode);
   void RestorePreviousBindingsAndBuffers();
   void RestorePreviousBindingsAndBuffers(unsigned int mode);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * User must take care that width/height match the dimensions of
    * the user defined texture attachments.
@@ -231,7 +232,7 @@ public:
    */
   bool Start(int width, int height);
   bool StartNonOrtho(int width, int height);
-  //@}
+  ///@}
 
   /**
    * Set up ortho viewport with scissor, lighting, blend, and depth
@@ -239,7 +240,7 @@ public:
    */
   void InitializeViewport(int width, int height);
 
-  //@{
+  ///@{
   // activate deactivate draw/read buffers (color buffers)
   void ActivateDrawBuffers(unsigned int n);
   void ActivateDrawBuffers(unsigned int* ids, int n);
@@ -252,7 +253,7 @@ public:
   }
   void DeactivateDrawBuffers();
   void DeactivateReadBuffer();
-  //@}
+  ///@}
 
   vtkGetMacro(ActiveReadBuffer, unsigned int);
   unsigned int GetActiveDrawBuffer(unsigned int id);
@@ -270,7 +271,7 @@ public:
   void RenderQuad(int minX, int maxX, int minY, int maxY, vtkShaderProgram* program,
     vtkOpenGLVertexArrayObject* vao);
 
-  //@{
+  ///@{
   /**
    * Directly assign/remove a texture to color attachments.
    */
@@ -279,7 +280,7 @@ public:
   void AddColorAttachment(unsigned int attId, vtkRenderbuffer* tex);
   void RemoveColorAttachment(unsigned int index);
   void RemoveColorAttachments(unsigned int num);
-  //@}
+  ///@}
 
   /**
    * Return the texture object bound to the passed attachment number.
@@ -292,7 +293,7 @@ public:
    */
   int GetNumberOfColorAttachments();
 
-  //@{
+  ///@{
   /**
    * Directly assign/remove a texture/renderbuffer to depth attachments.
    */
@@ -300,9 +301,10 @@ public:
   void AddDepthAttachment(vtkTextureObject* tex);
   void AddDepthAttachment(vtkRenderbuffer* tex);
   void RemoveDepthAttachment();
-  //@}
+  vtkTextureObject* GetDepthAttachmentAsTextureObject();
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convenience method to populate a framebuffer with
    * attachments created as well. Returns true if a
@@ -312,7 +314,7 @@ public:
   bool PopulateFramebuffer(int width, int height, bool useTextures, int numberOfColorAttachments,
     int colorDataType, bool wantDepthAttachment, int depthBitplanes, int multisamples,
     bool wantStencilAttachment = false);
-  //@}
+  ///@}
 
   /**
    * Returns the maximum number of targets that can be rendered to at one time.
@@ -328,7 +330,7 @@ public:
    */
   unsigned int GetMaximumNumberOfRenderTargets();
 
-  //@{
+  ///@{
   /**
    * Dimensions in pixels of the framebuffer.
    */
@@ -346,7 +348,7 @@ public:
                   << "," << _arg2 << ")");
   }
   void GetLastSize(int _arg[2]) override { this->GetLastSize(_arg[0], _arg[1]); }
-  //@}
+  ///@}
 
   /**
    * Returns if the context supports the required extensions.
@@ -516,4 +518,5 @@ private:
   void operator=(const vtkOpenGLFramebufferObject&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
