@@ -51,6 +51,7 @@
 #include <numeric>
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenGLGlyph3DHelper);
 
 //------------------------------------------------------------------------------
@@ -93,7 +94,7 @@ void vtkOpenGLGlyph3DHelper::ReplaceShaderPositionVC(
 {
   std::string VSSource = shaders[vtkShader::Vertex]->GetSource();
 
-  if (this->LastLightComplexity[this->LastBoundBO] > 0)
+  if (this->PrimitiveInfo[this->LastBoundBO].LastLightComplexity > 0)
   {
     // we use vertex instead of vertexMC
     vtkShaderProgram::Substitute(VSSource, "//VTK::PositionVC::Impl",
@@ -307,7 +308,7 @@ void vtkOpenGLGlyph3DHelper::GlyphRender(vtkRenderer* ren, vtkActor* actor, vtkI
   for (int i = PrimitiveStart;
        i < (draw_surface_with_edges ? PrimitiveEnd : PrimitiveTriStrips + 1); i++)
   {
-    this->DrawingVertices = (i > PrimitiveTriStrips ? true : false);
+    this->DrawingVertices = i > PrimitiveTriStrips;
     if (this->Primitives[i].IBO->IndexCount)
     {
       this->UpdateShaders(this->Primitives[i], ren, actor);
@@ -327,7 +328,7 @@ void vtkOpenGLGlyph3DHelper::GlyphRender(vtkRenderer* ren, vtkActor* actor, vtkI
         program->SetUniformMatrix4x4("GCMCMatrix", &(matrices[inPtId * 16]));
 
         // for lit shaders set normal matrix
-        if (this->LastLightComplexity[this->LastBoundBO] > 0 &&
+        if (this->PrimitiveInfo[this->LastBoundBO].LastLightComplexity > 0 &&
           this->VBOs->GetNumberOfComponents("normalMC") == 3 && !this->UsingInstancing)
         {
           program->SetUniformMatrix3x3("glyphNormalMatrix", &(normalMatrices[inPtId * 9]));
@@ -398,7 +399,7 @@ void vtkOpenGLGlyph3DHelper::GlyphRenderInstances(vtkRenderer* ren, vtkActor* ac
   for (int i = PrimitiveStart;
        i < (draw_surface_with_edges ? PrimitiveEnd : PrimitiveTriStrips + 1); i++)
   {
-    this->DrawingVertices = (i > PrimitiveTriStrips ? true : false);
+    this->DrawingVertices = i > PrimitiveTriStrips;
     if (this->Primitives[i].IBO->IndexCount)
     {
       GLenum mode = this->GetOpenGLMode(representation, i);
@@ -617,3 +618,4 @@ void vtkOpenGLGlyph3DHelper::SetLODColoring(bool val)
 {
   this->InstanceCulling->SetColorLOD(val);
 }
+VTK_ABI_NAMESPACE_END
