@@ -28,6 +28,7 @@
 #include "vtkOpenGLPolyDataMapper.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBitArray;
 
 class VTKRENDERINGOPENGL2_EXPORT vtkOpenGLGlyph3DHelper : public vtkOpenGLPolyDataMapper
@@ -72,7 +73,7 @@ protected:
   void GetShaderTemplate(
     std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* act) override;
 
-  //@{
+  ///@{
   /**
    * Perform string replacements on the shader templates
    */
@@ -86,10 +87,10 @@ protected:
     std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* act) override;
   void ReplaceShaderPositionVC(
     std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* act) override;
-  //@}
+  ///@}
 
   /**
-   * Set the shader parameteres related to the actor/mapper
+   * Set the shader parameters related to the actor/mapper
    */
   void SetMapperShaderParameters(vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act) override;
 
@@ -111,4 +112,5 @@ private:
   void operator=(const vtkOpenGLGlyph3DHelper&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
