@@ -26,24 +26,27 @@
 #include "vtkMath.h"
 #include "vtkMatrix3x3.h"
 #include "vtkObjectFactory.h"
+#include "vtkOpenGLError.h"
 #include "vtkOpenGLGlyph3DHelper.h"
 #include "vtkProperty.h"
-#include "vtkRenderer.h"
-#include "vtkRenderWindow.h"
-#include "vtkTransform.h"
-#include "vtkOpenGLError.h"
-#include "vtkSmartPointer.h"
 #include "vtkQuaternion.h"
+#include "vtkRenderWindow.h"
+#include "vtkRenderer.h"
+#include "vtkSmartPointer.h"
+#include "vtkTransform.h"
+#include "vtkUnsignedCharArray.h"
 
 #include <map>
 
-namespace {
-int getNumberOfChildren(vtkDataObjectTree *tree)
+VTK_ABI_NAMESPACE_BEGIN
+namespace
+{
+int getNumberOfChildren(vtkDataObjectTree* tree)
 {
   int result = 0;
   if (tree)
   {
-    vtkDataObjectTreeIterator *it = tree->NewTreeIterator();
+    vtkDataObjectTreeIterator* it = tree->NewTreeIterator();
     it->SetTraverseSubTree(false);
     it->SetVisitOnlyLeaves(false);
     for (it->InitTraversal(); !it->IsDoneWithTraversal(); it->GoToNextItem())
@@ -55,12 +58,12 @@ int getNumberOfChildren(vtkDataObjectTree *tree)
   return result;
 }
 
-vtkDataObject* getChildDataObject(vtkDataObjectTree *tree, int child)
+vtkDataObject* getChildDataObject(vtkDataObjectTree* tree, int child)
 {
-  vtkDataObject *result = nullptr;
+  vtkDataObject* result = nullptr;
   if (tree)
   {
-    vtkDataObjectTreeIterator *it = tree->NewTreeIterator();
+    vtkDataObjectTreeIterator* it = tree->NewTreeIterator();
     it->SetTraverseSubTree(false);
     it->SetVisitOnlyLeaves(false);
     it->InitTraversal();
@@ -80,22 +83,22 @@ class vtkOpenGLGlyph3DMappervtkColorMapper : public vtkMapper
 public:
   vtkTypeMacro(vtkOpenGLGlyph3DMappervtkColorMapper, vtkMapper);
   static vtkOpenGLGlyph3DMappervtkColorMapper* New();
-  void Render(vtkRenderer *, vtkActor *) override {}
+  void Render(vtkRenderer*, vtkActor*) override {}
   vtkUnsignedCharArray* GetColors() { return this->Colors; }
 };
 
-vtkStandardNewMacro(vtkOpenGLGlyph3DMappervtkColorMapper)
+vtkStandardNewMacro(vtkOpenGLGlyph3DMappervtkColorMapper);
 
 class vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry
 {
 public:
   std::vector<vtkIdType> PickIds;
   std::vector<unsigned char> Colors;
-  std::vector<float> Matrices;  // transposed
+  std::vector<float> Matrices;       // transposed
   std::vector<float> NormalMatrices; // transposed
   vtkTimeStamp BuildTime;
   // May be polydata or composite dataset:
-  vtkDataObject *DataObject;
+  vtkDataObject* DataObject;
   // maps composite dataset flat index to polydatamapper. Key = -1 for polydata
   // DataObject.
   typedef std::map<int, vtkOpenGLGlyph3DHelper*> MapperMap;
@@ -117,8 +120,7 @@ public:
   };
   void ClearMappers()
   {
-    for (MapperMap::iterator it = this->Mappers.begin();
-         it != this->Mappers.end(); ++it)
+    for (MapperMap::iterator it = this->Mappers.begin(); it != this->Mappers.end(); ++it)
     {
       it->second->Delete();
     }
@@ -129,17 +131,15 @@ public:
 class vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray
 {
 public:
-  std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry *>  Entries;
+  std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry*> Entries;
   vtkTimeStamp BuildTime;
   vtkOpenGLGlyph3DMapperSubArray() = default;
-  ~vtkOpenGLGlyph3DMapperSubArray()
-  {
-    this->ClearEntries();
-  };
+  ~vtkOpenGLGlyph3DMapperSubArray() { this->ClearEntries(); };
   void ClearEntries()
   {
-    std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry *>::iterator miter = this->Entries.begin();
-    for (;miter != this->Entries.end(); ++miter)
+    std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry*>::iterator miter =
+      this->Entries.begin();
+    for (; miter != this->Entries.end(); ++miter)
     {
       delete *miter;
     }
@@ -150,11 +150,12 @@ public:
 class vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperArray
 {
 public:
-  std::map<const vtkDataSet *, vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray *> Entries;
+  std::map<const vtkDataSet*, vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray*> Entries;
   ~vtkOpenGLGlyph3DMapperArray()
   {
-    std::map<const vtkDataSet *, vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray *>::iterator miter = this->Entries.begin();
-    for (;miter != this->Entries.end(); ++miter)
+    std::map<const vtkDataSet*, vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray*>::iterator
+      miter = this->Entries.begin();
+    for (; miter != this->Entries.end(); ++miter)
     {
       delete miter->second;
     }
@@ -162,9 +163,9 @@ public:
   };
 };
 
-vtkStandardNewMacro(vtkOpenGLGlyph3DMapper)
+vtkStandardNewMacro(vtkOpenGLGlyph3DMapper);
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct object with scaling on, scaling mode is by scalar value,
 // scale factor = 1.0, the range is (0,1), orient geometry is on, and
 // orientation is by vector. Clamping and indexing are turned off. No
@@ -175,7 +176,7 @@ vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapper()
   this->ColorMapper = vtkOpenGLGlyph3DMappervtkColorMapper::New();
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkOpenGLGlyph3DMapper::~vtkOpenGLGlyph3DMapper()
 {
   this->ColorMapper->Delete();
@@ -184,22 +185,22 @@ vtkOpenGLGlyph3DMapper::~vtkOpenGLGlyph3DMapper()
   this->GlyphValues = nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Send mapper ivars to sub-mapper.
 // \pre mapper_exists: mapper!=0
-void vtkOpenGLGlyph3DMapper::CopyInformationToSubMapper(
-    vtkOpenGLGlyph3DHelper *mapper)
+void vtkOpenGLGlyph3DMapper::CopyInformationToSubMapper(vtkOpenGLGlyph3DHelper* mapper)
 {
-  assert("pre: mapper_exists" && mapper!=nullptr);
+  assert("pre: mapper_exists" && mapper != nullptr);
   mapper->SetStatic(this->Static);
   mapper->ScalarVisibilityOff();
   // not used
   mapper->SetClippingPlanes(this->ClippingPlanes);
 
-  mapper->SetResolveCoincidentTopology(this->GetResolveCoincidentTopology());
-  mapper->SetResolveCoincidentTopologyZShift(
-    this->GetResolveCoincidentTopologyZShift());
+  vtkOpenGLGlyph3DHelper::SetResolveCoincidentTopology(
+    vtkOpenGLGlyph3DMapper::GetResolveCoincidentTopology());
+  vtkOpenGLGlyph3DHelper::SetResolveCoincidentTopologyZShift(
+    vtkOpenGLGlyph3DMapper::GetResolveCoincidentTopologyZShift());
 
   double f, u;
   this->GetRelativeCoincidentTopologyPolygonOffsetParameters(f, u);
@@ -210,8 +211,8 @@ void vtkOpenGLGlyph3DMapper::CopyInformationToSubMapper(
   mapper->SetRelativeCoincidentTopologyPointOffsetParameter(u);
 
   // ResolveCoincidentTopologyPolygonOffsetParameters is static
-  mapper->SetResolveCoincidentTopologyPolygonOffsetFaces(
-    this->GetResolveCoincidentTopologyPolygonOffsetFaces());
+  vtkOpenGLGlyph3DHelper::SetResolveCoincidentTopologyPolygonOffsetFaces(
+    vtkOpenGLGlyph3DMapper::GetResolveCoincidentTopologyPolygonOffsetFaces());
 
   if (static_cast<vtkIdType>(this->LODs.size()) > this->GetMaxNumberOfLOD())
   {
@@ -230,11 +231,11 @@ void vtkOpenGLGlyph3DMapper::SetupColorMapper()
   this->ColorMapper->ShallowCopy(this);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Method initiates the mapping process. Generally sent by the actor
 // as each frame is rendered.
-void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
+void vtkOpenGLGlyph3DMapper::Render(vtkRenderer* ren, vtkActor* actor)
 {
   vtkOpenGLClearErrorMacro();
 
@@ -254,9 +255,9 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
   // Create a default source, if no source is specified.
   if (!this->UseSourceTableTree && this->GetSource(0) == nullptr)
   {
-    vtkPolyData *defaultSource = vtkPolyData::New();
-    defaultSource->Allocate();
-    vtkPoints *defaultPoints = vtkPoints::New();
+    vtkPolyData* defaultSource = vtkPolyData::New();
+    defaultSource->AllocateEstimate(0, 0, 1, 2, 0, 0, 0, 0);
+    vtkPoints* defaultPoints = vtkPoints::New();
     defaultPoints->Allocate(6);
     defaultPoints->InsertNextPoint(0., 0., 0.);
     defaultPoints->InsertNextPoint(1., 0., 0.);
@@ -273,7 +274,7 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
   }
 
   // Check that source configuration is sane:
-  vtkDataObjectTree *sourceTableTree = this->GetSourceTableTree();
+  vtkDataObjectTree* sourceTableTree = this->GetSourceTableTree();
   int numSourceDataSets = this->GetNumberOfInputConnections(1);
   if (this->UseSourceTableTree)
   {
@@ -289,17 +290,17 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
                     "not a vtkDataObjectTree.");
       return;
     }
-    vtkDataObjectTreeIterator *it = sourceTableTree->NewTreeIterator();
+    vtkDataObjectTreeIterator* it = sourceTableTree->NewTreeIterator();
     it->SetTraverseSubTree(false);
     it->SetVisitOnlyLeaves(false);
     for (it->InitTraversal(); !it->IsDoneWithTraversal(); it->GoToNextItem())
     {
-      vtkDataObject *node = it->GetCurrentDataObject();
+      vtkDataObject* node = it->GetCurrentDataObject();
       if (!node->IsA("vtkPolyData") && !node->IsA("vtkCompositeDataSet"))
       {
         vtkErrorMacro("The source table tree must only contain vtkPolyData "
                       "or vtkCompositeDataSet children, but found a "
-                      << node->GetClassName() << ".");
+          << node->GetClassName() << ".");
         it->Delete();
         return;
       }
@@ -312,8 +313,9 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
     {
       if (!this->GetSource(i))
       {
-        vtkErrorMacro("Source input at index " << i << " not set, or not "
-                      "vtkPolyData.");
+        vtkErrorMacro("Source input at index " << i
+                                               << " not set, or not "
+                                                  "vtkPolyData.");
         return;
       }
     }
@@ -345,11 +347,13 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
 
       // Skip invisible blocks and unpickable ones when performing selection:
       bool blockVis =
-        (this->BlockAttributes && this->BlockAttributes->HasBlockVisibility(currentObj)) ?
-        this->BlockAttributes->GetBlockVisibility(currentObj) : true;
+        (this->BlockAttributes && this->BlockAttributes->HasBlockVisibility(currentObj))
+        ? this->BlockAttributes->GetBlockVisibility(currentObj)
+        : true;
       bool blockPick =
-        (this->BlockAttributes && this->BlockAttributes->HasBlockPickability(currentObj)) ?
-        this->BlockAttributes->GetBlockPickability(currentObj) : true;
+        (this->BlockAttributes && this->BlockAttributes->HasBlockPickability(currentObj))
+        ? this->BlockAttributes->GetBlockPickability(currentObj)
+        : true;
       if (!blockVis || (selector && !blockPick))
       {
         continue;
@@ -386,21 +390,21 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer *ren, vtkActor *actor)
   this->UpdateProgress(1.0);
 }
 
-// ---------------------------------------------------------------------------
-void vtkOpenGLGlyph3DMapper::Render(
-  vtkRenderer* ren, vtkActor* actor, vtkDataSet* dataset)
+//------------------------------------------------------------------------------
+void vtkOpenGLGlyph3DMapper::Render(vtkRenderer* ren, vtkActor* actor, vtkDataSet* dataset)
 {
   vtkIdType numPts = dataset->GetNumberOfPoints();
   if (numPts < 1)
   {
-    vtkDebugMacro(<<"No points to glyph!");
+    vtkDebugMacro(<< "No points to glyph!");
     return;
   }
 
   // make sure we have an entry for this dataset
-  vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray *subarray;
+  vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray* subarray;
   bool rebuild = false;
-  typedef std::map<const vtkDataSet *,vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray *>::iterator GVIter;
+  typedef std::map<const vtkDataSet*,
+    vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray*>::iterator GVIter;
   GVIter found = this->GlyphValues->Entries.find(dataset);
   if (found == this->GlyphValues->Entries.end())
   {
@@ -414,25 +418,23 @@ void vtkOpenGLGlyph3DMapper::Render(
   }
 
   // make sure we have a subentry for each source
-  vtkDataObjectTree *sourceTableTree = this->GetSourceTableTree();
+  vtkDataObjectTree* sourceTableTree = this->GetSourceTableTree();
   int sTTSize = getNumberOfChildren(sourceTableTree);
   int numSourceDataSets = this->GetNumberOfInputConnections(1);
-  size_t numberOfSources = this->UseSourceTableTree ? sTTSize
-                                                    : numSourceDataSets;
+  size_t numberOfSources = this->UseSourceTableTree ? sTTSize : numSourceDataSets;
   bool numberOfSourcesChanged = false;
   if (numberOfSources != subarray->Entries.size())
   {
     subarray->ClearEntries();
     for (size_t cc = 0; cc < numberOfSources; cc++)
     {
-      subarray->Entries.push_back(
-        new vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry());
+      subarray->Entries.push_back(new vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry());
     }
     numberOfSourcesChanged = true;
   }
 
   // make sure sources are up to date
-  vtkDataObjectTreeIterator *sTTIter = nullptr;
+  vtkDataObjectTreeIterator* sTTIter = nullptr;
   if (sourceTableTree)
   {
     sTTIter = sourceTableTree->NewTreeIterator();
@@ -442,12 +444,11 @@ void vtkOpenGLGlyph3DMapper::Render(
   }
   for (size_t cc = 0; cc < subarray->Entries.size(); cc++)
   {
-    vtkDataObject *s = this->UseSourceTableTree
-        ? sTTIter->GetCurrentDataObject()
-        : this->GetSource(static_cast<int>(cc));
+    vtkDataObject* s = this->UseSourceTableTree ? sTTIter->GetCurrentDataObject()
+                                                : this->GetSource(static_cast<int>(cc));
 
-    vtkOpenGLGlyph3DMapperEntry *entry = subarray->Entries[cc];
-    vtkDataObject *ss = entry->DataObject;
+    vtkOpenGLGlyph3DMapperEntry* entry = subarray->Entries[cc];
+    vtkDataObject* ss = entry->DataObject;
     if (ss && !ss->IsA(s->GetClassName()))
     {
       ss->Delete();
@@ -458,8 +459,7 @@ void vtkOpenGLGlyph3DMapper::Render(
       ss = s->NewInstance();
       entry->DataObject = ss;
     }
-    if (numberOfSourcesChanged ||
-      s->GetMTime() > ss->GetMTime() ||
+    if (numberOfSourcesChanged || s->GetMTime() > ss->GetMTime() ||
       this->GetMTime() > entry->BuildTime)
     {
       ss->ShallowCopy(s);
@@ -467,8 +467,8 @@ void vtkOpenGLGlyph3DMapper::Render(
     }
 
     // Create/update the helper mappers:
-    vtkCompositeDataIterator *cdsIter = nullptr;
-    if (vtkCompositeDataSet *cds = vtkCompositeDataSet::SafeDownCast(ss))
+    vtkCompositeDataIterator* cdsIter = nullptr;
+    if (vtkCompositeDataSet* cds = vtkCompositeDataSet::SafeDownCast(ss))
     {
       cdsIter = cds->NewIterator();
       cdsIter->InitTraversal();
@@ -476,11 +476,10 @@ void vtkOpenGLGlyph3DMapper::Render(
 
     for (;;)
     {
-      vtkOpenGLGlyph3DHelper *mapper = nullptr;
+      vtkOpenGLGlyph3DHelper* mapper = nullptr;
 
-      int mapperIdx = cdsIter ? cdsIter->GetCurrentFlatIndex() : -1;
-      vtkOpenGLGlyph3DMapperEntry::MapperMap::iterator mapIter =
-          entry->Mappers.find(mapperIdx);
+      int mapperIdx = cdsIter ? static_cast<int>(cdsIter->GetCurrentFlatIndex()) : -1;
+      vtkOpenGLGlyph3DMapperEntry::MapperMap::iterator mapIter = entry->Mappers.find(mapperIdx);
       if (mapIter == entry->Mappers.end())
       {
         mapper = vtkOpenGLGlyph3DHelper::New();
@@ -522,21 +521,20 @@ void vtkOpenGLGlyph3DMapper::Render(
 
   // rebuild all entries for this DataSet if it
   // has been modified
-  if (subarray->BuildTime < dataset->GetMTime() ||
-      subarray->BuildTime < this->GetMTime() ||
-      subarray->BuildTime < this->BlockMTime)
+  if (subarray->BuildTime < dataset->GetMTime() || subarray->BuildTime < this->GetMTime() ||
+    subarray->BuildTime < this->BlockMTime)
   {
     rebuild = true;
   }
 
   // get the mask array
-  vtkBitArray *maskArray = nullptr;
+  vtkBitArray* maskArray = nullptr;
   if (this->Masking)
   {
     maskArray = vtkArrayDownCast<vtkBitArray>(this->GetMaskArray(dataset));
     if (maskArray == nullptr)
     {
-      vtkDebugMacro(<<"masking is enabled but there is no mask array. Ignore masking.");
+      vtkDebugMacro(<< "masking is enabled but there is no mask array. Ignore masking.");
     }
     else
     {
@@ -558,19 +556,17 @@ void vtkOpenGLGlyph3DMapper::Render(
   // for each subarray
   for (size_t cc = 0; cc < subarray->Entries.size(); cc++)
   {
-    vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry *entry =
-      subarray->Entries[cc];
+    vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry* entry = subarray->Entries[cc];
     if (entry->NumberOfPoints <= 0)
     {
       continue;
     }
 
-    vtkDataObject *dObj = entry->DataObject;
-    vtkPolyData *pd = vtkPolyData::SafeDownCast(dObj);
-    vtkCompositeDataSet *cds = pd ? nullptr
-                                  : vtkCompositeDataSet::SafeDownCast(dObj);
+    vtkDataObject* dObj = entry->DataObject;
+    vtkPolyData* pd = vtkPolyData::SafeDownCast(dObj);
+    vtkCompositeDataSet* cds = pd ? nullptr : vtkCompositeDataSet::SafeDownCast(dObj);
 
-    vtkCompositeDataIterator *cdsIter = nullptr;
+    vtkCompositeDataIterator* cdsIter = nullptr;
     if (cds)
     {
       cdsIter = cds->NewIterator();
@@ -591,11 +587,10 @@ void vtkOpenGLGlyph3DMapper::Render(
 
       if (pd && pd->GetNumberOfPoints() > 0)
       {
-        vtkOpenGLGlyph3DHelper *gh = entry->Mappers[mapperIdx];
+        vtkOpenGLGlyph3DHelper* gh = entry->Mappers[mapperIdx];
         gh->CurrentInput = pd;
-        gh->GlyphRender(ren, actor, entry->NumberOfPoints,
-                        entry->Colors, entry->Matrices, entry->NormalMatrices,
-                        entry->PickIds, subarray->BuildTime, this->CullingAndLOD);
+        gh->GlyphRender(ren, actor, entry->NumberOfPoints, entry->Colors, entry->Matrices,
+          entry->NormalMatrices, entry->PickIds, subarray->BuildTime, this->CullingAndLOD);
       }
 
       if (!cdsIter || cdsIter->IsDoneWithTraversal())
@@ -614,15 +609,10 @@ void vtkOpenGLGlyph3DMapper::Render(
   vtkOpenGLCheckErrorMacro("failed after Render");
 }
 
-
-
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkOpenGLGlyph3DMapper::RebuildStructures(
-  vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray *subarray,
-  vtkIdType numPts,
-  vtkActor* actor,
-  vtkDataSet* dataset,
-  vtkBitArray *maskArray)
+  vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray* subarray, vtkIdType numPts,
+  vtkActor* actor, vtkDataSet* dataset, vtkBitArray* maskArray)
 {
   double den = this->Range[1] - this->Range[0];
   if (den == 0.0)
@@ -632,19 +622,19 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
 
   unsigned char color[4];
   {
-    const double *actorColor = actor->GetProperty()->GetColor();
+    const double* actorColor = actor->GetProperty()->GetColor();
     for (int i = 0; i != 3; ++i)
     {
       color[i] = static_cast<unsigned char>(actorColor[i] * 255. + 0.5);
     }
-    color[3] =
-      static_cast<unsigned char>(actor->GetProperty()->GetOpacity()*255. + 0.5);
+    color[3] = static_cast<unsigned char>(actor->GetProperty()->GetOpacity() * 255. + 0.5);
   }
 
   vtkDataArray* orientArray = this->GetOrientationArray(dataset);
   if (orientArray != nullptr)
   {
-    if ((this->OrientationMode == ROTATION || this->OrientationMode == DIRECTION) && orientArray->GetNumberOfComponents() != 3)
+    if ((this->OrientationMode == ROTATION || this->OrientationMode == DIRECTION) &&
+      orientArray->GetNumberOfComponents() != 3)
     {
       vtkErrorMacro(" expecting an orientation array with 3 components, getting "
         << orientArray->GetNumberOfComponents() << " components.");
@@ -665,13 +655,14 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
   /// FIXME: Didn't handle the premultiplycolorswithalpha aspect...
   this->ColorMapper->SetInputDataObject(dataset);
   this->ColorMapper->MapScalars(actor->GetProperty()->GetOpacity());
-  vtkUnsignedCharArray* colors = ((vtkOpenGLGlyph3DMappervtkColorMapper *)this->ColorMapper)->GetColors();
+  vtkUnsignedCharArray* colors =
+    ((vtkOpenGLGlyph3DMappervtkColorMapper*)this->ColorMapper)->GetColors();
   // Traverse all Input points, transforming Source points
 
   int numEntries = (int)subarray->Entries.size();
 
   // how many points for each source
-  int *numPointsPerSource = new int [numEntries];
+  int* numPointsPerSource = new int[numEntries];
   std::fill(numPointsPerSource, numPointsPerSource + numEntries, 0);
   if (numEntries > 1 && indexArray)
   {
@@ -685,10 +676,10 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
       }
 
       // Compute index into table of glyphs
-      double value = vtkMath::Norm(indexArray->GetTuple(inPtId),
-        indexArray->GetNumberOfComponents());
+      double value =
+        vtkMath::Norm(indexArray->GetTuple(inPtId), indexArray->GetNumberOfComponents());
       index = static_cast<int>(value);
-      index = vtkMath::ClampValue(index, 0, numEntries-1);
+      index = vtkMath::ClampValue(index, 0, numEntries - 1);
       numPointsPerSource[index]++;
     }
   }
@@ -700,28 +691,26 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
   // for each entry start with a reasonable allocation
   for (size_t cc = 0; cc < subarray->Entries.size(); cc++)
   {
-    vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry *entry =
-      subarray->Entries[cc];
+    vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry* entry = subarray->Entries[cc];
     entry->PickIds.resize(numPointsPerSource[cc]);
-    entry->Colors.resize(numPointsPerSource[cc]*4);
-    entry->Matrices.resize(numPointsPerSource[cc]*16);
-    entry->NormalMatrices.resize(numPointsPerSource[cc]*9);
+    entry->Colors.resize(numPointsPerSource[cc] * 4);
+    entry->Matrices.resize(numPointsPerSource[cc] * 16);
+    entry->NormalMatrices.resize(numPointsPerSource[cc] * 9);
     entry->NumberOfPoints = 0;
     entry->BuildTime.Modified();
   }
-  delete [] numPointsPerSource;
+  delete[] numPointsPerSource;
 
   // loop over every point and fill structures
   int index = 0;
-  vtkDataObjectTree *sourceTableTree = this->GetSourceTableTree();
+  vtkDataObjectTree* sourceTableTree = this->GetSourceTableTree();
 
   // cache sources to improve performances
   std::vector<vtkDataObject*> sourceCache(numEntries);
   for (vtkIdType i = 0; i < numEntries; i++)
   {
-    sourceCache[i] = this->UseSourceTableTree
-        ? getChildDataObject(sourceTableTree, i)
-        : this->GetSource(i);
+    sourceCache[i] =
+      this->UseSourceTableTree ? getChildDataObject(sourceTableTree, i) : this->GetSource(i);
   }
 
   double trans[16];
@@ -731,8 +720,7 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
   {
     if (!(inPtId % 10000))
     {
-      this->UpdateProgress (static_cast<double>(inPtId)/
-        static_cast<double>(numPts));
+      this->UpdateProgress(static_cast<double>(inPtId) / static_cast<double>(numPts));
       if (this->GetAbortExecute())
       {
         break;
@@ -747,25 +735,24 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
     // Compute index into table of glyphs
     if (indexArray)
     {
-      double value = vtkMath::Norm(indexArray->GetTuple(inPtId),
-        indexArray->GetNumberOfComponents());
+      double value =
+        vtkMath::Norm(indexArray->GetTuple(inPtId), indexArray->GetNumberOfComponents());
       index = static_cast<int>(value);
-      index = vtkMath::ClampValue(index, 0, numEntries-1);
+      index = vtkMath::ClampValue(index, 0, numEntries - 1);
     }
 
     // source can be null.
-    vtkDataObject *source = sourceCache[index];
+    vtkDataObject* source = sourceCache[index];
 
     // Make sure we're not indexing into empty glyph
     if (source)
     {
-      vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry *entry =
-        subarray->Entries[index];
+      vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry* entry = subarray->Entries[index];
 
-      entry->Colors[entry->NumberOfPoints*4] = color[0];
-      entry->Colors[entry->NumberOfPoints*4+1] = color[1];
-      entry->Colors[entry->NumberOfPoints*4+2] = color[2];
-      entry->Colors[entry->NumberOfPoints*4+3] = color[3];
+      entry->Colors[entry->NumberOfPoints * 4] = color[0];
+      entry->Colors[entry->NumberOfPoints * 4 + 1] = color[1];
+      entry->Colors[entry->NumberOfPoints * 4 + 2] = color[2];
+      entry->Colors[entry->NumberOfPoints * 4 + 3] = color[3];
 
       double scalex = 1.0;
       double scaley = 1.0;
@@ -776,39 +763,38 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
         double* tuple = scaleArray->GetTuple(inPtId);
         switch (this->ScaleMode)
         {
-        case SCALE_BY_MAGNITUDE:
-          scalex = scaley = scalez = vtkMath::Norm(tuple,
-            scaleArray->GetNumberOfComponents());
-          break;
-        case SCALE_BY_COMPONENTS:
-          if (scaleArray->GetNumberOfComponents() != 3)
-          {
-            vtkErrorMacro("Cannot scale by components since " <<
-              scaleArray->GetName() << " does not have 3 components.");
-          }
-          else
-          {
-            scalex = tuple[0];
-            scaley = tuple[1];
-            scalez = tuple[2];
-          }
-          break;
-        case NO_DATA_SCALING:
-        default:
-          break;
+          case SCALE_BY_MAGNITUDE:
+            scalex = scaley = scalez = vtkMath::Norm(tuple, scaleArray->GetNumberOfComponents());
+            break;
+          case SCALE_BY_COMPONENTS:
+            if (scaleArray->GetNumberOfComponents() != 3)
+            {
+              vtkErrorMacro("Cannot scale by components since " << scaleArray->GetName()
+                                                                << " does not have 3 components.");
+            }
+            else
+            {
+              scalex = tuple[0];
+              scaley = tuple[1];
+              scalez = tuple[2];
+            }
+            break;
+          case NO_DATA_SCALING:
+          default:
+            break;
         }
 
         // Clamp data scale if enabled
         if (this->Clamping && this->ScaleMode != NO_DATA_SCALING)
         {
-          scalex = (scalex < this->Range[0] ? this->Range[0] :
-            (scalex > this->Range[1] ? this->Range[1] : scalex));
+          scalex = (scalex < this->Range[0] ? this->Range[0]
+                                            : (scalex > this->Range[1] ? this->Range[1] : scalex));
           scalex = (scalex - this->Range[0]) / den;
-          scaley = (scaley < this->Range[0] ? this->Range[0] :
-            (scaley > this->Range[1] ? this->Range[1] : scaley));
+          scaley = (scaley < this->Range[0] ? this->Range[0]
+                                            : (scaley > this->Range[1] ? this->Range[1] : scaley));
           scaley = (scaley - this->Range[0]) / den;
-          scalez = (scalez < this->Range[0] ? this->Range[0] :
-            (scalez > this->Range[1] ? this->Range[1] : scalez));
+          scalez = (scalez < this->Range[0] ? this->Range[0]
+                                            : (scalez > this->Range[1] ? this->Range[1] : scalez));
           scalez = (scalez - this->Range[0]) / den;
         }
       }
@@ -837,49 +823,49 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
 
         switch (this->OrientationMode)
         {
-        case ROTATION:
+          case ROTATION:
           {
             double angle = vtkMath::RadiansFromDegrees(orientation[2]);
-            vtkQuaterniond qz(cos(0.5*angle), 0.0, 0.0, sin(0.5*angle));
+            vtkQuaterniond qz(cos(0.5 * angle), 0.0, 0.0, sin(0.5 * angle));
 
             angle = vtkMath::RadiansFromDegrees(orientation[0]);
-            vtkQuaterniond qx(cos(0.5*angle), sin(0.5*angle), 0.0, 0.0);
+            vtkQuaterniond qx(cos(0.5 * angle), sin(0.5 * angle), 0.0, 0.0);
 
             angle = vtkMath::RadiansFromDegrees(orientation[1]);
-            vtkQuaterniond qy(cos(0.5*angle), 0.0, sin(0.5*angle), 0.0);
+            vtkQuaterniond qy(cos(0.5 * angle), 0.0, sin(0.5 * angle), 0.0);
 
-            quaternion = qz*qx*qy;
+            quaternion = qz * qx * qy;
           }
           break;
 
-        case DIRECTION:
-          if (orientation[1] == 0.0 && orientation[2] == 0.0)
-          {
-            if (orientation[0] < 0) //just flip x if we need to
+          case DIRECTION:
+            if (orientation[1] == 0.0 && orientation[2] == 0.0)
             {
-              quaternion.Set(0.0, 0.0, 1.0, 0.0);
+              if (orientation[0] < 0) // just flip x if we need to
+              {
+                quaternion.Set(0.0, 0.0, 1.0, 0.0);
+              }
             }
-          }
-          else
-          {
-            double vMag = vtkMath::Norm(orientation);
-            double vNew[3];
-            vNew[0] = (orientation[0] + vMag) / 2.0;
-            vNew[1] = orientation[1] / 2.0;
-            vNew[2] = orientation[2] / 2.0;
+            else
+            {
+              double vMag = vtkMath::Norm(orientation);
+              double vNew[3];
+              vNew[0] = (orientation[0] + vMag) / 2.0;
+              vNew[1] = orientation[1] / 2.0;
+              vNew[2] = orientation[2] / 2.0;
 
-            double f = 1.0/sqrt(vNew[0]*vNew[0]+vNew[1]*vNew[1]+vNew[2]*vNew[2]);
-            vNew[0] *= f;
-            vNew[1] *= f;
-            vNew[2] *= f;
+              double f = 1.0 / sqrt(vNew[0] * vNew[0] + vNew[1] * vNew[1] + vNew[2] * vNew[2]);
+              vNew[0] *= f;
+              vNew[1] *= f;
+              vNew[2] *= f;
 
-            quaternion.Set(0.0, vNew[0], vNew[1], vNew[2]);
-          }
-          break;
+              quaternion.Set(0.0, vNew[0], vNew[1], vNew[2]);
+            }
+            break;
 
-        case QUATERNION:
-          quaternion.Set(orientation);
-          break;
+          case QUATERNION:
+            quaternion.Set(orientation);
+            break;
         }
 
         quaternion.ToMatrix3x3(rotMatrix);
@@ -888,8 +874,8 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
         {
           for (int j = 0; j < 3; j++)
           {
-            trans[4*i+j] = rotMatrix[i][j];
-            normalTrans[3*i+j] = rotMatrix[j][i]; // transpose
+            trans[4 * i + j] = rotMatrix[i][j];
+            normalTrans[3 * i + j] = rotMatrix[j][i]; // transpose
           }
         }
       }
@@ -899,23 +885,21 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
       vtkIdType selectionId = inPtId;
       if (this->UseSelectionIds)
       {
-        if (selectionArray == nullptr ||
-            selectionArray->GetNumberOfTuples() == 0)
+        if (selectionArray == nullptr || selectionArray->GetNumberOfTuples() == 0)
         {
-          vtkWarningMacro(<<"UseSelectionIds is true, but selection array"
-                          " is invalid. Ignoring selection array.");
+          vtkWarningMacro(<< "UseSelectionIds is true, but selection array"
+                             " is invalid. Ignoring selection array.");
         }
         else
         {
-          selectionId = static_cast<vtkIdType>(
-              *selectionArray->GetTuple(inPtId));
+          selectionId = static_cast<vtkIdType>(*selectionArray->GetTuple(inPtId));
         }
       }
       entry->PickIds[entry->NumberOfPoints] = selectionId;
 
       if (colors)
       {
-        colors->GetTypedTuple(inPtId, &(entry->Colors[entry->NumberOfPoints*4]));
+        colors->GetTypedTuple(inPtId, &(entry->Colors[entry->NumberOfPoints * 4]));
       }
 
       // scale data if appropriate
@@ -937,23 +921,23 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
         for (int i = 0; i < 3; i++)
         {
           // inverse of normal matrix is directly computed with inverse scale
-          trans[4*i] *= scalex;
+          trans[4 * i] *= scalex;
           normalTrans[i] /= scalex;
-          trans[4*i+1] *= scaley;
-          normalTrans[i+3] /= scaley;
-          trans[4*i+2] *= scalez;
-          normalTrans[i+6] /= scalez;
+          trans[4 * i + 1] *= scaley;
+          normalTrans[i + 3] /= scaley;
+          trans[4 * i + 2] *= scalez;
+          normalTrans[i + 6] /= scalez;
         }
       }
 
-      float* matrices = &entry->Matrices[entry->NumberOfPoints*16];
-      float* normalMatrices = &entry->NormalMatrices[entry->NumberOfPoints*9];
+      float* matrices = &entry->Matrices[entry->NumberOfPoints * 16];
+      float* normalMatrices = &entry->NormalMatrices[entry->NumberOfPoints * 9];
 
       for (int i = 0; i < 4; i++)
       {
         for (int j = 0; j < 4; j++)
         {
-          matrices[i*4+j] = trans[j*4+i];
+          matrices[i * 4 + j] = trans[j * 4 + i];
         }
       }
 
@@ -961,7 +945,7 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
       {
         for (int j = 0; j < 3; j++)
         {
-          normalMatrices[i*3+j] = normalTrans[i*3+j];
+          normalMatrices[i * 3 + j] = normalTrans[i * 3 + j];
         }
       }
       entry->NumberOfPoints++;
@@ -971,19 +955,20 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
   subarray->BuildTime.Modified();
 }
 
-
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Release any graphics resources that are being consumed by this mapper.
-void vtkOpenGLGlyph3DMapper::ReleaseGraphicsResources(vtkWindow *window)
+void vtkOpenGLGlyph3DMapper::ReleaseGraphicsResources(vtkWindow* window)
 {
   if (this->GlyphValues)
   {
-    std::map<const vtkDataSet *, vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray *>::iterator miter = this->GlyphValues->Entries.begin();
-    for (;miter != this->GlyphValues->Entries.end(); ++miter)
+    std::map<const vtkDataSet*, vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperSubArray*>::iterator
+      miter = this->GlyphValues->Entries.begin();
+    for (; miter != this->GlyphValues->Entries.end(); ++miter)
     {
-      std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry *>::iterator miter2 = miter->second->Entries.begin();
-      for (;miter2 != miter->second->Entries.end(); ++miter2)
+      std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry*>::iterator miter2 =
+        miter->second->Entries.begin();
+      for (; miter2 != miter->second->Entries.end(); ++miter2)
       {
         vtkOpenGLGlyph3DMapperEntry::MapperMap::iterator miter3 = (*miter2)->Mappers.begin();
         for (; miter3 != (*miter2)->Mappers.end(); ++miter3)
@@ -995,7 +980,7 @@ void vtkOpenGLGlyph3DMapper::ReleaseGraphicsResources(vtkWindow *window)
   }
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkOpenGLGlyph3DMapper::GetMaxNumberOfLOD()
 {
 #ifndef GL_ES_VERSION_3_0
@@ -1007,7 +992,8 @@ vtkIdType vtkOpenGLGlyph3DMapper::GetMaxNumberOfLOD()
   GLint streams, maxsize;
   glGetIntegerv(GL_MAX_VERTEX_STREAMS, &streams);
   glGetIntegerv(GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS, &maxsize);
-  maxsize /= 32; // each stream size can be 29 bytes (16 for transform matrix, 9 for normal, 4 for color)
+  maxsize /=
+    32; // each stream size can be 29 bytes (16 for transform matrix, 9 for normal, 4 for color)
 
   vtkIdType maxstreams = static_cast<vtkIdType>(std::min(streams, maxsize));
   return maxstreams - 1;
@@ -1016,23 +1002,26 @@ vtkIdType vtkOpenGLGlyph3DMapper::GetMaxNumberOfLOD()
 #endif
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkOpenGLGlyph3DMapper::SetNumberOfLOD(vtkIdType nb)
 {
-  this->LODs.resize(nb, {0.f, 0.f});
+  this->LODs.resize(nb, { 0.f, 0.f });
 }
 
-//---------------------------------------------------------------------------
-void vtkOpenGLGlyph3DMapper::SetLODDistanceAndTargetReduction(vtkIdType index, float distance, float targetReduction)
+//------------------------------------------------------------------------------
+void vtkOpenGLGlyph3DMapper::SetLODDistanceAndTargetReduction(
+  vtkIdType index, float distance, float targetReduction)
 {
   if (index < static_cast<vtkIdType>(this->LODs.size()))
   {
-    this->LODs[index] = {vtkMath::Max(0.f, distance), vtkMath::ClampValue(targetReduction, 0.f, 1.f)};
+    this->LODs[index] = { vtkMath::Max(0.f, distance),
+      vtkMath::ClampValue(targetReduction, 0.f, 1.f) };
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkOpenGLGlyph3DMapper::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
