@@ -37,6 +37,7 @@
 
 #define ID_OFFSET 1
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 void annotate(const std::string& str)
@@ -49,20 +50,21 @@ void annotate(const std::string& str)
 vtkStandardNewMacro(vtkOpenGLHardwareSelector);
 
 //------------------------------------------------------------------------------
+#ifdef vtkOpenGLHardwareSelectorDEBUG
 vtkOpenGLHardwareSelector::vtkOpenGLHardwareSelector()
 {
-#ifdef vtkOpenGLHardwareSelectorDEBUG
   cerr << "=====vtkOpenGLHardwareSelector::vtkOpenGLHardwareSelector" << endl;
-#endif
 }
 
 //------------------------------------------------------------------------------
 vtkOpenGLHardwareSelector::~vtkOpenGLHardwareSelector()
 {
-#ifdef vtkOpenGLHardwareSelectorDEBUG
   cerr << "=====vtkOpenGLHardwareSelector::~vtkOpenGLHardwareSelector" << endl;
-#endif
 }
+#else
+vtkOpenGLHardwareSelector::vtkOpenGLHardwareSelector() = default;
+vtkOpenGLHardwareSelector::~vtkOpenGLHardwareSelector() = default;
+#endif
 
 //------------------------------------------------------------------------------
 void vtkOpenGLHardwareSelector::PreCapturePass(int pass)
@@ -70,8 +72,7 @@ void vtkOpenGLHardwareSelector::PreCapturePass(int pass)
   annotate(std::string("Starting pass: ") + this->PassTypeToString(static_cast<PassTypes>(pass)));
 
   // Disable blending
-  vtkOpenGLRenderWindow* rwin =
-    static_cast<vtkOpenGLRenderWindow*>(this->Renderer->GetRenderWindow());
+  auto rwin = vtkOpenGLRenderWindow::SafeDownCast(this->Renderer->GetRenderWindow());
   vtkOpenGLState* ostate = rwin->GetState();
 
   this->OriginalBlending = ostate->GetEnumState(GL_BLEND);
@@ -82,8 +83,7 @@ void vtkOpenGLHardwareSelector::PreCapturePass(int pass)
 void vtkOpenGLHardwareSelector::PostCapturePass(int pass)
 {
   // Restore blending.
-  vtkOpenGLRenderWindow* rwin =
-    static_cast<vtkOpenGLRenderWindow*>(this->Renderer->GetRenderWindow());
+  auto rwin = vtkOpenGLRenderWindow::SafeDownCast(this->Renderer->GetRenderWindow());
   vtkOpenGLState* ostate = rwin->GetState();
 
   ostate->SetEnumState(GL_BLEND, this->OriginalBlending);
@@ -93,8 +93,7 @@ void vtkOpenGLHardwareSelector::PostCapturePass(int pass)
 //------------------------------------------------------------------------------
 void vtkOpenGLHardwareSelector::BeginSelection()
 {
-  vtkOpenGLRenderWindow* rwin =
-    static_cast<vtkOpenGLRenderWindow*>(this->Renderer->GetRenderWindow());
+  auto rwin = vtkOpenGLRenderWindow::SafeDownCast(this->Renderer->GetRenderWindow());
 
   this->OriginalMultiSample = rwin->GetMultiSamples();
   rwin->SetMultiSamples(0);
@@ -125,8 +124,7 @@ void vtkOpenGLHardwareSelector::EndSelection()
     this->Renderer->PreserveDepthBufferOff();
   }
 
-  vtkOpenGLRenderWindow* rwin =
-    static_cast<vtkOpenGLRenderWindow*>(this->Renderer->GetRenderWindow());
+  auto rwin = vtkOpenGLRenderWindow::SafeDownCast(this->Renderer->GetRenderWindow());
   rwin->SetMultiSamples(this->OriginalMultiSample);
   vtkOpenGLState* ostate = rwin->GetState();
   ostate->Pop();
@@ -193,7 +191,6 @@ void vtkOpenGLHardwareSelector::BeginRenderProp()
   vtkRenderWindow* renWin = this->Renderer->GetRenderWindow();
   this->BeginRenderProp(renWin);
 
-  // cout << "In BeginRenderProp" << endl;
   if (this->CurrentPass == ACTOR_PASS)
   {
     int propid = this->PropID;
@@ -202,17 +199,13 @@ void vtkOpenGLHardwareSelector::BeginRenderProp()
       vtkErrorMacro("Too many props. Currently only " << 0xfffffe << " props are supported.");
       return;
     }
-    float color[3];
     // Since 0 is reserved for nothing selected, we offset propid by 1.
     propid = propid + ID_OFFSET;
-    vtkHardwareSelector::Convert(propid, color);
-    this->SetPropColorValue(color);
+    this->SetPropColorValue(propid);
   }
   else if (this->CurrentPass == PROCESS_PASS)
   {
-    float color[3];
-    vtkHardwareSelector::Convert(this->ProcessID + 1, color);
-    this->SetPropColorValue(color);
+    this->SetPropColorValue(this->ProcessID + 1);
   }
 }
 
@@ -233,18 +226,14 @@ void vtkOpenGLHardwareSelector::EndRenderProp()
 //------------------------------------------------------------------------------
 void vtkOpenGLHardwareSelector::RenderCompositeIndex(unsigned int index)
 {
-
-  if (index > 0xffffff)
-  {
-    vtkErrorMacro("Indices > 0xffffff are not supported.");
-    return;
-  }
-
   if (this->CurrentPass == COMPOSITE_INDEX_PASS)
   {
-    float color[3];
-    vtkHardwareSelector::Convert(static_cast<vtkIdType>(0xffffff & index), color);
-    this->SetPropColorValue(color);
+    if (index > 0xffffff)
+    {
+      vtkErrorMacro("Indices > 0xffffff are not supported.");
+      return;
+    }
+    this->SetPropColorValue(static_cast<vtkIdType>(0xffffff & index));
   }
 }
 
@@ -258,10 +247,7 @@ void vtkOpenGLHardwareSelector::RenderProcessId(unsigned int processid)
       vtkErrorMacro("Invalid id: " << processid);
       return;
     }
-
-    float color[3];
-    vtkHardwareSelector::Convert(static_cast<vtkIdType>(processid + 1), color);
-    this->SetPropColorValue(color);
+    this->SetPropColorValue(static_cast<vtkIdType>(processid + 1));
   }
 }
 
@@ -270,3 +256,4 @@ void vtkOpenGLHardwareSelector::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
