@@ -14,42 +14,43 @@
 =========================================================================*/
 
 #include "vtkOpenGLImageAlgorithmHelper.h"
-#include "vtkObjectFactory.h"
-#include "vtkTextureObject.h"
-#include "vtkOpenGLRenderWindow.h"
 #include "vtkDataArray.h"
 #include "vtkImageData.h"
 #include "vtkNew.h"
+#include "vtkObjectFactory.h"
 #include "vtkOpenGLFramebufferObject.h"
+#include "vtkOpenGLRenderWindow.h"
 #include "vtkOpenGLShaderCache.h"
 #include "vtkOpenGLState.h"
-#include "vtk_glew.h"
+#include "vtkOpenGLVertexArrayObject.h"
 #include "vtkPointData.h"
 #include "vtkShaderProgram.h"
-#include "vtkOpenGLVertexArrayObject.h"
+#include "vtkTextureObject.h"
+#include "vtk_glew.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenGLImageAlgorithmHelper);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkOpenGLImageAlgorithmHelper::vtkOpenGLImageAlgorithmHelper()
 {
   this->RenderWindow = nullptr;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkOpenGLImageAlgorithmHelper::~vtkOpenGLImageAlgorithmHelper()
 {
   this->SetRenderWindow(nullptr);
 }
 
-void vtkOpenGLImageAlgorithmHelper::SetRenderWindow(vtkRenderWindow *renWin)
+void vtkOpenGLImageAlgorithmHelper::SetRenderWindow(vtkRenderWindow* renWin)
 {
   if (renWin == this->RenderWindow.GetPointer())
   {
     return;
   }
 
-  vtkOpenGLRenderWindow *orw  = nullptr;
+  vtkOpenGLRenderWindow* orw = nullptr;
   if (renWin)
   {
     orw = vtkOpenGLRenderWindow::SafeDownCast(renWin);
@@ -59,14 +60,9 @@ void vtkOpenGLImageAlgorithmHelper::SetRenderWindow(vtkRenderWindow *renWin)
   this->Modified();
 }
 
-void vtkOpenGLImageAlgorithmHelper::Execute(
-  vtkOpenGLImageAlgorithmCallback *cb,
-  vtkImageData *inImage, vtkDataArray *inArray,
-  vtkImageData *outImage, int outExt[6],
-  const char *vertexCode,
-  const char *fragmentCode,
-  const char *geometryCode
-  )
+void vtkOpenGLImageAlgorithmHelper::Execute(vtkOpenGLImageAlgorithmCallback* cb,
+  vtkImageData* inImage, vtkDataArray* inArray, vtkImageData* outImage, int outExt[6],
+  const char* vertexCode, const char* fragmentCode, const char* geometryCode)
 {
   // make sure it is initialized
   if (!this->RenderWindow)
@@ -81,7 +77,7 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
   int dims[3];
   inImage->GetDimensions(dims);
   int dimensions = 0;
-  for (int i = 0; i < 3; i ++)
+  for (int i = 0; i < 3; i++)
   {
     if (dims[i] > 1)
     {
@@ -99,7 +95,7 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
   // send vector data to a texture
   int inputExt[6];
   inImage->GetExtent(inputExt);
-  void *inPtr = inArray->GetVoidPointer(0);
+  void* inPtr = inArray->GetVoidPointer(0);
 
   // could do shortcut here if the input volume is
   // exactly what we want (updateExtent == wholeExtent)
@@ -110,9 +106,7 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
   vtkNew<vtkTextureObject> inputTex;
   inputTex->SetContext(this->RenderWindow);
   inputTex->Create3DFromRaw(
-    dims[0], dims[1], dims[2],
-    inArray->GetNumberOfComponents(),
-    inArray->GetDataType(), inPtr);
+    dims[0], dims[1], dims[2], inArray->GetNumberOfComponents(), inArray->GetDataType(), inPtr);
 
   float shift = 0.0;
   float scale = 1.0;
@@ -129,9 +123,9 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
 
   vtkNew<vtkOpenGLFramebufferObject> fbo;
   fbo->SetContext(this->RenderWindow);
-  fbo->SaveCurrentBindingsAndBuffers();
+  vtkOpenGLState* ostate = this->RenderWindow->GetState();
+  ostate->PushFramebufferBindings();
   fbo->Bind();
-  vtkOpenGLState *ostate = this->RenderWindow->GetState();
 
   outputTex->Create2D(outDims[0], outDims[1], 4, VTK_FLOAT, false);
   fbo->AddColorAttachment(0, outputTex);
@@ -146,11 +140,10 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
   ostate->vtkglScissor(0, 0, outDims[0], outDims[1]);
   ostate->vtkglDisable(GL_DEPTH_TEST);
   ostate->vtkglDepthMask(false);
-  ostate->vtkglClearColor(0.0,0.0,0.0,1.0);
+  ostate->vtkglClearColor(0.0, 0.0, 0.0, 1.0);
 
-  vtkShaderProgram *prog =
-    this->RenderWindow->GetShaderCache()->ReadyShaderProgram(
-      vertexCode, fragmentCode, geometryCode);
+  vtkShaderProgram* prog = this->RenderWindow->GetShaderCache()->ReadyShaderProgram(
+    vertexCode, fragmentCode, geometryCode);
   if (prog != this->Quad.Program)
   {
     this->Quad.Program = prog;
@@ -167,7 +160,7 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 
-  float *ftmp = new float[outDims[0]*outDims[1]*4];
+  float* ftmp = new float[outDims[0] * outDims[1] * 4];
   int outNumComponents = outImage->GetNumberOfScalarComponents();
 
   // for each zslice in the output
@@ -176,15 +169,12 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
     cb->UpdateShaderUniforms(prog, i);
     this->Quad.Program->SetUniformf("zPos", (i - outExt[4] + 0.5) / (outDims[2]));
     glClear(GL_COLOR_BUFFER_BIT);
-    fbo->RenderQuad(
-      0, outDims[0] - 1,
-      0, outDims[1] - 1,
-      this->Quad.Program, this->Quad.VAO);
-    glReadPixels(0,0,outDims[0], outDims[1], GL_RGBA, GL_FLOAT, ftmp);
+    fbo->RenderQuad(0, outDims[0] - 1, 0, outDims[1] - 1, this->Quad.Program, this->Quad.VAO);
+    glReadPixels(0, 0, outDims[0], outDims[1], GL_RGBA, GL_FLOAT, ftmp);
 
-    double *outP = static_cast<double *>(outImage->GetScalarPointer(outExt[0], outExt[2], i));
-    float *tmpP = ftmp;
-    for (int j = 0; j < outDims[1]*outDims[0]; ++j)
+    double* outP = static_cast<double*>(outImage->GetScalarPointer(outExt[0], outExt[2], i));
+    float* tmpP = ftmp;
+    for (int j = 0; j < outDims[1] * outDims[0]; ++j)
     {
       for (int c = 0; c < outNumComponents; ++c)
       {
@@ -196,22 +186,23 @@ void vtkOpenGLImageAlgorithmHelper::Execute(
   }
 
   inputTex->Deactivate();
-  fbo->RestorePreviousBindingsAndBuffers();
-  delete [] ftmp;
+  ostate->PopFramebufferBindings();
+  delete[] ftmp;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkOpenGLImageAlgorithmHelper::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "RenderWindow:";
-  if(this->RenderWindow != nullptr)
+  if (this->RenderWindow != nullptr)
   {
-    this->RenderWindow->PrintSelf(os,indent);
+    this->RenderWindow->PrintSelf(os, indent);
   }
   else
   {
-    os << "(none)" <<endl;
+    os << "(none)" << endl;
   }
 }
+VTK_ABI_NAMESPACE_END
