@@ -33,8 +33,15 @@
 #include <array>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenGLInstanceCulling);
 
+void vtkOpenGLInstanceCulling::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "ColorLOD: " << this->ColorLOD << endl;
+}
+
 //------------------------------------------------------------------------------
 vtkOpenGLInstanceCulling::~vtkOpenGLInstanceCulling()
 {
@@ -459,3 +466,4 @@ vtkIdType vtkOpenGLInstanceCulling::GetNumberOfLOD()
 {
   return static_cast<vtkIdType>(this->LODList.size());
 }
+VTK_ABI_NAMESPACE_END
