@@ -17,35 +17,37 @@
  *
  * vtkOpenGLLight is a concrete implementation of the abstract class vtkLight.
  * vtkOpenGLLight interfaces to the OpenGL rendering library.
-*/
+ */
 
 #ifndef vtkOpenGLLight_h
 #define vtkOpenGLLight_h
 
-#include "vtkRenderingOpenGL2Module.h" // For export macro
 #include "vtkLight.h"
+#include "vtkRenderingOpenGL2Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLRenderer;
 
 class VTKRENDERINGOPENGL2_EXPORT vtkOpenGLLight : public vtkLight
 {
 public:
-  static vtkOpenGLLight *New();
+  static vtkOpenGLLight* New();
   vtkTypeMacro(vtkOpenGLLight, vtkLight);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Implement base class method.
    */
-  void Render(vtkRenderer *ren, int light_index) VTK_OVERRIDE;
+  void Render(vtkRenderer* ren, int light_index) override;
 
 protected:
-  vtkOpenGLLight() {}
-  ~vtkOpenGLLight() VTK_OVERRIDE {}
+  vtkOpenGLLight() = default;
+  ~vtkOpenGLLight() override = default;
 
 private:
-  vtkOpenGLLight(const vtkOpenGLLight&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkOpenGLLight&) VTK_DELETE_FUNCTION;
+  vtkOpenGLLight(const vtkOpenGLLight&) = delete;
+  void operator=(const vtkOpenGLLight&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
