@@ -21,7 +21,7 @@
 #ifndef vtkOpenGLPolyDataMapper_h
 #define vtkOpenGLPolyDataMapper_h
 
-#include "vtkDeprecation.h"  // For VTK_DEPRECATED_IN_9_0_0
+#include "vtkInformation.h"  // for prim struct
 #include "vtkNew.h"          // For vtkNew
 #include "vtkOpenGLHelper.h" // used for ivars
 #include "vtkPolyDataMapper.h"
@@ -33,6 +33,7 @@
 #include <tuple>  // for tuple
 #include <vector> // for vector
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellArray;
 class vtkGenericOpenGLResourceFreeCallback;
 class vtkMatrix4x4;
@@ -61,14 +62,14 @@ public:
    */
   void RenderPiece(vtkRenderer* ren, vtkActor* act) override;
 
-  //@{
+  ///@{
   /**
    * Implemented by sub classes. Actual rendering is done here.
    */
   virtual void RenderPieceStart(vtkRenderer* ren, vtkActor* act);
   virtual void RenderPieceDraw(vtkRenderer* ren, vtkActor* act);
   virtual void RenderPieceFinish(vtkRenderer* ren, vtkActor* act);
-  //@}
+  ///@}
 
   /**
    * Release any graphics resources that are being consumed by this mapper.
@@ -93,7 +94,7 @@ public:
   // other polydata (not the input)
   vtkPolyData* CurrentInput;
 
-  //@{
+  ///@{
   /**
    * By default, this class uses the dataset's point and cell ids during
    * rendering. However, one can override those by specifying cell and point
@@ -104,9 +105,9 @@ public:
   vtkGetStringMacro(PointIdArrayName);
   vtkSetStringMacro(CellIdArrayName);
   vtkGetStringMacro(CellIdArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If this class should override the process id using a data-array,
    * set this variable to the name of the array to use. It must be a
@@ -114,9 +115,9 @@ public:
    */
   vtkSetStringMacro(ProcessIdArrayName);
   vtkGetStringMacro(ProcessIdArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Generally, this class can render the composite id when iterating
    * over composite datasets. However in some cases (as in AMR), the rendered
@@ -128,55 +129,7 @@ public:
    */
   vtkSetStringMacro(CompositeIdArrayName);
   vtkGetStringMacro(CompositeIdArrayName);
-  //@}
-
-  //@{
-  /**
-   * This function enables you to apply your own substitutions
-   * to the shader creation process. The shader code in this class
-   * is created by applying a bunch of string replacements to a
-   * shader template. Using this function you can apply your
-   * own string replacements to add features you desire.
-   *
-   * @deprecated Replaced By vtkShaderProperty::{Add,Clear,ClearAll}ShaderReplacements as of
-   * VTK 9.0.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::AddShaderReplacement")
-  void AddShaderReplacement(vtkShader::Type shaderType, // vertex, fragment, etc
-    const std::string& originalValue,
-    bool replaceFirst, // do this replacement before the default
-    const std::string& replacementValue, bool replaceAll);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::ClearShaderReplacement")
-  void ClearShaderReplacement(vtkShader::Type shaderType, // vertex, fragment, etc
-    const std::string& originalValue, bool replaceFirst);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::ClearAllShaderReplacements")
-  void ClearAllShaderReplacements(vtkShader::Type shaderType);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::ClearAllShaderReplacements")
-  void ClearAllShaderReplacements();
-  //@}
-
-  //@{
-  /**
-   * Allow the program to set the shader codes used directly
-   * instead of using the built in templates. Be aware, if
-   * set, this template will be used for all cases,
-   * primitive types, picking etc.
-   *
-   * @deprecated Replaced By vtkShaderProperty::Get*ShaderCode as of VTK 9.0.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::SetVertexShaderCode")
-  virtual void SetVertexShaderCode(const char* code);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::GetVertexShaderCode")
-  virtual char* GetVertexShaderCode();
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::SetFragmentShaderCode")
-  virtual void SetFragmentShaderCode(const char* code);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::GetFragmentShaderCode")
-  virtual char* GetFragmentShaderCode();
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::SetGeometryShaderCode")
-  virtual void SetGeometryShaderCode(const char* code);
-  VTK_DEPRECATED_IN_9_0_0("Use vtkOpenGLShaderProperty::GetGeometryShaderCode")
-  virtual char* GetGeometryShaderCode();
-  //@}
+  ///@}
 
   /**
    * Make a shallow copy of this mapper.
@@ -192,6 +145,36 @@ public:
   virtual void SetVBOShiftScaleMethod(int m);
   virtual int GetVBOShiftScaleMethod() { return this->ShiftScaleMethod; }
 
+  /**\brief Pause per-render updates to VBO shift+scale parameters.
+   *
+   * For large datasets, re-uploading the VBO during user interaction
+   * can cause stutters in the framerate. Interactors can use this
+   * method to force UpdateCameraShiftScale to return immediately
+   * (without changes) while users are zooming/rotating/etc. and then
+   * re-enable shift-scale just before a still render.
+   *
+   * This setting has no effect unless the shift-scale method is set
+   * to NEAR_PLANE_SHIFT_SCALE or FOCAL_POINT_SHIFT_SCALE.
+   *
+   * Changing this setting does **not** mark the mapper as modified as
+   * that would force a VBO upload – defeating its own purpose.
+   */
+  virtual void SetPauseShiftScale(bool pauseShiftScale) { this->PauseShiftScale = pauseShiftScale; }
+  vtkGetMacro(PauseShiftScale, bool);
+  vtkBooleanMacro(PauseShiftScale, bool);
+
+  /**
+   * Allow the shader code to set the point size (with gl_PointSize variable)
+   * instead of using the one defined by the property. Note that this flag is
+   * not available on OpenGLES as the feature is enabled by default. With
+   * OpenGL, the feature is turned off by default.
+   * Warning: on MacOS, enabling the feature result in non point drawing
+   * if the shaders do not set the point size.
+   */
+  vtkGetMacro(UseProgramPointSize, bool);
+  vtkSetMacro(UseProgramPointSize, bool);
+  vtkBooleanMacro(UseProgramPointSize, bool);
+
   enum PrimitiveTypes
   {
     PrimitiveStart = 0,
@@ -298,7 +281,7 @@ protected:
   virtual void ReplaceShaderValues(
     std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* act);
 
-  //@{
+  ///@{
   /**
    * Perform string replacements on the shader templates, called from
    * ReplaceShaderValues
@@ -329,7 +312,7 @@ protected:
     std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* act);
   virtual void ReplaceShaderDepth(
     std::map<vtkShader::Type, vtkShader*> shaders, vtkRenderer* ren, vtkActor* act);
-  //@}
+  ///@}
 
   /**
    * Set the value of user-defined uniform variables, called by UpdateShader
@@ -342,18 +325,18 @@ protected:
   virtual void SetMapperShaderParameters(vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act);
 
   /**
-   * Set the shader parameteres related to lighting, called by UpdateShader
+   * Set the shader parameters related to lighting, called by UpdateShader
    */
   virtual void SetLightingShaderParameters(
     vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act);
 
   /**
-   * Set the shader parameteres related to the Camera, called by UpdateShader
+   * Set the shader parameters related to the Camera, called by UpdateShader
    */
   virtual void SetCameraShaderParameters(vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act);
 
   /**
-   * Set the shader parameteres related to the property, called by UpdateShader
+   * Set the shader parameters related to the property, called by UpdateShader
    */
   virtual void SetPropertyShaderParameters(
     vtkOpenGLHelper& cellBO, vtkRenderer* ren, vtkActor* act);
@@ -428,22 +411,30 @@ protected:
   virtual bool HaveTCoords(vtkPolyData* poly);
 
   // values we use to determine if we need to rebuild shaders
-  std::map<const vtkOpenGLHelper*, int> LastLightComplexity;
-  std::map<const vtkOpenGLHelper*, int> LastLightCount;
-  std::map<const vtkOpenGLHelper*, vtkTimeStamp> LightComplexityChanged;
+  // stored in a map keyed on the vtkOpenGLHelper, so one
+  // typically entry per type of primitive we render which
+  // matches the shader programs we use
+  class primitiveInfo
+  {
+  public:
+    int LastLightComplexity;
+    int LastLightCount;
+    vtkTimeStamp LightComplexityChanged;
+
+    // Caches the vtkOpenGLRenderPass::RenderPasses() information.
+    // Note: Do not dereference the pointers held by this object. There is no
+    // guarantee that they are still valid!
+    vtkNew<vtkInformation> LastRenderPassInfo;
+  };
+  std::map<const vtkOpenGLHelper*, primitiveInfo> PrimitiveInfo;
 
   bool PointPicking;
   int LastSelectionState;
   vtkTimeStamp SelectionStateChanged;
 
-  // Caches the vtkOpenGLRenderPass::RenderPasses() information.
-  // Note: Do not dereference the pointers held by this object. There is no
-  // guarantee that they are still valid!
-  vtkNew<vtkInformation> LastRenderPassInfo;
-
   // Check the renderpasses in actor's property keys to see if they've changed
   // render stages:
-  vtkMTimeType GetRenderPassStageMTime(vtkActor* actor);
+  vtkMTimeType GetRenderPassStageMTime(vtkActor* actor, const vtkOpenGLHelper* cellBO);
 
   bool UsingScalarColoring;
   vtkTimeStamp VBOBuildTime;     // When was the OpenGL VBO updated?
@@ -461,6 +452,8 @@ protected:
   vtkNew<vtkTransform> VBOInverseTransform;
   vtkNew<vtkMatrix4x4> VBOShiftScale;
   int ShiftScaleMethod; // for points
+  bool PauseShiftScale;
+  bool UseProgramPointSize;
 
   // if set to true, tcoords will be passed to the
   // VBO even if the mapper knows of no texture maps
@@ -503,13 +496,6 @@ protected:
   };
   std::map<std::string, ExtraAttributeValue> ExtraAttributes;
 
-  // Store shader properties on this class by legacy shader replacement functions
-  // This should disappear when the functions are deprecated
-  // VTK_DEPRECATED_IN_9_0_0("legacy support functions")
-  vtkOpenGLShaderProperty* GetLegacyShaderProperty();
-  // VTK_DEPRECATED_IN_9_0_0("legacy support functions")
-  vtkSmartPointer<vtkOpenGLShaderProperty> LegacyShaderProperty;
-
   vtkOpenGLRenderTimer* TimerQuery;
 
   // are we currently drawing spheres/tubes
@@ -533,9 +519,9 @@ protected:
   // compute and set the maximum point and cell ID used in selection
   virtual void UpdateMaximumPointCellIds(vtkRenderer* ren, vtkActor* actor);
 
-  void AddPointIdsToSelectionPrimitives(vtkPolyData* poly, const char* arrayName,
+  virtual void AddPointIdsToSelectionPrimitives(vtkPolyData* poly, const char* arrayName,
     unsigned int processId, unsigned int compositeIndex, vtkIdType selectedId);
-  void AddCellIdsToSelectionPrimitives(vtkPolyData* poly, const char* arrayName,
+  virtual void AddCellIdsToSelectionPrimitives(vtkPolyData* poly, const char* arrayName,
     unsigned int processId, unsigned int compositeIndex, vtkIdType selectedId);
 
   vtkNew<vtkCellArray> SelectionArrays[4];
@@ -545,4 +531,5 @@ private:
   void operator=(const vtkOpenGLPolyDataMapper&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
