@@ -24,6 +24,11 @@
  * create the instance where used and delete it in ReleaseGraphicsResources
  * and the destructor.
  *
+ * It is possible to flip the Y direction of the quad texture coordinate by
+ * turning on the flipY option in the constructor. This can be useful when
+ * rendering in an external context having a different convention than OpenGL
+ * e.g. OpenGL-D3D shared textures. Off by default if unspecified.
+ *
  * Example usage:
  * @code
  * if (!this->QuadHelper)
@@ -47,6 +52,7 @@
 #include "vtkTimeStamp.h"
 #include <memory> // for std::unique_ptr
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLRenderWindow;
 class vtkOpenGLVertexArrayObject;
 class vtkShaderProgram;
@@ -62,12 +68,15 @@ public:
   vtkOpenGLVertexArrayObject* VAO;
   unsigned int ShaderChangeValue;
 
-  // create a quadhelper with the provided shaders
-  // if the vertex is nullptr
-  // then the default is used. Note that this
-  // class should be destroyed upon
-  // ReleaseGraphicsResources
-  vtkOpenGLQuadHelper(vtkOpenGLRenderWindow*, const char* vs, const char* fs, const char* gs);
+  /**
+   * Create a quadhelper with the provided shaders.
+   * If the vertex is nullptr then the default is used.
+   * Turning on the flipY option reverts the y component of the quad texture coordinates in
+   * order to flip the rendered texture.
+   * Note that this class should be destroyed upon ReleaseGraphicsResources.
+   */
+  vtkOpenGLQuadHelper(
+    vtkOpenGLRenderWindow*, const char* vs, const char* fs, const char* gs, bool flipY = false);
 
   ~vtkOpenGLQuadHelper();
 
@@ -87,6 +96,7 @@ private:
   std::unique_ptr<vtkGenericOpenGLResourceFreeCallback> ResourceCallback;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkOpenGLQuadHelper_h
 
 // VTK-HeaderTest-Exclude: vtkOpenGLQuadHelper.h
