@@ -25,8 +25,7 @@
 #ifndef vtkOpenGLRenderWindow_h
 #define vtkOpenGLRenderWindow_h
 
-#include "vtkDeprecation.h" // for VTK_DEPRECATED_IN_9_0_0
-#include "vtkRect.h"        // for vtkRecti
+#include "vtkRect.h" // for vtkRecti
 #include "vtkRenderWindow.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include "vtkType.h"                   // for ivar
@@ -34,6 +33,7 @@
 #include <set>                         // for ivar
 #include <string>                      // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkOpenGLBufferObject;
 class vtkOpenGLFramebufferObject;
@@ -43,7 +43,6 @@ class vtkOpenGLShaderCache;
 class vtkOpenGLVertexBufferObjectCache;
 class vtkOpenGLVertexArrayObject;
 class vtkShaderProgram;
-class vtkStdString;
 class vtkTexture;
 class vtkTextureObject;
 class vtkTextureUnitManager;
@@ -72,15 +71,15 @@ public:
    */
   const char* GetRenderingBackend() override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the maximum number of multisamples
    */
   static void SetGlobalMaximumNumberOfMultiSamples(int val);
   static int GetGlobalMaximumNumberOfMultiSamples();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the pixel data of an image, transmitted as RGBRGB...
    * front in this context indicates that the read should come from the
@@ -93,9 +92,9 @@ public:
     int x, int y, int x2, int y2, unsigned char* data, int front, int right) override;
   int SetPixelData(
     int x, int y, int x2, int y2, vtkUnsignedCharArray* data, int front, int right) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the pixel data of an image, transmitted as RGBARGBA...
    */
@@ -115,9 +114,9 @@ public:
     int blend = 0, int right = 0) override;
   int SetRGBACharPixelData(int x, int y, int x2, int y2, vtkUnsignedCharArray* data, int front,
     int blend = 0, int right = 0) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the zbuffer data from an image
    */
@@ -126,7 +125,7 @@ public:
   int GetZbufferData(int x1, int y1, int x2, int y2, vtkFloatArray* buffer) override;
   int SetZbufferData(int x1, int y1, int x2, int y2, float* buffer) override;
   int SetZbufferData(int x1, int y1, int x2, int y2, vtkFloatArray* buffer) override;
-  //@}
+  ///@}
 
   /**
    * Activate a texture unit for this texture
@@ -184,21 +183,6 @@ public:
    */
   void GetOpenGLVersion(int& major, int& minor);
 
-  //@{
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1, now always returns 0")
-  unsigned int GetBackLeftBuffer();
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1, now always returns 0")
-  unsigned int GetBackRightBuffer();
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1, now always returns 0")
-  unsigned int GetFrontLeftBuffer();
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1, now always returns 0")
-  unsigned int GetFrontRightBuffer();
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1, now always returns 0")
-  unsigned int GetBackBuffer();
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1, now always returns 0")
-  unsigned int GetFrontBuffer();
-  //@}
-
   /**
    * Get the time when the OpenGL context was created.
    */
@@ -214,14 +198,12 @@ public:
    */
   vtkOpenGLVertexBufferObjectCache* GetVBOCache();
 
-  //@{
+  ///@{
   /**
    * Returns the render framebuffer object.
    */
   vtkGetObjectMacro(RenderFramebuffer, vtkOpenGLFramebufferObject);
-  VTK_DEPRECATED_IN_9_1_0("Removed in 9.1")
-  vtkOpenGLFramebufferObject* GetOffScreenFramebuffer() { return this->RenderFramebuffer; }
-  //@}
+  ///@}
 
   /**
    * Returns the display framebuffer object.
@@ -366,7 +348,7 @@ public:
 
   // Activate and return thje texture unit for a generic 2d 64x64
   // float greyscale noise texture ranging from 0 to 1. The texture is
-  // generated using PerlinNoise.  This textur eunit will automatically
+  // a hard-coded blue noise texture.  This texture unit will automatically
   // be deactivated at the end of the render process.
   int GetNoiseTextureUnit();
 
@@ -406,7 +388,7 @@ public:
   void BlitDisplayFramebuffer(int right, int srcX, int srcY, int srcWidth, int srcHeight, int destX,
     int destY, int destWidth, int destHeight, int bufferMode, int interpolation);
 
-  //@{
+  ///@{
   /**
    * Blit the currently bound read buffer to the renderbuffer. This is useful for
    * taking rendering from an external system and then having VTK draw on top of it.
@@ -414,7 +396,7 @@ public:
   void BlitToRenderFramebuffer(bool includeDepth);
   void BlitToRenderFramebuffer(int srcX, int srcY, int srcWidth, int srcHeight, int destX,
     int destY, int destWidth, int destHeight, int bufferMode, int interpolation);
-  //@}
+  ///@}
 
   /**
    * Define how the resulting image should be blitted when at the end of the Frame() call if
@@ -427,7 +409,7 @@ public:
     NoBlit          // no blit, GUI or external code will handle the blit
   };
 
-  //@{
+  ///@{
   /**
    * SetGet how to handle blits at the end of a Frame() call.
    * Only happens when SwapBuffers is true.
@@ -437,7 +419,33 @@ public:
   void SetFrameBlitModeToBlitToHardware() { this->SetFrameBlitMode(BlitToHardware); }
   void SetFrameBlitModeToBlitToCurrent() { this->SetFrameBlitMode(BlitToCurrent); }
   void SetFrameBlitModeToNoBlit() { this->SetFrameBlitMode(NoBlit); }
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * Enable/Disable flipping the Y axis of the rendered texture.
+   */
+  vtkSetMacro(FramebufferFlipY, bool);
+  vtkGetMacro(FramebufferFlipY, bool);
+  vtkBooleanMacro(FramebufferFlipY, bool);
+  ///@}
+
+  ///@{
+  // copy depth values from a source framebuffer to a destination framebuffer
+  // using texture maps to do the copy. The source framebufferobject must be texture
+  // backed. This method is designed to work around issues with trying to blit depth
+  // values between framebuffers that have different depth formats.
+
+  // blit entire source texture to active viewport
+  virtual void TextureDepthBlit(vtkTextureObject* source);
+
+  // blit specified source texels to active viewport
+  virtual void TextureDepthBlit(vtkTextureObject* source, int srcX, int srcY, int srcX2, int srcY2);
+
+  // blit specified source texels to specified viewport
+  virtual void TextureDepthBlit(vtkTextureObject* source, int srcX, int srcY, int srcX2, int srcY2,
+    int destX, int destY, int destX2, int destY2);
+  ///@}
 
 protected:
   vtkOpenGLRenderWindow();
@@ -452,6 +460,33 @@ protected:
   // a FSQ we use to resolve MSAA that handles gamma
   vtkOpenGLQuadHelper* ResolveQuad;
 
+  // a FSQ we use to blit depth values
+  vtkOpenGLQuadHelper* DepthBlitQuad;
+
+  // a FSQ we use to flip framebuffer texture
+  vtkOpenGLQuadHelper* FlipQuad;
+
+  // a FSQ we use to read depth component on platforms with OpenGL ES implementations
+  // because `glReadPixels` cannot be used to read GL_DEPTH_COMPONENT
+  vtkOpenGLQuadHelper* DepthReadQuad;
+
+  // flip quad helpers Y tcoord
+  bool FramebufferFlipY;
+
+  // resolve and flip renderframebuffer as needed
+  // when copying to displayframebuffer. Returns
+  // true if the color buffer was copied.
+  virtual bool ResolveFlipRenderFramebuffer();
+
+  // On GLES, the depth attachment buffer cannot be downloaded from
+  // the GPU with `glReadPixels`.
+  // This method reads the depth buffer bits.
+  // Depth is always 32-bit. The values are split into 4 8-bit numbers.
+  // These are stored in the form of an RGBA color attachment in DepthFrameBuffer.
+  // `glReadPixels` can read that RGBA format and reconstruct full 32-bit integer
+  // followed by scaling down to 0-1.
+  bool ReadDepthComponent();
+
   // used in testing for opengl support
   // in the SupportsOpenGL() method
   bool OpenGLSupportTested;
@@ -477,6 +512,10 @@ protected:
   // framebuffer
   vtkOpenGLFramebufferObject* ResolveFramebuffer;
 
+  // used when we need to read depth component
+  // with OpenGL ES 3
+  vtkOpenGLFramebufferObject* DepthFramebuffer;
+
   /**
    * Create a not-off-screen window.
    */
@@ -537,4 +576,5 @@ private:
   vtkOpenGLState* State;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
