@@ -23,13 +23,13 @@
 #ifndef vtkOpenGLRenderer_h
 #define vtkOpenGLRenderer_h
 
-#include "vtkDeprecation.h" // for VTK_DEPRECATED_IN_9_0_0
 #include "vtkRenderer.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include "vtkSmartPointer.h"           // For vtkSmartPointer
 #include <string>                      // Ivars
 #include <vector>                      // STL Header
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFloatArray;
 class vtkOpenGLFXAAFilter;
 class vtkRenderPass;
@@ -85,16 +85,6 @@ public:
    */
   int GetDepthPeelingHigherLayer();
 
-  /**
-   * Indicate if this system is subject to the Apple/AMD bug
-   * of not having a working glPrimitiveId <rdar://20747550>.
-   * The bug is fixed on macOS 10.11 and later, and this method
-   * will return false when the OS is new enough.
-   */
-  VTK_DEPRECATED_IN_9_1_0(
-    "Removed in 9.1.0 as this bug does not affect any macOS release that VTK supports")
-  bool HaveApplePrimitiveIdBug();
-
   /**
    * Indicate if this system is subject to the apple/NVIDIA bug that causes
    * crashes in the driver when too many query objects are allocated.
@@ -137,40 +127,40 @@ public:
   // get the number of lights turned on
   vtkGetMacro(LightingCount, int);
 
-  //@{
+  ///@{
   /**
    * Set the user light transform applied after the camera transform.
    * Can be null to disable it.
    */
   void SetUserLightTransform(vtkTransform* transform);
   vtkTransform* GetUserLightTransform();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get environment textures used for image based lighting.
    */
   vtkPBRLUTTexture* GetEnvMapLookupTable();
   vtkPBRIrradianceTexture* GetEnvMapIrradiance();
   vtkPBRPrefilterTexture* GetEnvMapPrefiltered();
-  //@}
+  ///@}
 
   /**
    * Get spherical harmonics coefficients used for irradiance
    */
   vtkFloatArray* GetSphericalHarmonics();
 
-  //@{
+  ///@{
   /**
    * Use spherical harmonics instead of irradiance texture
    */
   vtkSetMacro(UseSphericalHarmonics, bool);
   vtkGetMacro(UseSphericalHarmonics, bool);
   vtkBooleanMacro(UseSphericalHarmonics, bool);
-  //@}
+  ///@}
 
   /**
-   * Overriden in order to connect the texture to the environment map textures.
+   * Overridden in order to connect the texture to the environment map textures.
    */
   void SetEnvironmentTexture(vtkTexture* texture, bool isSRGB = false) override;
 
@@ -259,4 +249,5 @@ private:
   void operator=(const vtkOpenGLRenderer&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
