@@ -19,27 +19,30 @@
 // Provide a mechanism for making sure graphics resources are
 // freed properly.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLRenderWindow;
 class vtkWindow;
 
 class vtkGenericOpenGLResourceFreeCallback
 {
-  public:
-    vtkGenericOpenGLResourceFreeCallback() {
-        this->VTKWindow = nullptr; this->Releasing = false; }
-    virtual ~vtkGenericOpenGLResourceFreeCallback() { }
+public:
+  vtkGenericOpenGLResourceFreeCallback()
+  {
+    this->VTKWindow = nullptr;
+    this->Releasing = false;
+  }
+  virtual ~vtkGenericOpenGLResourceFreeCallback() = default;
 
-    // Called when the event is invoked
-    virtual void Release() = 0;
+  // Called when the event is invoked
+  virtual void Release() = 0;
 
-    virtual void RegisterGraphicsResources(vtkOpenGLRenderWindow *rw) =  0;
+  virtual void RegisterGraphicsResources(vtkOpenGLRenderWindow* rw) = 0;
 
-    bool IsReleasing() {
-      return this->Releasing; }
+  bool IsReleasing() { return this->Releasing; }
 
-  protected:
-    vtkOpenGLRenderWindow *VTKWindow;
-    bool Releasing;
+protected:
+  vtkOpenGLRenderWindow* VTKWindow;
+  bool Releasing;
 };
 
 // Description:
@@ -48,15 +51,16 @@ template <class T>
 class vtkOpenGLResourceFreeCallback : public vtkGenericOpenGLResourceFreeCallback
 {
 public:
-  vtkOpenGLResourceFreeCallback(T* handler, void (T::*method)(vtkWindow *))
+  vtkOpenGLResourceFreeCallback(T* handler, void (T::*method)(vtkWindow*))
   {
     this->Handler = handler;
     this->Method = method;
   }
 
-  ~vtkOpenGLResourceFreeCallback() override { }
+  ~vtkOpenGLResourceFreeCallback() override = default;
 
-  void RegisterGraphicsResources(vtkOpenGLRenderWindow *rw) override {
+  void RegisterGraphicsResources(vtkOpenGLRenderWindow* rw) override
+  {
     if (this->VTKWindow == rw)
     {
       return;
@@ -86,10 +90,12 @@ public:
       this->Releasing = false;
     }
   }
+
 protected:
   T* Handler;
-  void (T::*Method)(vtkWindow *);
+  void (T::*Method)(vtkWindow*);
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkOpenGLResourceFreeCallback.h
