@@ -35,6 +35,7 @@
 #include "vtkShaderProperty.h"
 #include <map> // used for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLUniforms;
 
 class VTKRENDERINGOPENGL2_EXPORT vtkOpenGLShaderProperty : public vtkShaderProperty
@@ -76,7 +77,7 @@ public:
   void ClearAllGeometryShaderReplacements() override;
   void ClearAllShaderReplacements() override;
 
-  //@{
+  ///@{
   /**
    * This function enables you to apply your own substitutions
    * to the shader creation process. The shader code in this class
@@ -91,7 +92,7 @@ public:
   void ClearShaderReplacement(vtkShader::Type shaderType, // vertex, fragment, etc
     const std::string& originalValue, bool replaceFirst);
   void ClearAllShaderReplacements(vtkShader::Type shaderType);
-  //@}
+  ///@}
 
   /**
    * @brief GetAllShaderReplacements returns all user-specified shader
@@ -113,4 +114,5 @@ private:
   void operator=(const vtkOpenGLShaderProperty&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
