@@ -52,6 +52,7 @@
 
 // this method checks all the cached state to make sure
 // nothing is out of sync. It can be slow.
+VTK_ABI_NAMESPACE_BEGIN
 void vtkOpenGLState::CheckState()
 {
   bool error = false;
@@ -312,6 +313,7 @@ bool reportOpenGLErrors(std::string& result)
     }                                                                                              \
   }
 
+VTK_ABI_NAMESPACE_END
 #else // VTK_REPORT_OPENGL_ERRORS
 
 #define vtkCheckOpenGLErrorsWithStack(message)
@@ -322,6 +324,7 @@ bool reportOpenGLErrors(std::string& result)
 //
 //////////////////////////////////////////////////////////////////////////////
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkOpenGLState::BufferBindingState::BufferBindingState()
 {
   // this->Framebuffer = nullptr;
@@ -1442,6 +1445,8 @@ void vtkOpenGLState::Reset()
 
   ::glGetIntegerv(GL_CURRENT_PROGRAM, &cs.BoundProgram);
   ::glGetIntegerv(GL_VERTEX_ARRAY_BINDING, &cs.BoundVAO);
+  ::glGetIntegerv(GL_ARRAY_BUFFER_BINDING, &cs.BoundArrayBuffer);
+  ::glGetIntegerv(GL_ELEMENT_ARRAY_BUFFER_BINDING, &cs.BoundElementArrayBuffer);
   vtkOpenGLRenderUtilities::MarkDebugEvent("Finished Resetting OpenGL State");
 }
 
@@ -1529,6 +1534,8 @@ void vtkOpenGLState::Pop()
   ::glActiveTexture(cs.ActiveTexture);
 
   ::glBindVertexArray(cs.BoundVAO);
+  ::glBindBuffer(GL_ARRAY_BUFFER, cs.BoundArrayBuffer);
+  ::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, cs.BoundElementArrayBuffer);
   vtkOpenGLRenderUtilities::MarkDebugEvent("Finished Popping OpenGL State");
 }
 
@@ -1743,6 +1750,16 @@ void vtkOpenGLState::vtkglClear(GLbitfield val)
   ::glClear(val);
 }
 
+void vtkOpenGLState::vtkglBlitFramebuffer(int srcX0, int srcY0, int srcX1, int srcY1, int dstX0,
+  int dstY0, int dstX1, int dstY1, unsigned int mask, unsigned int filter)
+{
+  // ON APPLE MACOS you must turn off scissor test for DEPTH blits to work
+  vtkOpenGLState::ScopedglEnableDisable stsaver(this, GL_SCISSOR_TEST);
+  this->vtkglDisable(GL_SCISSOR_TEST);
+
+  ::glBlitFramebuffer(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
+}
+
 //------------------------------------------------------------------------------
 // Description:
 // Returns its texture unit manager object.
@@ -1832,6 +1849,17 @@ void vtkOpenGLState::VerifyNoActiveTextures()
 
 vtkStandardNewMacro(vtkOpenGLState);
 
+void vtkOpenGLState::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "MajorVersion: " << this->MajorVersion << endl;
+  os << indent << "MinorVersion: " << this->MinorVersion << endl;
+  os << indent << "MaxTextureSize: " << this->MaxTextureSize << endl;
+  os << indent << "Vendor: " << this->Vendor << endl;
+  os << indent << "Renderer: " << this->Renderer << endl;
+  os << indent << "Version: " << this->Version << endl;
+}
+
 vtkCxxSetObjectMacro(vtkOpenGLState, VBOCache, vtkOpenGLVertexBufferObjectCache);
 
 // initialize all state values. This is important so that in
@@ -2007,7 +2035,8 @@ int vtkOpenGLState::GetDefaultTextureInternalFormat(
   // 0 = none
   // 1 = float
   // 2 = int
-  if (vtktype >= VTK_UNICODE_STRING)
+  int dtypeCount = sizeof(this->TextureInternalFormats) / sizeof(this->TextureInternalFormats[0]);
+  if (vtktype >= dtypeCount)
   {
     return 0;
   }
@@ -2059,11 +2088,12 @@ void vtkOpenGLState::InitializeTextureInternalFormats()
   // 2 = int
 
   // initialize to zero
-  for (int dtype = 0; dtype < VTK_UNICODE_STRING; dtype++)
+  int dtypeCount = sizeof(this->TextureInternalFormats) / sizeof(this->TextureInternalFormats[0]);
+  for (int dtype = 0; dtype < dtypeCount; dtype++)
   {
     for (int ctype = 0; ctype < 3; ctype++)
     {
-      for (int comp = 0; comp <= 4; comp++)
+      for (int comp = 0; comp < 5; comp++)
       {
         this->TextureInternalFormats[dtype][ctype][comp] = 0;
       }
@@ -2161,3 +2191,4 @@ void vtkOpenGLState::InitializeTextureInternalFormats()
   this->TextureInternalFormats[VTK_SHORT][1][4] = GL_RGBA32F;
 #endif
 }
+VTK_ABI_NAMESPACE_END
