@@ -71,6 +71,7 @@
 #include <stack>                       // for ivar
 #include <string>                      // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLFramebufferObject;
 class vtkOpenGLRenderWindow;
 class vtkOpenGLShaderCache;
@@ -83,8 +84,9 @@ class VTKRENDERINGOPENGL2_EXPORT vtkOpenGLState : public vtkObject
 public:
   static vtkOpenGLState* New();
   vtkTypeMacro(vtkOpenGLState, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   // cached OpenGL methods. By calling these the context will check
   // the current value prior to making the OpenGL call. This can reduce
   // the burden on the driver.
@@ -129,9 +131,9 @@ public:
   void vtkReadBuffer(unsigned int, vtkOpenGLFramebufferObject*);
 
   void vtkglPixelStorei(unsigned int, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   // Methods to reset the state to the current OpenGL context value.
   // These methods are useful when interfacing with third party code
   // that may have changed the opengl state.
@@ -147,22 +149,22 @@ public:
   void ResetGLBlendEquationState();
   void ResetGLCullFaceState();
   void ResetGLActiveTexture();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   // OpenGL functions that we provide an API for even though they may
   // not hold any state.
   void vtkglClear(unsigned int mask);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   // Get methods that can be used to query state if the state is not cached
   // they fall through and call the underlying opengl functions
   void vtkglGetBooleanv(unsigned int pname, unsigned char* params);
   void vtkglGetIntegerv(unsigned int pname, int* params);
   void vtkglGetDoublev(unsigned int pname, double* params);
   void vtkglGetFloatv(unsigned int pname, float* params);
-  //@}
+  ///@}
 
   // convenience to get all 4 values at once
   void GetBlendFuncState(int*);
@@ -215,7 +217,7 @@ public:
    */
   void VerifyNoActiveTextures();
 
-  //@{
+  ///@{
   /**
    * Store/Restore the current framebuffer bindings and buffers.
    */
@@ -236,7 +238,7 @@ public:
   void PopReadFramebufferBinding();
 
   void ResetFramebufferBindings();
-  //@}
+  ///@}
 
   // Scoped classes you can use to save state
   class VTKRENDERINGOPENGL2_EXPORT ScopedglDepthMask : public ScopedValue<unsigned char>
@@ -345,6 +347,12 @@ public:
    */
   void GetCurrentDrawFramebufferState(unsigned int& drawBinding, unsigned int& drawBuffer);
 
+  /**
+   * Perform a blit but handle some driver bugs safely. Use this instead of directly calling
+   * glBlitFramebuffer.
+   */
+  void vtkglBlitFramebuffer(int, int, int, int, int, int, int, int, unsigned int, unsigned int);
+
   /**
    * Record the OpenGL state into this class. Lots of get calls so probably
    * a pipeline stall. This method is most useful when integrating VTK with
@@ -400,7 +408,7 @@ protected:
   void Scissor(std::array<int, 4> val);
   void Viewport(std::array<int, 4> val);
 
-  int TextureInternalFormats[VTK_UNICODE_STRING][3][5];
+  int TextureInternalFormats[VTK_OBJECT + 1][3][5];
   void InitializeTextureInternalFormats();
 
   vtkTextureUnitManager* TextureUnitManager;
@@ -476,6 +484,8 @@ protected:
     bool CubeMapSeamless;
     bool LineSmooth;
     int BoundVAO;
+    int BoundArrayBuffer;
+    int BoundElementArrayBuffer;
     int BoundProgram;
     BufferBindingState DrawBinding;
     BufferBindingState ReadBinding;
@@ -492,6 +502,5 @@ private:
   void operator=(const vtkOpenGLState&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkOpenGLState.h
