@@ -39,6 +39,7 @@ PURPOSE.  See the above copyright notice for more information.
 // the 2D blending shaders we use
 #include "vtkOrderIndependentTranslucentPassFinalFS.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOrderIndependentTranslucentPass);
 vtkCxxSetObjectMacro(vtkOrderIndependentTranslucentPass, TranslucentPass, vtkRenderPass);
 
@@ -285,7 +286,7 @@ void vtkOrderIndependentTranslucentPass::Render(const vtkRenderState* s)
 
   // bind the draw mode but leave read as the previous FO
   this->State->PushFramebufferBindings();
-  this->Framebuffer->Bind(this->Framebuffer->GetDrawMode());
+  this->Framebuffer->Bind(vtkOpenGLFramebufferObject::GetDrawMode());
   this->Framebuffer->ActivateDrawBuffers(2);
 
 #ifdef GL_MULTISAMPLE
@@ -307,9 +308,9 @@ void vtkOrderIndependentTranslucentPass::Render(const vtkRenderState* s)
   this->State->vtkglColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 #else
   // blit read buffer depth to FO depth texture
-  glBlitFramebuffer(this->ViewportX, this->ViewportY, this->ViewportX + this->ViewportWidth,
-    this->ViewportY + this->ViewportHeight, 0, 0, this->ViewportWidth, this->ViewportHeight,
-    GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+  this->State->vtkglBlitFramebuffer(this->ViewportX, this->ViewportY,
+    this->ViewportX + this->ViewportWidth, this->ViewportY + this->ViewportHeight, 0, 0,
+    this->ViewportWidth, this->ViewportHeight, GL_DEPTH_BUFFER_BIT, GL_NEAREST);
 #endif
 
   // now bind both read and draw
@@ -391,3 +392,4 @@ bool vtkOrderIndependentTranslucentPass::PostReplaceShaderValues(
 
   return true;
 }
+VTK_ABI_NAMESPACE_END
