@@ -29,6 +29,7 @@
 #include <sstream>
 #include <vtksys/SystemTools.hxx>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
@@ -405,7 +406,7 @@ bool vtkShaderProgram::Bind()
       else
       {
         vtksys::ofstream ofp(fname.c_str());
-        ofp << shaders[cc]->GetSource().c_str();
+        ofp << shaders[cc]->GetSource();
       }
     }
     this->CompileShader();
@@ -977,3 +978,4 @@ void vtkShaderProgram::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "FileNamePrefixForDebugging: "
      << (this->FileNamePrefixForDebugging ? this->FileNamePrefixForDebugging : "(null)") << endl;
 }
+VTK_ABI_NAMESPACE_END
