@@ -46,6 +46,7 @@
 #include "vtkSmartPointer.h"           // for ivars
 #include <vector>                      // STL Header
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLRenderWindow;
 class vtkInformationIntegerKey;
 class vtkCamera;
@@ -73,7 +74,7 @@ public:
    */
   void ReleaseGraphicsResources(vtkWindow* w) override;
 
-  //@{
+  ///@{
   /**
    * Delegate for rendering the camera, lights, and opaque geometry.
    * If it is NULL, nothing will be rendered and a warning will be emitted.
@@ -82,9 +83,9 @@ public:
    */
   vtkGetObjectMacro(OpaqueSequence, vtkRenderPass);
   virtual void SetOpaqueSequence(vtkRenderPass* opaqueSequence);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Delegate for compositing of the shadow maps across processors.
    * If it is NULL, there is no z compositing.
@@ -93,9 +94,9 @@ public:
    */
   vtkGetObjectMacro(CompositeZPass, vtkRenderPass);
   virtual void SetCompositeZPass(vtkRenderPass* compositeZPass);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the number of pixels in each dimension of the shadow maps
    * (shadow maps are square). Initial value is 256. The greater the better.
@@ -103,7 +104,7 @@ public:
    */
   vtkSetMacro(Resolution, unsigned int);
   vtkGetMacro(Resolution, unsigned int);
-  //@}
+  ///@}
 
   /**
    * INTERNAL USE ONLY.
@@ -137,7 +138,7 @@ public:
    * INTERNAL USE ONLY.
    * Internally used by vtkShadowMapBakerPass and vtkShadowMapPass.
 
-   * Give access the cameras builds from the ligths.
+   * Give access the cameras builds from the lights.
    */
   std::vector<vtkSmartPointer<vtkCamera>>* GetLightCameras();
 
@@ -231,4 +232,5 @@ private:
   void operator=(const vtkShadowMapBakerPass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
