@@ -45,6 +45,7 @@
 #include "vtkSobelGradientMagnitudePass2FS.h"
 #include "vtkTextureObjectVS.h" // a pass through shader
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSobelGradientMagnitudePass);
 
 //------------------------------------------------------------------------------
@@ -272,7 +273,7 @@ void vtkSobelGradientMagnitudePass::Render(const vtkRenderState* s)
   glFinish();
 #endif
 
-  if (!this->Program1->Program || this->Program1->Program->GetCompiled() != true)
+  if (!this->Program1->Program || !this->Program1->Program->GetCompiled())
   {
     vtkErrorMacro("Couldn't build the shader program. At this point , it can be an error in a "
                   "shader or a driver bug.");
@@ -365,6 +366,7 @@ void vtkSobelGradientMagnitudePass::Render(const vtkRenderState* s)
 
   // 4. Render in original FB (from renderstate in arg)
 
+  this->FrameBufferObject->RemoveColorAttachments(2);
   ostate->PopFramebufferBindings();
 
   // has something changed that would require us to recreate the shaders?
@@ -400,7 +402,7 @@ void vtkSobelGradientMagnitudePass::Render(const vtkRenderState* s)
   glFinish();
 #endif
 
-  if (!this->Program2->Program || this->Program2->Program->GetCompiled() != true)
+  if (!this->Program2->Program || !this->Program2->Program->GetCompiled())
   {
     vtkErrorMacro("Couldn't build the shader program. At this point , it can be an error in a "
                   "shader or a driver bug.");
@@ -507,3 +509,4 @@ void vtkSobelGradientMagnitudePass::ReleaseGraphicsResources(vtkWindow* w)
     this->Gy1 = nullptr;
   }
 }
+VTK_ABI_NAMESPACE_END
