@@ -47,6 +47,7 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkValuePass::Parameters
 {
   Parameters()
@@ -659,7 +660,7 @@ void vtkValuePass::ReleaseFBO(vtkWindow* win)
 
   win->MakeCurrent();
 
-  // Cleanup FBO (grahpics resources cleaned internally)
+  // Cleanup FBO (graphics resources cleaned internally)
   this->ImplFloat->ValueFBO->Delete();
   this->ImplFloat->ValueFBO = nullptr;
 
@@ -1061,3 +1062,4 @@ vtkAbstractArray* vtkValuePass::GetArrayFromCompositeData(vtkMapper* mapper, Par
 
   return abstractArray;
 }
+VTK_ABI_NAMESPACE_END
