@@ -42,11 +42,11 @@
 #ifndef vtkValuePass_h
 #define vtkValuePass_h
 
-#include "vtkDeprecation.h" // for VTK_DEPRECATED_IN_9_0_0
 #include "vtkOpenGLRenderPass.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include "vtkSmartPointer.h"           //for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkActor;
 class vtkDataArray;
@@ -72,17 +72,9 @@ public:
   vtkTypeMacro(vtkValuePass, vtkOpenGLRenderPass);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  // @deprecated As of 9.0, We are moving to only FLOATING_POINT.
-  VTK_DEPRECATED_IN_9_0_0("Removed in 9.0 (only FLOATING_POINT is supported)")
-  vtkSetMacro(RenderingMode, int);
-  VTK_DEPRECATED_IN_9_0_0("Removed in 9.0 (only FLOATING_POINT is supported)")
-  vtkGetMacro(RenderingMode, int);
   void SetInputArrayToProcess(int fieldAssociation, const char* name);
   void SetInputArrayToProcess(int fieldAssociation, int fieldId);
   void SetInputComponentToProcess(int component);
-  // @deprecated As of 9.0, Not needed with FLOATING_POINT.
-  VTK_DEPRECATED_IN_9_0_0("Removed in 9.0 (only FLOATING_POINT is supported)")
-  void SetScalarRange(double min, double max);
 
   /**
    * Perform rendering according to a render state \p s.
@@ -110,24 +102,8 @@ public:
    */
   int* GetFloatImageExtents();
 
-  /**
-   * Check for extension support.
-   * @deprecated As of 9.0, All platforms support FLOATING_POINT.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Removed in 9.0 (only FLOATING_POINT is supported)")
-  bool IsFloatingPointModeSupported();
-
   void ReleaseGraphicsResources(vtkWindow* win) override;
 
-  /**
-   * Convert an RGB triplet to a floating point value. This method is exposed
-   * as a convenience function for testing (TestValuePass2).
-   * @deprecated As of 9.0, not necessary with FLOATING_POINT.
-   */
-  VTK_DEPRECATED_IN_9_0_0("Removed in 9.0 (only FLOATING_POINT is supported)")
-  void ColorToValue(
-    unsigned char const* color, double const min, double const scale, double& value);
-
 protected:
   vtkValuePass();
   ~vtkValuePass() override;
@@ -138,7 +114,7 @@ protected:
    */
 
   /**
-   * Use vtkShaderProgram::Substitute to replace //VTK::XXX:YYY declarations in
+   * Use vtkShaderProgram::Substitute to replace @code //VTK::XXX:YYY @endcode declarations in
    * the shader sources. Gets called after other mapper shader replacements.
    * Return false on error.
    */
@@ -211,14 +187,14 @@ protected:
   void BindAttributes(vtkShaderProgram* prog, vtkOpenGLVertexArrayObject* VAO);
   void BindUniforms(vtkShaderProgram* prog);
 
-  //@{
+  ///@{
   /**
    * Methods managing graphics resources required during FLOATING_POINT mode.
    */
   bool HasWindowSizeChanged(vtkRenderer* ren);
   bool InitializeFBO(vtkRenderer* ren);
   void ReleaseFBO(vtkWindow* win);
-  //@}
+  ///@}
 
   class vtkInternalsFloat;
   vtkInternalsFloat* ImplFloat;
@@ -244,4 +220,5 @@ private:
   void operator=(const vtkValuePass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
