@@ -13,8 +13,11 @@
 
 =========================================================================*/
 
-#include "vtkXOpenGLRenderWindow.h"
+// Must be included first to avoid conflicts with X11's `Status` define.
+#include "vtksys/SystemTools.hxx"
+
 #include "vtkOpenGLRenderer.h"
+#include "vtkXOpenGLRenderWindow.h"
 
 #include "vtk_glew.h"
 // Define GLX_GLXEXT_LEGACY to prevent glx.h from including the glxext.h
@@ -57,8 +60,6 @@ typedef ptrdiff_t GLsizeiptr;
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRendererCollection.h"
 #include "vtkStringOutputWindow.h"
-#include "vtkToolkits.h"
-#include "vtksys/SystemTools.hxx"
 
 #include <sstream>
 
@@ -75,6 +76,7 @@ typedef ptrdiff_t GLsizeiptr;
  * structs working. We do not want to include XUtil.h in the header as
  * it populates the global namespace.
  */
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkXVisualInfo : public XVisualInfo
 {
 };
@@ -804,7 +806,7 @@ void vtkXOpenGLRenderWindow::DestroyWindow()
 }
 
 // Initialize the window for rendering.
-void vtkXOpenGLRenderWindow::WindowInitialize(void)
+void vtkXOpenGLRenderWindow::WindowInitialize()
 {
   this->CreateAWindow();
 
@@ -822,7 +824,7 @@ void vtkXOpenGLRenderWindow::WindowInitialize(void)
 }
 
 // Initialize the rendering window.
-void vtkXOpenGLRenderWindow::Initialize(void)
+void vtkXOpenGLRenderWindow::Initialize()
 {
   if (!this->Internal->ContextId)
   {
@@ -831,7 +833,7 @@ void vtkXOpenGLRenderWindow::Initialize(void)
   }
 }
 
-void vtkXOpenGLRenderWindow::Finalize(void)
+void vtkXOpenGLRenderWindow::Finalize()
 {
   // clean and destroy window
   this->DestroyWindow();
@@ -935,7 +937,7 @@ void vtkXOpenGLRenderWindow::WindowRemap()
 }
 
 // Begin the rendering process.
-void vtkXOpenGLRenderWindow::Start(void)
+void vtkXOpenGLRenderWindow::Start()
 {
   this->Initialize();
 
@@ -1106,6 +1108,15 @@ void vtkXOpenGLRenderWindow::MakeCurrent()
   }
 }
 
+void vtkXOpenGLRenderWindow::ReleaseCurrent()
+{
+  if (this->Internal->ContextId && (this->Internal->ContextId == glXGetCurrentContext()) &&
+    this->DisplayId)
+  {
+    glXMakeCurrent(this->DisplayId, None, nullptr);
+  }
+}
+
 //------------------------------------------------------------------------------
 // Description:
 // Tells if this window is the current OpenGL context for the calling thread.
@@ -1176,6 +1187,11 @@ void* vtkXOpenGLRenderWindow::GetGenericContext()
   return static_cast<void*>(gc);
 }
 
+void* vtkXOpenGLRenderWindow::GetGenericFBConfig()
+{
+  return reinterpret_cast<void*>(&(this->Internal->FBConfig));
+}
+
 vtkTypeBool vtkXOpenGLRenderWindow::GetEventPending()
 {
   XEvent report;
@@ -1216,7 +1232,7 @@ int* vtkXOpenGLRenderWindow::GetScreenSize()
 }
 
 // Get the position in screen coordinates (pixels) of the window.
-int* vtkXOpenGLRenderWindow::GetPosition(void)
+int* vtkXOpenGLRenderWindow::GetPosition()
 {
   XWindowAttributes attribs;
   int x, y;
@@ -1450,9 +1466,11 @@ void vtkXOpenGLRenderWindow::CloseDisplay()
   if (this->OwnDisplay && this->DisplayId)
   {
     XCloseDisplay(this->DisplayId);
-    this->DisplayId = nullptr;
-    this->OwnDisplay = 0;
   }
+
+  // disconnect from the display, even if we didn't own it
+  this->DisplayId = nullptr;
+  this->OwnDisplay = false;
 }
 
 vtkTypeBool vtkXOpenGLRenderWindow::IsDirect()
@@ -1743,3 +1761,4 @@ void vtkXOpenGLRenderWindow::SetCurrentCursor(int shape)
       break;
   }
 }
+VTK_ABI_NAMESPACE_END
