@@ -25,11 +25,13 @@
 #ifndef vtkXOpenGLRenderWindow_h
 #define vtkXOpenGLRenderWindow_h
 
+#include "vtkDeprecation.h" // For VTK_DEPRECATED_IN_9_3_0
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include <X11/Xlib.h>                  // Needed for X types used in the public interface
 #include <stack>                       // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkXOpenGLRenderWindowInternal;
 struct vtkXVisualInfo;
@@ -104,9 +106,10 @@ public:
    * Specify the size of the rendering window in pixels but do not resize
    * the XWindow. Useful when resizing is done interactively.
    */
+  VTK_DEPRECATED_IN_9_3_0("Use vtkRenderWindow::SetSize(w,h) instead")
   void SetSizeNoXResize(int, int);
 
-  //@{
+  ///@{
   /**
    * Get the X properties of an ideal rendering window.
    */
@@ -114,7 +117,7 @@ public:
   virtual Visual* GetDesiredVisual();
   virtual vtkXVisualInfo* GetDesiredVisualInfo();
   virtual int GetDesiredDepth();
-  //@}
+  ///@}
 
   /**
    * Prescribe that the window be created in a stereo-capable mode. This
@@ -134,6 +137,11 @@ public:
    */
   bool IsCurrent() override;
 
+  /**
+   * Release the current context.
+   */
+  void ReleaseCurrent() override;
+
   /**
    * If called, allow MakeCurrent() to skip cache-check when called.
    * MakeCurrent() reverts to original behavior of cache-checking
@@ -162,6 +170,8 @@ public:
   void* GetGenericContext() override;
   void* GetGenericDrawable() override { return reinterpret_cast<void*>(this->WindowId); }
 
+  void* GetGenericFBConfig();
+
   /**
    * Get the current size of the screen in pixels.
    * An HDTV for example would be 1920 x 1080 pixels.
@@ -179,40 +189,40 @@ public:
    */
   Display* GetDisplayId();
 
-  //@{
+  ///@{
   /**
    * Set the X display id for this RenderWindow to use to a pre-existing
    * X display id.
    */
   void SetDisplayId(Display*);
   void SetDisplayId(void*) override;
-  //@}
+  ///@}
 
   /**
    * Get this RenderWindow's parent X window id.
    */
   Window GetParentId();
 
-  //@{
+  ///@{
   /**
    * Sets the parent of the window that WILL BE created.
    */
   void SetParentId(Window);
   void SetParentId(void*) override;
-  //@}
+  ///@}
 
   /**
    * Get this RenderWindow's X window id.
    */
   Window GetWindowId();
 
-  //@{
+  ///@{
   /**
    * Set this RenderWindow's X window id to a pre-existing window.
    */
   void SetWindowId(Window);
   void SetWindowId(void*) override;
-  //@}
+  ///@}
 
   /**
    * Specify the X window id to use if a WindowRemap is done.
@@ -248,7 +258,7 @@ public:
    */
   bool GetPlatformSupportsRenderWindowSharing() override { return true; }
 
-  //@{
+  ///@{
   /**
    * Set the position (x and y) of the rendering window in
    * screen coordinates (in pixels). This resizes the operating
@@ -256,16 +266,16 @@ public:
    */
   void SetPosition(int x, int y) override;
   void SetPosition(int a[2]) override { this->SetPosition(a[0], a[1]); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Hide or Show the mouse cursor, it is nice to be able to hide the
    * default cursor if you want VTK to display a 3D cursor instead.
    */
   void HideCursor() override;
   void ShowCursor() override;
-  //@}
+  ///@}
 
   /**
    * Change the shape of the cursor
@@ -300,7 +310,7 @@ public:
    */
   void Render() override;
 
-  //@{
+  ///@{
   /**
    * Ability to push and pop this window's context
    * as the current context. The idea being to
@@ -310,7 +320,7 @@ public:
    */
   void PushContext() override;
   void PopContext() override;
-  //@}
+  ///@}
 
   /**
    * Set the number of vertical syncs required between frames.
@@ -366,4 +376,5 @@ private:
   void operator=(const vtkXOpenGLRenderWindow&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
