@@ -16,20 +16,20 @@
  * @brief   OpenVR overlay
  *
  * vtkOpenVRDefaultOverlay support for VR overlays
-*/
+ */
 
 #ifndef vtkOpenVRDefaultOverlay_h
 #define vtkOpenVRDefaultOverlay_h
 
-#include "vtkRenderingOpenVRModule.h" // For export macro
 #include "vtkOpenVROverlay.h"
+#include "vtkRenderingOpenVRModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGOPENVR_EXPORT vtkOpenVRDefaultOverlay : public vtkOpenVROverlay
 {
 public:
-  static vtkOpenVRDefaultOverlay *New();
+  static vtkOpenVRDefaultOverlay* New();
   vtkTypeMacro(vtkOpenVRDefaultOverlay, vtkOpenVROverlay);
-  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Render the overlay, we set some opf the spots based on current settings
@@ -37,8 +37,8 @@ public:
   void Render() override;
 
 protected:
-  vtkOpenVRDefaultOverlay();
-  ~vtkOpenVRDefaultOverlay();
+  vtkOpenVRDefaultOverlay() = default;
+  ~vtkOpenVRDefaultOverlay() override = default;
 
   void SetupSpots() override;
 
@@ -47,4 +47,5 @@ private:
   void operator=(const vtkOpenVRDefaultOverlay&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
