@@ -13,18 +13,13 @@
 =========================================================================*/
 #include "vtkOpenVROverlay.h"
 
-#include "vtkCallbackCommand.h"
 #include "vtkDataArray.h"
 #include "vtkImageData.h"
-#include "vtkInteractorStyle3D.h"
 #include "vtkJPEGReader.h"
-#include "vtkNew.h"
 #include "vtkObjectFactory.h"
-#include "vtkOpenVRCamera.h"
+#include "vtkOpenVROverlayInternal.h"
 #include "vtkOpenVRRenderWindow.h"
-#include "vtkOpenVRRenderWindowInteractor.h"
 #include "vtkPointData.h"
-#include "vtkRenderer.h"
 #include "vtkRendererCollection.h"
 #include "vtkTextureObject.h"
 #include "vtkXMLDataElement.h"
@@ -32,12 +27,9 @@
 #include "vtksys/FStream.hxx"
 #include "vtksys/SystemTools.hxx"
 
-#include "vtkOpenVROverlayInternal.h"
-
 #include "OpenVRDashboard.h"
 
-#include <cmath>
-
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenVROverlay);
 
 vtkOpenVROverlay::vtkOpenVROverlay()
@@ -60,12 +52,12 @@ vtkOpenVROverlay::~vtkOpenVROverlay()
   if (this->OriginalTextureData)
   {
     delete[] this->OriginalTextureData;
-    this->OriginalTextureData = 0;
+    this->OriginalTextureData = nullptr;
   }
   if (this->CurrentTextureData)
   {
     delete[] this->CurrentTextureData;
-    this->CurrentTextureData = 0;
+    this->CurrentTextureData = nullptr;
   }
 }
 
@@ -148,9 +140,9 @@ void vtkOpenVROverlay::ReadCameraPoses(vtkXMLDataElement* topel)
   if (topel)
   {
     int numPoses = topel->GetNumberOfNestedElements();
-    for (size_t i = 0; i < numPoses; i++)
+    for (int i = 0; i < numPoses; i++)
     {
-      vtkXMLDataElement* el = topel->GetNestedElement(static_cast<int>(i));
+      vtkXMLDataElement* el = topel->GetNestedElement(i);
       int poseNum = 0;
       el->GetScalarAttribute("PoseNumber", poseNum);
       el->GetVectorAttribute("Position", 3, this->SavedCameraPoses[poseNum].Position);
@@ -197,7 +189,7 @@ void vtkOpenVROverlay::LoadCameraPose(int slot)
 
 void vtkOpenVROverlay::LoadNextCameraPose()
 {
-  if (this->SavedCameraPoses.size() == 0)
+  if (this->SavedCameraPoses.empty())
   {
     return;
   }
@@ -292,7 +284,7 @@ void vtkOpenVROverlay::Create(vtkOpenVRRenderWindow* win)
   if (this->OriginalTextureData)
   {
     delete[] this->OriginalTextureData;
-    this->OriginalTextureData = 0;
+    this->OriginalTextureData = nullptr;
   }
 
   // if dashboard image exists use it
@@ -330,7 +322,7 @@ void vtkOpenVROverlay::Create(vtkOpenVRRenderWindow* win)
   }
   memcpy(this->CurrentTextureData, this->OriginalTextureData, dims[0] * dims[1] * 4);
   this->OverlayTexture->Create2DFromRaw(dims[0], dims[1], 4, VTK_UNSIGNED_CHAR,
-    const_cast<void*>(static_cast<const void* const>(this->OriginalTextureData)));
+    const_cast<void*>(static_cast<const void*>(this->OriginalTextureData)));
 
   this->SetupSpots();
 
@@ -355,7 +347,7 @@ void vtkOpenVROverlay::Render()
   dims[0] = this->OverlayTexture->GetWidth();
   dims[1] = this->OverlayTexture->GetHeight();
   this->OverlayTexture->Create2DFromRaw(dims[0], dims[1], 4, VTK_UNSIGNED_CHAR,
-    const_cast<void*>(static_cast<const void* const>(this->CurrentTextureData)));
+    const_cast<void*>(static_cast<const void*>(this->CurrentTextureData)));
   this->OverlayTexture->Bind();
   GLuint unTexture = this->OverlayTexture->GetHandle();
   if (unTexture != 0)
@@ -470,3 +462,4 @@ void vtkOpenVROverlay::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
