@@ -11,7 +11,7 @@ This software is distributed WITHOUT ANY WARRANTY; without even
 the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the above copyright notice for more information.
 
-Parts Copyright Valve Coproration from hellovr_opengl_main.cpp
+Parts Copyright Valve Corporation from hellovr_opengl_main.cpp
 under their BSD license found here:
 https://github.com/ValveSoftware/openvr/blob/master/LICENSE
 
@@ -22,6 +22,7 @@ https://github.com/ValveSoftware/openvr/blob/master/LICENSE
 #include "vtkObjectFactory.h"
 #include "vtkOpenVRCamera.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenVRRenderer);
 
 //------------------------------------------------------------------------------
@@ -31,3 +32,4 @@ vtkCamera* vtkOpenVRRenderer::MakeCamera()
   this->InvokeEvent(vtkCommand::CreateCameraEvent, cam);
   return cam;
 }
+VTK_ABI_NAMESPACE_END
