@@ -18,6 +18,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkOpenXRRenderWindowInteractor.h"
 
 // Map controller inputs to interaction states
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenXRInteractorStyle);
 
 //------------------------------------------------------------------------------
@@ -27,11 +28,14 @@ void vtkOpenXRInteractorStyle::SetupActions(vtkRenderWindowInteractor* iren)
 
   if (oiren)
   {
-    oiren->AddAction("startmovement", vtkCommand::ViewerMovement3DEvent);
+    oiren->AddAction("elevation", vtkCommand::ViewerMovement3DEvent);
     oiren->AddAction("movement", vtkCommand::ViewerMovement3DEvent);
     oiren->AddAction("nextcamerapose", vtkCommand::NextPose3DEvent);
-    oiren->AddAction("triggeraction", vtkCommand::Select3DEvent);
     oiren->AddAction("positionprop", vtkCommand::PositionProp3DEvent);
     oiren->AddAction("showmenu", vtkCommand::Menu3DEvent);
+    oiren->AddAction("startelevation", vtkCommand::ViewerMovement3DEvent);
+    oiren->AddAction("startmovement", vtkCommand::ViewerMovement3DEvent);
+    oiren->AddAction("triggeraction", vtkCommand::Select3DEvent);
   }
 }
+VTK_ABI_NAMESPACE_END
