@@ -28,6 +28,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include <atomic> // for ivars
 #include <vector> // for ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGOPENXR_EXPORT vtkOpenXRModel : public vtkVRModel
 {
 public:
@@ -43,8 +44,8 @@ protected:
   void CreateTextureObject(vtkOpenGLRenderWindow* win) override;
   void LoadModelAndTexture(vtkOpenGLRenderWindow* win) override;
 
-  std::atomic<bool> ModelLoading = false;
-  std::atomic<bool> ModelLoaded = false;
+  std::atomic<bool> ModelLoading{ false };
+  std::atomic<bool> ModelLoaded{ false };
   void AsyncLoad();
 
   std::vector<float> ModelVBOData;
@@ -56,4 +57,5 @@ private:
   void operator=(const vtkOpenXRModel&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
