@@ -53,10 +53,10 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkVRRenderWindow.h"
 
 #include "vtkEventData.h" // for method sig
-#include "vtkOpenXR.h"
 
 #include <array> // array
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMatrix4x4;
 
 class VTKRENDERINGOPENXR_EXPORT vtkOpenXRRenderWindow : public vtkVRRenderWindow
@@ -98,9 +98,7 @@ public:
    * application's rendering. Avoiding round trip.
    */
   void Render() override;
-  //@}
 
-  //@{
   /**
    * Initialize the rendering window.  This will setup all system-specific
    * resources.  This method and Finalize() must be symmetric and it
@@ -133,19 +131,10 @@ public:
    */
   vtkTypeBool GetEventPending() override { return 0; }
 
-  //@{
-  /**
-   * True if the window has been initialized successfully.
-   */
-  vtkGetMacro(Initialized, bool);
-  //@}
-
-  //@{
   /**
    * Set the active state (active: true / inactive: false) of the specified hand.
    */
   void SetModelActiveState(const int hand, bool state) { this->ModelsActiveState[hand] = state; }
-  //@}
 
   uint32_t GetDeviceHandleForOpenXRHandle(uint32_t index);
   vtkEventDataDevice GetDeviceForOpenXRHandle(uint32_t ohandle);
@@ -167,7 +156,7 @@ protected:
   bool BindTextureToFramebuffer(FramebufferDesc& framebufferDesc);
   void RenderFramebuffer(FramebufferDesc& framebufferDesc);
 
-  void RenderOneEye(const uint32_t eye);
+  virtual void RenderOneEye(uint32_t eye);
 
   void RenderModels();
 
@@ -182,5 +171,6 @@ private:
   void operator=(const vtkOpenXRRenderWindow&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkOpenXRRenderWindow.h
