@@ -33,6 +33,7 @@
 
 typedef vtkOpenXRManager::Action_t Action_t;
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGOPENXR_EXPORT vtkOpenXRRenderWindowInteractor : public vtkVRRenderWindowInteractor
 {
 public:
@@ -51,16 +52,16 @@ public:
    * and the hand \p hand or return nullptr if "handpose"
    * does not exist in the map.
    */
-  XrPosef* GetHandPose(const uint32_t hand);
+  XrPosef* GetHandPose(uint32_t hand);
 
-  //@{
+  ///@{
   /**
    * Assign an event or std::function to an event path.
    * Called by the interactor style for specific actions
    */
   void AddAction(const std::string& path, const vtkCommand::EventIds&);
   void AddAction(const std::string& path, const std::function<void(vtkEventData*)>&);
-  //@}
+  ///@}
   // add an event action
 
   void ConvertOpenXRPoseToWorldCoordinates(const XrPosef& xrPose,
@@ -69,6 +70,14 @@ public:
     double ppos[3],  // Output physical position
     double wdir[3]); // Output world view direction (-Z)
 
+  /**
+   * Apply haptic vibration using the provided action
+   * \p action to emit vibration on \p hand to emit on \p amplitude 0.0 to 1.0.
+   * \p duration nanoseconds, default 25ms \p frequency (hz)
+   */
+  bool ApplyVibration(const std::string& actionName, const int hand, const float amplitude = 0.5f,
+    const float duration = 25000000.0f, const float frequency = XR_FREQUENCY_UNSPECIFIED);
+
 protected:
   vtkOpenXRRenderWindowInteractor();
   ~vtkOpenXRRenderWindowInteractor() override;
@@ -123,5 +132,6 @@ private:
   void operator=(const vtkOpenXRRenderWindowInteractor&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkOpenXRRenderWindowInteractor.h
