@@ -34,6 +34,7 @@
 #include "vtkRenderPass.h"
 #include "vtkRenderingParallelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController;
 
 class vtkPixelBufferObject;
@@ -61,7 +62,7 @@ public:
    */
   void ReleaseGraphicsResources(vtkWindow* w) override;
 
-  //@{
+  ///@{
   /**
    * Controller
    * If it is NULL, nothing will be rendered and a warning will be emitted.
@@ -69,7 +70,7 @@ public:
    */
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
   virtual void SetController(vtkMultiProcessController* controller);
-  //@}
+  ///@}
 
   /**
    * Is the pass supported by the OpenGL context?
@@ -108,4 +109,5 @@ private:
   void operator=(const vtkCompositeZPass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
