@@ -18,9 +18,9 @@
 #include "vtkFloatArray.h"
 #include "vtkMultiProcessController.h"
 #include "vtkObjectFactory.h"
-#include "vtkToolkits.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCompositer);
 
 //------------------------------------------------------------------------------
@@ -44,20 +44,12 @@ vtkCompositer::~vtkCompositer()
 //------------------------------------------------------------------------------
 void vtkCompositer::SetController(vtkMultiProcessController* mpc)
 {
-  if (this->Controller == mpc)
-  {
-    return;
-  }
+  vtkSetObjectBodyMacro(Controller, vtkMultiProcessController, mpc);
+
   if (mpc)
   {
-    mpc->Register(this);
     this->NumberOfProcesses = mpc->GetNumberOfProcesses();
   }
-  if (this->Controller)
-  {
-    this->Controller->UnRegister(this);
-  }
-  this->Controller = mpc;
 }
 
 //------------------------------------------------------------------------------
@@ -140,3 +132,4 @@ void vtkCompositer::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Controller: (" << this->Controller << ")\n";
   os << indent << "NumberOfProcesses: " << this->NumberOfProcesses << endl;
 }
+VTK_ABI_NAMESPACE_END
