@@ -47,6 +47,7 @@
 #include "vtkObject.h"
 #include "vtkRenderingParallelModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDoubleArray;
 class vtkMultiProcessController;
 class vtkMultiProcessStream;
@@ -79,23 +80,23 @@ public:
    */
   virtual vtkRenderer* MakeRenderer();
 
-  //@{
+  ///@{
   /**
    * Set/Get the RenderWindow to use for compositing.
    * We add a start and end observer to the window.
    */
   vtkGetObjectMacro(RenderWindow, vtkRenderWindow);
   virtual void SetRenderWindow(vtkRenderWindow* renWin);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the vtkMultiProcessController which will handle communications
    * for the parallel rendering.
    */
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
   virtual void SetController(vtkMultiProcessController* controller);
-  //@}
+  ///@}
 
   /**
    * This method sets the piece and number of pieces for each
@@ -131,7 +132,7 @@ public:
    */
   virtual void StopServices();
 
-  //@{
+  ///@{
   /**
    * Callbacks that initialize and finish rendering and other tasks.
    */
@@ -143,7 +144,7 @@ public:
   virtual void ResetCamera(vtkRenderer* ren);
   virtual void ResetCameraClippingRange(vtkRenderer* ren);
   virtual void ComputeVisiblePropBoundsRMI(int renderId);
-  //@}
+  ///@}
 
   virtual void InitializeRMIs();
 
@@ -159,7 +160,7 @@ public:
    */
   virtual void ComputeVisiblePropBounds(vtkRenderer* ren, double bounds[6]);
 
-  //@{
+  ///@{
   /**
    * Turns on/off parallel rendering.  When on (the default) the object
    * responds to render events of the attached window, propagates the
@@ -169,9 +170,9 @@ public:
   vtkSetMacro(ParallelRendering, int);
   vtkGetMacro(ParallelRendering, int);
   vtkBooleanMacro(ParallelRendering, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turns on/off render event propagation.  When on (the default) and
    * ParallelRendering is on, process 0 will send an RMI call to all remote
@@ -181,7 +182,7 @@ public:
   vtkSetMacro(RenderEventPropagation, int);
   vtkGetMacro(RenderEventPropagation, int);
   vtkBooleanMacro(RenderEventPropagation, int);
-  //@}
+  ///@}
 
   /**
    * Get/Set the default value used for RenderEventPropagation when a new
@@ -197,7 +198,7 @@ public:
     return vtkParallelRenderManager::DefaultRenderEventPropagation;
   }
 
-  //@{
+  ///@{
   /**
    * This is used for tiled display rendering.  When data has been
    * duplicated on all processes, then we do not need to compositing.
@@ -206,9 +207,9 @@ public:
   vtkSetMacro(UseCompositing, int);
   vtkGetMacro(UseCompositing, int);
   vtkBooleanMacro(UseCompositing, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the reduction factor (for sort-last based parallel renderers).
    * The size of rendered image is divided by the reduction factor and then
@@ -224,7 +225,7 @@ public:
    */
   virtual void SetImageReductionFactor(double factor);
   vtkGetMacro(ImageReductionFactor, double);
-  //@}
+  ///@}
 
   vtkSetMacro(MaxImageReductionFactor, double);
   vtkGetMacro(MaxImageReductionFactor, double);
@@ -237,7 +238,7 @@ public:
    */
   virtual void SetImageReductionFactorForUpdateRate(double DesiredUpdateRate);
 
-  //@{
+  ///@{
   /**
    * If on, the ReductionFactor is automatically adjusted to best meet the
    * the DesiredUpdateRate in the current RenderWindow based on metrics
@@ -246,17 +247,17 @@ public:
   vtkSetMacro(AutoImageReductionFactor, int);
   vtkGetMacro(AutoImageReductionFactor, int);
   vtkBooleanMacro(AutoImageReductionFactor, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get rendering metrics.
    */
   vtkGetMacro(RenderTime, double);
   vtkGetMacro(ImageProcessingTime, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * By default, the state of all renderers in the root's render window is
    * propagated to the rest of the processes.  In order for this to work, all
@@ -272,9 +273,9 @@ public:
   virtual void AddRenderer(vtkRenderer*);
   virtual void RemoveRenderer(vtkRenderer*);
   virtual void RemoveAllRenderers();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If on (the default), the result of any image space manipulations are
    * written back to the render window frame buffer.  If off, the image
@@ -287,9 +288,9 @@ public:
   vtkSetMacro(WriteBackImages, int);
   vtkGetMacro(WriteBackImages, int);
   vtkBooleanMacro(WriteBackImages, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If on (the default), when the ImageReductionFactor is greater than 1
    * and WriteBackImages is on, the image will be magnified to fill the
@@ -298,7 +299,7 @@ public:
   vtkSetMacro(MagnifyImages, int);
   vtkGetMacro(MagnifyImages, int);
   vtkBooleanMacro(MagnifyImages, int);
-  //@}
+  ///@}
 
   enum
   {
@@ -306,7 +307,7 @@ public:
     LINEAR
   };
 
-  //@{
+  ///@{
   /**
    * Sets the method used to magnify images.  Nearest simply replicates
    * each pixel enough times to fill the image.  Linear performs linear
@@ -316,9 +317,9 @@ public:
   vtkGetMacro(MagnifyImageMethod, int);
   void SetMagnifyImageMethodToNearest() { this->SetMagnifyImageMethod(NEAREST); }
   void SetMagnifyImageMethodToLinear() { this->SetMagnifyImageMethod(LINEAR); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Convenience functions for magnifying images.
    */
@@ -331,9 +332,9 @@ public:
   static void MagnifyImageLinear(vtkUnsignedCharArray* fullImage, const int fullImageSize[2],
     vtkUnsignedCharArray* reducedImage, const int reducedImageSize[2],
     const int fullImageViewport[4] = nullptr, const int reducedImageViewport[4] = nullptr);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The most appropriate way to retrieve full size image data after a
    * render.  Will work regardless of whether WriteBackImages or
@@ -343,9 +344,9 @@ public:
    */
   virtual void GetPixelData(vtkUnsignedCharArray* data);
   virtual void GetPixelData(int x1, int y1, int x2, int y2, vtkUnsignedCharArray* data);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The most appropriate way to retrieve reduced size image data after a
    * render.  Will work regardless of whether WriteBackImages or
@@ -355,20 +356,20 @@ public:
    */
   virtual void GetReducedPixelData(vtkUnsignedCharArray* data);
   virtual void GetReducedPixelData(int x1, int y1, int x2, int y2, vtkUnsignedCharArray* data);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Returns the full image size calculated at the last render.
    */
   vtkGetVector2Macro(FullImageSize, int);
-  //@}
-  //@{
+  ///@}
+  ///@{
   /**
    * Returns the reduced image size calculated at the last render.
    */
   vtkGetVector2Macro(ReducedImageSize, int);
-  //@}
+  ///@}
 
   /**
    * Given the x and y size of the render windows, reposition them
@@ -376,32 +377,32 @@ public:
    */
   void TileWindows(int xsize, int ysize, int nColumns);
 
-  //@{
+  ///@{
   /**
    * Get/Set if all Images must use RGBA instead of RGB. By default,
    * this flag is on.
    */
   vtkSetMacro(UseRGBA, int);
   vtkGetMacro(UseRGBA, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If ForceRenderWindowSize is set to true, the render manager will use
    * the RenderWindowSize ivar instead of getting the size from the render window.
    */
   vtkSetMacro(ForceRenderWindowSize, int);
   vtkGetMacro(ForceRenderWindowSize, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If ForceRenderWindowSize is set to true, the render manager will use
    * the Size ivar instead of getting the size from the render window.
    */
   vtkSetVector2Macro(ForcedRenderWindowSize, int);
   vtkGetVector2Macro(ForcedRenderWindowSize, int);
-  //@}
+  ///@}
 
   enum Tags
   {
@@ -417,7 +418,7 @@ public:
   virtual void CheckForAbortRender() {}
   virtual int CheckForAbortComposite() { return 0; }
 
-  //@{
+  ///@{
   /**
    * The default is to allow the use of the back buffer for compositing.
    * If set to false, this will prevent to manager from swapping buffers.
@@ -427,9 +428,9 @@ public:
   vtkSetMacro(UseBackBuffer, int);
   vtkGetMacro(UseBackBuffer, int);
   vtkBooleanMacro(UseBackBuffer, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When set the render manager will synchronize the TileViewport and TileScale
    * properties. This may not be desirable in cases where there's some other
@@ -438,9 +439,9 @@ public:
   vtkSetMacro(SynchronizeTileProperties, int);
   vtkGetMacro(SynchronizeTileProperties, int);
   vtkBooleanMacro(SynchronizeTileProperties, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * INTERNAL METHODS (DON NOT USE).
    * There are internal methods made public so that they can be called from
@@ -448,19 +449,19 @@ public:
    */
   virtual void GenericStartRenderCallback();
   virtual void GenericEndRenderCallback();
-  //@}
+  ///@}
 
 protected:
   vtkParallelRenderManager();
   ~vtkParallelRenderManager() override;
 
-  //@{
+  ///@{
   /**
    * Add/Remove event handlers for the render window.
    */
   void AddRenderWindowEventHandlers();
   void RemoveRenderWindowEventHandlers();
-  //@}
+  ///@}
 
   vtkRenderWindow* RenderWindow;
   vtkMultiProcessController* Controller;
@@ -533,7 +534,7 @@ protected:
    * Used to synchronize rendering information per frame.
    * These are old methods provided for backward compatibility. One should look
    * at using CollectWindowInformation(), ProcessWindowInformation() etc. for
-   * bufferred sending of information over.
+   * buffered sending of information over.
    */
   virtual void SendWindowInformation() {}
   virtual void ReceiveWindowInformation() {}
@@ -553,14 +554,14 @@ protected:
   virtual void CollectRendererInformation(vtkRenderer*, vtkMultiProcessStream&) {}
   virtual bool ProcessRendererInformation(vtkRenderer*, vtkMultiProcessStream&) { return true; }
 
-  //@{
+  ///@{
   /**
    * Here is a good place to handle processing of data before and after
    * render.
    */
   virtual void PreRenderProcessing() = 0;
   virtual void PostRenderProcessing() = 0;
-  //@}
+  ///@}
 
   /**
    * Called in satellites to set the render window size to the current
@@ -684,4 +685,5 @@ private:
   void operator=(const vtkParallelRenderManager&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkParalleRenderManager_h
