@@ -23,7 +23,8 @@
 
 #include <map>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSynchronizedRenderWindows::vtkObserver : public vtkCommand
 {
 public:
@@ -34,23 +35,23 @@ public:
     return obs;
   }
 
-  void Execute(vtkObject *, unsigned long eventId, void *) override
+  void Execute(vtkObject*, unsigned long eventId, void*) override
   {
     if (this->Target)
     {
       switch (eventId)
       {
-      case vtkCommand::StartEvent:
-        this->Target->HandleStartRender();
-        break;
+        case vtkCommand::StartEvent:
+          this->Target->HandleStartRender();
+          break;
 
-      case vtkCommand::EndEvent:
-        this->Target->HandleEndRender();
-        break;
+        case vtkCommand::EndEvent:
+          this->Target->HandleEndRender();
+          break;
 
-      case vtkCommand::AbortCheckEvent:
-        this->Target->HandleAbortRender();
-        break;
+        case vtkCommand::AbortCheckEvent:
+          this->Target->HandleAbortRender();
+          break;
       }
     }
   }
@@ -58,37 +59,33 @@ public:
   vtkSynchronizedRenderWindows* Target;
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
-  typedef std::map<unsigned int, vtkWeakPointer<vtkSynchronizedRenderWindows> >
-    GlobalSynRenderWindowsMapType;
-  GlobalSynRenderWindowsMapType GlobalSynRenderWindowsMap;
+typedef std::map<unsigned int, vtkWeakPointer<vtkSynchronizedRenderWindows>>
+  GlobalSynRenderWindowsMapType;
+GlobalSynRenderWindowsMapType GlobalSynRenderWindowsMap;
 
-  void RenderRMI(void *vtkNotUsed(localArg),
-    void *remoteArg, int remoteArgLength,
-    int vtkNotUsed(remoteProcessId))
+void RenderRMI(
+  void* vtkNotUsed(localArg), void* remoteArg, int remoteArgLength, int vtkNotUsed(remoteProcessId))
+{
+  vtkMultiProcessStream stream;
+  stream.SetRawData(reinterpret_cast<unsigned char*>(remoteArg), remoteArgLength);
+  unsigned int id = 0;
+  stream >> id;
+  GlobalSynRenderWindowsMapType::iterator iter = GlobalSynRenderWindowsMap.find(id);
+  if (iter != GlobalSynRenderWindowsMap.end() && iter->second != nullptr &&
+    iter->second->GetRenderWindow() != nullptr)
   {
-    vtkMultiProcessStream stream;
-    stream.SetRawData(reinterpret_cast<unsigned char*>(remoteArg),
-      remoteArgLength);
-    unsigned int id = 0;
-    stream >> id;
-    GlobalSynRenderWindowsMapType::iterator iter =
-      GlobalSynRenderWindowsMap.find(id);
-    if (iter != GlobalSynRenderWindowsMap.end() &&
-      iter->second != nullptr &&
-      iter->second->GetRenderWindow() != nullptr)
-    {
-      iter->second->GetRenderWindow()->Render();
-    }
+    iter->second->GetRenderWindow()->Render();
   }
+}
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkStandardNewMacro(vtkSynchronizedRenderWindows);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSynchronizedRenderWindows::vtkSynchronizedRenderWindows()
 {
   this->Observer = vtkSynchronizedRenderWindows::vtkObserver::New();
@@ -102,7 +99,7 @@ vtkSynchronizedRenderWindows::vtkSynchronizedRenderWindows()
   this->RootProcessId = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSynchronizedRenderWindows::~vtkSynchronizedRenderWindows()
 {
   this->SetIdentifier(0);
@@ -115,7 +112,7 @@ vtkSynchronizedRenderWindows::~vtkSynchronizedRenderWindows()
   this->Observer = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::SetIdentifier(unsigned int id)
 {
   if (this->Identifier == id)
@@ -129,8 +126,7 @@ void vtkSynchronizedRenderWindows::SetIdentifier(unsigned int id)
     this->Identifier = 0;
   }
 
-  GlobalSynRenderWindowsMapType::iterator iter =
-    GlobalSynRenderWindowsMap.find(id);
+  GlobalSynRenderWindowsMapType::iterator iter = GlobalSynRenderWindowsMap.find(id);
   if (iter != GlobalSynRenderWindowsMap.end())
   {
     vtkErrorMacro("Identifier already in use: " << id);
@@ -144,7 +140,7 @@ void vtkSynchronizedRenderWindows::SetIdentifier(unsigned int id)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::SetRenderWindow(vtkRenderWindow* renWin)
 {
   if (this->RenderWindow != renWin)
@@ -163,17 +159,15 @@ void vtkSynchronizedRenderWindows::SetRenderWindow(vtkRenderWindow* renWin)
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkSynchronizedRenderWindows::SetParallelController(
-  vtkMultiProcessController* controller)
+//------------------------------------------------------------------------------
+void vtkSynchronizedRenderWindows::SetParallelController(vtkMultiProcessController* controller)
 {
   if (this->ParallelController == controller)
   {
     return;
   }
 
-  vtkSetObjectBodyMacro(
-    ParallelController, vtkMultiProcessController, controller);
+  vtkSetObjectBodyMacro(ParallelController, vtkMultiProcessController, controller);
 
   if (controller)
   {
@@ -182,22 +176,20 @@ void vtkSynchronizedRenderWindows::SetParallelController(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::AbortRender()
 {
-  if (this->ParallelRendering &&
-      this->ParallelController &&
-      this->ParallelController->GetLocalProcessId() == this->RootProcessId)
+  if (this->ParallelRendering && this->ParallelController &&
+    this->ParallelController->GetLocalProcessId() == this->RootProcessId)
   {
-    //TODO: trigger abort render message.
+    // TODO: trigger abort render message.
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::HandleStartRender()
 {
-  if (!this->RenderWindow || !this->ParallelRendering ||
-    !this->ParallelController ||
+  if (!this->RenderWindow || !this->ParallelRendering || !this->ParallelController ||
     (!this->Identifier && this->RenderEventPropagation))
   {
     return;
@@ -213,7 +205,7 @@ void vtkSynchronizedRenderWindows::HandleStartRender()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::MasterStartRender()
 {
   if (this->RenderEventPropagation)
@@ -225,7 +217,7 @@ void vtkSynchronizedRenderWindows::MasterStartRender()
     stream.GetRawData(data);
 
     this->ParallelController->TriggerRMIOnAllChildren(
-      &data[0], static_cast<int>(data.size()), SYNC_RENDER_TAG);
+      data.data(), static_cast<int>(data.size()), SYNC_RENDER_TAG);
   }
 
   RenderWindowInfo windowInfo;
@@ -236,7 +228,7 @@ void vtkSynchronizedRenderWindows::MasterStartRender()
   this->ParallelController->Broadcast(stream, this->RootProcessId);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::SlaveStartRender()
 {
   vtkMultiProcessStream stream;
@@ -247,18 +239,17 @@ void vtkSynchronizedRenderWindows::SlaveStartRender()
   windowInfo.CopyTo(this->RenderWindow);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Identifier: " << this->Identifier << endl;
   os << indent << "ParallelRendering: " << this->ParallelRendering << endl;
   os << indent << "RootProcessId: " << this->RootProcessId << endl;
-  os << indent << "RenderEventPropagation: " << this->RenderEventPropagation
-     << endl;
+  os << indent << "RenderEventPropagation: " << this->RenderEventPropagation << endl;
 
   os << indent << "RenderWindow: ";
-  if(this->RenderWindow==nullptr)
+  if (this->RenderWindow == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -266,7 +257,7 @@ void vtkSynchronizedRenderWindows::PrintSelf(ostream& os, vtkIndent indent)
   {
     os << this->RenderWindow << endl;
   }
-  if(this->ParallelController==nullptr)
+  if (this->ParallelController == nullptr)
   {
     os << "(none)" << endl;
   }
@@ -276,22 +267,17 @@ void vtkSynchronizedRenderWindows::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // ********* INFO OBJECT METHODS ***************************
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderWindows::RenderWindowInfo::Save(vtkMultiProcessStream& stream)
 {
-  stream << 1208
-    << this->WindowSize[0] << this->WindowSize[1]
-    << this->TileScale[0] << this->TileScale[1]
-    << this->TileViewport[0]
-    << this->TileViewport[1]
-    << this->TileViewport[2]
-    << this->TileViewport[3]
-    << this->DesiredUpdateRate;
+  stream << 1208 << this->WindowSize[0] << this->WindowSize[1] << this->TileScale[0]
+         << this->TileScale[1] << this->TileViewport[0] << this->TileViewport[1]
+         << this->TileViewport[2] << this->TileViewport[3] << this->DesiredUpdateRate;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkSynchronizedRenderWindows::RenderWindowInfo::Restore(vtkMultiProcessStream& stream)
 {
   int tag;
@@ -301,19 +287,14 @@ bool vtkSynchronizedRenderWindows::RenderWindowInfo::Restore(vtkMultiProcessStre
     return false;
   }
 
-  stream >> this->WindowSize[0] >> this->WindowSize[1]
-    >> this->TileScale[0] >> this->TileScale[1]
-    >> this->TileViewport[0]
-    >> this->TileViewport[1]
-    >> this->TileViewport[2]
-    >> this->TileViewport[3]
-    >> this->DesiredUpdateRate;
+  stream >> this->WindowSize[0] >> this->WindowSize[1] >> this->TileScale[0] >>
+    this->TileScale[1] >> this->TileViewport[0] >> this->TileViewport[1] >> this->TileViewport[2] >>
+    this->TileViewport[3] >> this->DesiredUpdateRate;
   return true;
 }
 
-//----------------------------------------------------------------------------
-void vtkSynchronizedRenderWindows::RenderWindowInfo::CopyFrom(
-  vtkRenderWindow *win)
+//------------------------------------------------------------------------------
+void vtkSynchronizedRenderWindows::RenderWindowInfo::CopyFrom(vtkRenderWindow* win)
 {
   this->WindowSize[0] = win->GetActualSize()[0];
   this->WindowSize[1] = win->GetActualSize()[1];
@@ -322,12 +303,12 @@ void vtkSynchronizedRenderWindows::RenderWindowInfo::CopyFrom(
   win->GetTileViewport(this->TileViewport);
 }
 
-//----------------------------------------------------------------------------
-void vtkSynchronizedRenderWindows::RenderWindowInfo::CopyTo(
-  vtkRenderWindow *win)
+//------------------------------------------------------------------------------
+void vtkSynchronizedRenderWindows::RenderWindowInfo::CopyTo(vtkRenderWindow* win)
 {
   win->SetSize(this->WindowSize[0], this->WindowSize[1]);
   win->SetTileScale(this->TileScale);
   win->SetTileViewport(this->TileViewport);
   win->SetDesiredUpdateRate(this->DesiredUpdateRate);
 }
+VTK_ABI_NAMESPACE_END
