@@ -21,6 +21,7 @@
 #include "vtkParallelTimer.h"
 
 //------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPLineIntegralConvolution2D);
 
 //------------------------------------------------------------------------------
@@ -30,7 +31,7 @@ vtkPLineIntegralConvolution2D::vtkPLineIntegralConvolution2D()
 }
 
 //------------------------------------------------------------------------------
-vtkPLineIntegralConvolution2D::~vtkPLineIntegralConvolution2D() {}
+vtkPLineIntegralConvolution2D::~vtkPLineIntegralConvolution2D() = default;
 
 //------------------------------------------------------------------------------
 void vtkPLineIntegralConvolution2D::SetCommunicator(vtkPainterCommunicator* comm)
@@ -110,3 +111,4 @@ void vtkPLineIntegralConvolution2D::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "LogFileName=" << this->LogFileName << endl;
 }
+VTK_ABI_NAMESPACE_END
