@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    vtkPPainterCommunicator.h
+  Module:    vtkPPainterCommunicator.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -15,29 +15,30 @@
 #include "vtkPPainterCommunicator.h"
 
 #include "vtkMPI.h"
-#include "vtkMultiProcessController.h"
-#include "vtkMPIController.h"
 #include "vtkMPICommunicator.h"
+#include "vtkMPIController.h"
+#include "vtkMultiProcessController.h"
 
 #include <vector>
 
 using std::vector;
 
 // use PImpl to avoid MPI types in public API.
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPPainterCommunicatorInternals
 {
 public:
   vtkPPainterCommunicatorInternals()
-      :
-  Ownership(false),
-  Communicator(MPI_COMM_WORLD)
-  {}
+    : Ownership(false)
+    , Communicator(MPI_COMM_WORLD)
+  {
+  }
 
   ~vtkPPainterCommunicatorInternals();
 
   // Description:
   // Set the communicator, by default ownership is not taken.
-  void SetCommunicator(MPI_Comm comm, bool ownership=false);
+  void SetCommunicator(MPI_Comm comm, bool ownership = false);
 
   // Description:
   // Duplicate the communicator, ownership of the new
@@ -48,16 +49,14 @@ public:
   MPI_Comm Communicator;
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPPainterCommunicatorInternals::~vtkPPainterCommunicatorInternals()
 {
   this->SetCommunicator(MPI_COMM_NULL);
 }
 
-//-----------------------------------------------------------------------------
-void vtkPPainterCommunicatorInternals::SetCommunicator(
-      MPI_Comm comm,
-      bool ownership)
+//------------------------------------------------------------------------------
+void vtkPPainterCommunicatorInternals::SetCommunicator(MPI_Comm comm, bool ownership)
 {
   // avoid unnecessary operations
   if (this->Communicator == comm)
@@ -65,13 +64,11 @@ void vtkPPainterCommunicatorInternals::SetCommunicator(
     return;
   }
   // do nothing without mpi
-  if ( vtkPPainterCommunicator::MPIInitialized()
-    && !vtkPPainterCommunicator::MPIFinalized() )
+  if (vtkPPainterCommunicator::MPIInitialized() && !vtkPPainterCommunicator::MPIFinalized())
   {
     // release the old communicator if it's ours
-    if ( this->Ownership
-      && (this->Communicator != MPI_COMM_NULL)
-      && (this->Communicator != MPI_COMM_WORLD) )
+    if (this->Ownership && (this->Communicator != MPI_COMM_NULL) &&
+      (this->Communicator != MPI_COMM_WORLD))
     {
       MPI_Comm_free(&this->Communicator);
     }
@@ -81,7 +78,7 @@ void vtkPPainterCommunicatorInternals::SetCommunicator(
   this->Communicator = comm;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPPainterCommunicatorInternals::DuplicateCommunicator(MPI_Comm comm)
 {
   // avoid unnecessary operations
@@ -90,8 +87,7 @@ void vtkPPainterCommunicatorInternals::DuplicateCommunicator(MPI_Comm comm)
     return;
   }
   // handle no mpi gracefully
-  if ( !vtkPPainterCommunicator::MPIInitialized()
-    || vtkPPainterCommunicator::MPIFinalized() )
+  if (!vtkPPainterCommunicator::MPIInitialized() || vtkPPainterCommunicator::MPIFinalized())
   {
     this->Ownership = false;
     this->Communicator = comm;
@@ -101,46 +97,39 @@ void vtkPPainterCommunicatorInternals::DuplicateCommunicator(MPI_Comm comm)
   this->SetCommunicator(MPI_COMM_NULL);
   if (comm != MPI_COMM_NULL)
   {
-    // duplcate
+    // duplicate
     this->Ownership = true;
     MPI_Comm_dup(comm, &this->Communicator);
   }
 }
 
-
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPPainterCommunicator::vtkPPainterCommunicator()
 {
   this->Internals = new ::vtkPPainterCommunicatorInternals;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPPainterCommunicator::~vtkPPainterCommunicator()
 {
   delete this->Internals;
 }
 
-//-----------------------------------------------------------------------------
-void vtkPPainterCommunicator::Copy(
-      const vtkPainterCommunicator *other,
-      bool ownership)
+//------------------------------------------------------------------------------
+void vtkPPainterCommunicator::Copy(const vtkPainterCommunicator* other, bool ownership)
 {
-  const vtkPPainterCommunicator *pOther
-    = dynamic_cast<const vtkPPainterCommunicator*>(other);
+  const vtkPPainterCommunicator* pOther = dynamic_cast<const vtkPPainterCommunicator*>(other);
 
   if (pOther && (pOther != this))
   {
-    this->Internals->SetCommunicator(
-          pOther->Internals->Communicator,
-          ownership);
+    this->Internals->SetCommunicator(pOther->Internals->Communicator, ownership);
   }
 }
 
-//-----------------------------------------------------------------------------
-void vtkPPainterCommunicator::Duplicate(const vtkPainterCommunicator *comm)
+//------------------------------------------------------------------------------
+void vtkPPainterCommunicator::Duplicate(const vtkPainterCommunicator* comm)
 {
-  const vtkPPainterCommunicator *pcomm
-     = dynamic_cast<const vtkPPainterCommunicator*>(comm);
+  const vtkPPainterCommunicator* pcomm = dynamic_cast<const vtkPPainterCommunicator*>(comm);
 
   if (pcomm)
   {
@@ -148,28 +137,28 @@ void vtkPPainterCommunicator::Duplicate(const vtkPainterCommunicator *comm)
   }
 }
 
-//-----------------------------------------------------------------------------
-void vtkPPainterCommunicator::SetCommunicator(vtkMPICommunicatorOpaqueComm *comm)
+//------------------------------------------------------------------------------
+void vtkPPainterCommunicator::SetCommunicator(vtkMPICommunicatorOpaqueComm* comm)
 {
   this->Internals->SetCommunicator(*comm->GetHandle());
 }
 
-//-----------------------------------------------------------------------------
-void vtkPPainterCommunicator::GetCommunicator(vtkMPICommunicatorOpaqueComm *comm)
+//------------------------------------------------------------------------------
+void vtkPPainterCommunicator::GetCommunicator(vtkMPICommunicatorOpaqueComm* comm)
 {
   *comm = &this->Internals->Communicator;
 }
 
-//-----------------------------------------------------------------------------
-void *vtkPPainterCommunicator::GetCommunicator()
+//------------------------------------------------------------------------------
+void* vtkPPainterCommunicator::GetCommunicator()
 {
   return &this->Internals->Communicator;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPPainterCommunicator::GetRank()
 {
-  if (!this->MPIInitialized() || this->MPIFinalized())
+  if (!vtkPPainterCommunicator::MPIInitialized() || vtkPPainterCommunicator::MPIFinalized())
   {
     return 0;
   }
@@ -178,10 +167,10 @@ int vtkPPainterCommunicator::GetRank()
   return rank;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPPainterCommunicator::GetSize()
 {
-  if (!this->MPIInitialized() || this->MPIFinalized())
+  if (!vtkPPainterCommunicator::MPIInitialized() || vtkPPainterCommunicator::MPIFinalized())
   {
     return 1;
   }
@@ -190,10 +179,10 @@ int vtkPPainterCommunicator::GetSize()
   return size;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPPainterCommunicator::GetWorldRank()
 {
-  if (!this->MPIInitialized() || this->MPIFinalized())
+  if (!vtkPPainterCommunicator::MPIInitialized() || vtkPPainterCommunicator::MPIFinalized())
   {
     return 0;
   }
@@ -202,10 +191,10 @@ int vtkPPainterCommunicator::GetWorldRank()
   return rank;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPPainterCommunicator::GetWorldSize()
 {
-  if (!this->MPIInitialized() || this->MPIFinalized())
+  if (!vtkPPainterCommunicator::MPIInitialized() || vtkPPainterCommunicator::MPIFinalized())
   {
     return 1;
   }
@@ -214,21 +203,21 @@ int vtkPPainterCommunicator::GetWorldSize()
   return size;
 }
 
-// ----------------------------------------------------------------------------
-vtkMPICommunicatorOpaqueComm *vtkPPainterCommunicator::GetGlobalCommunicator()
+//------------------------------------------------------------------------------
+vtkMPICommunicatorOpaqueComm* vtkPPainterCommunicator::GetGlobalCommunicator()
 {
-  static vtkMPICommunicatorOpaqueComm *globalComm = nullptr;
+  static vtkMPICommunicatorOpaqueComm* globalComm = nullptr;
   if (!globalComm)
   {
     if (vtkPPainterCommunicator::MPIInitialized())
     {
-      vtkMultiProcessController *controller = vtkMultiProcessController::GetGlobalController();
+      vtkMultiProcessController* controller = vtkMultiProcessController::GetGlobalController();
 
-      vtkMPIController *mpiController = vtkMPIController::SafeDownCast(controller);
-      vtkMPICommunicator *mpiCommunicator;
+      vtkMPIController* mpiController = vtkMPIController::SafeDownCast(controller);
+      vtkMPICommunicator* mpiCommunicator;
 
-      if ( mpiController
-        && (mpiCommunicator = vtkMPICommunicator::SafeDownCast(controller->GetCommunicator())) )
+      if (mpiController &&
+        (mpiCommunicator = vtkMPICommunicator::SafeDownCast(controller->GetCommunicator())))
       {
         globalComm = new vtkMPICommunicatorOpaqueComm(*mpiCommunicator->GetMPIComm());
       }
@@ -241,7 +230,7 @@ vtkMPICommunicatorOpaqueComm *vtkPPainterCommunicator::GetGlobalCommunicator()
   return globalComm;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkPPainterCommunicator::MPIInitialized()
 {
   int initialized;
@@ -249,7 +238,7 @@ bool vtkPPainterCommunicator::MPIInitialized()
   return initialized == 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkPPainterCommunicator::MPIFinalized()
 {
   int finished;
@@ -257,23 +246,20 @@ bool vtkPPainterCommunicator::MPIFinalized()
   return finished == 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkPPainterCommunicator::GetIsNull()
 {
   return this->Internals->Communicator == MPI_COMM_NULL;
 }
 
-//-----------------------------------------------------------------------------
-void vtkPPainterCommunicator::SubsetCommunicator(
-      vtkMPICommunicatorOpaqueComm *comm,
-      int include)
+//------------------------------------------------------------------------------
+void vtkPPainterCommunicator::SubsetCommunicator(vtkMPICommunicatorOpaqueComm* comm, int include)
 {
-  #if defined(vtkPPainterCommunicatorDEBUG)
-  cerr
-    << "=====vtkPPainterCommunicator::SubsetCommunicator" << endl
-    << "creating communicator " << (include?"with":"WITHOUT")
-    << this->GetWorldRank() << endl;
-  #endif
+#if defined(vtkPPainterCommunicatorDEBUG)
+  cerr << "=====vtkPPainterCommunicator::SubsetCommunicator" << endl
+       << "creating communicator " << (include ? "with" : "WITHOUT") << this->GetWorldRank()
+       << endl;
+#endif
 
   if (this->MPIInitialized() && !this->MPIFinalized())
   {
@@ -284,19 +270,12 @@ void vtkPPainterCommunicator::SubsetCommunicator(
     int worldSize = 0;
     MPI_Comm_size(defaultComm, &worldSize);
 
-    vector<int> included(worldSize,0);
-    MPI_Allgather(
-          &include,
-          1,
-          MPI_INT,
-          &included[0],
-          1,
-          MPI_INT,
-          defaultComm);
+    vector<int> included(worldSize, 0);
+    MPI_Allgather(&include, 1, MPI_INT, included.data(), 1, MPI_INT, defaultComm);
 
     vector<int> activeRanks;
     activeRanks.reserve(worldSize);
-    for (int i=0; i<worldSize; ++i)
+    for (int i = 0; i < worldSize; ++i)
     {
       if (included[i] != 0)
       {
@@ -305,14 +284,14 @@ void vtkPPainterCommunicator::SubsetCommunicator(
     }
 
     int nActive = (int)activeRanks.size();
-    if (nActive==0)
+    if (nActive == 0)
     {
       // no active ranks
       // no rendering will occur so no communicator
       // is needed
       this->Internals->SetCommunicator(MPI_COMM_NULL);
     }
-    else if (nActive==worldSize)
+    else if (nActive == worldSize)
     {
       // all ranks are active
       // use the default communicator.
@@ -326,11 +305,7 @@ void vtkPPainterCommunicator::SubsetCommunicator(
       MPI_Comm_group(defaultComm, &wholeGroup);
 
       MPI_Group activeGroup;
-      MPI_Group_incl(
-            wholeGroup,
-            nActive,
-            &activeRanks[0],
-            &activeGroup);
+      MPI_Group_incl(wholeGroup, nActive, activeRanks.data(), &activeGroup);
 
       MPI_Comm subsetComm;
       MPI_Comm_create(defaultComm, activeGroup, &subsetComm);
@@ -340,3 +315,4 @@ void vtkPPainterCommunicator::SubsetCommunicator(
     }
   }
 }
+VTK_ABI_NAMESPACE_END
