@@ -133,6 +133,7 @@ static void MPIAPI vtkPixelExtentUnion(void* in, void* out, int* len, MPI_Dataty
   }
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 // Description:
 // Container for our custom MPI_Op's
 class vtkPPixelExtentOps
@@ -194,6 +195,7 @@ void MPITypeFree(deque<MPI_Datatype>& types)
     MPI_Type_free(&types[i]);
   }
 }
+VTK_ABI_NAMESPACE_END
 
 // ****************************************************************************
 static size_t Size(deque<deque<vtkPixelExtent>> exts)
@@ -275,13 +277,13 @@ static int ScanMPIStatusForError(vector<MPI_Status>& stat)
 }
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 //------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkPSurfaceLICComposite);
 
 //------------------------------------------------------------------------------
 vtkPSurfaceLICComposite::vtkPSurfaceLICComposite()
-  : vtkSurfaceLICComposite()
-  , PainterComm(nullptr)
+  : PainterComm(nullptr)
   , PixelOps(nullptr)
   , CommRank(0)
   , CommSize(1)
@@ -301,7 +303,7 @@ vtkPSurfaceLICComposite::~vtkPSurfaceLICComposite()
   if (this->CompositeShader)
   {
     delete this->CompositeShader;
-    this->CompositeShader = 0;
+    this->CompositeShader = nullptr;
   }
   if (this->FBO)
   {
@@ -448,7 +450,7 @@ int vtkPSurfaceLICComposite::AllReduceVectorMax(
   for (int r = 0; r < this->CommSize; ++r)
   {
     // check the intersection of each new extent with that of each
-    // original extent. data for origial extent is local.
+    // original extent. data for original extent is local.
     size_t nNew = newExts[r].size();
     tmpMax[r].resize(nNew, -VTK_FLOAT_MAX);
     for (size_t n = 0; n < nNew; ++n)
@@ -531,7 +533,7 @@ int vtkPSurfaceLICComposite::DecomposeExtent(
   list<vtkPixelExtent> splitExts;
 
   int dir = 0;
-  while (1)
+  while (true)
   {
     // stop when we have enough out or all out have unit size
     int nExts = static_cast<int>(out.size());
@@ -651,7 +653,7 @@ int vtkPSurfaceLICComposite::MakeDecompLocallyDisjoint(
   for (size_t r = 0; r < nr; ++r)
   {
     deque<vtkPixelExtent> tmp(in[r]);
-    this->MakeDecompDisjoint(tmp, out[r]);
+    vtkPSurfaceLICComposite::MakeDecompDisjoint(tmp, out[r]);
   }
   return 0;
 }
@@ -742,18 +744,18 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   // accumulate contrib from remote data
   size_t remSize = 4 * ne;
   vector<int> rem(remSize);
-  int* pRem = ne ? &rem[0] : nullptr;
+  int* pRem = ne ? rem.data() : nullptr;
   for (size_t e = 0; e < ne; ++e, pRem += 4)
   {
     tmpOut1[e].second.GetData(pRem);
   }
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
   MPI_Op parUnion = this->PixelOps->GetUnion();
-  MPI_Allreduce(MPI_IN_PLACE, ne ? &rem[0] : nullptr, (int)remSize, MPI_INT, parUnion, comm);
+  MPI_Allreduce(MPI_IN_PLACE, ne ? rem.data() : nullptr, (int)remSize, MPI_INT, parUnion, comm);
 
   // move from flat order back to rank indexed order and remove
   // empty extents
-  pRem = ne ? &rem[0] : nullptr;
+  pRem = ne ? rem.data() : nullptr;
   out.resize(this->CommSize);
   for (size_t e = 0; e < ne; ++e, pRem += 4)
   {
@@ -823,7 +825,7 @@ int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent>>&
       guardExts[r] = tmpExts;
       // make sure it's disjoint
       disjointGuardExts[r].clear();
-      this->MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
+      vtkPSurfaceLICComposite::MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
     }
   }
   else
@@ -861,7 +863,7 @@ int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent>>&
       guardExts[r] = tmpExts;
       // make sure it's disjoint
       disjointGuardExts[r].clear();
-      this->MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
+      vtkPSurfaceLICComposite::MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
     }
 #ifdef vtkSurfaceLICPainterTIME
     log->GetHeader() << "\n";
@@ -1041,8 +1043,8 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
 
             if (!sharedExt.Empty())
             {
-              this->ScatterProgram.push_back(vtkPPixelTransfer(
-                srcRank, this->WindowExt, sharedExt, destRank, this->WindowExt, sharedExt, id));
+              this->ScatterProgram.emplace_back(
+                srcRank, this->WindowExt, sharedExt, destRank, this->WindowExt, sharedExt, id);
             }
             id += 1;
           }
@@ -1111,10 +1113,9 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
           {
             // to move vectors for the LIC decomp
             // into a contiguous recv buffer
-            this->GatherProgram.push_back(
-              vtkPPixelTransfer(srcRank, this->WindowExt, sharedExt, destRank,
-                sharedExt, // dest ext
-                sharedExt, id));
+            this->GatherProgram.emplace_back(srcRank, this->WindowExt, sharedExt, destRank,
+              sharedExt, // dest ext
+              sharedExt, id);
           }
 
           id += 1;
@@ -1138,7 +1139,7 @@ int vtkPSurfaceLICComposite::Gather(
   cerr << "=====vtkPSurfaceLICComposite::Composite" << endl;
 #endif
 
-  // two pipleines depending on if this process recv's or send's
+  // two pipelines depending on if this process recv's or send's
   //
   // send:
   // tex -> pbo -> mpi_send
@@ -1347,7 +1348,7 @@ int vtkPSurfaceLICComposite::Gather(
     // wait for the completion of one of the recvs
     MPI_Status stat;
     int reqId;
-    int iErr = MPI_Waitany(nRecvReqs, &mpiRecvReqs[0], &reqId, &stat);
+    int iErr = MPI_Waitany(nRecvReqs, mpiRecvReqs.data(), &reqId, &stat);
     if (iErr)
     {
       vtkErrorMacro("comm error in recv");
@@ -1420,7 +1421,7 @@ int vtkPSurfaceLICComposite::Gather(
   int nSendReqs = static_cast<int>(mpiSendReqs.size());
   if (nSendReqs)
   {
-    int iErr = MPI_Waitall(nSendReqs, &mpiSendReqs[0], MPI_STATUSES_IGNORE);
+    int iErr = MPI_Waitall(nSendReqs, mpiSendReqs.data(), MPI_STATUSES_IGNORE);
     if (iErr)
     {
       vtkErrorMacro("comm error in send");
@@ -1472,7 +1473,7 @@ int vtkPSurfaceLICComposite::Scatter(
 #endif
 
   int iErr = 0;
-  // two pipleines depending on if this process recv's or send's
+  // two pipelines depending on if this process recv's or send's
   //
   // send:
   // tex -> pbo -> mpi_send
@@ -1597,7 +1598,7 @@ int vtkPSurfaceLICComposite::Scatter(
   int nRecvReqs = static_cast<int>(mpiRecvReqs.size());
   if (nRecvReqs)
   {
-    iErr = MPI_Waitall(nRecvReqs, &mpiRecvReqs[0], MPI_STATUSES_IGNORE);
+    iErr = MPI_Waitall(nRecvReqs, mpiRecvReqs.data(), MPI_STATUSES_IGNORE);
     if (iErr)
     {
       vtkErrorMacro("comm error in recv");
@@ -1637,7 +1638,7 @@ int vtkPSurfaceLICComposite::Scatter(
   int nSendReqs = static_cast<int>(mpiSendReqs.size());
   if (nSendReqs)
   {
-    iErr = MPI_Waitall(nSendReqs, &mpiSendReqs[0], MPI_STATUSES_IGNORE);
+    iErr = MPI_Waitall(nSendReqs, mpiSendReqs.data(), MPI_STATUSES_IGNORE);
     if (iErr)
     {
       vtkErrorMacro("comm error in send");
@@ -1652,7 +1653,7 @@ int vtkPSurfaceLICComposite::Scatter(
 //------------------------------------------------------------------------------
 void vtkPSurfaceLICComposite::PrintSelf(ostream& os, vtkIndent indent)
 {
-  vtkObject::PrintSelf(os, indent);
+  Superclass::PrintSelf(os, indent);
   os << *this << endl;
 }
 
@@ -1708,3 +1709,4 @@ ostream& operator<<(ostream& os, vtkPSurfaceLICComposite& ss)
   }
   return os;
 }
+VTK_ABI_NAMESPACE_END
