@@ -37,6 +37,7 @@ using std::vector;
 #include <Winsock2.h>
 #include <ctime>
 #include <process.h>
+VTK_ABI_NAMESPACE_BEGIN
 static int gettimeofday(struct timeval* tv, void*)
 {
   FILETIME ft;
@@ -56,6 +57,7 @@ static int gettimeofday(struct timeval* tv, void*)
 
   return 0;
 }
+VTK_ABI_NAMESPACE_END
 #endif
 
 using std::ios_base;
@@ -63,7 +65,8 @@ using std::ios_base;
 /*
 For singleton pattern
 **/
-vtkParallelTimer* vtkParallelTimer::GlobalInstance = 0;
+VTK_ABI_NAMESPACE_BEGIN
+vtkParallelTimer* vtkParallelTimer::GlobalInstance = nullptr;
 vtkParallelTimer::vtkParallelTimerDestructor vtkParallelTimer::GlobalInstanceDestructor;
 
 //------------------------------------------------------------------------------
@@ -108,9 +111,9 @@ public:
 
   // Description:
   // Stream insertion operators for adding data to the buffer.
-  vtkParallelTimerBuffer& operator<<(const int v);
-  vtkParallelTimerBuffer& operator<<(const long long v);
-  vtkParallelTimerBuffer& operator<<(const double v);
+  vtkParallelTimerBuffer& operator<<(int v);
+  vtkParallelTimerBuffer& operator<<(long long v);
+  vtkParallelTimerBuffer& operator<<(double v);
   vtkParallelTimerBuffer& operator<<(const char* v);
   template <size_t N>
   vtkParallelTimerBuffer& operator<<(const char v[N]);
@@ -155,7 +158,7 @@ vtkParallelTimerBuffer::vtkParallelTimerBuffer()
   : Size(0)
   , At(0)
   , GrowBy(4096)
-  , Data(0)
+  , Data(nullptr)
 {
 }
 
@@ -170,7 +173,7 @@ vtkParallelTimerBuffer::vtkParallelTimerBuffer(const vtkParallelTimerBuffer& oth
   : Size(0)
   , At(0)
   , GrowBy(4096)
-  , Data(0)
+  , Data(nullptr)
 {
   *this = other;
 }
@@ -194,11 +197,11 @@ void vtkParallelTimerBuffer::ClearForReal()
   this->At = 0;
   this->Size = 0;
   free(this->Data);
-  this->Data = 0;
+  this->Data = nullptr;
 }
 
 //------------------------------------------------------------------------------
-vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(const int v)
+vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(int v)
 {
   const char c = 'i';
   this->PushBack(&c, 1);
@@ -207,7 +210,7 @@ vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(const int v)
 }
 
 //------------------------------------------------------------------------------
-vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(const long long v)
+vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(long long v)
 {
   const char c = 'l';
   this->PushBack(&c, 1);
@@ -216,7 +219,7 @@ vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(const long long v)
 }
 
 //------------------------------------------------------------------------------
-vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(const double v)
+vtkParallelTimerBuffer& vtkParallelTimerBuffer::operator<<(double v)
 {
   const char c = 'd';
   this->PushBack(&c, 1);
@@ -307,8 +310,8 @@ void vtkParallelTimerBuffer::Gather(int rootRank)
   // in serial this is a no-op
   if (worldSize > 1)
   {
-    int* bufferSizes = 0;
-    int* disp = 0;
+    int* bufferSizes = nullptr;
+    int* disp = nullptr;
     if (worldRank == rootRank)
     {
       bufferSizes = static_cast<int*>(malloc(worldSize * sizeof(int)));
@@ -316,7 +319,7 @@ void vtkParallelTimerBuffer::Gather(int rootRank)
     }
     int bufferSize = static_cast<int>(this->GetSize());
     MPI_Gather(&bufferSize, 1, MPI_INT, bufferSizes, 1, MPI_INT, rootRank, MPI_COMM_WORLD);
-    char* log = 0;
+    char* log = nullptr;
     int cumSize = 0;
     if (worldRank == rootRank)
     {
@@ -381,9 +384,9 @@ vtkParallelTimer::vtkParallelTimer()
   : GlobalLevel(0)
   , WorldRank(0)
   , WriterRank(0)
-  , FileName(0)
+  , FileName(nullptr)
   , WriteOnClose(0)
-  , Log(0)
+  , Log(nullptr)
 {
 #if vtkParallelTimerDEBUG > 1
   cerr << "=====vtkParallelTimer::vtkParallelTimer" << endl;
@@ -407,13 +410,13 @@ vtkParallelTimer::~vtkParallelTimer()
 
   // Alert the user that he left events on the stack,
   // this is usually a sign of trouble.
-  if (this->StartTime.size() > 0)
+  if (!this->StartTime.empty())
   {
     vtkErrorMacro(<< "Start time stack has " << this->StartTime.size() << " remaining.");
   }
 
 #if vtkParallelTimerDEBUG < 0
-  if (this->EventId.size() > 0)
+  if (!this->EventId.empty())
   {
     size_t nIds = this->EventId.size();
     vtkErrorMacro(<< "Event id stack has " << nIds << " remaining.");
@@ -424,7 +427,7 @@ vtkParallelTimer::~vtkParallelTimer()
   }
 #endif
 
-  this->SetFileName(0);
+  this->SetFileName(nullptr);
 
   delete this->Log;
 }
@@ -436,7 +439,7 @@ vtkParallelTimer* vtkParallelTimer::GetGlobalInstance()
   cerr << "=====vtkParallelTimer::GetGlobalInstance" << endl;
 #endif
 
-  if (vtkParallelTimer::GlobalInstance == 0)
+  if (vtkParallelTimer::GlobalInstance == nullptr)
   {
     vtkParallelTimer* log = vtkParallelTimer::New();
     ostringstream oss;
@@ -465,7 +468,7 @@ void vtkParallelTimer::DeleteGlobalInstance()
     vtkParallelTimer::GlobalInstance->Delete();
     vtkParallelTimer::GlobalInstance = nullptr;
 
-    vtkParallelTimer::GlobalInstanceDestructor.SetLog(0);
+    vtkParallelTimer::GlobalInstanceDestructor.SetLog(nullptr);
   }
 }
 
@@ -502,11 +505,11 @@ void vtkParallelTimer::StartEvent(const char* event)
 #endif
 
   timeval wallt;
-  gettimeofday(&wallt, 0x0);
+  gettimeofday(&wallt, nullptr);
   double walls = static_cast<double>(wallt.tv_sec) + static_cast<double>(wallt.tv_usec) / 1.0E6;
 
 #if vtkParallelTimerDEBUG < 0
-  this->EventId.push_back(event);
+  this->EventId.emplace_back(event);
 #endif
 
   this->StartTime.push_back(walls);
@@ -534,11 +537,11 @@ void vtkParallelTimer::EndEvent(const char* event)
 #endif
 
   timeval wallt;
-  gettimeofday(&wallt, 0x0);
+  gettimeofday(&wallt, nullptr);
   double walle = static_cast<double>(wallt.tv_sec) + static_cast<double>(wallt.tv_usec) / 1.0E6;
 
 #if vtkParallelTimerDEBUG > 0
-  if (this->StartTime.size() == 0)
+  if (this->StartTime.empty())
   {
     vtkErrorMacro("No event to end! " << event);
     return;
@@ -556,7 +559,7 @@ void vtkParallelTimer::EndEvent(const char* event)
   const string eEventId = event;
   if (sEventId != eEventId)
   {
-    vtkErrorMacro(<< "Event mismatch " << sEventId.c_str() << " != " << eEventId.c_str());
+    vtkErrorMacro(<< "Event mismatch " << sEventId << " != " << eEventId);
   }
   this->EventId.pop_back();
 #endif
@@ -648,3 +651,4 @@ void vtkParallelTimer::PrintSelf(ostream& os, vtkIndent)
   *this->Log >> oss;
   os << oss.str();
 }
+VTK_ABI_NAMESPACE_END
