@@ -47,6 +47,7 @@
 #include <QTextDocument>
 #include <QTextStream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQtLabelRenderStrategy);
 
 bool operator<(const vtkQtLabelMapEntry& a, const vtkQtLabelMapEntry& other)
@@ -181,7 +182,7 @@ void vtkQtLabelRenderStrategy::StartFrame()
 // int compute_bounds_iter = 0;
 //------------------------------------------------------------------------------
 void vtkQtLabelRenderStrategy::ComputeLabelBounds(
-  vtkTextProperty* tprop, vtkUnicodeString label, double bds[4])
+  vtkTextProperty* tprop, vtkStdString label, double bds[4])
 {
   if (!QApplication::instance())
   {
@@ -209,7 +210,7 @@ void vtkQtLabelRenderStrategy::ComputeLabelBounds(
     fontSpec.setStyleStrategy(QFont::NoAntialias);
   }
 
-  QString text = QString::fromUtf8(label.utf8_str());
+  QString text = QString::fromUtf8(label.c_str());
   QColor textColor =
     this->Implementation->TextPropertyToColor(tprop->GetColor(), tprop->GetOpacity());
   vtkQtLabelMapEntry key;
@@ -280,7 +281,7 @@ void vtkQtLabelRenderStrategy::ComputeLabelBounds(
 // int render_label_iter = 0;
 //------------------------------------------------------------------------------
 void vtkQtLabelRenderStrategy::RenderLabel(
-  int x[2], vtkTextProperty* tprop, vtkUnicodeString label, int maxWidth)
+  int x[2], vtkTextProperty* tprop, vtkStdString label, int maxWidth)
 {
   if (!QApplication::instance())
   {
@@ -292,7 +293,7 @@ void vtkQtLabelRenderStrategy::RenderLabel(
   // timer->StartTimer();
 
   // Determine if we can render the label to fit the width
-  QString origText = QString::fromUtf8(label.utf8_str());
+  QString origText = QString::fromUtf8(label.c_str());
   QFont fontSpec = this->Implementation->TextPropertyToFont(tprop);
 
   // This is the recommended Qt way of controlling text antialiasing.
@@ -384,7 +385,7 @@ void vtkQtLabelRenderStrategy::RenderLabel(
 }
 
 //------------------------------------------------------------------------------
-void vtkQtLabelRenderStrategy::RenderLabel(int x[2], vtkTextProperty* tprop, vtkUnicodeString label)
+void vtkQtLabelRenderStrategy::RenderLabel(int x[2], vtkTextProperty* tprop, vtkStdString label)
 {
   if (!QApplication::instance())
   {
@@ -401,7 +402,7 @@ void vtkQtLabelRenderStrategy::RenderLabel(int x[2], vtkTextProperty* tprop, vtk
   // vtkTimerLog* timer = vtkTimerLog::New();
   // timer->StartTimer();
 
-  QString text = QString::fromUtf8(label.utf8_str());
+  QString text = QString::fromUtf8(label.c_str());
   QFont fontSpec = this->Implementation->TextPropertyToFont(tprop);
 
   // This is the recommended Qt way of controlling text antialiasing.
@@ -548,3 +549,4 @@ void vtkQtLabelRenderStrategy::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
