@@ -19,7 +19,6 @@
 #include "vtkQImageToImageSource.h"
 #include "vtkStdString.h"
 #include "vtkTextProperty.h"
-#include "vtkUnicodeString.h"
 #include "vtkVector.h"
 
 #include "vtkObjectFactory.h"
@@ -36,6 +35,7 @@
 #include <QTextDocument>
 #include <QTextStream>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 struct vtkQtLabelMapEntry
@@ -82,37 +82,6 @@ vtkQtStringToImage::~vtkQtStringToImage()
   delete this->Implementation;
 }
 
-//------------------------------------------------------------------------------
-vtkVector2i vtkQtStringToImage::GetBounds(
-  vtkTextProperty* property, const vtkUnicodeString& string, int dpi)
-{
-  vtkVector2i recti(0, 0);
-  if (!QApplication::instance())
-  {
-    vtkErrorMacro("You must initialize a QApplication before using this class.");
-    return recti;
-  }
-
-  if (!property)
-  {
-    return recti;
-  }
-
-  QFont fontSpec = this->Implementation->TextPropertyToFont(property, dpi);
-
-  QString text = QString::fromUtf8(string.utf8_str());
-
-  QRectF rect;
-  QPainterPath path;
-  path.addText(0, 0, fontSpec, text);
-  rect = path.boundingRect();
-
-  recti.SetX(static_cast<int>(rect.width()));
-  recti.SetY(static_cast<int>(rect.height()));
-
-  return recti;
-}
-
 //------------------------------------------------------------------------------
 vtkVector2i vtkQtStringToImage::GetBounds(
   vtkTextProperty* property, const vtkStdString& string, int dpi)
@@ -144,8 +113,8 @@ vtkVector2i vtkQtStringToImage::GetBounds(
   return recti;
 }
 
-int vtkQtStringToImage::RenderString(vtkTextProperty* property, const vtkUnicodeString& string,
-  int dpi, vtkImageData* data, int textDims[2])
+int vtkQtStringToImage::RenderString(vtkTextProperty* property, const vtkStdString& string, int dpi,
+  vtkImageData* data, int textDims[2])
 {
   if (!QApplication::instance())
   {
@@ -164,7 +133,7 @@ int vtkQtStringToImage::RenderString(vtkTextProperty* property, const vtkUnicode
     textDims[1] = box.GetY();
   }
 
-  QString text = QString::fromUtf8(string.utf8_str());
+  QString text = QString::fromUtf8(string.c_str());
   QFont fontSpec = this->Implementation->TextPropertyToFont(property, dpi);
   QFontMetrics fontMetric(fontSpec);
 
@@ -219,12 +188,6 @@ int vtkQtStringToImage::RenderString(vtkTextProperty* property, const vtkUnicode
   return 1;
 }
 
-int vtkQtStringToImage::RenderString(vtkTextProperty* property, const vtkStdString& string, int dpi,
-  vtkImageData* data, int textDims[2])
-{
-  return this->RenderString(property, vtkUnicodeString::from_utf8(string), dpi, data, textDims);
-}
-
 //------------------------------------------------------------------------------
 void vtkQtStringToImage::DeepCopy(vtkQtStringToImage*) {}
 
@@ -233,3 +196,4 @@ void vtkQtStringToImage::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
