@@ -39,8 +39,6 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkTextureMapToPlane.h"
 #include "vtkTexturedActor2D.h"
 #include "vtkTree.h"
-#include "vtkUnicodeString.h"
-#include "vtkUnicodeStringArray.h"
 
 #include <QApplication>
 #include <QFont>
@@ -56,6 +54,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkSmartPointer.h"
 #define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQtTreeRingLabelMapper);
 
 vtkCxxSetObjectMacro(vtkQtTreeRingLabelMapper, LabelTextProperty, vtkTextProperty);
@@ -164,7 +163,6 @@ void vtkQtTreeRingLabelMapper::RenderOpaqueGeometry(vtkViewport* viewport, vtkAc
   vtkAbstractArray* abstractData;
   vtkDataArray *numericData, *sectorInfo;
   vtkStringArray* stringData;
-  vtkUnicodeStringArray* uStringData;
   vtkTree* input = this->GetInputTree();
   if (!input)
   {
@@ -207,7 +205,6 @@ void vtkQtTreeRingLabelMapper::RenderOpaqueGeometry(vtkViewport* viewport, vtkAc
     abstractData = nullptr;
     numericData = nullptr;
     stringData = nullptr;
-    uStringData = nullptr;
     switch (this->LabelMode)
     {
       case VTK_LABEL_SCALARS:
@@ -255,7 +252,6 @@ void vtkQtTreeRingLabelMapper::RenderOpaqueGeometry(vtkViewport* viewport, vtkAc
         }
         numericData = vtkArrayDownCast<vtkDataArray>(abstractData);
         stringData = vtkArrayDownCast<vtkStringArray>(abstractData);
-        uStringData = vtkArrayDownCast<vtkUnicodeStringArray>(abstractData);
       };
       break;
     }
@@ -271,14 +267,13 @@ void vtkQtTreeRingLabelMapper::RenderOpaqueGeometry(vtkViewport* viewport, vtkAc
         numComp = 1;
       }
     }
-    else if (!stringData && !uStringData)
+    else if (!stringData)
     {
       vtkErrorMacro(<< "Need input data to render labels (3)");
       return;
     }
 
-    this->LabelTree(
-      input, sectorInfo, numericData, stringData, uStringData, activeComp, numComp, viewport);
+    this->LabelTree(input, sectorInfo, numericData, stringData, activeComp, numComp, viewport);
   }
 
   VTK_CREATE(vtkQImageToImageSource, qis);
@@ -294,8 +289,8 @@ void vtkQtTreeRingLabelMapper::RenderOpaqueGeometry(vtkViewport* viewport, vtkAc
 }
 
 void vtkQtTreeRingLabelMapper::LabelTree(vtkTree* tree, vtkDataArray* sectorInfo,
-  vtkDataArray* numericData, vtkStringArray* stringData, vtkUnicodeStringArray* uStringData,
-  int activeComp, int numComps, vtkViewport* viewport)
+  vtkDataArray* numericData, vtkStringArray* stringData, int activeComp, int numComps,
+  vtkViewport* viewport)
 {
   delete this->QtImage;
   this->QtImage = new QImage(this->WindowSize[0], this->WindowSize[1], QImage::Format_ARGB32);
@@ -340,8 +335,7 @@ void vtkQtTreeRingLabelMapper::LabelTree(vtkTree* tree, vtkDataArray* sectorInfo
     }
 
     // check to see if the text will fit in the sector
-    this->GetVertexLabel(
-      i, numericData, stringData, uStringData, activeComp, numComps, string, sizeof(string));
+    this->GetVertexLabel(i, numericData, stringData, activeComp, numComps, string, sizeof(string));
     QString ResultString(string);
 
     double x[3];
@@ -360,10 +354,15 @@ void vtkQtTreeRingLabelMapper::LabelTree(vtkTree* tree, vtkDataArray* sectorInfo
     // set ellipsis bounds for this piece of text
     // Note, don't use ellipsis unless at least 5 characters (w's) can be displayed...
     QString minString("wwwww");
+#if (QT_VERSION <= QT_VERSION_CHECK(5, 11, 0))
+    int minStringWidth = fontMetric.width(minString);
+#else
+    int minStringWidth = fontMetric.horizontalAdvance(minString);
+#endif
     double allowedTextWidth = 0;
     if (sdimDC[0] > sdimDC[1])
     {
-      if (sdimDC[0] < fontMetric.width(minString))
+      if (sdimDC[0] < minStringWidth)
       {
         continue;
       }
@@ -371,7 +370,7 @@ void vtkQtTreeRingLabelMapper::LabelTree(vtkTree* tree, vtkDataArray* sectorInfo
     }
     else
     {
-      if (sdimDC[1] < fontMetric.width(minString))
+      if (sdimDC[1] < minStringWidth)
       {
         continue;
       }
@@ -408,11 +407,19 @@ void vtkQtTreeRingLabelMapper::LabelTree(vtkTree* tree, vtkDataArray* sectorInfo
         break;
       case VTK_TEXT_CENTERED:
         // FIXME - The width is not correct for html encodings...
+#if (QT_VERSION <= QT_VERSION_CHECK(5, 11, 0))
         delta_x = -(fontMetric.width(testString)) / 2.;
+#else
+        delta_x = -(fontMetric.horizontalAdvance(testString)) / 2.;
+#endif
         break;
       case VTK_TEXT_RIGHT:
         // FIXME - The width is not correct for html encodings...
+#if (QT_VERSION <= QT_VERSION_CHECK(5, 11, 0))
         delta_x = -fontMetric.width(testString);
+#else
+        delta_x = -fontMetric.horizontalAdvance(testString);
+#endif
         break;
     }
 
@@ -580,15 +587,14 @@ void vtkQtTreeRingLabelMapper::PrintSelf(ostream& os, vtkIndent indent)
 }
 
 void vtkQtTreeRingLabelMapper::GetVertexLabel(vtkIdType vertex, vtkDataArray* numericData,
-  vtkStringArray* stringData, vtkUnicodeStringArray* uStringData, int activeComp, int numComp,
-  char* string, size_t stringSize)
+  vtkStringArray* stringData, int activeComp, int numComps, char* string, size_t stringSize)
 {
   char format[1024];
   double val;
   int j;
   if (numericData)
   {
-    if (numComp == 1)
+    if (numComps == 1)
     {
       if (numericData->GetDataType() == VTK_CHAR)
       {
@@ -611,14 +617,14 @@ void vtkQtTreeRingLabelMapper::GetVertexLabel(vtkIdType vertex, vtkDataArray* nu
     {
       strcpy(format, "(");
       strcat(format, this->LabelFormat);
-      for (j = 0; j < (numComp - 1); j++)
+      for (j = 0; j < (numComps - 1); j++)
       {
         snprintf(string, stringSize, format, numericData->GetComponent(vertex, j));
         strcpy(format, string);
         strcat(format, ", ");
         strcat(format, this->LabelFormat);
       }
-      snprintf(string, stringSize, format, numericData->GetComponent(vertex, numComp - 1));
+      snprintf(string, stringSize, format, numericData->GetComponent(vertex, numComps - 1));
       strcat(string, ")");
     }
   }
@@ -632,16 +638,6 @@ void vtkQtTreeRingLabelMapper::GetVertexLabel(vtkIdType vertex, vtkDataArray* nu
     }
     snprintf(string, stringSize, this->LabelFormat, stringData->GetValue(vertex).c_str());
   }
-  else if (uStringData) // rendering unicode string data
-  {
-    if (strcmp(this->LabelFormat, "%s") != 0)
-    {
-      vtkErrorMacro(<< "Label format must be %s to use with strings");
-      string[0] = '\0';
-      return;
-    }
-    snprintf(string, stringSize, this->LabelFormat, uStringData->GetValue(vertex).utf8_str());
-  }
   else // Use the vertex id
   {
     val = static_cast<double>(vertex);
@@ -670,3 +666,4 @@ vtkMTimeType vtkQtTreeRingLabelMapper::GetMTime()
   }
   return filterMTime;
 }
+VTK_ABI_NAMESPACE_END
