@@ -49,6 +49,8 @@
 
 class QImage;
 
+VTK_ABI_NAMESPACE_BEGIN
+
 class vtkQImageToImageSource;
 class vtkCoordinate;
 class vtkDoubleArray;
@@ -59,7 +61,6 @@ class vtkStringArray;
 class vtkTexture;
 class vtkTextureMapToPlane;
 class vtkTree;
-class vtkUnicodeStringArray;
 
 class VTKRENDERINGQT_EXPORT vtkQtTreeRingLabelMapper : public vtkLabeledDataMapper
 {
@@ -68,13 +69,13 @@ public:
   vtkTypeMacro(vtkQtTreeRingLabelMapper, vtkLabeledDataMapper);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Draw the text to the screen at each input point.
    */
   void RenderOpaqueGeometry(vtkViewport* viewport, vtkActor2D* actor) override;
   void RenderOverlay(vtkViewport* viewport, vtkActor2D* actor) override;
-  //@}
+  ///@}
 
   /**
    * The input to this filter.
@@ -86,7 +87,7 @@ public:
    */
   virtual void SetSectorsArrayName(const char* name);
 
-  //@{
+  ///@{
   /**
    * Set/Get the text property. Note that multiple type text properties
    * (set with a second integer parameter) are not currently supported,
@@ -102,15 +103,15 @@ public:
   {
     return this->Superclass::GetLabelTextProperty(type);
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the name of the text rotation array.
    */
   vtkSetStringMacro(TextRotationArrayName);
   vtkGetStringMacro(TextRotationArrayName);
-  //@}
+  ///@}
 
   /**
    * Return the object's MTime. This is overridden to include
@@ -132,11 +133,9 @@ protected:
   vtkQtTreeRingLabelMapper();
   ~vtkQtTreeRingLabelMapper() override;
   void LabelTree(vtkTree* tree, vtkDataArray* sectorInfo, vtkDataArray* numericData,
-    vtkStringArray* stringData, vtkUnicodeStringArray* uStringData, int activeComp, int numComps,
-    vtkViewport* viewport);
+    vtkStringArray* stringData, int activeComp, int numComps, vtkViewport* viewport);
   void GetVertexLabel(vtkIdType vertex, vtkDataArray* numericData, vtkStringArray* stringData,
-    vtkUnicodeStringArray* uStringData, int activeComp, int numComps, char* string,
-    size_t stringSize);
+    int activeComp, int numComps, char* string, size_t stringSize);
 
   // Returns true if the center of the sector is in the window
   // along with the pixel dimensions (width, height)  of the sector
@@ -160,4 +159,5 @@ private:
   void operator=(const vtkQtTreeRingLabelMapper&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
