@@ -35,6 +35,7 @@
 
 #include "RTWrapper/RTWrapper.h" // for handle types
 
+VTK_ABI_NAMESPACE_BEGIN
 template <class T>
 class VTKRENDERINGRAYTRACING_EXPORT vtkOSPRayCache
 {
@@ -69,7 +70,7 @@ public:
     return nullptr;
   }
 
-  //@{
+  ///@{
   /**
    * Set/Get the number of slots available in the cache.
    * Default is 0.
@@ -87,7 +88,7 @@ public:
     this->Size = sz;
   }
   size_t GetSize() { return this->Size; }
-  //@}
+  ///@}
 
   /**
    * Query whether cache contains tstep
@@ -126,5 +127,6 @@ public:
   RTW::Backend* backend = nullptr;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkOSPRayCache_h
 // VTK-HeaderTest-Exclude: vtkOSPRayCache.h
