@@ -34,8 +34,10 @@
 #include <string>           //for string!
 #include <vector>           //for vector!
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOSPRayMaterialLibraryInternals;
 class vtkTexture;
+struct TextureInfo;
 
 class VTKRENDERINGRAYTRACING_EXPORT vtkOSPRayMaterialLibrary : public vtkObject
 {
@@ -58,8 +60,19 @@ public:
 
   /**
    * Serialize contents to an in memory buffer.
+   * If writeImageInline, all textures are stored in a XML format.
+   * Else, store the texture using its filename stored in its TextureInfo struct.
+   * Warning: you must free the return value using delete.
    */
-  const char* WriteBuffer();
+  const char* WriteBuffer(bool writeImageInline = true);
+
+  /**
+   * Serialize contents to a file specified by \p filename.
+   * If writeImageInline, all textures are stored in a XML format.
+   * Else, store the texture using its filename stored in its TextureInfo struct
+   * Warning: if \p filename exists, its content is discarded.
+   */
+  void WriteFile(const std::string& filename, bool writeImageInline = false);
 
   /**
    * DeSerialize contents from an in memory buffer as ReadFile does from a
@@ -99,6 +112,23 @@ public:
    */
   vtkTexture* GetTexture(const std::string& nickname, const std::string& varname);
 
+  /**
+   * Returns the texture information (name, texture and filename) of this \p varname.
+   * If not found, return nullptr;
+   */
+  const TextureInfo* GetTextureInfo(const std::string& nickname, const std::string& varname);
+
+  /**
+   * Returns the name (and not the shader variable name) associated to a
+   * texture.
+   */
+  std::string GetTextureName(const std::string& nickname, const std::string& varname);
+
+  /**
+   * Returns the filename associated ti a texture (if any).
+   */
+  std::string GetTextureFilename(const std::string& nickname, const std::string& varname);
+
   /**
    * Add Material
    * Adds a new material nickname to the set of known materials.
@@ -115,15 +145,23 @@ public:
 
   /**
    * Add Texture
-   * Adds a new texture. Replaces any previous content.
+   * Given a material @c nickname and a shader variable @c varname, set its data
+   * to a specific texture @c tex named @c texturename. If not specified the texture
+   * is called "unnamedTexture".
+   * The last parameter, filename, is defaulted to empty. If specified, the absolute path
+   * to find the texture will be stored. Useful when writing the library into a file.
+   *
+   * Replaces any previous content.
    **/
-  void AddTexture(const std::string& nickname, const std::string& texturename, vtkTexture* tex);
+  void AddTexture(const std::string& nickname, const std::string& varname, vtkTexture* tex,
+    const std::string& texturename = "unnamedTexture", const std::string& filename = "");
 
   /**
    * Remove Texture
-   * Removes a texture. Do nothing if texture does not exist.
+   * Removes a texture for a specific materal @c nickname and shader variable @c varname.
+   * Do nothing if texture does not exist.
    **/
-  void RemoveTexture(const std::string& nickname, const std::string& texturename);
+  void RemoveTexture(const std::string& nickname, const std::string& varname);
 
   /**
    * Remove all textures of a specific material
@@ -186,6 +224,9 @@ protected:
   bool InternalParse(const char* name, bool IsFile);
   bool InternalParseJSON(const char* name, bool IsFile, std::istream* doc);
   bool InternalParseMTL(const char* name, bool IsFile, std::istream* doc);
+  bool ReadTextureFileOrData(const std::string& texFilenameOrData, bool fromfile,
+    const std::string& parentDir, vtkTexture* textr, std::string& textureName,
+    std::string& textureFilename);
 
 private:
   vtkOSPRayMaterialLibrary(const vtkOSPRayMaterialLibrary&) = delete;
@@ -194,4 +235,5 @@ private:
   vtkOSPRayMaterialLibraryInternals* Internal;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
