@@ -42,6 +42,7 @@
 
 #include <string> // for std::string
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCameraPass;
 class vtkLightsPass;
 class vtkOSPRayPassInternals;
@@ -63,28 +64,33 @@ public:
    */
   void Render(const vtkRenderState* s) override;
 
-  //@{
+  ///@{
   /**
    * Tells the pass what it will render.
    */
   void SetSceneGraph(vtkOSPRayRendererNode*);
   vtkGetObjectMacro(SceneGraph, vtkOSPRayRendererNode);
-  //@}
+  ///@}
 
   /**
    * Called by the internals of this class
    */
   virtual void RenderInternal(const vtkRenderState* s);
 
-  //@{
+  ///@{
   /**
    * Wrapper around ospray's init and shutdown that protect
    * with a reference count.
    */
-  //@}
+  ///@}
   static void RTInit();
   static void RTShutdown();
 
+  /**
+   * A run time query to see if OSPRay can possibly work.
+   */
+  static bool IsSupported();
+
   /**
    * A run time query to see if a particular backend is available.
    * Eg. "OSPRay raycaster", "OSPRay pathtracer" or "OptiX pathtracer".
@@ -119,4 +125,5 @@ private:
   static int RTDeviceRefCount;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
