@@ -60,6 +60,7 @@ namespace ospray
 {
 namespace opengl
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 // code borrowed from ospray::modules::opengl to facilitate updating
 // and linking
@@ -172,9 +173,11 @@ OSPTexture getOSPDepthTextureFromOpenGLPerspective(const double& fovy, const dou
 
   return depthTexture;
 }
+VTK_ABI_NAMESPACE_END
 }
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkInformationKeyMacro(vtkOSPRayRendererNode, SAMPLES_PER_PIXEL, Integer);
 vtkInformationKeyMacro(vtkOSPRayRendererNode, MAX_CONTRIBUTION, Double);
 vtkInformationKeyMacro(vtkOSPRayRendererNode, MAX_DEPTH, Integer);
@@ -285,7 +288,7 @@ public:
   {
     vtkRenderer* ren = vtkRenderer::SafeDownCast(this->Owner->GetRenderable());
 
-    int bgMode = vtkOSPRayRendererNode::GetBackgroundMode(ren);
+    auto bgMode = vtkOSPRayRendererNode::GetBackgroundMode(ren);
     bool sameMode = (bgMode == this->lBackgroundMode);
     bool forpathtracer = true;
     if (std::string(this->Owner->GetRendererType(ren)).find(std::string("pathtracer")) ==
@@ -301,7 +304,7 @@ public:
       {
         return true;
       }
-      bgMode = 0x1; // ignore user setting
+      bgMode = vtkOSPRayRendererNode::Backplate; // ignore user setting
     }
 
     OSPTexture t2d = nullptr;
@@ -389,7 +392,7 @@ public:
       // now apply the texture we chose above to the right place
       if (forbackplate)
       {
-        if (bgMode & 0x1)
+        if (bgMode & vtkOSPRayRendererNode::Backplate)
         {
           ospSetObject(this->Owner->GetORenderer(), "map_backplate", t2d);
         }
@@ -414,7 +417,7 @@ public:
           east = ren->GetEnvironmentRight();
         }
         ospSetVec3f(ospLight, "direction", (float)east[0], (float)east[1], (float)east[2]);
-        if (bgMode == 0x2)
+        if (bgMode == vtkOSPRayRendererNode::Environment)
         {
           ospSetBool(ospLight, "visible", true);
         }
@@ -427,7 +430,7 @@ public:
       }
     } //! reusable
 
-    if (!forbackplate && (bgMode & 0x2))
+    if (!forbackplate && (bgMode & vtkOSPRayRendererNode::Environment))
     {
       this->Owner->AddLight(this->BGLight); // lights cleared every frame, so always add
     }
@@ -437,7 +440,7 @@ public:
   std::map<vtkProp3D*, vtkAbstractMapper3D*> LastMapperFor;
   vtkOSPRayRendererNode* Owner;
 
-  int lBackgroundMode = 0;
+  vtkOSPRayRendererNode::BackgroundMode lBackgroundMode = vtkOSPRayRendererNode::None;
   double lColor1[2][3] = { { 0.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0 } };
   bool lUseGradient[2] = { false, false };
   double lColor2[2][3] = { { 0.0, 0.0, 0.0 }, { 0.0, 0.0, 0.0 } };
@@ -639,33 +642,6 @@ int vtkOSPRayRendererNode::GetRouletteDepth(vtkRenderer* renderer)
   return DEFAULT_ROULETTE_DEPTH;
 }
 
-//----------------------------------------------------------------------------
-void vtkOSPRayRendererNode::SetVolumeAnisotropy(double value, vtkRenderer* renderer)
-{
-  if (!renderer)
-  {
-    return;
-  }
-  vtkInformation* info = renderer->GetInformation();
-  info->Set(vtkOSPRayRendererNode::VOLUME_ANISOTROPY(), value);
-}
-
-//----------------------------------------------------------------------------
-double vtkOSPRayRendererNode::GetVolumeAnisotropy(vtkRenderer* renderer)
-{
-  constexpr double DEFAULT_VOLUME_ANISOTROPY = 0.0;
-  if (!renderer)
-  {
-    return DEFAULT_VOLUME_ANISOTROPY;
-  }
-  vtkInformation* info = renderer->GetInformation();
-  if (info && info->Has(vtkOSPRayRendererNode::VOLUME_ANISOTROPY()))
-  {
-    return (info->Get(vtkOSPRayRendererNode::VOLUME_ANISOTROPY()));
-  }
-  return DEFAULT_VOLUME_ANISOTROPY;
-}
-
 //----------------------------------------------------------------------------
 void vtkOSPRayRendererNode::SetVarianceThreshold(double value, vtkRenderer* renderer)
 {
@@ -1007,9 +983,10 @@ int vtkOSPRayRendererNode::GetEnableDenoiser(vtkRenderer* renderer)
 }
 
 //------------------------------------------------------------------------------
-void vtkOSPRayRendererNode::SetBackgroundMode(int value, vtkRenderer* renderer)
+void vtkOSPRayRendererNode::SetBackgroundMode(
+  vtkOSPRayRendererNode::BackgroundMode value, vtkRenderer* renderer)
 {
-  if (!renderer || value < 0 || value > 3)
+  if (!renderer || value < 0 || value >= vtkOSPRayRendererNode::NumberOfMode)
   {
     return;
   }
@@ -1018,18 +995,20 @@ void vtkOSPRayRendererNode::SetBackgroundMode(int value, vtkRenderer* renderer)
 }
 
 //------------------------------------------------------------------------------
-int vtkOSPRayRendererNode::GetBackgroundMode(vtkRenderer* renderer)
+vtkOSPRayRendererNode::BackgroundMode vtkOSPRayRendererNode::GetBackgroundMode(
+  vtkRenderer* renderer)
 {
   if (!renderer)
   {
-    return 2;
+    return vtkOSPRayRendererNode::Environment;
   }
   vtkInformation* info = renderer->GetInformation();
   if (info && info->Has(vtkOSPRayRendererNode::BACKGROUND_MODE()))
   {
-    return (info->Get(vtkOSPRayRendererNode::BACKGROUND_MODE()));
+    return (vtkOSPRayRendererNode::BackgroundMode)(
+      info->Get(vtkOSPRayRendererNode::BACKGROUND_MODE()));
   }
-  return 2;
+  return vtkOSPRayRendererNode::Environment;
 }
 
 //------------------------------------------------------------------------------
@@ -1464,7 +1443,7 @@ void vtkOSPRayRendererNode::Render(bool prepass)
       {
         // check camera
         // Why not cam->mtime?
-        // cam->mtime is bumped by synch after this in parallel so never reuses
+        // cam->mtime is bumped by sync after this in parallel so never reuses
         // Why not cam->MVTO->mtime?
         //  cam set's elements directly, so the mtime doesn't bump with motion
         vtkMatrix4x4* camnow = ren->GetActiveCamera()->GetModelViewTransformObject()->GetMatrix();
@@ -1796,3 +1775,4 @@ RTW::Backend* vtkOSPRayRendererNode::GetBackend()
 {
   return this->Internal->Backend;
 }
+VTK_ABI_NAMESPACE_END
