@@ -39,6 +39,7 @@
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOSPRayUnstructuredVolumeMapperNode);
 
 //------------------------------------------------------------------------------
@@ -152,7 +153,9 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
         }
         verticesData = ospNewCopyData1D(vertices.data(), OSP_VEC3F, numberOfPoints);
       }
+      ospCommit(verticesData);
       ospSetObject(this->OSPRayVolume, "vertex.position", verticesData);
+      ospRelease(verticesData);
 
       // Now the connectivity
       auto cellArray = dataSet->GetCells();
@@ -163,15 +166,21 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
         auto ctypes = dataSet->GetCellTypesArray();
         OSPData cellTypeData =
           ospNewSharedData1D(ctypes->GetVoidPointer(0), OSP_UCHAR, numberOfCells);
+        ospCommit(cellTypeData);
         ospSetObject(this->OSPRayVolume, "cell.type", cellTypeData);
         auto off = cellArray->GetOffsetsArray();
         OSPData cellIndexData =
           ospNewSharedData1D(off->GetVoidPointer(0), is32bit ? OSP_UINT : OSP_ULONG, numberOfCells);
+        ospCommit(cellIndexData);
         ospSetObject(this->OSPRayVolume, "cell.index", cellIndexData);
         auto con = cellArray->GetConnectivityArray();
         OSPData indexData = ospNewSharedData1D(
           con->GetVoidPointer(0), is32bit ? OSP_UINT : OSP_ULONG, con->GetNumberOfTuples() - 1);
+        ospCommit(indexData);
         ospSetObject(this->OSPRayVolume, "index", indexData);
+        ospRelease(cellTypeData);
+        ospRelease(cellIndexData);
+        ospRelease(indexData);
       }
       else
       {
@@ -218,11 +227,17 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
           }
         }
         OSPData cellTypeData = ospNewCopyData1D(ctypes.data(), OSP_UCHAR, ctypes.size());
+        ospCommit(cellTypeData);
         ospSetObject(this->OSPRayVolume, "cell.type", cellTypeData);
         OSPData cellIndexData = ospNewCopyData1D(off.data(), OSP_UINT, off.size());
+        ospCommit(cellIndexData);
         ospSetObject(this->OSPRayVolume, "cell.index", cellIndexData);
         OSPData indexData = ospNewCopyData1D(con.data(), OSP_UINT, con.size());
+        ospCommit(indexData);
         ospSetObject(this->OSPRayVolume, "index", indexData);
+        ospRelease(cellTypeData);
+        ospRelease(cellIndexData);
+        ospRelease(indexData);
       }
     }
 
@@ -269,6 +284,7 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
         }
         fieldData = ospNewCopyData1D(field.data(), OSP_FLOAT, numberOfElements);
       }
+      ospCommit(fieldData);
       if (fieldAssociation)
       {
         ospSetObject(this->OSPRayVolume, "cell.data", fieldData);
@@ -299,31 +315,38 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
       tfCVals.resize(this->NumColors * 3);
       tfOVals.resize(this->NumColors);
       double range[2];
-      array->GetRange(range, comp);
-      if (mode == 0 && array->GetNumberOfComponents() > 1) // vector magnitude
+      // prefer transfer function's range
+      scalarTF->GetRange(range);
+      // but use data's range if we can and we have to
+      if (range[1] <= range[0])
       {
-        double min = 0;
-        double max = 0;
-        for (int c = 0; c < array->GetNumberOfComponents(); c++)
+        array->GetRange(range, comp);
+        if (mode == 0 && array->GetNumberOfComponents() > 1) // vector magnitude
         {
-          double lmin = 0;
-          double lmax = 0;
-          double cRange[2];
-          array->GetRange(cRange, c);
-          double ldist = cRange[0] * cRange[0];
-          double rdist = cRange[1] * cRange[1];
-          lmin = std::min(ldist, rdist);
-          if (cRange[0] < 0 && cRange[1] > 0)
+          double min = 0;
+          double max = 0;
+          for (int c = 0; c < array->GetNumberOfComponents(); c++)
           {
-            lmin = 0;
+            double lmin = 0;
+            double lmax = 0;
+            double cRange[2];
+            array->GetRange(cRange, c);
+            double ldist = cRange[0] * cRange[0];
+            double rdist = cRange[1] * cRange[1];
+            lmin = std::min(ldist, rdist);
+            if (cRange[0] < 0 && cRange[1] > 0)
+            {
+              lmin = 0;
+            }
+            lmax = std::max(ldist, rdist);
+            min += lmin;
+            max += lmax;
           }
-          lmax = std::max(ldist, rdist);
-          min += lmin;
-          max += lmax;
+          range[0] = std::sqrt(min);
+          range[1] = std::sqrt(max);
         }
-        range[0] = std::sqrt(min);
-        range[1] = std::sqrt(max);
       }
+
       scalarTF->GetTable(range[0], range[1], this->NumColors, &tfOVals[0]);
       colorTF->GetTable(range[0], range[1], this->NumColors, &tfCVals[0]);
 
@@ -338,10 +361,12 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
       }
 
       OSPData colorData = ospNewCopyData1D(&tfCVals[0], OSP_VEC3F, this->NumColors);
+      ospCommit(colorData);
 
       auto oTF = ospNewTransferFunction("piecewiseLinear");
       ospSetObject(oTF, "color", colorData);
       OSPData tfAlphaData = ospNewCopyData1D(&tfOVals[0], OSP_FLOAT, NumColors);
+      ospCommit(tfAlphaData);
       ospSetObject(oTF, "opacity", tfAlphaData);
       ospSetVec2f(oTF, "valueRange", range[0], range[1]);
       ospCommit(oTF);
@@ -354,7 +379,7 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
       ospSetObject(this->OSPRayVolumeModel, "transferFunction", oTF);
       const float densityScale = 1.0f / volProperty->GetScalarOpacityUnitDistance();
       ospSetFloat(this->OSPRayVolumeModel, "densityScale", densityScale);
-      const float anisotropy = orn->GetVolumeAnisotropy(ren);
+      const float anisotropy = volProperty->GetScatteringAnisotropy();
       ospSetFloat(this->OSPRayVolumeModel, "anisotropy", anisotropy);
       ospSetFloat(
         this->OSPRayVolumeModel, "gradientShadingScale", volProperty->GetShade() ? 0.5 : 0.0);
@@ -365,6 +390,8 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
     }
 
     OSPGroup group = ospNewGroup();
+    // instance object doesn't need a matching ospRelease() here because the responsibility
+    // for its destruction gets handed off to the vtkRendererNode
     OSPInstance instance = ospNewInstance(group);
     OSPData instanceData = ospNewSharedData1D(&this->OSPRayVolumeModel, OSP_VOLUMETRIC_MODEL, 1);
     ospCommit(instanceData);
@@ -379,3 +406,4 @@ void vtkOSPRayUnstructuredVolumeMapperNode::Render(bool prepass)
     this->BuildTime.Modified();
   }
 }
+VTK_ABI_NAMESPACE_END
