@@ -21,12 +21,14 @@
 #include "vtkOSPRayCompositePolyDataMapper2Node.h"
 #include "vtkOSPRayLightNode.h"
 #include "vtkOSPRayMoleculeMapperNode.h"
+#include "vtkOSPRayPointGaussianMapperNode.h"
 #include "vtkOSPRayPolyDataMapperNode.h"
 #include "vtkOSPRayRendererNode.h"
 #include "vtkOSPRayUnstructuredVolumeMapperNode.h"
 #include "vtkOSPRayVolumeMapperNode.h"
 #include "vtkOSPRayVolumeNode.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkViewNode* ren_maker()
 {
   vtkOSPRayRendererNode* vn = vtkOSPRayRendererNode::New();
@@ -92,6 +94,12 @@ vtkViewNode* tetm_maker()
   return vn;
 }
 
+vtkViewNode* particle_maker()
+{
+  vtkOSPRayPointGaussianMapperNode* vn = vtkOSPRayPointGaussianMapperNode::New();
+  return vn;
+}
+
 //============================================================================
 vtkStandardNewMacro(vtkOSPRayViewNodeFactory);
 
@@ -120,6 +128,7 @@ vtkOSPRayViewNodeFactory::vtkOSPRayViewNodeFactory()
   this->RegisterOverride("vtkUnstructuredGridVolumeRayCastMapper", tetm_maker);
   this->RegisterOverride("vtkAMRVolumeMapper", amrm_maker);
   this->RegisterOverride("vtkMoleculeMapper", molecule_maker);
+  this->RegisterOverride("vtkOpenGLPointGaussianMapper", particle_maker);
 }
 
 //------------------------------------------------------------------------------
@@ -130,3 +139,4 @@ void vtkOSPRayViewNodeFactory::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
