@@ -27,6 +27,7 @@
 #include "RTWrapper/RTWrapper.h"
 
 //============================================================================
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOSPRayWindowNode);
 
 //------------------------------------------------------------------------------
@@ -53,6 +54,17 @@ void vtkOSPRayWindowNode::PrintSelf(ostream& os, vtkIndent indent)
 //------------------------------------------------------------------------------
 void vtkOSPRayWindowNode::Render(bool prepass)
 {
+  if (!vtkOSPRayPass::IsSupported())
+  {
+    static bool warned = false;
+    if (!warned)
+    {
+      vtkWarningMacro(<< "Ignoring render request because OSPRay is not supported.");
+      warned = true;
+    }
+    return;
+  }
+
   if (!prepass)
   {
     // composite all renderers framebuffers together
@@ -84,3 +96,4 @@ void vtkOSPRayWindowNode::Render(bool prepass)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
