@@ -17,7 +17,7 @@
  * @brief   vtkViewNode specialized for vtkRenderers
  *
  * State storage and graph traversal for vtkRenderer
-*/
+ */
 
 #ifndef vtkRendererNode_h
 #define vtkRendererNode_h
@@ -25,35 +25,51 @@
 #include "vtkRenderingSceneGraphModule.h" // For export macro
 #include "vtkViewNode.h"
 
-class  vtkCollection;
+VTK_ABI_NAMESPACE_BEGIN
+class vtkCollection;
 
-class VTKRENDERINGSCENEGRAPH_EXPORT vtkRendererNode :
-  public vtkViewNode
+class VTKRENDERINGSCENEGRAPH_EXPORT vtkRendererNode : public vtkViewNode
 {
 public:
   static vtkRendererNode* New();
   vtkTypeMacro(vtkRendererNode, vtkViewNode);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Build containers for our child nodes.
    */
-  virtual void Build(bool prepass) VTK_OVERRIDE;
+  void Build(bool prepass) override;
 
   /**
-   * Synchronize our state
+   * Get/Set the framebuffer size
    */
-  virtual void Synchronize(bool prepass) VTK_OVERRIDE;
+  vtkGetVector2Macro(Size, int);
+  vtkSetVector2Macro(Size, int);
+
+  /**
+   * Get/Set the window viewport
+   */
+  vtkGetVector4Macro(Viewport, double);
+  vtkSetVector4Macro(Viewport, double);
+
+  /**
+   * Get/Set the window tile scale
+   */
+  vtkGetVector2Macro(Scale, int);
+  vtkSetVector2Macro(Scale, int);
 
 protected:
   vtkRendererNode();
-  ~vtkRendererNode();
+  ~vtkRendererNode() override;
 
   int Size[2];
+  double Viewport[4];
+  int Scale[2];
 
 private:
-  vtkRendererNode(const vtkRendererNode&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkRendererNode&) VTK_DELETE_FUNCTION;
+  vtkRendererNode(const vtkRendererNode&) = delete;
+  void operator=(const vtkRendererNode&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
