@@ -19,7 +19,6 @@
 #include "vtkRenderWindowInteractor.h"
 #include "vtkTclUtil.h"
 #include "vtkTkInternals.h"
-#include "vtkToolkits.h"
 #include "vtkVersionMacros.h"
 
 #ifdef _WIN32
@@ -120,7 +119,6 @@ void vtkExtractImageData(unsigned char* buffer, T* inPtr, double shift, double s
       ImagePtr += pixelSize - components;
     }
   }
-  return;
 }
 
 extern "C"
@@ -160,7 +158,6 @@ extern "C"
     }
 
     // Find the image
-#ifdef VTK_PYTHON_BUILD
     char typeCheck[256];
     unsigned long long l;
     sscanf(argv[1], "_%llx_%s", &l, typeCheck);
@@ -191,21 +188,6 @@ extern "C"
       u.p = nullptr;
     }
     image = static_cast<vtkImageData*>(u.p);
-#else
-    image = static_cast<vtkImageData*>(
-      vtkTclGetPointerFromObject(argv[1], "vtkImageData", interp, status));
-    if (!image)
-    {
-      vtkAlgorithmOutput* algOutput = static_cast<vtkAlgorithmOutput*>(
-        vtkTclGetPointerFromObject(argv[1], "vtkAlgorithmOutput", interp, status));
-      if (algOutput)
-      {
-        vtkAlgorithm* alg = algOutput->GetProducer();
-        alg->Update();
-        image = vtkImageData::SafeDownCast(alg->GetOutputDataObject(algOutput->GetIndex()));
-      }
-    }
-#endif
     if (!image)
     {
       Tcl_AppendResult(interp, "could not find vtkImageData: ", argv[1], nullptr);
@@ -276,7 +258,7 @@ extern "C"
     block.height = 0;
     block.pixelSize = 0;
     block.pitch = 0;
-    void* TempPointer = 0;
+    void* TempPointer = nullptr;
     switch (orientation)
     {
       case VTKIMAGEDATATOTKPHOTO_TRANSVERSE:
@@ -612,7 +594,7 @@ extern "C"
       if (self->RenderWindow->GetInteractor() &&
         self->RenderWindow->GetInteractor()->GetRenderWindow() == self->RenderWindow)
       {
-        self->RenderWindow->GetInteractor()->SetRenderWindow(0);
+        self->RenderWindow->GetInteractor()->SetRenderWindow(nullptr);
       }
       if (self->RenderWindow->GetReferenceCount() > 1)
       {
@@ -641,12 +623,7 @@ extern "C"
     switch (eventPtr->type)
     {
       case Expose:
-        if (eventPtr->xexpose.count == 0)
-        /* && !self->UpdatePending)*/
-        {
-          // let the user bind expose events
-          // self->RenderWindow->Render();
-        }
+        // let the user handle Expose events
         break;
       case ConfigureNotify:
         // if ( Tk_IsMapped(self->TkWin) )
@@ -901,9 +878,6 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
     self->RenderWindow->Register(nullptr);
     self->RenderWindow->Delete();
     renderWindow = (vtkWin32OpenGLRenderWindow*)(self->RenderWindow);
-#ifndef VTK_PYTHON_BUILD
-    vtkTclGetObjectFromPointer(self->Interp, self->RenderWindow, "vtkRenderWindow");
-#endif
     // in Tcl 8.6.x, ckalloc was changed to return "void *".
     self->RW = static_cast<char*>(
       ckalloc(static_cast<unsigned int>(strlen(Tcl_GetStringResult(self->Interp)) + 1)));
@@ -921,12 +895,7 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
     }
     else
     {
-#ifndef VTK_PYTHON_BUILD
-      renderWindow = (vtkWin32OpenGLRenderWindow*)vtkTclGetPointerFromObject(
-        self->RW, "vtkRenderWindow", self->Interp, new_flag);
-#else
-      renderWindow = 0;
-#endif
+      renderWindow = nullptr;
     }
     if (renderWindow != self->RenderWindow)
     {
@@ -1066,9 +1035,6 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
     self->RenderWindow->Register(nullptr);
     self->RenderWindow->Delete();
     renderWindow = self->RenderWindow;
-#ifndef VTK_PYTHON_BUILD
-    vtkTclGetObjectFromPointer(self->Interp, self->RenderWindow, "vtkRenderWindow");
-#endif
     // in Tcl 8.6.x, ckalloc was changed to return "void *".
     self->RW = static_cast<char*>(
       ckalloc(static_cast<unsigned int>(strlen(Tcl_GetStringResult(self->Interp)) + 1)));
@@ -1084,14 +1050,6 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
       sscanf(self->RW + 5, "%p", &tmp);
       renderWindow = reinterpret_cast<vtkRenderWindow*>(tmp);
     }
-    else
-    {
-#ifndef VTK_PYTHON_BUILD
-      int new_flag;
-      renderWindow = static_cast<vtkRenderWindow*>(
-        vtkTclGetPointerFromObject(self->RW, "vtkRenderWindow", self->Interp, new_flag));
-#endif
-    }
 
     if (renderWindow != self->RenderWindow)
     {
@@ -1165,7 +1123,7 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
 static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
 {
   Display* dpy;
-  vtkXOpenGLRenderWindow* renderWindow = 0;
+  vtkXOpenGLRenderWindow* renderWindow = nullptr;
 
   if (self->RenderWindow)
   {
@@ -1186,9 +1144,6 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
     self->RenderWindow->Register(nullptr);
     self->RenderWindow->Delete();
     renderWindow = (vtkXOpenGLRenderWindow*)(self->RenderWindow);
-#ifndef VTK_PYTHON_BUILD
-    vtkTclGetObjectFromPointer(self->Interp, self->RenderWindow, "vtkRenderWindow");
-#endif
     // in Tcl 8.6.x, ckalloc was changed to return "void *".
     self->RW = static_cast<char*>(
       ckalloc(static_cast<unsigned int>(strlen(Tcl_GetStringResult(self->Interp)) + 1)));
@@ -1204,14 +1159,6 @@ static int vtkTkRenderWidget_MakeRenderWindow(struct vtkTkRenderWidget* self)
       sscanf(self->RW + 5, "%p", &tmp);
       renderWindow = (vtkXOpenGLRenderWindow*)tmp;
     }
-    else
-    {
-#ifndef VTK_PYTHON_BUILD
-      int new_flag;
-      renderWindow = (vtkXOpenGLRenderWindow*)vtkTclGetPointerFromObject(
-        self->RW, "vtkRenderWindow", self->Interp, new_flag);
-#endif
-    }
     if (renderWindow != self->RenderWindow)
     {
       if (self->RenderWindow != nullptr)
