@@ -37,9 +37,12 @@
 #include "vtkRenderingUIModule.h" // For export macro
 #include "vtkTDxConfigure.h"      // defines VTK_USE_TDX
 #ifdef VTK_USE_TDX
+VTK_ABI_NAMESPACE_BEGIN
 class vtkTDxMacDevice;
+VTK_ABI_NAMESPACE_END
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGUI_EXPORT vtkCocoaRenderWindowInteractor : public vtkRenderWindowInteractor
 {
 public:
@@ -56,7 +59,7 @@ public:
    */
   void Initialize() override;
 
-  //@{
+  ///@{
   /**
    * Enable/Disable interactions.  By default interactors are enabled when
    * initialized.  Initialize() must be called prior to enabling/disabling
@@ -68,12 +71,12 @@ public:
    */
   void Enable() override;
   void Disable() override;
-  //@}
+  ///@}
 
   /**
    * Cocoa specific application terminate, calls ClassExitMethod then
    * calls PostQuitMessage(0) to terminate app. An application can Specify
-   * ExitMethod for alternative behaviour (i.e. suppresion of keyboard exit)
+   * ExitMethod for alternative behaviour (i.e. suppression of keyboard exit)
    */
   void TerminateApp() override;
 
@@ -84,7 +87,7 @@ public:
    */
   void ProcessEvents() override;
 
-  //@{
+  ///@{
   /**
    * Methods to set the default exit method for the class. This method is
    * only used if no instance level ExitMethod has been defined.  It is
@@ -93,7 +96,7 @@ public:
    */
   static void SetClassExitMethod(void (*f)(void*), void* arg);
   static void SetClassExitMethodArgDelete(void (*f)(void*));
-  //@}
+  ///@}
 
   /**
    * These methods correspond to the Exit, User and Pick
@@ -115,7 +118,7 @@ protected:
   void SetTimerDictionary(void* dictionary); // Really an NSMutableDictionary*
   void* GetTimerDictionary();
 
-  //@{
+  ///@{
   /**
    * Class variables so an exit method can be defined for this class
    * (used to set different exit methods for various language bindings,
@@ -124,16 +127,16 @@ protected:
   static void (*ClassExitMethod)(void*);
   static void (*ClassExitMethodArgDelete)(void*);
   static void* ClassExitMethodArg;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Cocoa-specific internal timer methods. See the superclass for detailed
    * documentation.
    */
   int InternalCreateTimer(int timerId, int timerType, unsigned long duration) override;
   int InternalDestroyTimer(int platformTimerId) override;
-  //@}
+  ///@}
 
   /**
    * This will start up the event loop and never return. If you
@@ -142,14 +145,14 @@ protected:
    */
   void StartEventLoop() override;
 
-  //@{
+  ///@{
   /**
    * Accessors for the cocoa manager (Really an NSMutableDictionary*).
    * It manages all Cocoa objects in this C++ class.
    */
   void SetCocoaManager(void* manager);
   void* GetCocoaManager();
-  //@}
+  ///@}
 
 #ifdef VTK_USE_TDX
   vtkTDxMacDevice* Device;
@@ -168,4 +171,5 @@ private:
   void* CocoaManager; // Really an NSMutableDictionary*
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
