@@ -24,6 +24,7 @@
 #include "vtkRenderingUIModule.h" // For export macro
 #include "vtkWindows.h"           // For windows API
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGUI_EXPORT vtkWin32HardwareWindow : public vtkHardwareWindow
 {
 public:
@@ -38,7 +39,7 @@ public:
   void Create() override;
   void Destroy() override;
 
-  //@{
+  ///@{
   /**
    * These are window system independent methods that are used
    * to help interface vtkWindow to native windowing systems.
@@ -49,23 +50,23 @@ public:
   void* GetGenericDisplayId() override;
   void* GetGenericWindowId() override;
   void* GetGenericParentId() override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the size of the window in pixels.
    */
   void SetSize(int, int) override;
   using vtkHardwareWindow::SetSize;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set the position of the window.
    */
   void SetPosition(int, int) override;
   using vtkHardwareWindow::SetPosition;
-  //@}
+  ///@}
 
 protected:
   vtkWin32HardwareWindow();
@@ -80,4 +81,5 @@ private:
   void operator=(const vtkWin32HardwareWindow&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
