@@ -27,10 +27,10 @@
 
 #include "vtkHardwareWindow.h"
 #include "vtkRenderWindow.h"
+#include "vtkStringArray.h"
 #include "vtkWin32RenderWindowInteractor.h"
 #include "vtkWindows.h"
-
-#include "vtkStringArray.h"
+#include "vtksys/Encoding.hxx"
 
 #include <shellapi.h> // for drag and drop
 #include <winuser.h>  // for touch support
@@ -49,10 +49,12 @@
 // sees it in the friend decl in vtkWin32RenderWindowInteractor, but
 // GCC needs to see the declaration beforehand. It has to do with the
 // CALLBACK attribute.
+VTK_ABI_NAMESPACE_BEGIN
 VTKRENDERINGUI_EXPORT LRESULT CALLBACK vtkHandleMessage(HWND, UINT, WPARAM, LPARAM);
 VTKRENDERINGUI_EXPORT LRESULT CALLBACK vtkHandleMessage2(
   HWND, UINT, WPARAM, LPARAM, class vtkWin32RenderWindowInteractor*);
 
+VTK_ABI_NAMESPACE_END
 #include "vtkActor.h"
 #include "vtkCommand.h"
 #include "vtkObjectFactory.h"
@@ -79,6 +81,7 @@ typedef bool(WINAPI* RegisterTouchWindowType)(HWND, ULONG);
 typedef bool(WINAPI* GetTouchInputInfoType)(HTOUCHINPUT, UINT, PTOUCHINPUT, int);
 typedef bool(WINAPI* CloseTouchInputHandleType)(HTOUCHINPUT);
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkWin32RenderWindowInteractor);
 
 void (*vtkWin32RenderWindowInteractor::ClassExitMethod)(void*) = (void (*)(void*)) nullptr;
@@ -310,6 +313,11 @@ void vtkWin32RenderWindowInteractor::Disable()
 //------------------------------------------------------------------------------
 void vtkWin32RenderWindowInteractor::TerminateApp(void)
 {
+  if (this->Done)
+  {
+    return;
+  }
+
   this->Done = true;
 
   // Only post a quit message if Start was called...
@@ -789,7 +797,7 @@ int vtkWin32RenderWindowInteractor::OnDropFiles(HWND, WPARAM wParam)
     this->InvokeEvent(vtkCommand::UpdateDropLocationEvent, location);
   }
 
-  UINT cFiles = DragQueryFile(hdrop, 0xFFFFFFFF, nullptr, 0);
+  UINT cFiles = DragQueryFileW(hdrop, 0xFFFFFFFF, nullptr, 0);
 
   if (cFiles > 0)
   {
@@ -798,17 +806,11 @@ int vtkWin32RenderWindowInteractor::OnDropFiles(HWND, WPARAM wParam)
 
     for (UINT i = 0; i < cFiles; i++)
     {
-      TCHAR file[MAX_PATH];
-      UINT cch = DragQueryFile(hdrop, i, file, MAX_PATH);
+      wchar_t file[MAX_PATH];
+      UINT cch = DragQueryFileW(hdrop, i, file, MAX_PATH);
       if (cch > 0 && cch < MAX_PATH)
       {
-#ifdef UNICODE
-        char cFile[MAX_PATH];
-        wcstombs(cFile, file, cch);
-        filePaths->InsertNextValue(cFile);
-#else
-        filePaths->InsertNextValue(file);
-#endif
+        filePaths->InsertNextValue(vtksys::Encoding::ToNarrow(file));
         ret = 1;
       }
     }
@@ -1057,3 +1059,4 @@ void vtkWin32RenderWindowInteractor::ExitCallback()
 
   this->TerminateApp();
 }
+VTK_ABI_NAMESPACE_END
