@@ -12,6 +12,10 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
+// Must be included first to avoid conflicts with X11's `Status` define.
+#include <vtksys/SystemTools.hxx>
+
 #include "vtkXRenderWindowInteractor.h"
 
 #include <algorithm>
@@ -28,8 +32,6 @@
 #include "vtkRenderWindow.h"
 #include "vtkStringArray.h"
 
-#include <vtksys/SystemTools.hxx>
-
 #include <X11/X.h>
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
@@ -41,6 +43,7 @@
 #include <set>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkXRenderWindowInteractor);
 
 template <int EventType>
@@ -55,6 +58,8 @@ struct vtkXRenderWindowInteractorTimer
   timeval lastFire;
 };
 
+constexpr unsigned char XDND_VERSION = 5;
+
 // Map between the X native id to our own integer count id.  Note this
 // is separate from the TimerMap in the vtkRenderWindowInteractor
 // superclass.  This is used to avoid passing 64-bit values back
@@ -150,6 +155,10 @@ vtkXRenderWindowInteractor::vtkXRenderWindowInteractor()
   this->WindowId = 0;
   this->KillAtom = 0;
   this->XdndSource = 0;
+  this->XdndFormatAtom = 0;
+  this->XdndURIListAtom = 0;
+  this->XdndTypeListAtom = 0;
+  this->XdndEnterAtom = 0;
   this->XdndPositionAtom = 0;
   this->XdndDropAtom = 0;
   this->XdndActionCopyAtom = 0;
@@ -195,17 +204,88 @@ void vtkXRenderWindowInteractor::TerminateApp()
 
   XSendEvent(client.display, client.window, True, NoEventMask, reinterpret_cast<XEvent*>(&client));
   XFlush(client.display);
-  this->RenderWindow->Finalize();
 }
 
 void vtkXRenderWindowInteractor::ProcessEvents()
 {
+  std::vector<int> rwiFileDescriptors;
+  fd_set in_fds;
+  struct timeval tv;
+  struct timeval minTv;
+
+  bool wait = true;
+  bool done = true;
+  minTv.tv_sec = 1000;
+  minTv.tv_usec = 1000;
   XEvent event;
-  while (XPending(this->DisplayId) && !this->Done)
+
+  rwiFileDescriptors.reserve(vtkXRenderWindowInteractorInternals::Instances.size());
+  for (auto rwi : vtkXRenderWindowInteractorInternals::Instances)
   {
-    XNextEvent(this->DisplayId, &event);
-    this->DispatchEvent(&event);
+    rwiFileDescriptors.push_back(ConnectionNumber(rwi->DisplayId));
   }
+
+  for (auto rwi = vtkXRenderWindowInteractorInternals::Instances.begin();
+       rwi != vtkXRenderWindowInteractorInternals::Instances.end();)
+  {
+
+    if (XPending((*rwi)->DisplayId) == 0)
+    {
+      // get how long to wait for the next timer
+      (*rwi)->Internal->GetTimeToNextTimer(tv);
+      minTv.tv_sec = std::min(tv.tv_sec, minTv.tv_sec);
+      minTv.tv_usec = std::min(tv.tv_usec, minTv.tv_usec);
+    }
+    else
+    {
+      // If events are pending, dispatch them to the right RenderWindowInteractor
+      XNextEvent((*rwi)->DisplayId, &event);
+      (*rwi)->DispatchEvent(&event);
+      wait = false;
+    }
+    (*rwi)->FireTimers();
+
+    // Check if all RenderWindowInteractors have been terminated
+    done = done && (*rwi)->Done;
+
+    // If current RenderWindowInteractor have been terminated, handle its last event,
+    // then remove it from the Instance vector
+    if ((*rwi)->Done)
+    {
+      // Empty the event list
+      while (XPending((*rwi)->DisplayId) != 0)
+      {
+        XNextEvent((*rwi)->DisplayId, &event);
+        (*rwi)->DispatchEvent(&event);
+      }
+
+      // Finalize the rwi
+      (*rwi)->Finalize();
+
+      // Adjust the file descriptors vector
+      int rwiPosition = std::distance(vtkXRenderWindowInteractorInternals::Instances.begin(), rwi);
+      rwi = vtkXRenderWindowInteractorInternals::Instances.erase(rwi);
+      rwiFileDescriptors.erase(rwiFileDescriptors.begin() + rwiPosition);
+    }
+    else
+    {
+      ++rwi;
+    }
+  }
+
+  if (wait && !done)
+  {
+    // select will wait until 'tv' elapses or something else wakes us
+    FD_ZERO(&in_fds);
+    for (auto rwiFileDescriptor : rwiFileDescriptors)
+    {
+      FD_SET(rwiFileDescriptor, &in_fds);
+    }
+    int maxFileDescriptor = *std::max_element(rwiFileDescriptors.begin(), rwiFileDescriptors.end());
+    select(maxFileDescriptor + 1, &in_fds, nullptr, nullptr, &minTv);
+  }
+
+  this->Done = done;
 }
 
 //------------------------------------------------------------------------------
@@ -214,84 +294,14 @@ void vtkXRenderWindowInteractor::ProcessEvents()
 // loop is exited.
 void vtkXRenderWindowInteractor::StartEventLoop()
 {
-  std::vector<int> rwiFileDescriptors;
-  fd_set in_fds;
-  struct timeval tv;
-  struct timeval minTv;
-
   for (auto rwi : vtkXRenderWindowInteractorInternals::Instances)
   {
     rwi->Done = false;
-    rwiFileDescriptors.push_back(ConnectionNumber(rwi->DisplayId));
   }
-
-  bool done = true;
   do
   {
-    bool wait = true;
-    done = true;
-    minTv.tv_sec = 1000;
-    minTv.tv_usec = 1000;
-    XEvent event;
-    for (auto rwi = vtkXRenderWindowInteractorInternals::Instances.begin();
-         rwi != vtkXRenderWindowInteractorInternals::Instances.end();)
-    {
-
-      if (XPending((*rwi)->DisplayId) == 0)
-      {
-        // get how long to wait for the next timer
-        (*rwi)->Internal->GetTimeToNextTimer(tv);
-        minTv.tv_sec = std::min(tv.tv_sec, minTv.tv_sec);
-        minTv.tv_usec = std::min(tv.tv_usec, minTv.tv_usec);
-      }
-      else
-      {
-        // If events are pending, dispatch them to the right RenderWindowInteractor
-        XNextEvent((*rwi)->DisplayId, &event);
-        (*rwi)->DispatchEvent(&event);
-        wait = false;
-      }
-      (*rwi)->FireTimers();
-
-      // Check if all RenderWindowInteractors have been terminated
-      done = done && (*rwi)->Done;
-
-      // If current RenderWindowInteractor have been terminated, handle its last event,
-      // then remove it from the Instance vector
-      if ((*rwi)->Done)
-      {
-        // Empty the event list
-        while (XPending((*rwi)->DisplayId) != 0)
-        {
-          XNextEvent((*rwi)->DisplayId, &event);
-          (*rwi)->DispatchEvent(&event);
-        }
-        // Adjust the file descriptors vector
-        int rwiPosition =
-          std::distance(vtkXRenderWindowInteractorInternals::Instances.begin(), rwi);
-        rwi = vtkXRenderWindowInteractorInternals::Instances.erase(rwi);
-        rwiFileDescriptors.erase(rwiFileDescriptors.begin() + rwiPosition);
-      }
-      else
-      {
-        ++rwi;
-      }
-    }
-
-    if (wait && !done)
-    {
-      // select will wait until 'tv' elapses or something else wakes us
-      FD_ZERO(&in_fds);
-      for (auto rwiFileDescriptor : rwiFileDescriptors)
-      {
-        FD_SET(rwiFileDescriptor, &in_fds);
-      }
-      int maxFileDescriptor =
-        *std::max_element(rwiFileDescriptors.begin(), rwiFileDescriptors.end());
-      select(maxFileDescriptor + 1, &in_fds, nullptr, nullptr, &minTv);
-    }
-
-  } while (!done);
+    this->ProcessEvents();
+  } while (!this->Done);
 }
 
 //------------------------------------------------------------------------------
@@ -323,6 +333,7 @@ void vtkXRenderWindowInteractor::Initialize()
   {
     vtkDebugMacro("opening display");
     this->DisplayId = XOpenDisplay(nullptr);
+    this->OwnDisplay = true;
     vtkDebugMacro("opened display");
     ren->SetDisplayId(this->DisplayId);
   }
@@ -352,6 +363,29 @@ void vtkXRenderWindowInteractor::Initialize()
   this->Size[1] = size[1];
 }
 
+void vtkXRenderWindowInteractor::Finalize()
+{
+  if (this->RenderWindow)
+  {
+    // Finalize the window
+    this->RenderWindow->Finalize();
+  }
+
+  // if we create the display, we'll delete it
+  if (this->OwnDisplay && this->DisplayId)
+  {
+    XCloseDisplay(this->DisplayId);
+  }
+
+  // disconnect from the display, even if we didn't own it
+  this->DisplayId = nullptr;
+  this->OwnDisplay = false;
+
+  // revert to uninitialized state
+  this->Initialized = false;
+  this->Enabled = false;
+}
+
 //------------------------------------------------------------------------------
 void vtkXRenderWindowInteractor::Enable()
 {
@@ -378,9 +412,11 @@ void vtkXRenderWindowInteractor::Enable()
 
   // Enable drag and drop
   Atom xdndAwareAtom = XInternAtom(this->DisplayId, "XdndAware", False);
-  char xdndVersion = 5;
-  XChangeProperty(this->DisplayId, this->WindowId, xdndAwareAtom, XA_ATOM, 32, PropModeReplace,
-    (unsigned char*)&xdndVersion, 1);
+  XChangeProperty(
+    this->DisplayId, this->WindowId, xdndAwareAtom, XA_ATOM, 32, PropModeReplace, &XDND_VERSION, 1);
+  this->XdndURIListAtom = XInternAtom(this->DisplayId, "text/uri-list", False);
+  this->XdndTypeListAtom = XInternAtom(this->DisplayId, "XdndTypeList", False);
+  this->XdndEnterAtom = XInternAtom(this->DisplayId, "XdndEnter", False);
   this->XdndPositionAtom = XInternAtom(this->DisplayId, "XdndPosition", False);
   this->XdndDropAtom = XInternAtom(this->DisplayId, "XdndDrop", False);
   this->XdndActionCopyAtom = XInternAtom(this->DisplayId, "XdndActionCopy", False);
@@ -431,8 +467,8 @@ void vtkXRenderWindowInteractor::UpdateSizeNoXResize(int x, int y)
   {
     this->Size[0] = x;
     this->Size[1] = y;
-    // static_cast<vtkXOpenGLRenderWindow*>(this->RenderWindow)->SetSizeNoXResize(x, y);
-    this->RenderWindow->SetSize(x, y);
+    // change the ivars but don't resize the X window
+    this->RenderWindow->vtkRenderWindow::SetSize(x, y);
   }
 }
 
@@ -661,13 +697,11 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
       int ctrl = ((reinterpret_cast<XButtonEvent*>(event))->state & ControlMask) ? 1 : 0;
       int shift = ((reinterpret_cast<XButtonEvent*>(event))->state & ShiftMask) ? 1 : 0;
       int alt = ((reinterpret_cast<XButtonEvent*>(event))->state & Mod1Mask) ? 1 : 0;
-      vtkKeySym ks;
-      static char buffer[20];
-      buffer[0] = '\0';
-      XLookupString(reinterpret_cast<XKeyEvent*>(event), buffer, 20, &ks, nullptr);
+      vtkKeySym keySym = XLookupKeysym(reinterpret_cast<XKeyEvent*>(event), 0);
+      char keyCode = keySym < 128 ? static_cast<char>(keySym) : 0;
       xp = (reinterpret_cast<XKeyEvent*>(event))->x;
       yp = (reinterpret_cast<XKeyEvent*>(event))->y;
-      this->SetEventInformationFlipY(xp, yp, ctrl, shift, buffer[0], 1, XKeysymToString(ks));
+      this->SetEventInformationFlipY(xp, yp, ctrl, shift, keyCode, 1, XKeysymToString(keySym));
       this->SetAltKey(alt);
       this->InvokeEvent(vtkCommand::KeyPressEvent, nullptr);
       this->InvokeEvent(vtkCommand::CharEvent, nullptr);
@@ -683,13 +717,11 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
       int ctrl = ((reinterpret_cast<XButtonEvent*>(event))->state & ControlMask) ? 1 : 0;
       int shift = ((reinterpret_cast<XButtonEvent*>(event))->state & ShiftMask) ? 1 : 0;
       int alt = ((reinterpret_cast<XButtonEvent*>(event))->state & Mod1Mask) ? 1 : 0;
-      vtkKeySym ks;
-      static char buffer[20];
-      buffer[0] = '\0';
-      XLookupString(reinterpret_cast<XKeyEvent*>(event), buffer, 20, &ks, nullptr);
+      vtkKeySym keySym = XLookupKeysym(reinterpret_cast<XKeyEvent*>(event), 0);
+      char keyCode = keySym < 128 ? static_cast<char>(keySym) : 0;
       xp = (reinterpret_cast<XKeyEvent*>(event))->x;
       yp = (reinterpret_cast<XKeyEvent*>(event))->y;
-      this->SetEventInformationFlipY(xp, yp, ctrl, shift, buffer[0], 1, XKeysymToString(ks));
+      this->SetEventInformationFlipY(xp, yp, ctrl, shift, keyCode, 1, XKeysymToString(keySym));
       this->SetAltKey(alt);
       this->InvokeEvent(vtkCommand::KeyReleaseEvent, nullptr);
     }
@@ -731,7 +763,7 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
       unsigned long itemCount, bytesAfter;
       XGetWindowProperty(this->DisplayId, event->xselection.requestor, event->xselection.property,
         0, LONG_MAX, False, event->xselection.target, &actualType, &actualFormat, &itemCount,
-        &bytesAfter, (unsigned char**)&data);
+        &bytesAfter, reinterpret_cast<unsigned char**>(&data));
 
       // Conversion checks
       if ((event->xselection.target != AnyPropertyType && actualType != event->xselection.target) ||
@@ -768,17 +800,21 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
       this->InvokeEvent(vtkCommand::DropFilesEvent, filePaths);
       XFree(data);
 
-      // Inform the source the the drag and drop operation was sucessfull
+      // Inform the source the the drag and drop operation was successful
       XEvent reply;
       memset(&reply, 0, sizeof(reply));
 
       reply.type = ClientMessage;
-      reply.xclient.window = event->xclient.data.l[0];
+      reply.xclient.window = this->XdndSource;
       reply.xclient.message_type = this->XdndFinishedAtom;
       reply.xclient.format = 32;
       reply.xclient.data.l[0] = this->WindowId;
-      reply.xclient.data.l[1] = itemCount;
-      reply.xclient.data.l[2] = this->XdndActionCopyAtom;
+      reply.xclient.data.l[1] = 1;
+
+      if (this->XdndSourceVersion >= 2)
+      {
+        reply.xclient.data.l[2] = this->XdndActionCopyAtom;
+      }
 
       XSendEvent(this->DisplayId, this->XdndSource, False, NoEventMask, &reply);
       XFlush(this->DisplayId);
@@ -788,9 +824,62 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
 
     case ClientMessage:
     {
+      if (event->xclient.message_type == this->XdndEnterAtom)
+      {
+        // Drag and drop event enter the window
+        this->XdndSource = event->xclient.data.l[0];
+
+        // Check version
+        this->XdndSourceVersion = event->xclient.data.l[1] >> 24;
+        if (this->XdndSourceVersion > XDND_VERSION)
+        {
+          return;
+        }
+
+        // Recover the formats provided by the dnd source
+        Atom* formats = nullptr;
+        unsigned long count;
+        bool list = event->xclient.data.l[1] & 1;
+        if (list)
+        {
+          Atom actualType;
+          int actualFormat;
+          unsigned long bytesAfter;
+          XGetWindowProperty(this->DisplayId, this->XdndSource, this->XdndTypeListAtom, 0, LONG_MAX,
+            False, XA_ATOM, &actualType, &actualFormat, &count, &bytesAfter,
+            reinterpret_cast<unsigned char**>(&formats));
+        }
+        else
+        {
+          count = 3;
+          formats = reinterpret_cast<Atom*>(event->xclient.data.l + 2);
+        }
+
+        // Check one of these format is an URI list
+        // Which is the only supported format
+        for (unsigned long i = 0; i < count; i++)
+        {
+          if (formats[i] == this->XdndURIListAtom)
+          {
+            this->XdndFormatAtom = XdndURIListAtom;
+            break;
+          }
+        }
+
+        // Free the allocated formats
+        if (list && formats)
+        {
+          XFree(formats);
+        }
+      }
       if (event->xclient.message_type == this->XdndPositionAtom)
       {
         // Drag and drop event inside the window
+        if (this->XdndSource != static_cast<Window>(event->xclient.data.l[0]))
+        {
+          vtkWarningMacro("Only one dnd action at a time is supported");
+          return;
+        }
 
         // Recover the position
         int xWindow, yWindow;
@@ -812,7 +901,7 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
         memset(&reply, 0, sizeof(reply));
 
         reply.type = ClientMessage;
-        reply.xclient.window = event->xclient.data.l[0];
+        reply.xclient.window = this->XdndSource;
         reply.xclient.message_type = this->XdndStatusAtom;
         reply.xclient.format = 32;
         reply.xclient.data.l[0] = this->WindowId;
@@ -821,20 +910,41 @@ void vtkXRenderWindowInteractor::DispatchEvent(XEvent* event)
         reply.xclient.data.l[3] = 0;
         reply.xclient.data.l[4] = this->XdndActionCopyAtom;
 
-        XSendEvent(this->DisplayId, event->xclient.data.l[0], False, NoEventMask, &reply);
+        XSendEvent(this->DisplayId, this->XdndSource, False, NoEventMask, &reply);
         XFlush(this->DisplayId);
       }
       else if (event->xclient.message_type == this->XdndDropAtom)
       {
         // Item dropped in the window
-        // Store the source of the drag and drop
-        this->XdndSource = event->xclient.data.l[0];
+        if (this->XdndSource != static_cast<Window>(event->xclient.data.l[0]))
+        {
+          vtkWarningMacro("Only one dnd action at a time is supported");
+          return;
+        }
 
-        // Ask for a conversion of the selection. This will trigger a SelectioNotify event later.
-        Atom xdndSelectionAtom = XInternAtom(this->DisplayId, "XdndSelection", False);
-        XConvertSelection(this->DisplayId, xdndSelectionAtom,
-          XInternAtom(this->DisplayId, "UTF8_STRING", False), xdndSelectionAtom, this->WindowId,
-          CurrentTime);
+        if (this->XdndFormatAtom)
+        {
+          // Ask for a conversion of the selection. This will trigger a SelectionNotify event later.
+          Atom xdndSelectionAtom = XInternAtom(this->DisplayId, "XdndSelection", False);
+          XConvertSelection(this->DisplayId, xdndSelectionAtom, this->XdndFormatAtom,
+            xdndSelectionAtom, this->WindowId, CurrentTime);
+        }
+        else if (this->XdndSourceVersion >= 2)
+        {
+          XEvent reply;
+          memset(&reply, 0, sizeof(reply));
+
+          reply.type = ClientMessage;
+          reply.xclient.window = this->XdndSource;
+          reply.xclient.message_type = this->XdndFinishedAtom;
+          reply.xclient.format = 32;
+          reply.xclient.data.l[0] = this->WindowId;
+          reply.xclient.data.l[1] = 0; // The drag was rejected
+          reply.xclient.data.l[2] = None;
+
+          XSendEvent(this->DisplayId, this->XdndSource, False, NoEventMask, &reply);
+          XFlush(this->DisplayId);
+        }
       }
       else if (static_cast<Atom>(event->xclient.data.l[0]) == this->KillAtom)
       {
@@ -869,3 +979,4 @@ void vtkXRenderWindowInteractor::GetMousePosition(int* x, int* y)
 // {
 //   vtkXRenderWindowInteractorCallback(w, client_data, event, ctd);
 // }
+VTK_ABI_NAMESPACE_END
