@@ -18,6 +18,7 @@
 #include "vtkRendererCollection.h"
 #include "vtkVRRenderWindow.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 void (*vtkVRRenderWindowInteractor::ClassExitMethod)(void*) = (void (*)(void*)) nullptr;
 void* vtkVRRenderWindowInteractor::ClassExitMethodArg = (void*)nullptr;
 void (*vtkVRRenderWindowInteractor::ClassExitMethodArgDelete)(void*) = (void (*)(void*)) nullptr;
@@ -126,6 +127,40 @@ void vtkVRRenderWindowInteractor::ExitCallback()
   this->TerminateApp();
 }
 
+//------------------------------------------------------------------------------
+void vtkVRRenderWindowInteractor::SetPhysicalViewDirection(double x, double y, double z)
+{
+  vtkVRRenderWindow* win = vtkVRRenderWindow::SafeDownCast(this->RenderWindow);
+  if (win)
+  {
+    win->SetPhysicalViewDirection(x, y, z);
+  }
+}
+
+//------------------------------------------------------------------------------
+double* vtkVRRenderWindowInteractor::GetPhysicalViewDirection()
+{
+  vtkVRRenderWindow* win = vtkVRRenderWindow::SafeDownCast(this->RenderWindow);
+  return win ? win->GetPhysicalViewDirection() : nullptr;
+}
+
+//------------------------------------------------------------------------------
+void vtkVRRenderWindowInteractor::SetPhysicalViewUp(double x, double y, double z)
+{
+  vtkVRRenderWindow* win = vtkVRRenderWindow::SafeDownCast(this->RenderWindow);
+  if (win)
+  {
+    win->SetPhysicalViewUp(x, y, z);
+  }
+}
+
+//------------------------------------------------------------------------------
+double* vtkVRRenderWindowInteractor::GetPhysicalViewUp()
+{
+  vtkVRRenderWindow* win = vtkVRRenderWindow::SafeDownCast(this->RenderWindow);
+  return win ? win->GetPhysicalViewUp() : nullptr;
+}
+
 //------------------------------------------------------------------------------
 void vtkVRRenderWindowInteractor::SetPhysicalTranslation(
   vtkCamera*, double t1, double t2, double t3)
@@ -484,3 +519,4 @@ void vtkVRRenderWindowInteractor::RecognizeComplexGesture(vtkEventDataDevice3D*)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
