@@ -27,6 +27,7 @@
 
 #include <string> // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMatrix4x4;
 class vtkVRRenderWindow;
 
@@ -70,11 +71,32 @@ public:
 
   ///@{
   /**
-   * Set/Get the optional translation to map world coordinates into the
-   * 3D physical space (meters, 0,0,0).
+   * Set/get the direction of the physical coordinate system -Z axis in world coordinates.
+   */
+  void SetPhysicalViewDirection(double, double, double) override;
+  double* GetPhysicalViewDirection() override;
+  ///@}
+
+  ///@{
+  /**
+   * Set/get the direction of the physical coordinate system +Y axis in world coordinates.
+   */
+  void SetPhysicalViewUp(double, double, double) override;
+  double* GetPhysicalViewUp() override;
+  ///@}
+
+  ///@{
+  /**
+   * Set/get position of the physical coordinate system origin in world coordinates.
    */
   void SetPhysicalTranslation(vtkCamera*, double, double, double) override;
   double* GetPhysicalTranslation(vtkCamera*) override;
+  ///@}
+
+  ///@{
+  /**
+   * Set/get the physical scale (world / physical distance ratio)
+   */
   void SetPhysicalScale(double) override;
   double GetPhysicalScale() override;
   ///@}
@@ -167,4 +189,5 @@ private:
   void operator=(const vtkVRRenderWindowInteractor&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
