@@ -36,7 +36,6 @@
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRenderer.h"
 #include "vtkSLCReader.h"
-#include "vtkStdString.h"
 #include "vtkStructuredPoints.h"
 #include "vtkStructuredPointsReader.h"
 #include "vtkThreshold.h"
@@ -87,10 +86,10 @@ int TestProjectedTetrahedra(int argc, char* argv[])
 
   // Create the reader for the data.
   // This is the data that will be volume rendered.
-  vtkStdString filename;
+  std::string filename;
   filename = data_root;
   filename += "/Data/ironProt.vtk";
-  cout << "Loading " << filename.c_str() << endl;
+  cout << "Loading " << filename << endl;
   vtkStructuredPointsReader* reader = vtkStructuredPointsReader::New();
   reader->SetFileName(filename.c_str());
 
@@ -98,14 +97,15 @@ int TestProjectedTetrahedra(int argc, char* argv[])
   // displayed as a polygonal mesh.
   filename = data_root;
   filename += "/Data/neghip.slc";
-  cout << "Loading " << filename.c_str() << endl;
+  cout << "Loading " << filename << endl;
   vtkSLCReader* reader2 = vtkSLCReader::New();
   reader2->SetFileName(filename.c_str());
 
   // Convert from vtkImageData to vtkUnstructuredGrid.
   // Remove any cells where all values are below 80.
   vtkThreshold* thresh = vtkThreshold::New();
-  thresh->ThresholdByUpper(80);
+  thresh->SetThresholdFunction(vtkThreshold::THRESHOLD_UPPER);
+  thresh->SetUpperThreshold(80.0);
   thresh->AllScalarsOff();
   thresh->SetInputConnection(reader->GetOutputPort());
 
