@@ -15,18 +15,20 @@
 =========================================================================*/
 #include "vtkFixedPointVolumeRayCastCompositeHelper.h"
 
-#include "vtkImageData.h"
 #include "vtkCommand.h"
+#include "vtkDataArray.h"
+#include "vtkFixedPointRayCastImage.h"
 #include "vtkFixedPointVolumeRayCastMapper.h"
+#include "vtkImageData.h"
 #include "vtkObjectFactory.h"
+#include "vtkRectilinearGrid.h"
 #include "vtkRenderWindow.h"
 #include "vtkVolume.h"
 #include "vtkVolumeProperty.h"
-#include "vtkFixedPointRayCastImage.h"
-#include "vtkDataArray.h"
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFixedPointVolumeRayCastCompositeHelper);
 
 // Construct a new vtkFixedPointVolumeRayCastCompositeHelper with default values
@@ -35,7 +37,6 @@ vtkFixedPointVolumeRayCastCompositeHelper::vtkFixedPointVolumeRayCastCompositeHe
 // Destruct a vtkFixedPointVolumeRayCastCompositeHelper - clean up any memory used
 vtkFixedPointVolumeRayCastCompositeHelper::~vtkFixedPointVolumeRayCastCompositeHelper() = default;
 
-
 // This method is used when the interpolation type is nearest neighbor and
 // the data has one component and scale == 1.0 and shift == 0.0. In the inner
 // loop we get the data value as an unsigned short, and use this index to
@@ -44,38 +45,35 @@ vtkFixedPointVolumeRayCastCompositeHelper::~vtkFixedPointVolumeRayCastCompositeH
 // this point (if the accumulated opacity is higher than some threshold).
 // Finally we move on to the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageOneSimpleNN( T *data,
-                                                   int threadID,
-                                                   int threadCount,
-                                                   vtkFixedPointVolumeRayCastMapper *mapper,
-                                                   vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageOneSimpleNN(T* data, int threadID, int threadCount,
+  vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartNN();
   VTKKWRCHelper_InitializeCompositeOneNN();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
 
-    if ( k )
+    if (k)
     {
       VTKKWRCHelper_MoveToNextSampleNN();
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckNN( pos );
+    VTKKWRCHelper_CroppingCheckNN(pos);
 
     unsigned short val = static_cast<unsigned short>(((*dptr)));
 
-    VTKKWRCHelper_LookupColorUS( colorTable[0], scalarOpacityTable[0], val, tmp );
+    VTKKWRCHelper_LookupColorUS(colorTable[0], scalarOpacityTable[0], val, tmp);
 
-    if ( tmp[3] )
+    if (tmp[3])
     {
-      VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+      VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
     }
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
@@ -87,41 +85,37 @@ void vtkFixedPointCompositeHelperGenerateImageOneSimpleNN( T *data,
 // this point (if the accumulated opacity is higher than some threshold).
 // Finally we move on to the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageOneNN( T *data,
-                                             int threadID,
-                                             int threadCount,
-                                             vtkFixedPointVolumeRayCastMapper *mapper,
-                                             vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageOneNN(T* data, int threadID, int threadCount,
+  vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartNN();
   VTKKWRCHelper_InitializeCompositeOneNN();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
       VTKKWRCHelper_MoveToNextSampleNN();
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckNN( pos );
+    VTKKWRCHelper_CroppingCheckNN(pos);
 
-    unsigned short val = static_cast<unsigned short>(((*dptr) + shift[0])*scale[0]);
+    unsigned short val = static_cast<unsigned short>(((*dptr) + shift[0]) * scale[0]);
 
-    VTKKWRCHelper_LookupColorUS( colorTable[0], scalarOpacityTable[0], val, tmp );
+    VTKKWRCHelper_LookupColorUS(colorTable[0], scalarOpacityTable[0], val, tmp);
 
-    if ( tmp[3] )
+    if (tmp[3])
     {
-      VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+      VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
     }
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
-
 // This method is used when the interpolation type is nearest neighbor and
 // the data has two components which are not considered independent. In the
 // inner loop we compute the two unsigned short index values from the data
@@ -131,49 +125,45 @@ void vtkFixedPointCompositeHelperGenerateImageOneNN( T *data,
 // see if we can terminate here (if the opacity accumulated exceed some
 // threshold). Finally we move to the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageTwoDependentNN( T *data,
-                                                      int threadID,
-                                                      int threadCount,
-                                                      vtkFixedPointVolumeRayCastMapper *mapper,
-                                                      vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageTwoDependentNN(T* data, int threadID, int threadCount,
+  vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartNN();
   VTKKWRCHelper_InitializeCompositeOneNN();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
       VTKKWRCHelper_MoveToNextSampleNN();
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckNN( pos );
+    VTKKWRCHelper_CroppingCheckNN(pos);
 
     unsigned short val[2];
-    val[1] = static_cast<unsigned short>(((*(dptr+1)) + shift[1])*scale[1]);
+    val[1] = static_cast<unsigned short>(((*(dptr + 1)) + shift[1]) * scale[1]);
 
     tmp[3] = scalarOpacityTable[0][val[1]];
-    if ( !tmp[3] )
+    if (!tmp[3])
     {
       continue;
     }
 
-    val[0] = static_cast<unsigned short>(((*(dptr  )) + shift[0])*scale[0]);
+    val[0] = static_cast<unsigned short>(((*(dptr)) + shift[0]) * scale[0]);
 
-    tmp[0] = static_cast<unsigned short>
-      ((colorTable[0][3*val[0]  ]*tmp[3] + 0x7fff)>>(VTKKW_FP_SHIFT));
-    tmp[1] = static_cast<unsigned short>
-      ((colorTable[0][3*val[0]+1]*tmp[3] + 0x7fff)>>(VTKKW_FP_SHIFT));
-    tmp[2] = static_cast<unsigned short>
-      ((colorTable[0][3*val[0]+2]*tmp[3] + 0x7fff)>>(VTKKW_FP_SHIFT));
-
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+    tmp[0] = static_cast<unsigned short>(
+      (colorTable[0][3 * val[0]] * tmp[3] + 0x7fff) >> (VTKKW_FP_SHIFT));
+    tmp[1] = static_cast<unsigned short>(
+      (colorTable[0][3 * val[0] + 1] * tmp[3] + 0x7fff) >> (VTKKW_FP_SHIFT));
+    tmp[2] = static_cast<unsigned short>(
+      (colorTable[0][3 * val[0] + 2] * tmp[3] + 0x7fff) >> (VTKKW_FP_SHIFT));
 
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
@@ -188,47 +178,44 @@ void vtkFixedPointCompositeHelperGenerateImageTwoDependentNN( T *data,
 // terminate here (if our accumulated opacity has exceed some threshold).
 // Finally we move onto the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageFourDependentNN( T *data,
-                                                       int threadID,
-                                                       int threadCount,
-                                                       vtkFixedPointVolumeRayCastMapper *mapper,
-                                                       vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageFourDependentNN(T* data, int threadID,
+  int threadCount, vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartNN();
   VTKKWRCHelper_InitializeCompositeOneNN();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
       VTKKWRCHelper_MoveToNextSampleNN();
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckNN( pos );
+    VTKKWRCHelper_CroppingCheckNN(pos);
 
     unsigned short val[4];
-    val[3] = static_cast<unsigned short>(((*(dptr+3)) + shift[3])*scale[3]);
+    val[3] = static_cast<unsigned short>(((*(dptr + 3)) + shift[3]) * scale[3]);
 
     tmp[3] = scalarOpacityTable[0][val[3]];
-    if ( !tmp[3] )
+    if (!tmp[3])
     {
       continue;
     }
 
-    val[0] = *(dptr  );
-    val[1] = *(dptr+1);
-    val[2] = *(dptr+2);
+    val[0] = *(dptr);
+    val[1] = *(dptr + 1);
+    val[2] = *(dptr + 2);
 
-    tmp[0] = (val[0]*tmp[3]+0x7f)>>(8);
-    tmp[1] = (val[1]*tmp[3]+0x7f)>>(8);
-    tmp[2] = (val[2]*tmp[3]+0x7f)>>(8);
+    tmp[0] = (val[0] * tmp[3] + 0x7f) >> (8);
+    tmp[1] = (val[1] * tmp[3] + 0x7f) >> (8);
+    tmp[2] = (val[2] * tmp[3] + 0x7f) >> (8);
 
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
@@ -242,40 +229,36 @@ void vtkFixedPointCompositeHelperGenerateImageFourDependentNN( T *data,
 // whether we can terminate here (if the accumulated opacity exceeds some
 // threshold). Finally we increment to the next sample on the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageIndependentNN( T *data,
-                                                     int threadID,
-                                                     int threadCount,
-                                                     vtkFixedPointVolumeRayCastMapper *mapper,
-                                                     vtkVolume *vol)
+void vtkFixedPointCompositeHelperGenerateImageIndependentNN(
+  T* data, int threadID, int threadCount, vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vol)
 {
   VTKKWRCHelper_InitializeWeights();
   VTKKWRCHelper_InitializationAndLoopStartNN();
   VTKKWRCHelper_InitializeCompositeMultiNN();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
       VTKKWRCHelper_MoveToNextSampleNN();
     }
 
-    VTKKWRCHelper_CroppingCheckNN( pos );
+    VTKKWRCHelper_CroppingCheckNN(pos);
 
-    for ( c = 0; c < components; c++ )
+    for (c = 0; c < components; c++)
     {
-      val[c] = static_cast<unsigned short>(((*(dptr+c)) + shift[c])*scale[c]);
+      val[c] = static_cast<unsigned short>(((*(dptr + c)) + shift[c]) * scale[c]);
     }
 
-
-    VTKKWRCHelper_LookupAndCombineIndependentColorsUS( colorTable, scalarOpacityTable,
-                                                       val, weights, components, tmp );
-    if ( tmp[3] )
+    VTKKWRCHelper_LookupAndCombineIndependentColorsUS(
+      colorTable, scalarOpacityTable, val, weights, components, tmp);
+    if (tmp[3])
     {
-      VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+      VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
     }
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
@@ -291,48 +274,43 @@ void vtkFixedPointCompositeHelperGenerateImageIndependentNN( T *data,
 // opacity is higher than some threshold). Finally we move on to the next
 // sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageOneSimpleTrilin( T *data,
-                                                       int threadID,
-                                                       int threadCount,
-                                                       vtkFixedPointVolumeRayCastMapper *mapper,
-                                                       vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageOneSimpleTrilin(T* data, int threadID,
+  int threadCount, vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartTrilin();
   VTKKWRCHelper_InitializeCompositeOneTrilin();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
-      mapper->FixedPointIncrement( pos, dir );
+      mapper->FixedPointIncrement(pos, dir);
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckTrilin( pos );
+    VTKKWRCHelper_CroppingCheckTrilin(pos);
 
-    mapper->ShiftVectorDown( pos, spos );
+    mapper->ShiftVectorDown(pos, spos);
 
-    if ( spos[0] != oldSPos[0] ||
-         spos[1] != oldSPos[1] ||
-         spos[2] != oldSPos[2] )
+    if (spos[0] != oldSPos[0] || spos[1] != oldSPos[1] || spos[2] != oldSPos[2])
     {
       oldSPos[0] = spos[0];
       oldSPos[1] = spos[1];
       oldSPos[2] = spos[2];
 
-      dptr = data + spos[0]*inc[0] + spos[1]*inc[1] + spos[2]*inc[2];
-      VTKKWRCHelper_GetCellScalarValuesSimple( dptr );
+      dptr = data + spos[0] * inc[0] + spos[1] * inc[1] + spos[2] * inc[2];
+      VTKKWRCHelper_GetCellScalarValuesSimple(dptr);
     }
 
     VTKKWRCHelper_ComputeWeights(pos);
     VTKKWRCHelper_InterpolateScalar(val);
 
-    VTKKWRCHelper_LookupColorUS( colorTable[0], scalarOpacityTable[0], val, tmp );
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+    VTKKWRCHelper_LookupColorUS(colorTable[0], scalarOpacityTable[0], val, tmp);
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
@@ -347,52 +325,45 @@ void vtkFixedPointCompositeHelperGenerateImageOneSimpleTrilin( T *data,
 // terminate at this point (if the accumulated opacity is higher than some
 // threshold). Finally we move on to the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageOneTrilin( T *data,
-                                                 int threadID,
-                                                 int threadCount,
-                                                 vtkFixedPointVolumeRayCastMapper *mapper,
-                                                 vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageOneTrilin(T* data, int threadID, int threadCount,
+  vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartTrilin();
   VTKKWRCHelper_InitializeCompositeOneTrilin();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
-      mapper->FixedPointIncrement( pos, dir );
+      mapper->FixedPointIncrement(pos, dir);
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckTrilin( pos );
+    VTKKWRCHelper_CroppingCheckTrilin(pos);
 
-    mapper->ShiftVectorDown( pos, spos );
-    if ( spos[0] != oldSPos[0] ||
-         spos[1] != oldSPos[1] ||
-         spos[2] != oldSPos[2] )
+    mapper->ShiftVectorDown(pos, spos);
+    if (spos[0] != oldSPos[0] || spos[1] != oldSPos[1] || spos[2] != oldSPos[2])
     {
       oldSPos[0] = spos[0];
       oldSPos[1] = spos[1];
       oldSPos[2] = spos[2];
 
-
-      dptr = data + spos[0]*inc[0] + spos[1]*inc[1] + spos[2]*inc[2];
-      VTKKWRCHelper_GetCellScalarValues( dptr, scale[0], shift[0] );
+      dptr = data + spos[0] * inc[0] + spos[1] * inc[1] + spos[2] * inc[2];
+      VTKKWRCHelper_GetCellScalarValues(dptr, scale[0], shift[0]);
     }
 
     VTKKWRCHelper_ComputeWeights(pos);
     VTKKWRCHelper_InterpolateScalar(val);
 
-    VTKKWRCHelper_LookupColorUS( colorTable[0], scalarOpacityTable[0], val, tmp );
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+    VTKKWRCHelper_LookupColorUS(colorTable[0], scalarOpacityTable[0], val, tmp);
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
-
 // This method is used when the interpolation type is linear, the data has
 // two components and the components are not considered independent. In the
 // inner loop we get the data value for the eight cell corners (if we have
@@ -406,69 +377,60 @@ void vtkFixedPointCompositeHelperGenerateImageOneTrilin( T *data,
 // higher than some threshold). Finally we move on to the next sample along
 // the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageTwoDependentTrilin( T *data,
-                                                          int threadID,
-                                                          int threadCount,
-                                                          vtkFixedPointVolumeRayCastMapper *mapper,
-                                                          vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageTwoDependentTrilin(T* data, int threadID,
+  int threadCount, vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartTrilin();
   VTKKWRCHelper_InitializeCompositeMultiTrilin();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
-      mapper->FixedPointIncrement( pos, dir );
+      mapper->FixedPointIncrement(pos, dir);
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckTrilin( pos );
+    VTKKWRCHelper_CroppingCheckTrilin(pos);
 
-    mapper->ShiftVectorDown( pos, spos );
-    if ( spos[0] != oldSPos[0] ||
-         spos[1] != oldSPos[1] ||
-         spos[2] != oldSPos[2] )
+    mapper->ShiftVectorDown(pos, spos);
+    if (spos[0] != oldSPos[0] || spos[1] != oldSPos[1] || spos[2] != oldSPos[2])
     {
       oldSPos[0] = spos[0];
       oldSPos[1] = spos[1];
       oldSPos[2] = spos[2];
 
-      dptr = data + spos[0]*inc[0] + spos[1]*inc[1] + spos[2]*inc[2];
-      VTKKWRCHelper_GetCellComponentScalarValues( dptr, 0, scale[0], shift[0] );
+      dptr = data + spos[0] * inc[0] + spos[1] * inc[1] + spos[2] * inc[2];
+      VTKKWRCHelper_GetCellComponentScalarValues(dptr, 0, scale[0], shift[0]);
 
       dptr++;
-      VTKKWRCHelper_GetCellComponentScalarValues( dptr, 1, scale[1], shift[1] );
+      VTKKWRCHelper_GetCellComponentScalarValues(dptr, 1, scale[1], shift[1]);
     }
 
     VTKKWRCHelper_ComputeWeights(pos);
-    VTKKWRCHelper_InterpolateScalarComponent( val, c, 2 );
+    VTKKWRCHelper_InterpolateScalarComponent(val, c, 2);
 
     tmp[3] = scalarOpacityTable[0][val[1]];
-    if ( !tmp[3] )
+    if (!tmp[3])
     {
       continue;
     }
 
-    tmp[0] = static_cast<unsigned short>
-      ((colorTable[0][3*val[0]  ]*tmp[3] + 0x7fff)>>(VTKKW_FP_SHIFT));
-    tmp[1] = static_cast<unsigned short>
-      ((colorTable[0][3*val[0]+1]*tmp[3] + 0x7fff)>>(VTKKW_FP_SHIFT));
-    tmp[2] = static_cast<unsigned short>
-      ((colorTable[0][3*val[0]+2]*tmp[3] + 0x7fff)>>(VTKKW_FP_SHIFT));
-
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
-
+    tmp[0] = static_cast<unsigned short>(
+      (colorTable[0][3 * val[0]] * tmp[3] + 0x7fff) >> (VTKKW_FP_SHIFT));
+    tmp[1] = static_cast<unsigned short>(
+      (colorTable[0][3 * val[0] + 1] * tmp[3] + 0x7fff) >> (VTKKW_FP_SHIFT));
+    tmp[2] = static_cast<unsigned short>(
+      (colorTable[0][3 * val[0] + 2] * tmp[3] + 0x7fff) >> (VTKKW_FP_SHIFT));
 
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
-
-
 // This method is used when the interpolation type is linear, the data has
 // four components and the components are not considered independent. In the
 // inner loop we get the data value for the eight cell corners (if we have
@@ -483,66 +445,60 @@ void vtkFixedPointCompositeHelperGenerateImageTwoDependentTrilin( T *data,
 // point (if the accumulated opacity is higher than some threshold). Finally we
 // move on to the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageFourDependentTrilin( T *data,
-                                                           int threadID,
-                                                           int threadCount,
-                                                           vtkFixedPointVolumeRayCastMapper *mapper,
-                                                           vtkVolume *vtkNotUsed(vol))
+void vtkFixedPointCompositeHelperGenerateImageFourDependentTrilin(T* data, int threadID,
+  int threadCount, vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vtkNotUsed(vol))
 {
   VTKKWRCHelper_InitializationAndLoopStartTrilin();
   VTKKWRCHelper_InitializeCompositeMultiTrilin();
   VTKKWRCHelper_SpaceLeapSetup();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
-      mapper->FixedPointIncrement( pos, dir );
+      mapper->FixedPointIncrement(pos, dir);
     }
 
     VTKKWRCHelper_SpaceLeapCheck();
-    VTKKWRCHelper_CroppingCheckTrilin( pos );
+    VTKKWRCHelper_CroppingCheckTrilin(pos);
 
-    mapper->ShiftVectorDown( pos, spos );
-    if ( spos[0] != oldSPos[0] ||
-         spos[1] != oldSPos[1] ||
-         spos[2] != oldSPos[2] )
+    mapper->ShiftVectorDown(pos, spos);
+    if (spos[0] != oldSPos[0] || spos[1] != oldSPos[1] || spos[2] != oldSPos[2])
     {
       oldSPos[0] = spos[0];
       oldSPos[1] = spos[1];
       oldSPos[2] = spos[2];
 
-      dptr = data + spos[0]*inc[0] + spos[1]*inc[1] + spos[2]*inc[2];
-      VTKKWRCHelper_GetCellComponentRawScalarValues( dptr, 0 );
+      dptr = data + spos[0] * inc[0] + spos[1] * inc[1] + spos[2] * inc[2];
+      VTKKWRCHelper_GetCellComponentRawScalarValues(dptr, 0);
 
       dptr++;
-      VTKKWRCHelper_GetCellComponentRawScalarValues( dptr, 1 );
+      VTKKWRCHelper_GetCellComponentRawScalarValues(dptr, 1);
 
       dptr++;
-      VTKKWRCHelper_GetCellComponentRawScalarValues( dptr, 2 );
+      VTKKWRCHelper_GetCellComponentRawScalarValues(dptr, 2);
 
       dptr++;
-      VTKKWRCHelper_GetCellComponentScalarValues( dptr, 3, scale[3], shift[3] );
-
+      VTKKWRCHelper_GetCellComponentScalarValues(dptr, 3, scale[3], shift[3]);
     }
 
     VTKKWRCHelper_ComputeWeights(pos);
-    VTKKWRCHelper_InterpolateScalarComponent( val, c, components );
+    VTKKWRCHelper_InterpolateScalarComponent(val, c, components);
 
     tmp[3] = scalarOpacityTable[0][val[3]];
-    if ( !tmp[3] )
+    if (!tmp[3])
     {
       continue;
     }
 
-    tmp[0] = (val[0]*tmp[3]+0x7f)>>8;
-    tmp[1] = (val[1]*tmp[3]+0x7f)>>8;
-    tmp[2] = (val[2]*tmp[3]+0x7f)>>8;
+    tmp[0] = (val[0] * tmp[3] + 0x7f) >> 8;
+    tmp[1] = (val[1] * tmp[3] + 0x7f) >> 8;
+    tmp[2] = (val[2] * tmp[3] + 0x7f) >> 8;
 
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
@@ -559,115 +515,98 @@ void vtkFixedPointCompositeHelperGenerateImageFourDependentTrilin( T *data,
 // point (if the accumulated opacity is higher than some threshold). Finally we
 // move on to the next sample along the ray.
 template <class T>
-void vtkFixedPointCompositeHelperGenerateImageIndependentTrilin( T *data,
-                                                         int threadID,
-                                                         int threadCount,
-                                                         vtkFixedPointVolumeRayCastMapper *mapper,
-                                                         vtkVolume *vol)
+void vtkFixedPointCompositeHelperGenerateImageIndependentTrilin(
+  T* data, int threadID, int threadCount, vtkFixedPointVolumeRayCastMapper* mapper, vtkVolume* vol)
 {
   VTKKWRCHelper_InitializeWeights();
   VTKKWRCHelper_InitializationAndLoopStartTrilin();
   VTKKWRCHelper_InitializeCompositeMultiTrilin();
 
-  for ( k = 0; k < numSteps; k++ )
+  for (k = 0; k < numSteps; k++)
   {
-    if ( k )
+    if (k)
     {
-      mapper->FixedPointIncrement( pos, dir );
+      mapper->FixedPointIncrement(pos, dir);
     }
 
-    VTKKWRCHelper_CroppingCheckTrilin( pos );
+    VTKKWRCHelper_CroppingCheckTrilin(pos);
 
-    mapper->ShiftVectorDown( pos, spos );
-    if ( spos[0] != oldSPos[0] ||
-         spos[1] != oldSPos[1] ||
-         spos[2] != oldSPos[2] )
+    mapper->ShiftVectorDown(pos, spos);
+    if (spos[0] != oldSPos[0] || spos[1] != oldSPos[1] || spos[2] != oldSPos[2])
     {
       oldSPos[0] = spos[0];
       oldSPos[1] = spos[1];
       oldSPos[2] = spos[2];
 
-      dptr = data + spos[0]*inc[0] + spos[1]*inc[1] + spos[2]*inc[2];
-      VTKKWRCHelper_GetCellComponentScalarValues( dptr, 0, scale[0], shift[0] );
+      dptr = data + spos[0] * inc[0] + spos[1] * inc[1] + spos[2] * inc[2];
+      VTKKWRCHelper_GetCellComponentScalarValues(dptr, 0, scale[0], shift[0]);
 
       dptr++;
-      VTKKWRCHelper_GetCellComponentScalarValues( dptr, 1, scale[1], shift[1] );
+      VTKKWRCHelper_GetCellComponentScalarValues(dptr, 1, scale[1], shift[1]);
 
-      if ( components > 2 )
+      if (components > 2)
       {
         dptr++;
-        VTKKWRCHelper_GetCellComponentScalarValues( dptr, 2, scale[2], shift[2] );
+        VTKKWRCHelper_GetCellComponentScalarValues(dptr, 2, scale[2], shift[2]);
       }
 
-      if ( components > 3 )
+      if (components > 3)
       {
         dptr++;
-        VTKKWRCHelper_GetCellComponentScalarValues( dptr, 3, scale[3], shift[3] );
+        VTKKWRCHelper_GetCellComponentScalarValues(dptr, 3, scale[3], shift[3]);
       }
     }
 
     VTKKWRCHelper_ComputeWeights(pos);
-    VTKKWRCHelper_InterpolateScalarComponent( val, c, components );
+    VTKKWRCHelper_InterpolateScalarComponent(val, c, components);
 
-    VTKKWRCHelper_LookupAndCombineIndependentColorsUS( colorTable, scalarOpacityTable,
-                                                       val, weights, components, tmp );
-
-    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination( color, tmp, remainingOpacity );
+    VTKKWRCHelper_LookupAndCombineIndependentColorsUS(
+      colorTable, scalarOpacityTable, val, weights, components, tmp);
 
+    VTKKWRCHelper_CompositeColorAndCheckEarlyTermination(color, tmp, remainingOpacity);
   }
 
-  VTKKWRCHelper_SetPixelColor( imagePtr, color, remainingOpacity );
+  VTKKWRCHelper_SetPixelColor(imagePtr, color, remainingOpacity);
   VTKKWRCHelper_IncrementAndLoopEnd();
 }
 
-
 void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
-  int threadID,
-  int threadCount,
-  vtkVolume *vol,
-  vtkFixedPointVolumeRayCastMapper *mapper )
+  int threadID, int threadCount, vtkVolume* vol, vtkFixedPointVolumeRayCastMapper* mapper)
 {
-  void *data     = mapper->GetCurrentScalars()->GetVoidPointer(0);
+  void* data = mapper->GetCurrentScalars()->GetVoidPointer(0);
   int scalarType = mapper->GetCurrentScalars()->GetDataType();
 
   // Nearest Neighbor interpolate
-  if ( mapper->ShouldUseNearestNeighborInterpolation( vol ) )
+  if (mapper->ShouldUseNearestNeighborInterpolation(vol))
   {
     // One component data
-    if ( mapper->GetCurrentScalars()->GetNumberOfComponents() == 1 )
+    if (mapper->GetCurrentScalars()->GetNumberOfComponents() == 1)
     {
       // Scale == 1.0 and shift == 0.0 - simple case (faster)
-      if ( mapper->GetTableScale()[0] == 1.0 &&
-           mapper->GetTableShift()[0] == 0.0 )
+      if (mapper->GetTableScale()[0] == 1.0 && mapper->GetTableShift()[0] == 0.0)
       {
-        switch ( scalarType )
+        switch (scalarType)
         {
-          vtkTemplateMacro(
-            vtkFixedPointCompositeHelperGenerateImageOneSimpleNN(
-              static_cast<VTK_TT *>(data),
-              threadID, threadCount, mapper, vol) );
+          vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageOneSimpleNN(
+            static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
         }
       }
       else
       {
-        switch ( scalarType )
+        switch (scalarType)
         {
-          vtkTemplateMacro(
-            vtkFixedPointCompositeHelperGenerateImageOneNN(
-              static_cast<VTK_TT *>(data),
-              threadID, threadCount, mapper, vol) );
+          vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageOneNN(
+            static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
         }
       }
     }
     // More that one independent components
-    else if ( vol->GetProperty()->GetIndependentComponents() )
+    else if (vol->GetProperty()->GetIndependentComponents())
     {
-      switch ( scalarType )
+      switch (scalarType)
       {
-        vtkTemplateMacro(
-          vtkFixedPointCompositeHelperGenerateImageIndependentNN(
-            static_cast<VTK_TT *>(data),
-            threadID, threadCount, mapper, vol) );
+        vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageIndependentNN(
+          static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
       }
     }
     // Dependent (color) components
@@ -675,14 +614,12 @@ void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
     {
       // Two components - the first specifies color (through a lookup table)
       // and the second specified opacity (through a lookup table)
-      if ( mapper->GetCurrentScalars()->GetNumberOfComponents() == 2 )
+      if (mapper->GetCurrentScalars()->GetNumberOfComponents() == 2)
       {
-        switch ( scalarType )
+        switch (scalarType)
         {
-          vtkTemplateMacro(
-            vtkFixedPointCompositeHelperGenerateImageTwoDependentNN(
-              static_cast<VTK_TT *>(data),
-              threadID, threadCount, mapper, vol) );
+          vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageTwoDependentNN(
+            static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
         }
       }
       // Four components - they must be unsigned char, the first three directly
@@ -690,11 +627,10 @@ void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
       // table)
       else
       {
-        if ( scalarType == VTK_UNSIGNED_CHAR )
+        if (scalarType == VTK_UNSIGNED_CHAR)
         {
           vtkFixedPointCompositeHelperGenerateImageFourDependentNN(
-            static_cast<unsigned char *>(data), threadID, threadCount, mapper,
-            vol );
+            static_cast<unsigned char*>(data), threadID, threadCount, mapper, vol);
         }
         else
         {
@@ -707,41 +643,34 @@ void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
   else
   {
     // One component
-    if ( mapper->GetCurrentScalars()->GetNumberOfComponents() == 1 )
+    if (mapper->GetCurrentScalars()->GetNumberOfComponents() == 1)
     {
       // Scale == 1.0 and shift == 0.0 - simple case (faster)
-      if ( mapper->GetTableScale()[0] == 1.0 &&
-           mapper->GetTableShift()[0] == 0.0 )
+      if (mapper->GetTableScale()[0] == 1.0 && mapper->GetTableShift()[0] == 0.0)
       {
-        switch ( scalarType )
+        switch (scalarType)
         {
-          vtkTemplateMacro(
-            vtkFixedPointCompositeHelperGenerateImageOneSimpleTrilin(
-              static_cast<VTK_TT *>(data),
-              threadID, threadCount, mapper, vol) );
+          vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageOneSimpleTrilin(
+            static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
         }
       }
       // Scale != 1.0 or shift != 0.0 - must apply scale/shift in inner loop
       else
       {
-        switch ( scalarType )
+        switch (scalarType)
         {
-          vtkTemplateMacro(
-            vtkFixedPointCompositeHelperGenerateImageOneTrilin(
-              static_cast<VTK_TT *>(data),
-              threadID, threadCount, mapper, vol) );
+          vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageOneTrilin(
+            static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
         }
       }
     }
     // Independent components (more than one)
-    else if ( vol->GetProperty()->GetIndependentComponents() )
+    else if (vol->GetProperty()->GetIndependentComponents())
     {
-      switch ( scalarType )
+      switch (scalarType)
       {
-        vtkTemplateMacro(
-          vtkFixedPointCompositeHelperGenerateImageIndependentTrilin(
-            static_cast<VTK_TT *>(data),
-            threadID, threadCount, mapper, vol) );
+        vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageIndependentTrilin(
+          static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
       }
     }
     // Dependent components
@@ -749,14 +678,12 @@ void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
     {
       // Two components - the first specifies color (through a lookup table)
       // and the second specified opacity (through a lookup table)
-      if ( mapper->GetCurrentScalars()->GetNumberOfComponents() == 2 )
+      if (mapper->GetCurrentScalars()->GetNumberOfComponents() == 2)
       {
-        switch ( scalarType )
+        switch (scalarType)
         {
-          vtkTemplateMacro(
-            vtkFixedPointCompositeHelperGenerateImageTwoDependentTrilin(
-              static_cast<VTK_TT *>(data),
-              threadID, threadCount, mapper, vol) );
+          vtkTemplateMacro(vtkFixedPointCompositeHelperGenerateImageTwoDependentTrilin(
+            static_cast<VTK_TT*>(data), threadID, threadCount, mapper, vol));
         }
       }
       // Four components - they must be unsigned char, the first three directly
@@ -764,11 +691,10 @@ void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
       // table)
       else
       {
-        if ( scalarType == VTK_UNSIGNED_CHAR )
+        if (scalarType == VTK_UNSIGNED_CHAR)
         {
           vtkFixedPointCompositeHelperGenerateImageFourDependentTrilin(
-            static_cast<unsigned char *>(data), threadID, threadCount, mapper,
-            vol );
+            static_cast<unsigned char*>(data), threadID, threadCount, mapper, vol);
         }
         else
         {
@@ -782,6 +708,6 @@ void vtkFixedPointVolumeRayCastCompositeHelper::GenerateImage(
 // Print method for vtkFixedPointVolumeRayCastCompositeHelper
 void vtkFixedPointVolumeRayCastCompositeHelper::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 }
-
+VTK_ABI_NAMESPACE_END
