@@ -39,6 +39,7 @@
 #include <vtkVolumeProperty.h>
 
 // Return nullptr if no override is supplied.
+VTK_ABI_NAMESPACE_BEGIN
 vtkAbstractObjectFactoryNewMacro(vtkGPUVolumeRayCastMapper);
 vtkCxxSetObjectMacro(vtkGPUVolumeRayCastMapper, MaskInput, vtkImageData);
 
@@ -107,6 +108,8 @@ vtkGPUVolumeRayCastMapper::vtkGPUVolumeRayCastMapper()
   this->ReportProgress = true;
 
   this->SetNumberOfInputPorts(10);
+
+  this->Transfer2DYAxisArray = nullptr;
 }
 
 //------------------------------------------------------------------------------
@@ -126,6 +129,7 @@ vtkGPUVolumeRayCastMapper::~vtkGPUVolumeRayCastMapper()
   {
     this->DepthPassContourValues->Delete();
   }
+  this->SetTransfer2DYAxisArray(nullptr);
 }
 
 //------------------------------------------------------------------------------
@@ -350,7 +354,7 @@ int vtkGPUVolumeRayCastMapper::ValidateInput(vtkVolumeProperty* property, const
   if (goodSoFar)
   {
     // Now make sure we can find scalars
-    scalars = this->GetScalars(this->TransformedInputs[port], this->ScalarMode,
+    scalars = vtkGPUVolumeRayCastMapper::GetScalars(this->TransformedInputs[port], this->ScalarMode,
       this->ArrayAccessMode, this->ArrayId, this->ArrayName, this->CellFlag);
 
     // We couldn't find scalars
@@ -856,3 +860,4 @@ int vtkGPUVolumeRayCastMapper::GetInputCount()
 {
   return static_cast<int>(this->Ports.size());
 }
+VTK_ABI_NAMESPACE_END
