@@ -53,6 +53,7 @@
 // VTK's native classes for defining transfer functions is actually slow to
 // access, so we have to cache it somehow.  This class is straightforward
 // copy of the transfer function.
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLinearRayIntegratorTransferFunction
 {
 public:
@@ -492,7 +493,8 @@ void vtkUnstructuredGridLinearRayIntegrator::Integrate(vtkDoubleArray* intersect
             }
           }
         }
-        this->IntegrateRay(length, nearcolor, nearcolor[3], farcolor, farcolor[3], color);
+        vtkUnstructuredGridLinearRayIntegrator::IntegrateRay(
+          length, nearcolor, nearcolor[3], farcolor, farcolor[3], color);
 
         nearInterpolant = farInterpolant;
       }
@@ -510,8 +512,8 @@ void vtkUnstructuredGridLinearRayIntegrator::Integrate(vtkDoubleArray* intersect
         double length = intersectionLengths->GetValue(i);
         double* nearcolor = nearIntersections->GetTuple(i);
         double* farcolor = farIntersections->GetTuple(i);
-        this->IntegrateRay(length, nearcolor, nearcolor[3] / unitdistance, farcolor,
-          farcolor[3] / unitdistance, color);
+        vtkUnstructuredGridLinearRayIntegrator::IntegrateRay(length, nearcolor,
+          nearcolor[3] / unitdistance, farcolor, farcolor[3] / unitdistance, color);
       }
     }
     else // Two components.
@@ -521,8 +523,8 @@ void vtkUnstructuredGridLinearRayIntegrator::Integrate(vtkDoubleArray* intersect
         double length = intersectionLengths->GetValue(i);
         double* nearcolor = nearIntersections->GetTuple(i);
         double* farcolor = farIntersections->GetTuple(i);
-        this->IntegrateRay(length, nearcolor[0], nearcolor[1] / unitdistance, farcolor[0],
-          farcolor[1] / unitdistance, color);
+        vtkUnstructuredGridLinearRayIntegrator::IntegrateRay(length, nearcolor[0],
+          nearcolor[1] / unitdistance, farcolor[0], farcolor[1] / unitdistance, color);
       }
     }
   }
@@ -693,3 +695,4 @@ float vtkUnstructuredGridLinearRayIntegrator::Psi(
     }
   }
 }
+VTK_ABI_NAMESPACE_END
