@@ -19,9 +19,9 @@
 #include "vtkInformation.h"
 #include "vtkUnstructuredGrid.h"
 
-
 // Construct a vtkUnstructuredGridVolumeMapper with empty scalar input and
 // clipping off.
+VTK_ABI_NAMESPACE_BEGIN
 vtkUnstructuredGridVolumeMapper::vtkUnstructuredGridVolumeMapper()
 {
   this->BlendMode = vtkUnstructuredGridVolumeMapper::COMPOSITE_BLEND;
@@ -29,14 +29,13 @@ vtkUnstructuredGridVolumeMapper::vtkUnstructuredGridVolumeMapper()
 
 vtkUnstructuredGridVolumeMapper::~vtkUnstructuredGridVolumeMapper() = default;
 
-void vtkUnstructuredGridVolumeMapper::SetInputData( vtkDataSet *genericInput )
+void vtkUnstructuredGridVolumeMapper::SetInputData(vtkDataSet* genericInput)
 {
-  vtkUnstructuredGridBase *input =
-    vtkUnstructuredGridBase::SafeDownCast( genericInput );
+  vtkUnstructuredGridBase* input = vtkUnstructuredGridBase::SafeDownCast(genericInput);
 
-  if ( input )
+  if (input)
   {
-    this->SetInputData( input );
+    this->SetInputData(input);
   }
   else
   {
@@ -45,36 +44,33 @@ void vtkUnstructuredGridVolumeMapper::SetInputData( vtkDataSet *genericInput )
   }
 }
 
-void vtkUnstructuredGridVolumeMapper::SetInputData( vtkUnstructuredGridBase *input )
+void vtkUnstructuredGridVolumeMapper::SetInputData(vtkUnstructuredGridBase* input)
 {
   this->SetInputDataInternal(0, input);
 }
 
-vtkUnstructuredGridBase *vtkUnstructuredGridVolumeMapper::GetInput()
+vtkUnstructuredGridBase* vtkUnstructuredGridVolumeMapper::GetInput()
 {
   if (this->GetNumberOfInputConnections(0) < 1)
   {
     return nullptr;
   }
-  return vtkUnstructuredGridBase::SafeDownCast(
-    this->GetExecutive()->GetInputData(0, 0));
+  return vtkUnstructuredGridBase::SafeDownCast(this->GetExecutive()->GetInputData(0, 0));
 }
 
-
 // Print the vtkUnstructuredGridVolumeMapper
 void vtkUnstructuredGridVolumeMapper::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   os << indent << "Blend Mode: " << this->BlendMode << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkUnstructuredGridVolumeMapper::FillInputPortInformation(
-  int vtkNotUsed( port ), vtkInformation* info)
+  int vtkNotUsed(port), vtkInformation* info)
 {
-  info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(),
-            "vtkUnstructuredGridBase");
+  info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkUnstructuredGridBase");
   return 1;
 }
-
+VTK_ABI_NAMESPACE_END
